
#######################################################################################
############################### 1 - Data download: ####################################
#######################################################################################

#* Understanding Society documentation confirms that the data on parental occupational
#* NS-SEC is scattered across various waves of both Understanding Society and BHPS.[1] 
#* The _dv suffix for the relevant variables (pannsec8 and manssec8) refers to the fact
#* it's derived from SOCs converted into NS_SEC, and not (unlike some other variables)
#* that they've derived it from multiple waves brought forward.

#* Those variables offer the best source of information on parental social class. There is 
#* for example insufficient data on parental education to form an alternative using that data. 
#* Whilst some studies using Understanding Society have used a variable of parental 
#* education[2], these appear to only look at education of parents within the household 
#* in their individual responses to questions. This is useful for eg surveys of children 
#* since most children are in households with said parents, but they tell us nothing of 
#* adult workers' parents education because most of these won't live with their parents: 
#* you need a direct question for that. 

#* Download BHPS data. Note that Waves B2-B7 don't have this question: 
WaveB1 <- read_dta('ba_indresp.dta') |> 
  select(pidp, ba_panssec8_dv, ba_manssec8_dv, 
         ba_paju, ba_maju)
WaveB8 <- read_dta('bh_indresp.dta') |> 
  select(pidp, bh_panssec8_dv, bh_manssec8_dv, 
         bh_paju, bh_maju, bh_j1nssec8_dv)
WaveB9 <- read_dta('bi_indresp.dta') |> 
  select(pidp, bi_panssec8_dv, bi_manssec8_dv, 
         bi_paju, bi_maju, bi_j1nssec8_dv)
WaveB10 <- read_dta('bj_indresp.dta') |> 
  select(pidp, bj_panssec8_dv, bj_manssec8_dv, 
         bj_paju, bj_maju, bj_j1nssec8_dv)
WaveB11 <- read_dta('bk_indresp.dta') |> 
  select(pidp, bk_panssec8_dv, bk_manssec8_dv, 
         bk_paju, bk_maju, bk_j1nssec8_dv)
WaveB12 <- read_dta('bl_indresp.dta') |> 
  select(pidp, bl_panssec8_dv, bl_manssec8_dv, 
         bl_paju, bl_maju, bl_j1nssec8_dv)
WaveB13 <- read_dta('bm_indresp.dta') |> 
  select(pidp, bm_panssec8_dv, bm_manssec8_dv, 
         bm_paju, bm_maju, bm_j1nssec8_dv)
WaveB14 <- read_dta('bn_indresp.dta') |> 
  select(pidp, bn_panssec8_dv, bn_manssec8_dv, 
         bn_paju, bn_maju, bn_j1nssec8_dv)
WaveB15 <- read_dta('bo_indresp.dta') |> 
  select(pidp, bo_panssec8_dv, bo_manssec8_dv, 
         bo_paju, bo_maju, bo_j1nssec8_dv)
WaveB16 <- read_dta('bp_indresp.dta') |> 
  select(pidp, bp_panssec8_dv, bp_manssec8_dv, 
         bp_paju, bp_maju, bp_j1nssec8_dv)
WaveB17 <- read_dta('bq_indresp.dta') |> 
  select(pidp, bq_panssec8_dv, bq_manssec8_dv, 
         bq_paju, bq_maju, bq_j1nssec8_dv)
WaveB18 <- read_dta('br_indresp.dta') |> 
  select(pidp, br_panssec8_dv, br_manssec8_dv, 
         br_paju, br_maju, br_j1nssec8_dv)

#* Understanding Society data:
Wave1 <- read_dta('a_indresp.dta') |> 
  select(pidp, a_panssec8_dv, a_manssec8_dv, 
         a_paju, a_maju, a_j1nssec8_dv, a_j2nssec8_dv)
Wave2 <- read_dta('b_indresp.dta') |> 
  select(pidp, b_panssec8_dv, b_manssec8_dv, 
         b_paju, b_maju, b_j1nssec8_dv, b_j2nssec8_dv)
Wave3 <- read_dta('c_indresp.dta') |> 
  select(pidp, c_panssec8_dv, c_manssec8_dv, 
         c_paju, c_maju, c_j1nssec8_dv, c_j2nssec8_dv)
Wave4 <- read_dta('d_indresp.dta') |> 
  select(pidp, d_panssec8_dv, d_manssec8_dv, 
         d_paju, d_maju, d_jbhas, d_jboff, d_j1nssec8_dv, d_j2nssec8_dv)
Wave5 <- read_dta('e_indresp.dta') |> 
  select(pidp, e_panssec8_dv, e_manssec8_dv, 
         e_paju, e_maju, e_j1nssec8_dv, e_j2nssec8_dv)
Wave6 <- read_dta('f_indresp.dta') |> 
  select(pidp, f_panssec8_dv, f_manssec8_dv, 
         f_paju, f_maju, f_jbhas, f_jboff, f_j1nssec8_dv, f_j2nssec8_dv)
Wave7 <- read_dta('g_indresp.dta') |> 
  select(pidp, g_panssec8_dv, g_manssec8_dv, 
         g_paju, g_maju, g_j1nssec8_dv, g_j2nssec8_dv)
Wave8 <- read_dta('h_indresp.dta') |> 
  select(pidp, h_panssec8_dv, h_manssec8_dv, 
         h_paju, h_maju, h_jbhas, h_jboff, h_j1nssec8_dv, h_j2nssec8_dv)
Wave9 <- read_dta('i_indresp.dta') |> 
  select(pidp, i_panssec8_dv, i_manssec8_dv, 
         i_paju, i_maju, i_j1nssec8_dv, i_j2nssec8_dv)
Wave10 <- read_dta('j_indresp.dta') |> 
  select(pidp, j_panssec8_dv, j_manssec8_dv, 
         j_paju, j_maju, j_jbhas, j_jboff, j_j1nssec8_dv, j_j2nssec8_dv)
Wave11 <- read_dta('k_indresp.dta') |> 
  select(pidp, k_panssec8_dv, k_manssec8_dv, 
         k_paju, k_maju, k_j1nssec8_dv, k_j2nssec8_dv)
Wave12 <- read_dta('l_indresp.dta') |> 
  select(pidp, l_panssec8_dv, l_manssec8_dv, 
         l_paju, l_maju, l_jbhas, l_jboff, l_j1nssec8_dv, l_j2nssec8_dv)

#* Create QoW index member variables for Waves 4, 6, 8, 10 and 12:
Wave4$d_QoW_Index_Member <- case_when((Wave4$d_jbhas == 1 | Wave4$d_jboff == 1) ~ 1, TRUE ~ 0)
Wave6$f_QoW_Index_Member <- case_when((Wave6$f_jbhas == 1 | Wave6$f_jboff == 1) ~ 1, TRUE ~ 0)
Wave8$h_QoW_Index_Member <- case_when((Wave8$h_jbhas == 1 | Wave8$h_jboff == 1) ~ 1, TRUE ~ 0)
Wave10$j_QoW_Index_Member <- case_when((Wave10$j_jbhas == 1 | Wave10$j_jboff == 1) ~ 1, TRUE ~ 0)
Wave12$l_QoW_Index_Member <- case_when((Wave12$l_jbhas == 1 | Wave12$l_jboff == 1) ~ 1, TRUE ~ 0)

#* REFERENCES:
#* [1] Understanding Society User Support Forum (2020), 
#* 'Support Ticket #1452: panssec8_dv and manssec8_dv',
#* https://iserredex.essex.ac.uk/support/issues/1587
#* [2] Janmaat and Hoskins (2022),
#* 'The changing impact of family background on political engagement during adolescence and early adulthood',
#* Social Forces, Vol. 101, Issue. 1, September 2022, pp. 227-251,
#* https://doi.org/10.1093/sf/soab112

#######################################################################################
######################## 2 - Group into relevant waves: ###############################
#######################################################################################

#* The process for merging this data into the QoW index is rather different than for continuous
#* employment. This is simply because the indicator I'm creating is quite distinct: it's about 
#* what the respondent tells us, in *any* wave of BHPS or UKHLS, their parents' job was (if any)
#* when they were aged 14. So for any given wave, even the answers the respondent gives in future 
#* waves can inform the creation of that variable. 

#* This obviously contrasts with indicators like continuous employment, because that indicator can 
#* inherently only be based on what the respondent said in the current wave and in prior waves. The
#* process for creating the parental NS-SEC is therefore simpler than for continuous employment: you
#* merge all the data into one data frame, and you create a single variable for all respondents. You 
#* can then identify the NS-SEC of respondents' parents in specific waves by filtering to respondents
#* of that wave. 

#* Merge data from all waves together:
AllWaves_M <- full_join(Wave12, Wave11, by = "pidp")
AllWaves_M <- full_join(AllWaves_M, Wave10, by = "pidp")
AllWaves_M <- full_join(AllWaves_M, Wave9, by = "pidp")
AllWaves_M <- full_join(AllWaves_M, Wave8, by = "pidp")
AllWaves_M <- full_join(AllWaves_M, Wave7, by = "pidp")
AllWaves_M <- full_join(AllWaves_M, Wave6, by = "pidp")
AllWaves_M <- full_join(AllWaves_M, Wave5, by = "pidp")
AllWaves_M <- full_join(AllWaves_M, Wave4, by = "pidp")
AllWaves_M <- full_join(AllWaves_M, Wave3, by = "pidp")
AllWaves_M <- full_join(AllWaves_M, Wave2, by = "pidp")
AllWaves_M <- full_join(AllWaves_M, Wave1, by = "pidp")
AllWaves_M <- full_join(AllWaves_M, WaveB18, by = "pidp")
AllWaves_M <- full_join(AllWaves_M, WaveB17, by = "pidp")
AllWaves_M <- full_join(AllWaves_M, WaveB16, by = "pidp")
AllWaves_M <- full_join(AllWaves_M, WaveB15, by = "pidp")
AllWaves_M <- full_join(AllWaves_M, WaveB14, by = "pidp")
AllWaves_M <- full_join(AllWaves_M, WaveB13, by = "pidp")
AllWaves_M <- full_join(AllWaves_M, WaveB12, by = "pidp")
AllWaves_M <- full_join(AllWaves_M, WaveB11, by = "pidp")
AllWaves_M <- full_join(AllWaves_M, WaveB10, by = "pidp")
AllWaves_M <- full_join(AllWaves_M, WaveB9, by = "pidp")
AllWaves_M <- full_join(AllWaves_M, WaveB8, by = "pidp")
AllWaves_M <- full_join(AllWaves_M, WaveB1, by = "pidp")

#* Quality checks [22.09.23]. This process creates a lot of NAs, which will 
#* consist of anyone who doesn't respond to any of these waves. This isn't a problem
#* for our purposes:
xtabs(~l_panssec8_dv + k_panssec8_dv, data = AllWaves_M)
sum(is.na(Wave12$l_panssec8_dv))
sum(is.na(AllWaves_M$l_panssec8_dv))
sum(is.na(Wave11$k_panssec8_dv))
sum(is.na(AllWaves_M$k_panssec8_dv))

#* Remove unnecessary data and clear memory:
rm(WaveB1, WaveB8, WaveB9, WaveB10, WaveB11, WaveB12, WaveB13, WaveB14, 
   WaveB15, WaveB16, WaveB17, WaveB18)
rm(Wave1, Wave2, Wave3, Wave4, Wave5, Wave6, Wave7, Wave8, Wave9, Wave10, Wave11, Wave12)
gc()

#######################################################################################
###################### 3 - Create parental NS-SEC indicator: ##########################
#######################################################################################

#* I'll be going for two separate and equally-weighted parental NS-SEC indicators. So
#* each have a minimum score of 0 and a maximum score of 1. This relies on splitting 
#* up the top category (higher managerial, administrative and professional) into two
#* groupings. This is in line with the way they're categorised in the ONS,[1]
#* but with some compromises due to data availability: 
#* [0] = [maju/maju = 2|3|4] Parent not working, full-time student, deceased or 
#* not living with respondent when respondent was aged 14. Note that 
#* full-time students are an unclassified group in the NS-SEC, but the question 
#* wording of maju/paju doesn't distinguish between students and non-students. 
#* The decision to include deceased and parents not living with the respondent is 
#* also a slight (but necessary) departure from NS-SEC;
#* [0.125] = [panssec8_dv / manssec8_dv == 8] Routine occupations;
#* [0.250] = [panssec8_dv / manssec8_dv == 7] Semi-routine;
#* [0.375] = [panssec8_dv / manssec8_dv == 6] Lower supervisory and technical;
#* [0.5] = [panssec8_dv / manssec8_dv == 5] Small employers & own account;
#* [0.625] = [panssec8_dv / manssec8_dv == 4] Intermediate;
#* [0.75] = [panssec8_dv / manssec8_dv == 3] Lower management & professional;
#* [0.875] = [panssec8_dv / manssec8_dv == 2] Higher professional;
#* [1.0] = [panssec8_dv / manssec8_dv == 1] Large employers & higher management.

#* Note that in the BHPS, the mother and father not working variables (maju and paju)
#* aren't as comprehensive as they eventually become in Understanding Society: there 
#* isn't a category for father/mother working. In some earlier waves of BHPS there is 
#* also a tiny amount of overlap between maju and manssec, with respondents giving 
#* contradictory answers like saying their parent didn't live with them / was deceased
#* but then giving their occupational code. This is too small to cause an issue, but 
#* where this occurs the below case_when statements should go with the answer to paju/maju
#* instead. This is much less of an issue with later waves, where the paju/maju question wording
#* has been improved and there is a very strong (and usually perfect) consistency between the
#* two variables:
xtabs(~ba_maju + ba_manssec8_dv, data = AllWaves_M)
xtabs(~ba_maju + ba_manssec8_dv, data = AllWaves_M)
xtabs(~br_maju + br_manssec8_dv, data = AllWaves_M)
xtabs(~a_maju + a_manssec8_dv, data = AllWaves_M)

#* Mothers' NS-SEC:
AllWaves_M$DV_MothersNSSEC <- case_when((AllWaves_M$ba_maju == 2 | AllWaves_M$ba_maju == 3 | AllWaves_M$ba_maju == 4) ~ 0,
                                     (AllWaves_M$bh_maju == 2 | AllWaves_M$bh_maju == 3 | AllWaves_M$bh_maju == 4) ~ 0,
                                     (AllWaves_M$bi_maju == 2 | AllWaves_M$bi_maju == 3 | AllWaves_M$bi_maju == 4) ~ 0,
                                     (AllWaves_M$bj_maju == 2 | AllWaves_M$bj_maju == 3 | AllWaves_M$bj_maju == 4) ~ 0,
                                     (AllWaves_M$bk_maju == 2 | AllWaves_M$bk_maju == 3 | AllWaves_M$bk_maju == 4) ~ 0,
                                     (AllWaves_M$bl_maju == 2 | AllWaves_M$bl_maju == 3 | AllWaves_M$bl_maju == 4) ~ 0,
                                     (AllWaves_M$bm_maju == 2 | AllWaves_M$bm_maju == 3 | AllWaves_M$bm_maju == 4) ~ 0,
                                     (AllWaves_M$bn_maju == 2 | AllWaves_M$bn_maju == 3 | AllWaves_M$bn_maju == 4) ~ 0,
                                     (AllWaves_M$bo_maju == 2 | AllWaves_M$bo_maju == 3 | AllWaves_M$bo_maju == 4) ~ 0,
                                     (AllWaves_M$bp_maju == 2 | AllWaves_M$bp_maju == 3 | AllWaves_M$bp_maju == 4) ~ 0,
                                     (AllWaves_M$bq_maju == 2 | AllWaves_M$bq_maju == 3 | AllWaves_M$bq_maju == 4) ~ 0,
                                     (AllWaves_M$br_maju == 2 | AllWaves_M$br_maju == 3 | AllWaves_M$br_maju == 4) ~ 0,
                                     (AllWaves_M$a_maju == 2 | AllWaves_M$a_maju == 3 | AllWaves_M$a_maju == 4) ~ 0,
                                     (AllWaves_M$b_maju == 2 | AllWaves_M$b_maju == 3 | AllWaves_M$b_maju == 4) ~ 0,
                                     (AllWaves_M$c_maju == 2 | AllWaves_M$c_maju == 3 | AllWaves_M$c_maju == 4) ~ 0,
                                     (AllWaves_M$d_maju == 2 | AllWaves_M$d_maju == 3 | AllWaves_M$d_maju == 4) ~ 0,
                                     (AllWaves_M$e_maju == 2 | AllWaves_M$e_maju == 3 | AllWaves_M$e_maju == 4) ~ 0,
                                     (AllWaves_M$f_maju == 2 | AllWaves_M$f_maju == 3 | AllWaves_M$f_maju == 4) ~ 0,
                                     (AllWaves_M$g_maju == 2 | AllWaves_M$g_maju == 3 | AllWaves_M$g_maju == 4) ~ 0,
                                     (AllWaves_M$h_maju == 2 | AllWaves_M$h_maju == 3 | AllWaves_M$h_maju == 4) ~ 0,
                                     (AllWaves_M$i_maju == 2 | AllWaves_M$i_maju == 3 | AllWaves_M$i_maju == 4) ~ 0,
                                     (AllWaves_M$j_maju == 2 | AllWaves_M$j_maju == 3 | AllWaves_M$j_maju == 4) ~ 0,
                                     (AllWaves_M$k_maju == 2 | AllWaves_M$k_maju == 3 | AllWaves_M$k_maju == 4) ~ 0,
                                     (AllWaves_M$l_maju == 2 | AllWaves_M$l_maju == 3 | AllWaves_M$l_maju == 4) ~ 0,
                                     AllWaves_M$ba_manssec8_dv == 8 ~ 0.125,
                                     AllWaves_M$bh_manssec8_dv == 8 ~ 0.125,
                                     AllWaves_M$bi_manssec8_dv == 8 ~ 0.125,
                                     AllWaves_M$bj_manssec8_dv == 8 ~ 0.125,
                                     AllWaves_M$bk_manssec8_dv == 8 ~ 0.125,
                                     AllWaves_M$bl_manssec8_dv == 8 ~ 0.125,
                                     AllWaves_M$bm_manssec8_dv == 8 ~ 0.125,
                                     AllWaves_M$bn_manssec8_dv == 8 ~ 0.125,
                                     AllWaves_M$bo_manssec8_dv == 8 ~ 0.125,
                                     AllWaves_M$bp_manssec8_dv == 8 ~ 0.125,
                                     AllWaves_M$bq_manssec8_dv == 8 ~ 0.125,
                                     AllWaves_M$br_manssec8_dv == 8 ~ 0.125,
                                     AllWaves_M$a_manssec8_dv == 8 ~ 0.125,
                                     AllWaves_M$b_manssec8_dv == 8 ~ 0.125,
                                     AllWaves_M$c_manssec8_dv == 8 ~ 0.125,
                                     AllWaves_M$d_manssec8_dv == 8 ~ 0.125,
                                     AllWaves_M$e_manssec8_dv == 8 ~ 0.125,
                                     AllWaves_M$f_manssec8_dv == 8 ~ 0.125,
                                     AllWaves_M$g_manssec8_dv == 8 ~ 0.125,
                                     AllWaves_M$h_manssec8_dv == 8 ~ 0.125,
                                     AllWaves_M$i_manssec8_dv == 8 ~ 0.125,
                                     AllWaves_M$j_manssec8_dv == 8 ~ 0.125,
                                     AllWaves_M$k_manssec8_dv == 8 ~ 0.125,
                                     AllWaves_M$l_manssec8_dv == 8 ~ 0.125,
                                     AllWaves_M$ba_manssec8_dv == 7 ~ 0.250,
                                     AllWaves_M$bh_manssec8_dv == 7 ~ 0.250,
                                     AllWaves_M$bi_manssec8_dv == 7 ~ 0.250,
                                     AllWaves_M$bj_manssec8_dv == 7 ~ 0.250,
                                     AllWaves_M$bk_manssec8_dv == 7 ~ 0.250,
                                     AllWaves_M$bl_manssec8_dv == 7 ~ 0.250,
                                     AllWaves_M$bm_manssec8_dv == 7 ~ 0.250,
                                     AllWaves_M$bn_manssec8_dv == 7 ~ 0.250,
                                     AllWaves_M$bo_manssec8_dv == 7 ~ 0.250,
                                     AllWaves_M$bp_manssec8_dv == 7 ~ 0.250,
                                     AllWaves_M$bq_manssec8_dv == 7 ~ 0.250,
                                     AllWaves_M$br_manssec8_dv == 7 ~ 0.250,
                                     AllWaves_M$a_manssec8_dv == 7 ~ 0.250,
                                     AllWaves_M$b_manssec8_dv == 7 ~ 0.250,
                                     AllWaves_M$c_manssec8_dv == 7 ~ 0.250,
                                     AllWaves_M$d_manssec8_dv == 7 ~ 0.250,
                                     AllWaves_M$e_manssec8_dv == 7 ~ 0.250,
                                     AllWaves_M$f_manssec8_dv == 7 ~ 0.250,
                                     AllWaves_M$g_manssec8_dv == 7 ~ 0.250,
                                     AllWaves_M$h_manssec8_dv == 7 ~ 0.250,
                                     AllWaves_M$i_manssec8_dv == 7 ~ 0.250,
                                     AllWaves_M$j_manssec8_dv == 7 ~ 0.250,
                                     AllWaves_M$k_manssec8_dv == 7 ~ 0.250,
                                     AllWaves_M$l_manssec8_dv == 7 ~ 0.250,
                                     AllWaves_M$ba_manssec8_dv == 6 ~ 0.375,
                                     AllWaves_M$bh_manssec8_dv == 6 ~ 0.375,
                                     AllWaves_M$bi_manssec8_dv == 6 ~ 0.375,
                                     AllWaves_M$bj_manssec8_dv == 6 ~ 0.375,
                                     AllWaves_M$bk_manssec8_dv == 6 ~ 0.375,
                                     AllWaves_M$bl_manssec8_dv == 6 ~ 0.375,
                                     AllWaves_M$bm_manssec8_dv == 6 ~ 0.375,
                                     AllWaves_M$bn_manssec8_dv == 6 ~ 0.375,
                                     AllWaves_M$bo_manssec8_dv == 6 ~ 0.375,
                                     AllWaves_M$bp_manssec8_dv == 6 ~ 0.375,
                                     AllWaves_M$bq_manssec8_dv == 6 ~ 0.375,
                                     AllWaves_M$br_manssec8_dv == 6 ~ 0.375,
                                     AllWaves_M$a_manssec8_dv == 6 ~ 0.375,
                                     AllWaves_M$b_manssec8_dv == 6 ~ 0.375,
                                     AllWaves_M$c_manssec8_dv == 6 ~ 0.375,
                                     AllWaves_M$d_manssec8_dv == 6 ~ 0.375,
                                     AllWaves_M$e_manssec8_dv == 6 ~ 0.375,
                                     AllWaves_M$f_manssec8_dv == 6 ~ 0.375,
                                     AllWaves_M$g_manssec8_dv == 6 ~ 0.375,
                                     AllWaves_M$h_manssec8_dv == 6 ~ 0.375,
                                     AllWaves_M$i_manssec8_dv == 6 ~ 0.375,
                                     AllWaves_M$j_manssec8_dv == 6 ~ 0.375,
                                     AllWaves_M$k_manssec8_dv == 6 ~ 0.375,
                                     AllWaves_M$l_manssec8_dv == 6 ~ 0.375,
                                     AllWaves_M$ba_manssec8_dv == 5 ~ 0.5,
                                     AllWaves_M$bh_manssec8_dv == 5 ~ 0.5,
                                     AllWaves_M$bi_manssec8_dv == 5 ~ 0.5,
                                     AllWaves_M$bj_manssec8_dv == 5 ~ 0.5,
                                     AllWaves_M$bk_manssec8_dv == 5 ~ 0.5,
                                     AllWaves_M$bl_manssec8_dv == 5 ~ 0.5,
                                     AllWaves_M$bm_manssec8_dv == 5 ~ 0.5,
                                     AllWaves_M$bn_manssec8_dv == 5 ~ 0.5,
                                     AllWaves_M$bo_manssec8_dv == 5 ~ 0.5,
                                     AllWaves_M$bp_manssec8_dv == 5 ~ 0.5,
                                     AllWaves_M$bq_manssec8_dv == 5 ~ 0.5,
                                     AllWaves_M$br_manssec8_dv == 5 ~ 0.5,
                                     AllWaves_M$a_manssec8_dv == 5 ~ 0.5,
                                     AllWaves_M$b_manssec8_dv == 5 ~ 0.5,
                                     AllWaves_M$c_manssec8_dv == 5 ~ 0.5,
                                     AllWaves_M$d_manssec8_dv == 5 ~ 0.5,
                                     AllWaves_M$e_manssec8_dv == 5 ~ 0.5,
                                     AllWaves_M$f_manssec8_dv == 5 ~ 0.5,
                                     AllWaves_M$g_manssec8_dv == 5 ~ 0.5,
                                     AllWaves_M$h_manssec8_dv == 5 ~ 0.5,
                                     AllWaves_M$i_manssec8_dv == 5 ~ 0.5,
                                     AllWaves_M$j_manssec8_dv == 5 ~ 0.5,
                                     AllWaves_M$k_manssec8_dv == 5 ~ 0.5,
                                     AllWaves_M$l_manssec8_dv == 5 ~ 0.5,
                                     AllWaves_M$ba_manssec8_dv == 4 ~ 0.625,
                                     AllWaves_M$bh_manssec8_dv == 4 ~ 0.625,
                                     AllWaves_M$bi_manssec8_dv == 4 ~ 0.625,
                                     AllWaves_M$bj_manssec8_dv == 4 ~ 0.625,
                                     AllWaves_M$bk_manssec8_dv == 4 ~ 0.625,
                                     AllWaves_M$bl_manssec8_dv == 4 ~ 0.625,
                                     AllWaves_M$bm_manssec8_dv == 4 ~ 0.625,
                                     AllWaves_M$bn_manssec8_dv == 4 ~ 0.625,
                                     AllWaves_M$bo_manssec8_dv == 4 ~ 0.625,
                                     AllWaves_M$bp_manssec8_dv == 4 ~ 0.625,
                                     AllWaves_M$bq_manssec8_dv == 4 ~ 0.625,
                                     AllWaves_M$br_manssec8_dv == 4 ~ 0.625,
                                     AllWaves_M$a_manssec8_dv == 4 ~ 0.625,
                                     AllWaves_M$b_manssec8_dv == 4 ~ 0.625,
                                     AllWaves_M$c_manssec8_dv == 4 ~ 0.625,
                                     AllWaves_M$d_manssec8_dv == 4 ~ 0.625,
                                     AllWaves_M$e_manssec8_dv == 4 ~ 0.625,
                                     AllWaves_M$f_manssec8_dv == 4 ~ 0.625,
                                     AllWaves_M$g_manssec8_dv == 4 ~ 0.625,
                                     AllWaves_M$h_manssec8_dv == 4 ~ 0.625,
                                     AllWaves_M$i_manssec8_dv == 4 ~ 0.625,
                                     AllWaves_M$j_manssec8_dv == 4 ~ 0.625,
                                     AllWaves_M$k_manssec8_dv == 4 ~ 0.625,
                                     AllWaves_M$l_manssec8_dv == 4 ~ 0.625,
                                     AllWaves_M$ba_manssec8_dv == 3 ~ 0.75,
                                     AllWaves_M$bh_manssec8_dv == 3 ~ 0.75,
                                     AllWaves_M$bi_manssec8_dv == 3 ~ 0.75,
                                     AllWaves_M$bj_manssec8_dv == 3 ~ 0.75,
                                     AllWaves_M$bk_manssec8_dv == 3 ~ 0.75,
                                     AllWaves_M$bl_manssec8_dv == 3 ~ 0.75,
                                     AllWaves_M$bm_manssec8_dv == 3 ~ 0.75,
                                     AllWaves_M$bn_manssec8_dv == 3 ~ 0.75,
                                     AllWaves_M$bo_manssec8_dv == 3 ~ 0.75,
                                     AllWaves_M$bp_manssec8_dv == 3 ~ 0.75,
                                     AllWaves_M$bq_manssec8_dv == 3 ~ 0.75,
                                     AllWaves_M$br_manssec8_dv == 3 ~ 0.75,
                                     AllWaves_M$a_manssec8_dv == 3 ~ 0.75,
                                     AllWaves_M$b_manssec8_dv == 3 ~ 0.75,
                                     AllWaves_M$c_manssec8_dv == 3 ~ 0.75,
                                     AllWaves_M$d_manssec8_dv == 3 ~ 0.75,
                                     AllWaves_M$e_manssec8_dv == 3 ~ 0.75,
                                     AllWaves_M$f_manssec8_dv == 3 ~ 0.75,
                                     AllWaves_M$g_manssec8_dv == 3 ~ 0.75,
                                     AllWaves_M$h_manssec8_dv == 3 ~ 0.75,
                                     AllWaves_M$i_manssec8_dv == 3 ~ 0.75,
                                     AllWaves_M$j_manssec8_dv == 3 ~ 0.75,
                                     AllWaves_M$k_manssec8_dv == 3 ~ 0.75,
                                     AllWaves_M$l_manssec8_dv == 3 ~ 0.75,
                                     AllWaves_M$ba_manssec8_dv == 2 ~ 0.875,
                                     AllWaves_M$bh_manssec8_dv == 2 ~ 0.875,
                                     AllWaves_M$bi_manssec8_dv == 2 ~ 0.875,
                                     AllWaves_M$bj_manssec8_dv == 2 ~ 0.875,
                                     AllWaves_M$bk_manssec8_dv == 2 ~ 0.875,
                                     AllWaves_M$bl_manssec8_dv == 2 ~ 0.875,
                                     AllWaves_M$bm_manssec8_dv == 2 ~ 0.875,
                                     AllWaves_M$bn_manssec8_dv == 2 ~ 0.875,
                                     AllWaves_M$bo_manssec8_dv == 2 ~ 0.875,
                                     AllWaves_M$bp_manssec8_dv == 2 ~ 0.875,
                                     AllWaves_M$bq_manssec8_dv == 2 ~ 0.875,
                                     AllWaves_M$br_manssec8_dv == 2 ~ 0.875,
                                     AllWaves_M$a_manssec8_dv == 2 ~ 0.875,
                                     AllWaves_M$b_manssec8_dv == 2 ~ 0.875,
                                     AllWaves_M$c_manssec8_dv == 2 ~ 0.875,
                                     AllWaves_M$d_manssec8_dv == 2 ~ 0.875,
                                     AllWaves_M$e_manssec8_dv == 2 ~ 0.875,
                                     AllWaves_M$f_manssec8_dv == 2 ~ 0.875,
                                     AllWaves_M$g_manssec8_dv == 2 ~ 0.875,
                                     AllWaves_M$h_manssec8_dv == 2 ~ 0.875,
                                     AllWaves_M$i_manssec8_dv == 2 ~ 0.875,
                                     AllWaves_M$j_manssec8_dv == 2 ~ 0.875,
                                     AllWaves_M$k_manssec8_dv == 2 ~ 0.875,
                                     AllWaves_M$l_manssec8_dv == 2 ~ 0.875,
                                     AllWaves_M$ba_manssec8_dv == 1 ~ 1,
                                     AllWaves_M$bh_manssec8_dv == 1 ~ 1,
                                     AllWaves_M$bi_manssec8_dv == 1 ~ 1,
                                     AllWaves_M$bj_manssec8_dv == 1 ~ 1,
                                     AllWaves_M$bk_manssec8_dv == 1 ~ 1,
                                     AllWaves_M$bl_manssec8_dv == 1 ~ 1,
                                     AllWaves_M$bm_manssec8_dv == 1 ~ 1,
                                     AllWaves_M$bn_manssec8_dv == 1 ~ 1,
                                     AllWaves_M$bo_manssec8_dv == 1 ~ 1,
                                     AllWaves_M$bp_manssec8_dv == 1 ~ 1,
                                     AllWaves_M$bq_manssec8_dv == 1 ~ 1,
                                     AllWaves_M$br_manssec8_dv == 1 ~ 1,
                                     AllWaves_M$a_manssec8_dv == 1 ~ 1,
                                     AllWaves_M$b_manssec8_dv == 1 ~ 1,
                                     AllWaves_M$c_manssec8_dv == 1 ~ 1,
                                     AllWaves_M$d_manssec8_dv == 1 ~ 1,
                                     AllWaves_M$e_manssec8_dv == 1 ~ 1,
                                     AllWaves_M$f_manssec8_dv == 1 ~ 1,
                                     AllWaves_M$g_manssec8_dv == 1 ~ 1,
                                     AllWaves_M$h_manssec8_dv == 1 ~ 1,
                                     AllWaves_M$i_manssec8_dv == 1 ~ 1,
                                     AllWaves_M$j_manssec8_dv == 1 ~ 1,
                                     AllWaves_M$k_manssec8_dv == 1 ~ 1,
                                     AllWaves_M$l_manssec8_dv == 1 ~ 1,
                                     TRUE ~ -1)

#* Fathers' NS-SEC:                   
AllWaves_M$DV_FathersNSSEC <- case_when((AllWaves_M$ba_paju == 2 | AllWaves_M$ba_paju == 3 | AllWaves_M$ba_paju == 4) ~ 0,
                                      (AllWaves_M$bh_paju == 2 | AllWaves_M$bh_paju == 3 | AllWaves_M$bh_paju == 4) ~ 0,
                                      (AllWaves_M$bi_paju == 2 | AllWaves_M$bi_paju == 3 | AllWaves_M$bi_paju == 4) ~ 0,
                                      (AllWaves_M$bj_paju == 2 | AllWaves_M$bj_paju == 3 | AllWaves_M$bj_paju == 4) ~ 0,
                                      (AllWaves_M$bk_paju == 2 | AllWaves_M$bk_paju == 3 | AllWaves_M$bk_paju == 4) ~ 0,
                                      (AllWaves_M$bl_paju == 2 | AllWaves_M$bl_paju == 3 | AllWaves_M$bl_paju == 4) ~ 0,
                                      (AllWaves_M$bm_paju == 2 | AllWaves_M$bm_paju == 3 | AllWaves_M$bm_paju == 4) ~ 0,
                                      (AllWaves_M$bn_paju == 2 | AllWaves_M$bn_paju == 3 | AllWaves_M$bn_paju == 4) ~ 0,
                                      (AllWaves_M$bo_paju == 2 | AllWaves_M$bo_paju == 3 | AllWaves_M$bo_paju == 4) ~ 0,
                                      (AllWaves_M$bp_paju == 2 | AllWaves_M$bp_paju == 3 | AllWaves_M$bp_paju == 4) ~ 0,
                                      (AllWaves_M$bq_paju == 2 | AllWaves_M$bq_paju == 3 | AllWaves_M$bq_paju == 4) ~ 0,
                                      (AllWaves_M$br_paju == 2 | AllWaves_M$br_paju == 3 | AllWaves_M$br_paju == 4) ~ 0,
                                      (AllWaves_M$a_paju == 2 | AllWaves_M$a_paju == 3 | AllWaves_M$a_paju == 4) ~ 0,
                                      (AllWaves_M$b_paju == 2 | AllWaves_M$b_paju == 3 | AllWaves_M$b_paju == 4) ~ 0,
                                      (AllWaves_M$c_paju == 2 | AllWaves_M$c_paju == 3 | AllWaves_M$c_paju == 4) ~ 0,
                                      (AllWaves_M$d_paju == 2 | AllWaves_M$d_paju == 3 | AllWaves_M$d_paju == 4) ~ 0,
                                      (AllWaves_M$e_paju == 2 | AllWaves_M$e_paju == 3 | AllWaves_M$e_paju == 4) ~ 0,
                                      (AllWaves_M$f_paju == 2 | AllWaves_M$f_paju == 3 | AllWaves_M$f_paju == 4) ~ 0,
                                      (AllWaves_M$g_paju == 2 | AllWaves_M$g_paju == 3 | AllWaves_M$g_paju == 4) ~ 0,
                                      (AllWaves_M$h_paju == 2 | AllWaves_M$h_paju == 3 | AllWaves_M$h_paju == 4) ~ 0,
                                      (AllWaves_M$i_paju == 2 | AllWaves_M$i_paju == 3 | AllWaves_M$i_paju == 4) ~ 0,
                                      (AllWaves_M$j_paju == 2 | AllWaves_M$j_paju == 3 | AllWaves_M$j_paju == 4) ~ 0,
                                      (AllWaves_M$k_paju == 2 | AllWaves_M$k_paju == 3 | AllWaves_M$k_paju == 4) ~ 0,
                                      (AllWaves_M$l_paju == 2 | AllWaves_M$l_paju == 3 | AllWaves_M$l_paju == 4) ~ 0,
                                      AllWaves_M$ba_panssec8_dv == 8 ~ 0.125,
                                      AllWaves_M$bh_panssec8_dv == 8 ~ 0.125,
                                      AllWaves_M$bi_panssec8_dv == 8 ~ 0.125,
                                      AllWaves_M$bj_panssec8_dv == 8 ~ 0.125,
                                      AllWaves_M$bk_panssec8_dv == 8 ~ 0.125,
                                      AllWaves_M$bl_panssec8_dv == 8 ~ 0.125,
                                      AllWaves_M$bm_panssec8_dv == 8 ~ 0.125,
                                      AllWaves_M$bn_panssec8_dv == 8 ~ 0.125,
                                      AllWaves_M$bo_panssec8_dv == 8 ~ 0.125,
                                      AllWaves_M$bp_panssec8_dv == 8 ~ 0.125,
                                      AllWaves_M$bq_panssec8_dv == 8 ~ 0.125,
                                      AllWaves_M$br_panssec8_dv == 8 ~ 0.125,
                                      AllWaves_M$a_panssec8_dv == 8 ~ 0.125,
                                      AllWaves_M$b_panssec8_dv == 8 ~ 0.125,
                                      AllWaves_M$c_panssec8_dv == 8 ~ 0.125,
                                      AllWaves_M$d_panssec8_dv == 8 ~ 0.125,
                                      AllWaves_M$e_panssec8_dv == 8 ~ 0.125,
                                      AllWaves_M$f_panssec8_dv == 8 ~ 0.125,
                                      AllWaves_M$g_panssec8_dv == 8 ~ 0.125,
                                      AllWaves_M$h_panssec8_dv == 8 ~ 0.125,
                                      AllWaves_M$i_panssec8_dv == 8 ~ 0.125,
                                      AllWaves_M$j_panssec8_dv == 8 ~ 0.125,
                                      AllWaves_M$k_panssec8_dv == 8 ~ 0.125,
                                      AllWaves_M$l_panssec8_dv == 8 ~ 0.125,
                                      AllWaves_M$ba_panssec8_dv == 7 ~ 0.250,
                                      AllWaves_M$bh_panssec8_dv == 7 ~ 0.250,
                                      AllWaves_M$bi_panssec8_dv == 7 ~ 0.250,
                                      AllWaves_M$bj_panssec8_dv == 7 ~ 0.250,
                                      AllWaves_M$bk_panssec8_dv == 7 ~ 0.250,
                                      AllWaves_M$bl_panssec8_dv == 7 ~ 0.250,
                                      AllWaves_M$bm_panssec8_dv == 7 ~ 0.250,
                                      AllWaves_M$bn_panssec8_dv == 7 ~ 0.250,
                                      AllWaves_M$bo_panssec8_dv == 7 ~ 0.250,
                                      AllWaves_M$bp_panssec8_dv == 7 ~ 0.250,
                                      AllWaves_M$bq_panssec8_dv == 7 ~ 0.250,
                                      AllWaves_M$br_panssec8_dv == 7 ~ 0.250,
                                      AllWaves_M$a_panssec8_dv == 7 ~ 0.250,
                                      AllWaves_M$b_panssec8_dv == 7 ~ 0.250,
                                      AllWaves_M$c_panssec8_dv == 7 ~ 0.250,
                                      AllWaves_M$d_panssec8_dv == 7 ~ 0.250,
                                      AllWaves_M$e_panssec8_dv == 7 ~ 0.250,
                                      AllWaves_M$f_panssec8_dv == 7 ~ 0.250,
                                      AllWaves_M$g_panssec8_dv == 7 ~ 0.250,
                                      AllWaves_M$h_panssec8_dv == 7 ~ 0.250,
                                      AllWaves_M$i_panssec8_dv == 7 ~ 0.250,
                                      AllWaves_M$j_panssec8_dv == 7 ~ 0.250,
                                      AllWaves_M$k_panssec8_dv == 7 ~ 0.250,
                                      AllWaves_M$l_panssec8_dv == 7 ~ 0.250,
                                      AllWaves_M$ba_panssec8_dv == 6 ~ 0.375,
                                      AllWaves_M$bh_panssec8_dv == 6 ~ 0.375,
                                      AllWaves_M$bi_panssec8_dv == 6 ~ 0.375,
                                      AllWaves_M$bj_panssec8_dv == 6 ~ 0.375,
                                      AllWaves_M$bk_panssec8_dv == 6 ~ 0.375,
                                      AllWaves_M$bl_panssec8_dv == 6 ~ 0.375,
                                      AllWaves_M$bm_panssec8_dv == 6 ~ 0.375,
                                      AllWaves_M$bn_panssec8_dv == 6 ~ 0.375,
                                      AllWaves_M$bo_panssec8_dv == 6 ~ 0.375,
                                      AllWaves_M$bp_panssec8_dv == 6 ~ 0.375,
                                      AllWaves_M$bq_panssec8_dv == 6 ~ 0.375,
                                      AllWaves_M$br_panssec8_dv == 6 ~ 0.375,
                                      AllWaves_M$a_panssec8_dv == 6 ~ 0.375,
                                      AllWaves_M$b_panssec8_dv == 6 ~ 0.375,
                                      AllWaves_M$c_panssec8_dv == 6 ~ 0.375,
                                      AllWaves_M$d_panssec8_dv == 6 ~ 0.375,
                                      AllWaves_M$e_panssec8_dv == 6 ~ 0.375,
                                      AllWaves_M$f_panssec8_dv == 6 ~ 0.375,
                                      AllWaves_M$g_panssec8_dv == 6 ~ 0.375,
                                      AllWaves_M$h_panssec8_dv == 6 ~ 0.375,
                                      AllWaves_M$i_panssec8_dv == 6 ~ 0.375,
                                      AllWaves_M$j_panssec8_dv == 6 ~ 0.375,
                                      AllWaves_M$k_panssec8_dv == 6 ~ 0.375,
                                      AllWaves_M$l_panssec8_dv == 6 ~ 0.375,
                                      AllWaves_M$ba_panssec8_dv == 5 ~ 0.5,
                                      AllWaves_M$bh_panssec8_dv == 5 ~ 0.5,
                                      AllWaves_M$bi_panssec8_dv == 5 ~ 0.5,
                                      AllWaves_M$bj_panssec8_dv == 5 ~ 0.5,
                                      AllWaves_M$bk_panssec8_dv == 5 ~ 0.5,
                                      AllWaves_M$bl_panssec8_dv == 5 ~ 0.5,
                                      AllWaves_M$bm_panssec8_dv == 5 ~ 0.5,
                                      AllWaves_M$bn_panssec8_dv == 5 ~ 0.5,
                                      AllWaves_M$bo_panssec8_dv == 5 ~ 0.5,
                                      AllWaves_M$bp_panssec8_dv == 5 ~ 0.5,
                                      AllWaves_M$bq_panssec8_dv == 5 ~ 0.5,
                                      AllWaves_M$br_panssec8_dv == 5 ~ 0.5,
                                      AllWaves_M$a_panssec8_dv == 5 ~ 0.5,
                                      AllWaves_M$b_panssec8_dv == 5 ~ 0.5,
                                      AllWaves_M$c_panssec8_dv == 5 ~ 0.5,
                                      AllWaves_M$d_panssec8_dv == 5 ~ 0.5,
                                      AllWaves_M$e_panssec8_dv == 5 ~ 0.5,
                                      AllWaves_M$f_panssec8_dv == 5 ~ 0.5,
                                      AllWaves_M$g_panssec8_dv == 5 ~ 0.5,
                                      AllWaves_M$h_panssec8_dv == 5 ~ 0.5,
                                      AllWaves_M$i_panssec8_dv == 5 ~ 0.5,
                                      AllWaves_M$j_panssec8_dv == 5 ~ 0.5,
                                      AllWaves_M$k_panssec8_dv == 5 ~ 0.5,
                                      AllWaves_M$l_panssec8_dv == 5 ~ 0.5,
                                      AllWaves_M$ba_panssec8_dv == 4 ~ 0.625,
                                      AllWaves_M$bh_panssec8_dv == 4 ~ 0.625,
                                      AllWaves_M$bi_panssec8_dv == 4 ~ 0.625,
                                      AllWaves_M$bj_panssec8_dv == 4 ~ 0.625,
                                      AllWaves_M$bk_panssec8_dv == 4 ~ 0.625,
                                      AllWaves_M$bl_panssec8_dv == 4 ~ 0.625,
                                      AllWaves_M$bm_panssec8_dv == 4 ~ 0.625,
                                      AllWaves_M$bn_panssec8_dv == 4 ~ 0.625,
                                      AllWaves_M$bo_panssec8_dv == 4 ~ 0.625,
                                      AllWaves_M$bp_panssec8_dv == 4 ~ 0.625,
                                      AllWaves_M$bq_panssec8_dv == 4 ~ 0.625,
                                      AllWaves_M$br_panssec8_dv == 4 ~ 0.625,
                                      AllWaves_M$a_panssec8_dv == 4 ~ 0.625,
                                      AllWaves_M$b_panssec8_dv == 4 ~ 0.625,
                                      AllWaves_M$c_panssec8_dv == 4 ~ 0.625,
                                      AllWaves_M$d_panssec8_dv == 4 ~ 0.625,
                                      AllWaves_M$e_panssec8_dv == 4 ~ 0.625,
                                      AllWaves_M$f_panssec8_dv == 4 ~ 0.625,
                                      AllWaves_M$g_panssec8_dv == 4 ~ 0.625,
                                      AllWaves_M$h_panssec8_dv == 4 ~ 0.625,
                                      AllWaves_M$i_panssec8_dv == 4 ~ 0.625,
                                      AllWaves_M$j_panssec8_dv == 4 ~ 0.625,
                                      AllWaves_M$k_panssec8_dv == 4 ~ 0.625,
                                      AllWaves_M$l_panssec8_dv == 4 ~ 0.625,
                                      AllWaves_M$ba_panssec8_dv == 3 ~ 0.75,
                                      AllWaves_M$bh_panssec8_dv == 3 ~ 0.75,
                                      AllWaves_M$bi_panssec8_dv == 3 ~ 0.75,
                                      AllWaves_M$bj_panssec8_dv == 3 ~ 0.75,
                                      AllWaves_M$bk_panssec8_dv == 3 ~ 0.75,
                                      AllWaves_M$bl_panssec8_dv == 3 ~ 0.75,
                                      AllWaves_M$bm_panssec8_dv == 3 ~ 0.75,
                                      AllWaves_M$bn_panssec8_dv == 3 ~ 0.75,
                                      AllWaves_M$bo_panssec8_dv == 3 ~ 0.75,
                                      AllWaves_M$bp_panssec8_dv == 3 ~ 0.75,
                                      AllWaves_M$bq_panssec8_dv == 3 ~ 0.75,
                                      AllWaves_M$br_panssec8_dv == 3 ~ 0.75,
                                      AllWaves_M$a_panssec8_dv == 3 ~ 0.75,
                                      AllWaves_M$b_panssec8_dv == 3 ~ 0.75,
                                      AllWaves_M$c_panssec8_dv == 3 ~ 0.75,
                                      AllWaves_M$d_panssec8_dv == 3 ~ 0.75,
                                      AllWaves_M$e_panssec8_dv == 3 ~ 0.75,
                                      AllWaves_M$f_panssec8_dv == 3 ~ 0.75,
                                      AllWaves_M$g_panssec8_dv == 3 ~ 0.75,
                                      AllWaves_M$h_panssec8_dv == 3 ~ 0.75,
                                      AllWaves_M$i_panssec8_dv == 3 ~ 0.75,
                                      AllWaves_M$j_panssec8_dv == 3 ~ 0.75,
                                      AllWaves_M$k_panssec8_dv == 3 ~ 0.75,
                                      AllWaves_M$l_panssec8_dv == 3 ~ 0.75,
                                      AllWaves_M$ba_panssec8_dv == 2 ~ 0.875,
                                      AllWaves_M$bh_panssec8_dv == 2 ~ 0.875,
                                      AllWaves_M$bi_panssec8_dv == 2 ~ 0.875,
                                      AllWaves_M$bj_panssec8_dv == 2 ~ 0.875,
                                      AllWaves_M$bk_panssec8_dv == 2 ~ 0.875,
                                      AllWaves_M$bl_panssec8_dv == 2 ~ 0.875,
                                      AllWaves_M$bm_panssec8_dv == 2 ~ 0.875,
                                      AllWaves_M$bn_panssec8_dv == 2 ~ 0.875,
                                      AllWaves_M$bo_panssec8_dv == 2 ~ 0.875,
                                      AllWaves_M$bp_panssec8_dv == 2 ~ 0.875,
                                      AllWaves_M$bq_panssec8_dv == 2 ~ 0.875,
                                      AllWaves_M$br_panssec8_dv == 2 ~ 0.875,
                                      AllWaves_M$a_panssec8_dv == 2 ~ 0.875,
                                      AllWaves_M$b_panssec8_dv == 2 ~ 0.875,
                                      AllWaves_M$c_panssec8_dv == 2 ~ 0.875,
                                      AllWaves_M$d_panssec8_dv == 2 ~ 0.875,
                                      AllWaves_M$e_panssec8_dv == 2 ~ 0.875,
                                      AllWaves_M$f_panssec8_dv == 2 ~ 0.875,
                                      AllWaves_M$g_panssec8_dv == 2 ~ 0.875,
                                      AllWaves_M$h_panssec8_dv == 2 ~ 0.875,
                                      AllWaves_M$i_panssec8_dv == 2 ~ 0.875,
                                      AllWaves_M$j_panssec8_dv == 2 ~ 0.875,
                                      AllWaves_M$k_panssec8_dv == 2 ~ 0.875,
                                      AllWaves_M$l_panssec8_dv == 2 ~ 0.875,
                                      AllWaves_M$ba_panssec8_dv == 1 ~ 1,
                                      AllWaves_M$bh_panssec8_dv == 1 ~ 1,
                                      AllWaves_M$bi_panssec8_dv == 1 ~ 1,
                                      AllWaves_M$bj_panssec8_dv == 1 ~ 1,
                                      AllWaves_M$bk_panssec8_dv == 1 ~ 1,
                                      AllWaves_M$bl_panssec8_dv == 1 ~ 1,
                                      AllWaves_M$bm_panssec8_dv == 1 ~ 1,
                                      AllWaves_M$bn_panssec8_dv == 1 ~ 1,
                                      AllWaves_M$bo_panssec8_dv == 1 ~ 1,
                                      AllWaves_M$bp_panssec8_dv == 1 ~ 1,
                                      AllWaves_M$bq_panssec8_dv == 1 ~ 1,
                                      AllWaves_M$br_panssec8_dv == 1 ~ 1,
                                      AllWaves_M$a_panssec8_dv == 1 ~ 1,
                                      AllWaves_M$b_panssec8_dv == 1 ~ 1,
                                      AllWaves_M$c_panssec8_dv == 1 ~ 1,
                                      AllWaves_M$d_panssec8_dv == 1 ~ 1,
                                      AllWaves_M$e_panssec8_dv == 1 ~ 1,
                                      AllWaves_M$f_panssec8_dv == 1 ~ 1,
                                      AllWaves_M$g_panssec8_dv == 1 ~ 1,
                                      AllWaves_M$h_panssec8_dv == 1 ~ 1,
                                      AllWaves_M$i_panssec8_dv == 1 ~ 1,
                                      AllWaves_M$j_panssec8_dv == 1 ~ 1,
                                      AllWaves_M$k_panssec8_dv == 1 ~ 1,
                                      AllWaves_M$l_panssec8_dv == 1 ~ 1,
                                      TRUE ~ -1)

#* The above variable creates data for all waves. To find the specific waves I'm interested in,
#* it's just a case of filtering by the relevant QoW_Index_Member variable for that wave. There
#* are more missings across each wave than would be ideal, making this indicator a candidate for 
#* imputation. As would be expected, mothers have worse scores on this indicator than fathers: 
xtabs(~DV_MothersNSSEC + l_QoW_Index_Member, data = AllWaves_M)
xtabs(~DV_FathersNSSEC + l_QoW_Index_Member, data = AllWaves_M)
xtabs(~DV_MothersNSSEC + j_QoW_Index_Member, data = AllWaves_M)
xtabs(~DV_FathersNSSEC + j_QoW_Index_Member, data = AllWaves_M)
xtabs(~DV_MothersNSSEC + h_QoW_Index_Member, data = AllWaves_M)
xtabs(~DV_FathersNSSEC + h_QoW_Index_Member, data = AllWaves_M)
xtabs(~DV_MothersNSSEC + f_QoW_Index_Member, data = AllWaves_M)
xtabs(~DV_FathersNSSEC + f_QoW_Index_Member, data = AllWaves_M)
xtabs(~DV_MothersNSSEC + d_QoW_Index_Member, data = AllWaves_M)
xtabs(~DV_FathersNSSEC + d_QoW_Index_Member, data = AllWaves_M)

#* Perhaps positively, most of those with missing fathers' NS-SEC data also have missing
#* missing mothers' NS-SEC data, and vice-versa. So there isn't much extra missing from
#* having both indicators in the Capability Set: 
xtabs(~DV_MothersNSSEC + DV_FathersNSSEC + l_QoW_Index_Member, data = AllWaves_M)
xtabs(~DV_MothersNSSEC + DV_FathersNSSEC + j_QoW_Index_Member, data = AllWaves_M)
xtabs(~DV_MothersNSSEC + DV_FathersNSSEC + h_QoW_Index_Member, data = AllWaves_M)
xtabs(~DV_MothersNSSEC + DV_FathersNSSEC + f_QoW_Index_Member, data = AllWaves_M)
xtabs(~DV_MothersNSSEC + DV_FathersNSSEC + d_QoW_Index_Member, data = AllWaves_M)

#######################################################################################
####################### 4 - Create individual NS-SEC indicator: ########################
#######################################################################################

#* First job NS-SEC:                   
AllWaves_M$DV_FirstJobNSSEC <- case_when(AllWaves_M$bh_j1nssec8_dv == 8 ~ 0,
                                         AllWaves_M$bi_j1nssec8_dv == 8 ~ 0,
                                         AllWaves_M$bj_j1nssec8_dv == 8 ~ 0,
                                         AllWaves_M$bk_j1nssec8_dv == 8 ~ 0,
                                         AllWaves_M$bl_j1nssec8_dv == 8 ~ 0,
                                         AllWaves_M$bm_j1nssec8_dv == 8 ~ 0,
                                         AllWaves_M$bn_j1nssec8_dv == 8 ~ 0,
                                         AllWaves_M$bo_j1nssec8_dv == 8 ~ 0,
                                         AllWaves_M$bp_j1nssec8_dv == 8 ~ 0,
                                         AllWaves_M$bq_j1nssec8_dv == 8 ~ 0,
                                         AllWaves_M$br_j1nssec8_dv == 8 ~ 0,
                                         AllWaves_M$a_j1nssec8_dv == 8 ~ 0,
                                         AllWaves_M$b_j1nssec8_dv == 8 ~ 0,
                                         AllWaves_M$c_j1nssec8_dv == 8 ~ 0,
                                         AllWaves_M$d_j1nssec8_dv == 8 ~ 0,
                                         AllWaves_M$e_j1nssec8_dv == 8 ~ 0,
                                         AllWaves_M$f_j1nssec8_dv == 8 ~ 0,
                                         AllWaves_M$g_j1nssec8_dv == 8 ~ 0,
                                         AllWaves_M$h_j1nssec8_dv == 8 ~ 0,
                                         AllWaves_M$i_j1nssec8_dv == 8 ~ 0,
                                         AllWaves_M$j_j1nssec8_dv == 8 ~ 0,
                                         AllWaves_M$k_j1nssec8_dv == 8 ~ 0,
                                         AllWaves_M$l_j1nssec8_dv == 8 ~ 0,
                                         AllWaves_M$bh_j1nssec8_dv == 7 ~ 1,
                                         AllWaves_M$bi_j1nssec8_dv == 7 ~ 1,
                                         AllWaves_M$bj_j1nssec8_dv == 7 ~ 1,
                                         AllWaves_M$bk_j1nssec8_dv == 7 ~ 1,
                                         AllWaves_M$bl_j1nssec8_dv == 7 ~ 1,
                                         AllWaves_M$bm_j1nssec8_dv == 7 ~ 1,
                                         AllWaves_M$bn_j1nssec8_dv == 7 ~ 1,
                                         AllWaves_M$bo_j1nssec8_dv == 7 ~ 1,
                                         AllWaves_M$bp_j1nssec8_dv == 7 ~ 1,
                                         AllWaves_M$bq_j1nssec8_dv == 7 ~ 1,
                                         AllWaves_M$br_j1nssec8_dv == 7 ~ 1,
                                         AllWaves_M$a_j1nssec8_dv == 7 ~ 1,
                                         AllWaves_M$b_j1nssec8_dv == 7 ~ 1,
                                         AllWaves_M$c_j1nssec8_dv == 7 ~ 1,
                                         AllWaves_M$d_j1nssec8_dv == 7 ~ 1,
                                         AllWaves_M$e_j1nssec8_dv == 7 ~ 1,
                                         AllWaves_M$f_j1nssec8_dv == 7 ~ 1,
                                         AllWaves_M$g_j1nssec8_dv == 7 ~ 1,
                                         AllWaves_M$h_j1nssec8_dv == 7 ~ 1,
                                         AllWaves_M$i_j1nssec8_dv == 7 ~ 1,
                                         AllWaves_M$j_j1nssec8_dv == 7 ~ 1,
                                         AllWaves_M$k_j1nssec8_dv == 7 ~ 1,
                                         AllWaves_M$l_j1nssec8_dv == 7 ~ 1,
                                         AllWaves_M$bh_j1nssec8_dv == 6 ~ 2,
                                         AllWaves_M$bi_j1nssec8_dv == 6 ~ 2,
                                         AllWaves_M$bj_j1nssec8_dv == 6 ~ 2,
                                         AllWaves_M$bk_j1nssec8_dv == 6 ~ 2,
                                         AllWaves_M$bl_j1nssec8_dv == 6 ~ 2,
                                         AllWaves_M$bm_j1nssec8_dv == 6 ~ 2,
                                         AllWaves_M$bn_j1nssec8_dv == 6 ~ 2,
                                         AllWaves_M$bo_j1nssec8_dv == 6 ~ 2,
                                         AllWaves_M$bp_j1nssec8_dv == 6 ~ 2,
                                         AllWaves_M$bq_j1nssec8_dv == 6 ~ 2,
                                         AllWaves_M$br_j1nssec8_dv == 6 ~ 2,
                                         AllWaves_M$a_j1nssec8_dv == 6 ~ 2,
                                         AllWaves_M$b_j1nssec8_dv == 6 ~ 2,
                                         AllWaves_M$c_j1nssec8_dv == 6 ~ 2,
                                         AllWaves_M$d_j1nssec8_dv == 6 ~ 2,
                                         AllWaves_M$e_j1nssec8_dv == 6 ~ 2,
                                         AllWaves_M$f_j1nssec8_dv == 6 ~ 2,
                                         AllWaves_M$g_j1nssec8_dv == 6 ~ 2,
                                         AllWaves_M$h_j1nssec8_dv == 6 ~ 2,
                                         AllWaves_M$i_j1nssec8_dv == 6 ~ 2,
                                         AllWaves_M$j_j1nssec8_dv == 6 ~ 2,
                                         AllWaves_M$k_j1nssec8_dv == 6 ~ 2,
                                         AllWaves_M$l_j1nssec8_dv == 6 ~ 2,
                                         AllWaves_M$bh_j1nssec8_dv == 5 ~ 3,
                                         AllWaves_M$bi_j1nssec8_dv == 5 ~ 3,
                                         AllWaves_M$bj_j1nssec8_dv == 5 ~ 3,
                                         AllWaves_M$bk_j1nssec8_dv == 5 ~ 3,
                                         AllWaves_M$bl_j1nssec8_dv == 5 ~ 3,
                                         AllWaves_M$bm_j1nssec8_dv == 5 ~ 3,
                                         AllWaves_M$bn_j1nssec8_dv == 5 ~ 3,
                                         AllWaves_M$bo_j1nssec8_dv == 5 ~ 3,
                                         AllWaves_M$bp_j1nssec8_dv == 5 ~ 3,
                                         AllWaves_M$bq_j1nssec8_dv == 5 ~ 3,
                                         AllWaves_M$br_j1nssec8_dv == 5 ~ 3,
                                         AllWaves_M$a_j1nssec8_dv == 5 ~ 3,
                                         AllWaves_M$b_j1nssec8_dv == 5 ~ 3,
                                         AllWaves_M$c_j1nssec8_dv == 5 ~ 3,
                                         AllWaves_M$d_j1nssec8_dv == 5 ~ 3,
                                         AllWaves_M$e_j1nssec8_dv == 5 ~ 3,
                                         AllWaves_M$f_j1nssec8_dv == 5 ~ 3,
                                         AllWaves_M$g_j1nssec8_dv == 5 ~ 3,
                                         AllWaves_M$h_j1nssec8_dv == 5 ~ 3,
                                         AllWaves_M$i_j1nssec8_dv == 5 ~ 3,
                                         AllWaves_M$j_j1nssec8_dv == 5 ~ 3,
                                         AllWaves_M$k_j1nssec8_dv == 5 ~ 3,
                                         AllWaves_M$l_j1nssec8_dv == 5 ~ 3,
                                         AllWaves_M$bh_j1nssec8_dv == 4 ~ 4,
                                         AllWaves_M$bi_j1nssec8_dv == 4 ~ 4,
                                         AllWaves_M$bj_j1nssec8_dv == 4 ~ 4,
                                         AllWaves_M$bk_j1nssec8_dv == 4 ~ 4,
                                         AllWaves_M$bl_j1nssec8_dv == 4 ~ 4,
                                         AllWaves_M$bm_j1nssec8_dv == 4 ~ 4,
                                         AllWaves_M$bn_j1nssec8_dv == 4 ~ 4,
                                         AllWaves_M$bo_j1nssec8_dv == 4 ~ 4,
                                         AllWaves_M$bp_j1nssec8_dv == 4 ~ 4,
                                         AllWaves_M$bq_j1nssec8_dv == 4 ~ 4,
                                         AllWaves_M$br_j1nssec8_dv == 4 ~ 4,
                                         AllWaves_M$a_j1nssec8_dv == 4 ~ 4,
                                         AllWaves_M$b_j1nssec8_dv == 4 ~ 4,
                                         AllWaves_M$c_j1nssec8_dv == 4 ~ 4,
                                         AllWaves_M$d_j1nssec8_dv == 4 ~ 4,
                                         AllWaves_M$e_j1nssec8_dv == 4 ~ 4,
                                         AllWaves_M$f_j1nssec8_dv == 4 ~ 4,
                                         AllWaves_M$g_j1nssec8_dv == 4 ~ 4,
                                         AllWaves_M$h_j1nssec8_dv == 4 ~ 4,
                                         AllWaves_M$i_j1nssec8_dv == 4 ~ 4,
                                         AllWaves_M$j_j1nssec8_dv == 4 ~ 4,
                                         AllWaves_M$k_j1nssec8_dv == 4 ~ 4,
                                         AllWaves_M$l_j1nssec8_dv == 4 ~ 4,
                                         AllWaves_M$bh_j1nssec8_dv == 3 ~ 5,
                                         AllWaves_M$bi_j1nssec8_dv == 3 ~ 5,
                                         AllWaves_M$bj_j1nssec8_dv == 3 ~ 5,
                                         AllWaves_M$bk_j1nssec8_dv == 3 ~ 5,
                                         AllWaves_M$bl_j1nssec8_dv == 3 ~ 5,
                                         AllWaves_M$bm_j1nssec8_dv == 3 ~ 5,
                                         AllWaves_M$bn_j1nssec8_dv == 3 ~ 5,
                                         AllWaves_M$bo_j1nssec8_dv == 3 ~ 5,
                                         AllWaves_M$bp_j1nssec8_dv == 3 ~ 5,
                                         AllWaves_M$bq_j1nssec8_dv == 3 ~ 5,
                                         AllWaves_M$br_j1nssec8_dv == 3 ~ 5,
                                         AllWaves_M$a_j1nssec8_dv == 3 ~ 5,
                                         AllWaves_M$b_j1nssec8_dv == 3 ~ 5,
                                         AllWaves_M$c_j1nssec8_dv == 3 ~ 5,
                                         AllWaves_M$d_j1nssec8_dv == 3 ~ 5,
                                         AllWaves_M$e_j1nssec8_dv == 3 ~ 5,
                                         AllWaves_M$f_j1nssec8_dv == 3 ~ 5,
                                         AllWaves_M$g_j1nssec8_dv == 3 ~ 5,
                                         AllWaves_M$h_j1nssec8_dv == 3 ~ 5,
                                         AllWaves_M$i_j1nssec8_dv == 3 ~ 5,
                                         AllWaves_M$j_j1nssec8_dv == 3 ~ 5,
                                         AllWaves_M$k_j1nssec8_dv == 3 ~ 5,
                                         AllWaves_M$l_j1nssec8_dv == 3 ~ 5,
                                         AllWaves_M$bh_j1nssec8_dv == 2 ~ 6,
                                         AllWaves_M$bi_j1nssec8_dv == 2 ~ 6,
                                         AllWaves_M$bj_j1nssec8_dv == 2 ~ 6,
                                         AllWaves_M$bk_j1nssec8_dv == 2 ~ 6,
                                         AllWaves_M$bl_j1nssec8_dv == 2 ~ 6,
                                         AllWaves_M$bm_j1nssec8_dv == 2 ~ 6,
                                         AllWaves_M$bn_j1nssec8_dv == 2 ~ 6,
                                         AllWaves_M$bo_j1nssec8_dv == 2 ~ 6,
                                         AllWaves_M$bp_j1nssec8_dv == 2 ~ 6,
                                         AllWaves_M$bq_j1nssec8_dv == 2 ~ 6,
                                         AllWaves_M$br_j1nssec8_dv == 2 ~ 6,
                                         AllWaves_M$a_j1nssec8_dv == 2 ~ 6,
                                         AllWaves_M$b_j1nssec8_dv == 2 ~ 6,
                                         AllWaves_M$c_j1nssec8_dv == 2 ~ 6,
                                         AllWaves_M$d_j1nssec8_dv == 2 ~ 6,
                                         AllWaves_M$e_j1nssec8_dv == 2 ~ 6,
                                         AllWaves_M$f_j1nssec8_dv == 2 ~ 6,
                                         AllWaves_M$g_j1nssec8_dv == 2 ~ 6,
                                         AllWaves_M$h_j1nssec8_dv == 2 ~ 6,
                                         AllWaves_M$i_j1nssec8_dv == 2 ~ 6,
                                         AllWaves_M$j_j1nssec8_dv == 2 ~ 6,
                                         AllWaves_M$k_j1nssec8_dv == 2 ~ 6,
                                         AllWaves_M$l_j1nssec8_dv == 2 ~ 6,
                                         AllWaves_M$bh_j1nssec8_dv == 1 ~ 7,
                                         AllWaves_M$bi_j1nssec8_dv == 1 ~ 7,
                                         AllWaves_M$bj_j1nssec8_dv == 1 ~ 7,
                                         AllWaves_M$bk_j1nssec8_dv == 1 ~ 7,
                                         AllWaves_M$bl_j1nssec8_dv == 1 ~ 7,
                                         AllWaves_M$bm_j1nssec8_dv == 1 ~ 7,
                                         AllWaves_M$bn_j1nssec8_dv == 1 ~ 7,
                                         AllWaves_M$bo_j1nssec8_dv == 1 ~ 7,
                                         AllWaves_M$bp_j1nssec8_dv == 1 ~ 7,
                                         AllWaves_M$bq_j1nssec8_dv == 1 ~ 7,
                                         AllWaves_M$br_j1nssec8_dv == 1 ~ 7,
                                         AllWaves_M$a_j1nssec8_dv == 1 ~ 7,
                                         AllWaves_M$b_j1nssec8_dv == 1 ~ 7,
                                         AllWaves_M$c_j1nssec8_dv == 1 ~ 7,
                                         AllWaves_M$d_j1nssec8_dv == 1 ~ 7,
                                         AllWaves_M$e_j1nssec8_dv == 1 ~ 7,
                                         AllWaves_M$f_j1nssec8_dv == 1 ~ 7,
                                         AllWaves_M$g_j1nssec8_dv == 1 ~ 7,
                                         AllWaves_M$h_j1nssec8_dv == 1 ~ 7,
                                         AllWaves_M$i_j1nssec8_dv == 1 ~ 7,
                                         AllWaves_M$j_j1nssec8_dv == 1 ~ 7,
                                         AllWaves_M$k_j1nssec8_dv == 1 ~ 7,
                                         AllWaves_M$l_j1nssec8_dv == 1 ~ 7,
                                         TRUE ~ -1)

#* Second job NS-SEC:
AllWaves_M$DV_SecondJobNSSEC <- case_when(AllWaves_M$a_j2nssec8_dv == 8 ~ 0,
                                          AllWaves_M$b_j2nssec8_dv == 8 ~ 0,
                                          AllWaves_M$c_j2nssec8_dv == 8 ~ 0,
                                          AllWaves_M$d_j2nssec8_dv == 8 ~ 0,
                                          AllWaves_M$e_j2nssec8_dv == 8 ~ 0,
                                          AllWaves_M$f_j2nssec8_dv == 8 ~ 0,
                                          AllWaves_M$g_j2nssec8_dv == 8 ~ 0,
                                          AllWaves_M$h_j2nssec8_dv == 8 ~ 0,
                                          AllWaves_M$i_j2nssec8_dv == 8 ~ 0,
                                          AllWaves_M$j_j2nssec8_dv == 8 ~ 0,
                                          AllWaves_M$k_j2nssec8_dv == 8 ~ 0,
                                          AllWaves_M$l_j2nssec8_dv == 8 ~ 0,
                                          AllWaves_M$a_j2nssec8_dv == 7 ~ 1,
                                          AllWaves_M$b_j2nssec8_dv == 7 ~ 1,
                                          AllWaves_M$c_j2nssec8_dv == 7 ~ 1,
                                          AllWaves_M$d_j2nssec8_dv == 7 ~ 1,
                                          AllWaves_M$e_j2nssec8_dv == 7 ~ 1,
                                          AllWaves_M$f_j2nssec8_dv == 7 ~ 1,
                                          AllWaves_M$g_j2nssec8_dv == 7 ~ 1,
                                          AllWaves_M$h_j2nssec8_dv == 7 ~ 1,
                                          AllWaves_M$i_j2nssec8_dv == 7 ~ 1,
                                          AllWaves_M$j_j2nssec8_dv == 7 ~ 1,
                                          AllWaves_M$k_j2nssec8_dv == 7 ~ 1,
                                          AllWaves_M$l_j2nssec8_dv == 7 ~ 1,
                                          AllWaves_M$a_j2nssec8_dv == 6 ~ 2,
                                          AllWaves_M$b_j2nssec8_dv == 6 ~ 2,
                                          AllWaves_M$c_j2nssec8_dv == 6 ~ 2,
                                          AllWaves_M$d_j2nssec8_dv == 6 ~ 2,
                                          AllWaves_M$e_j2nssec8_dv == 6 ~ 2,
                                          AllWaves_M$f_j2nssec8_dv == 6 ~ 2,
                                          AllWaves_M$g_j2nssec8_dv == 6 ~ 2,
                                          AllWaves_M$h_j2nssec8_dv == 6 ~ 2,
                                          AllWaves_M$i_j2nssec8_dv == 6 ~ 2,
                                          AllWaves_M$j_j2nssec8_dv == 6 ~ 2,
                                          AllWaves_M$k_j2nssec8_dv == 6 ~ 2,
                                          AllWaves_M$l_j2nssec8_dv == 6 ~ 2,
                                          AllWaves_M$a_j2nssec8_dv == 5 ~ 3,
                                          AllWaves_M$b_j2nssec8_dv == 5 ~ 3,
                                          AllWaves_M$c_j2nssec8_dv == 5 ~ 3,
                                          AllWaves_M$d_j2nssec8_dv == 5 ~ 3,
                                          AllWaves_M$e_j2nssec8_dv == 5 ~ 3,
                                          AllWaves_M$f_j2nssec8_dv == 5 ~ 3,
                                          AllWaves_M$g_j2nssec8_dv == 5 ~ 3,
                                          AllWaves_M$h_j2nssec8_dv == 5 ~ 3,
                                          AllWaves_M$i_j2nssec8_dv == 5 ~ 3,
                                          AllWaves_M$j_j2nssec8_dv == 5 ~ 3,
                                          AllWaves_M$k_j2nssec8_dv == 5 ~ 3,
                                          AllWaves_M$l_j2nssec8_dv == 5 ~ 3,
                                          AllWaves_M$a_j2nssec8_dv == 4 ~ 4,
                                          AllWaves_M$b_j2nssec8_dv == 4 ~ 4,
                                          AllWaves_M$c_j2nssec8_dv == 4 ~ 4,
                                          AllWaves_M$d_j2nssec8_dv == 4 ~ 4,
                                          AllWaves_M$e_j2nssec8_dv == 4 ~ 4,
                                          AllWaves_M$f_j2nssec8_dv == 4 ~ 4,
                                          AllWaves_M$g_j2nssec8_dv == 4 ~ 4,
                                          AllWaves_M$h_j2nssec8_dv == 4 ~ 4,
                                          AllWaves_M$i_j2nssec8_dv == 4 ~ 4,
                                          AllWaves_M$j_j2nssec8_dv == 4 ~ 4,
                                          AllWaves_M$k_j2nssec8_dv == 4 ~ 4,
                                          AllWaves_M$l_j2nssec8_dv == 4 ~ 4,
                                          AllWaves_M$a_j2nssec8_dv == 3 ~ 5,
                                          AllWaves_M$b_j2nssec8_dv == 3 ~ 5,
                                          AllWaves_M$c_j2nssec8_dv == 3 ~ 5,
                                          AllWaves_M$d_j2nssec8_dv == 3 ~ 5,
                                          AllWaves_M$e_j2nssec8_dv == 3 ~ 5,
                                          AllWaves_M$f_j2nssec8_dv == 3 ~ 5,
                                          AllWaves_M$g_j2nssec8_dv == 3 ~ 5,
                                          AllWaves_M$h_j2nssec8_dv == 3 ~ 5,
                                          AllWaves_M$i_j2nssec8_dv == 3 ~ 5,
                                          AllWaves_M$j_j2nssec8_dv == 3 ~ 5,
                                          AllWaves_M$k_j2nssec8_dv == 3 ~ 5,
                                          AllWaves_M$l_j2nssec8_dv == 3 ~ 5,
                                          AllWaves_M$a_j2nssec8_dv == 2 ~ 6,
                                          AllWaves_M$b_j2nssec8_dv == 2 ~ 6,
                                          AllWaves_M$c_j2nssec8_dv == 2 ~ 6,
                                          AllWaves_M$d_j2nssec8_dv == 2 ~ 6,
                                          AllWaves_M$e_j2nssec8_dv == 2 ~ 6,
                                          AllWaves_M$f_j2nssec8_dv == 2 ~ 6,
                                          AllWaves_M$g_j2nssec8_dv == 2 ~ 6,
                                          AllWaves_M$h_j2nssec8_dv == 2 ~ 6,
                                          AllWaves_M$i_j2nssec8_dv == 2 ~ 6,
                                          AllWaves_M$j_j2nssec8_dv == 2 ~ 6,
                                          AllWaves_M$k_j2nssec8_dv == 2 ~ 6,
                                          AllWaves_M$l_j2nssec8_dv == 2 ~ 6,
                                          AllWaves_M$a_j2nssec8_dv == 1 ~ 7,
                                          AllWaves_M$b_j2nssec8_dv == 1 ~ 7,
                                          AllWaves_M$c_j2nssec8_dv == 1 ~ 7,
                                          AllWaves_M$d_j2nssec8_dv == 1 ~ 7,
                                          AllWaves_M$e_j2nssec8_dv == 1 ~ 7,
                                          AllWaves_M$f_j2nssec8_dv == 1 ~ 7,
                                          AllWaves_M$g_j2nssec8_dv == 1 ~ 7,
                                          AllWaves_M$h_j2nssec8_dv == 1 ~ 7,
                                          AllWaves_M$i_j2nssec8_dv == 1 ~ 7,
                                          AllWaves_M$j_j2nssec8_dv == 1 ~ 7,
                                          AllWaves_M$k_j2nssec8_dv == 1 ~ 7,
                                          AllWaves_M$l_j2nssec8_dv == 1 ~ 7,
                                          TRUE ~ -1)

#######################################################################################
######################## 5 - Prepare to export to QoW index: ##########################
#######################################################################################

#* The process from here is similar to continuous employment, but without the need 
#* to separate out into data frames. It should suffice to simply bring in pidp and
#* then let the inner_join function for each individual wave (waves 4, 6, 8, 10 and 12)
#* do the work in finding the merged data:
AllWavesNSSEC <- AllWaves_M |> select(pidp, DV_MothersNSSEC, DV_FathersNSSEC, DV_FirstJobNSSEC, DV_SecondJobNSSEC)

#* Save for future download. Refer to Section 3 of the '0 - Data Download' file from this
#* point onwards:
write_dta(AllWavesNSSEC, file.path(getwd(), '0 - All Waves - NSSEC.dta'))

#* The below code - completed after the merge process in the '0 - Data download' section 
#* is complete - shows that the merge process has worked. There are however lots of missings,
#* especially for first- and second- job NS-SECs:
xtabs(~DV_MothersNSSEC + year, Dat)
xtabs(~DV_FathersNSSEC + year, Dat)
xtabs(~DV_FirstJobNSSEC + year, Dat)
xtabs(~DV_SecondJobNSSEC + year, Dat)

prop.table(xtabs(~DV_MothersNSSEC + year, JQ),2)
prop.table(xtabs(~DV_FathersNSSEC + year, JQ),2)
prop.table(xtabs(~DV_FirstJobNSSEC + year, JQ),2)
prop.table(xtabs(~DV_SecondJobNSSEC + year, JQ),2)

#* The below code [25.09.23] also shows that the merging process hasn't created any new NAs:
sum(is.na(Dat$variables$DV_MothersNSSEC))
sum(is.na(Dat$variables$DV_FathersNSSEC))
sum(is.na(Dat$variables$QoW_Index_Member))

#######################################################################################
################# 6 - Merge parental NS-SEC into a single indicator: ##################
#######################################################################################

#* *After* I have merged the data into Dat, I now also create a merged indicator of mothers'
#* and father's NS-SEC. It is this merged indicator which forms the basis for the variable in
#* the Capability Set, as this reduces missingness.

#* Filter to create the variable:
Dat$variables$CS_ParentalNSSEC <- case_when(Dat$variables$DV_FathersNSSEC > Dat$variables$DV_MothersNSSEC ~ as.numeric(as.character(Dat$variables$DV_FathersNSSEC)),
                                            Dat$variables$DV_FathersNSSEC < Dat$variables$DV_MothersNSSEC ~ as.numeric(as.character(Dat$variables$DV_MothersNSSEC)),
                                            Dat$variables$DV_FathersNSSEC == -1 & Dat$variables$DV_MothersNSSEC == -1 ~ -1,
                                            Dat$variables$DV_FathersNSSEC == -1 & Dat$variables$DV_MothersNSSEC != -1 ~ as.numeric(as.character(Dat$variables$DV_MothersNSSEC)),
                                            Dat$variables$DV_FathersNSSEC != -1 & Dat$variables$DV_MothersNSSEC == -1 ~ as.numeric(as.character(Dat$variables$DV_FathersNSSEC)),
                                            TRUE ~ as.numeric(as.character(Dat$variables$DV_FathersNSSEC)))

#* The below shows that the code has worked; however there are still more missings, especially
#* later on in the time series, than would be preferred. It is unclear why this is the case, but
#* I suspect it may be due to people in the BHPS attriting out of the survey; and procedures
#* for capturing UKHLS respondents' answers to these are poorer:
xtabs(~CS_ParentalNSSEC + DV_FathersNSSEC, Dat)          
xtabs(~CS_ParentalNSSEC + DV_MothersNSSEC, Dat)   

#* Outputs: 
prop.table(svytable(~DV_FathersNSSEC + year, JQ), 2) |> round(3)
prop.table(svytable(~CS_ParentalNSSEC + year, JQ), 2) |> round(2)

#* Saved the above as of [11.10.23]:
# saveRDS(Dat, file = "0 - Dat.RData")

#######################################################################################
################# 7 - Merge individual NS-SEC into a single indicator: ################
#######################################################################################

#* I now also merge first and second job NS-SEC. Where either is missing and the other isn't, 
#* it goes with the non-missing value. Where both are available, it goes with the higher 
#* of the two. This process is virtually identical to the process used for creating parental
#* NS-SEC, although with the difference that - because it's a DV_ variable - I subsequently 
#* recode all -1s to NA:

Dat$variables$DV_IndividualNSSEC <- case_when(Dat$variables$DV_FirstJobNSSEC > Dat$variables$DV_SecondJobNSSEC ~ as.numeric(as.character(Dat$variables$DV_FirstJobNSSEC)),
                                            Dat$variables$DV_FirstJobNSSEC < Dat$variables$DV_SecondJobNSSEC ~ as.numeric(as.character(Dat$variables$DV_SecondJobNSSEC)),
                                            Dat$variables$DV_FirstJobNSSEC == -1 & Dat$variables$DV_SecondJobNSSEC == -1 ~ -1,
                                            Dat$variables$DV_FirstJobNSSEC == -1 & Dat$variables$DV_SecondJobNSSEC != -1 ~ as.numeric(as.character(Dat$variables$DV_SecondJobNSSEC)),
                                            Dat$variables$DV_FirstJobNSSEC != -1 & Dat$variables$DV_SecondJobNSSEC == -1 ~ as.numeric(as.character(Dat$variables$DV_FirstJobNSSEC)),
                                            TRUE ~ as.numeric(as.character(Dat$variables$DV_FirstJobNSSEC)))

#* This process removes many missings, but not as pronounced as for individual NS-SEC:
xtabs(~DV_IndividualNSSEC + DV_FirstJobNSSEC, JQ)          
xtabs(~DV_IndividualNSSEC + DV_SecondJobNSSEC, JQ)   
prop.table(svytable(~DV_IndividualNSSEC + year, JQ), 2)
prop.table(svytable(~DV_FirstJobNSSEC + year, JQ), 2)
prop.table(svytable(~DV_SecondJobNSSEC + year, JQ), 2)

#* Only after I've done the above cross-tabs, to check the data do I recode the 
#* NAs to -1:
Dat$variables$DV_IndividualNSSEC <- replace(Dat$variables$DV_IndividualNSSEC, 
                                            Dat$variables$DV_IndividualNSSEC %in% c(-1), NA)

#* Saved the above as of [13.10.23]:
# saveRDS(Dat, file = "0 - Dat.RData")

#######################################################################################
###################### 8 - Merge individual and parental NS-SEC: ######################
#######################################################################################

#* As a final step, should both mothers' and fathers' NS-SEC be missing, I go with the NS-SEC of the individual's own first 
#* or second job. To create this I first adjust the individual NS-SEC variable so it has the same values as the others. Note
#* there is no zero value for individual NS-SEC of first/second job because I created this for instances where the parent wasn't
#* working, so we start with 0 equalling 0.125 and move up sequentially from there:
xtabs(~CS_ParentalNSSEC + DV_IndividualNSSEC, Dat)
Dat$variables$DV_IndividualNSSEC_adj <- case_when(Dat$variables$DV_IndividualNSSEC == 0 ~ 0.125,
                                                  Dat$variables$DV_IndividualNSSEC == 1 ~ 0.25,
                                                  Dat$variables$DV_IndividualNSSEC == 2 ~ 0.375,
                                                  Dat$variables$DV_IndividualNSSEC == 3 ~ 0.5,
                                                  Dat$variables$DV_IndividualNSSEC == 4 ~ 0.625,
                                                  Dat$variables$DV_IndividualNSSEC == 5 ~ 0.75, 
                                                  Dat$variables$DV_IndividualNSSEC == 6 ~ 0.875,
                                                  Dat$variables$DV_IndividualNSSEC == 7 ~ 1)
summary(Dat$variables$DV_IndividualNSSEC_adj)

Dat$variables$CS_ParentalNSSEC_IndAdj <- case_when(Dat$variables$CS_ParentalNSSEC == -1 & Dat$variables$DV_IndividualNSSEC_adj > 0 ~ Dat$variables$DV_IndividualNSSEC_adj,
                                              TRUE ~ as.numeric(as.character(Dat$variables$CS_ParentalNSSEC)))
length(which(Dat$variables$CS_ParentalNSSEC == -1))
length(which(Dat$variables$CS_ParentalNSSEC_IndAdj == -1))

#* The above process reduces the number of missing values slightly, but not by much. However it reduces it much more dramatically
#* for those in the QoW index. Conversely, however, this means that our data on NS-SEC for respondents in the QoW index is a bit 
#* more reliant on data from respondents' first or second jobs:
xtabs(~CS_ParentalNSSEC + year, Dat) |> prop.table(2)
xtabs(~CS_ParentalNSSEC_IndAdj + year, Dat) |> prop.table(2)

xtabs(~CS_ParentalNSSEC + year, JQ) |> prop.table(2)
xtabs(~CS_ParentalNSSEC_IndAdj + year, JQ) |> prop.table(2)

#* Saved the above as of [14.04.24]:
# saveRDS(Dat, file = "0 - Dat.RData")
