
#######################################################################################
############################# 1 - Non-employment spells: ##############################
#######################################################################################

#* ----------------------------------------------------------------
#* -------------- [a - Prepare the data:]
#* ----------------------------------------------------------------

#* Download all the data:
UKHLS_2_2010_11 <- read_dta('b_indresp.dta') |>
  select(pidp, b_nnmpsp_dv, b_nunmpsp_dv)
UKHLS_3_2011_12 <- read_dta('c_indresp.dta') |>
  select(pidp, c_nnmpsp_dv, c_nunmpsp_dv)
UKHLS_4_2012_13 <- read_dta('d_indresp.dta') |>
  select(pidp, d_nnmpsp_dv, d_nunmpsp_dv)
UKHLS_5_2013_14 <- read_dta('e_indresp.dta') |>
  select(pidp, e_nnmpsp_dv, e_nunmpsp_dv)
UKHLS_6_2014_15 <- read_dta('f_indresp.dta') |>
  select(pidp, f_nnmpsp_dv, f_nunmpsp_dv)
UKHLS_7_2015_16 <- read_dta('g_indresp.dta') |>
  select(pidp, g_nnmpsp_dv, g_nunmpsp_dv)
UKHLS_8_2016_17 <- read_dta('h_indresp.dta') |>
  select(pidp, h_nnmpsp_dv, h_nunmpsp_dv)
UKHLS_9_2017_18 <- read_dta('i_indresp.dta') |>
  select(pidp, i_nnmpsp_dv, i_nunmpsp_dv)
UKHLS_10_2018_19 <- read_dta('j_indresp.dta') |>
  select(pidp, j_nnmpsp_dv, j_nunmpsp_dv)
UKHLS_11_2019_20 <- read_dta('k_indresp.dta') |>
  select(pidp, k_nnmpsp_dv, k_nunmpsp_dv)
UKHLS_12_2020_21 <- read_dta('l_indresp.dta') |>
  select(pidp, l_nnmpsp_dv, l_nunmpsp_dv)
gc()

#* Merge the data into wide format, but retaining the wave prefixes:
AllWaves_Merge <- full_join(UKHLS_12_2020_21, UKHLS_11_2019_20, by = "pidp")
AllWaves_Merge <- full_join(AllWaves_Merge, UKHLS_10_2018_19, by = "pidp")
AllWaves_Merge <- full_join(AllWaves_Merge, UKHLS_9_2017_18, by = "pidp")
AllWaves_Merge <- full_join(AllWaves_Merge, UKHLS_8_2016_17, by = "pidp")
AllWaves_Merge <- full_join(AllWaves_Merge, UKHLS_7_2015_16, by = "pidp")
AllWaves_Merge <- full_join(AllWaves_Merge, UKHLS_6_2014_15, by = "pidp")
AllWaves_Merge <- full_join(AllWaves_Merge, UKHLS_5_2013_14, by = "pidp")
AllWaves_Merge <- full_join(AllWaves_Merge, UKHLS_4_2012_13, by = "pidp")
AllWaves_Merge <- full_join(AllWaves_Merge, UKHLS_3_2011_12, by = "pidp")
AllWaves_Merge <- full_join(AllWaves_Merge, UKHLS_2_2010_11, by = "pidp")

#* The below code [11.04.24] confirms that each pidp is unique in this new dataset:
all_unique(AllWaves_Merge$pidp)

#* I now delete the old files to save space on the disk:
rm(UKHLS_2_2010_11, UKHLS_3_2011_12, UKHLS_4_2012_13, UKHLS_5_2013_14, 
   UKHLS_6_2014_15, UKHLS_7_2015_16, UKHLS_8_2016_17, UKHLS_9_2017_18, 
   UKHLS_10_2018_19, UKHLS_11_2019_20, UKHLS_12_2020_21)
gc()

#* I then convert all the missings to NA. This will add even more NAs to the data than are already there,
#* since people who didn't respond to the wave immediately prior to the one interviewed are given codes like (-8),
#* and of course other people who did respond to the given wave will report don't know, e.t.c:
AllWaves_Merge$b_nunmpsp_dv_NAs <- replace(AllWaves_Merge$b_nunmpsp_dv, 
                                           AllWaves_Merge$b_nunmpsp_dv %in% c(-9,-8,-7,-2,-1), NA)
AllWaves_Merge$b_nnmpsp_dv_NAs <- replace(AllWaves_Merge$b_nnmpsp_dv, 
                                          AllWaves_Merge$b_nnmpsp_dv %in% c(-9,-8,-7,-2,-1), NA)
AllWaves_Merge$c_nunmpsp_dv_NAs <- replace(AllWaves_Merge$c_nunmpsp_dv, 
                                           AllWaves_Merge$c_nunmpsp_dv %in% c(-9,-8,-7,-2,-1), NA)
AllWaves_Merge$c_nnmpsp_dv_NAs <- replace(AllWaves_Merge$c_nnmpsp_dv, 
                                          AllWaves_Merge$c_nnmpsp_dv %in% c(-9,-8,-7,-2,-1), NA)
AllWaves_Merge$d_nunmpsp_dv_NAs <- replace(AllWaves_Merge$d_nunmpsp_dv, 
                                       AllWaves_Merge$d_nunmpsp_dv %in% c(-9,-8,-7,-2,-1), NA)
AllWaves_Merge$d_nnmpsp_dv_NAs <- replace(AllWaves_Merge$d_nnmpsp_dv, 
                                      AllWaves_Merge$d_nnmpsp_dv %in% c(-9,-8,-7,-2,-1), NA)
AllWaves_Merge$e_nunmpsp_dv_NAs <- replace(AllWaves_Merge$e_nunmpsp_dv, 
                                       AllWaves_Merge$e_nunmpsp_dv %in% c(-9,-8,-7,-2,-1), NA)
AllWaves_Merge$e_nnmpsp_dv_NAs <- replace(AllWaves_Merge$e_nnmpsp_dv, 
                                      AllWaves_Merge$e_nnmpsp_dv %in% c(-9,-8,-7,-2,-1), NA)
AllWaves_Merge$f_nunmpsp_dv_NAs <- replace(AllWaves_Merge$f_nunmpsp_dv, 
                                       AllWaves_Merge$f_nunmpsp_dv %in% c(-9,-8,-7,-2,-1), NA)
AllWaves_Merge$f_nnmpsp_dv_NAs <- replace(AllWaves_Merge$f_nnmpsp_dv, 
                                      AllWaves_Merge$f_nnmpsp_dv %in% c(-9,-8,-7,-2,-1), NA)
AllWaves_Merge$g_nunmpsp_dv_NAs <- replace(AllWaves_Merge$g_nunmpsp_dv, 
                                           AllWaves_Merge$g_nunmpsp_dv %in% c(-9,-8,-7,-2,-1), NA)
AllWaves_Merge$g_nnmpsp_dv_NAs <- replace(AllWaves_Merge$g_nnmpsp_dv, 
                                          AllWaves_Merge$g_nnmpsp_dv %in% c(-9,-8,-7,-2,-1), NA)
AllWaves_Merge$h_nunmpsp_dv_NAs <- replace(AllWaves_Merge$h_nunmpsp_dv, 
                                           AllWaves_Merge$h_nunmpsp_dv %in% c(-9,-8,-7,-2,-1), NA)
AllWaves_Merge$h_nnmpsp_dv_NAs <- replace(AllWaves_Merge$h_nnmpsp_dv, 
                                          AllWaves_Merge$h_nnmpsp_dv %in% c(-9,-8,-7,-2,-1), NA)
AllWaves_Merge$i_nunmpsp_dv_NAs <- replace(AllWaves_Merge$i_nunmpsp_dv, 
                                           AllWaves_Merge$i_nunmpsp_dv %in% c(-9,-8,-7,-2,-1), NA)
AllWaves_Merge$i_nnmpsp_dv_NAs <- replace(AllWaves_Merge$i_nnmpsp_dv, 
                                          AllWaves_Merge$i_nnmpsp_dv %in% c(-9,-8,-7,-2,-1), NA)
AllWaves_Merge$j_nunmpsp_dv_NAs <- replace(AllWaves_Merge$j_nunmpsp_dv, 
                                           AllWaves_Merge$j_nunmpsp_dv %in% c(-9,-8,-7,-2,-1), NA)
AllWaves_Merge$j_nnmpsp_dv_NAs <- replace(AllWaves_Merge$j_nnmpsp_dv, 
                                          AllWaves_Merge$j_nnmpsp_dv %in% c(-9,-8,-7,-2,-1), NA)
AllWaves_Merge$k_nunmpsp_dv_NAs <- replace(AllWaves_Merge$k_nunmpsp_dv, 
                                           AllWaves_Merge$k_nunmpsp_dv %in% c(-9,-8,-7,-2,-1), NA)
AllWaves_Merge$k_nnmpsp_dv_NAs <- replace(AllWaves_Merge$k_nnmpsp_dv, 
                                          AllWaves_Merge$k_nnmpsp_dv %in% c(-9,-8,-7,-2,-1), NA)
AllWaves_Merge$l_nunmpsp_dv_NAs <- replace(AllWaves_Merge$l_nunmpsp_dv, 
                                           AllWaves_Merge$l_nunmpsp_dv %in% c(-9,-8,-7,-2,-1), NA)
AllWaves_Merge$l_nnmpsp_dv_NAs <- replace(AllWaves_Merge$l_nnmpsp_dv, 
                                          AllWaves_Merge$l_nnmpsp_dv %in% c(-9,-8,-7,-2,-1), NA)

#* Finally, for the _NAs suffixed indicator, I add both of the unemployment (nunmpsp_dv)[1] and non-employed 
#* (nnmpsp_dv)[2] variables together to give a single number of total non-employment spells. I do this for each
#* wave. Understanding Society online variable documentation shows these two variables are mutually-exclusive:
AllWaves_Merge$b_NonEmpSpells_NAs <- AllWaves_Merge$b_nunmpsp_dv_NAs + AllWaves_Merge$b_nnmpsp_dv_NAs
AllWaves_Merge$c_NonEmpSpells_NAs <- AllWaves_Merge$c_nunmpsp_dv_NAs + AllWaves_Merge$c_nnmpsp_dv_NAs
AllWaves_Merge$d_NonEmpSpells_NAs <- AllWaves_Merge$d_nunmpsp_dv_NAs + AllWaves_Merge$d_nnmpsp_dv_NAs
AllWaves_Merge$e_NonEmpSpells_NAs <- AllWaves_Merge$e_nunmpsp_dv_NAs + AllWaves_Merge$e_nnmpsp_dv_NAs
AllWaves_Merge$f_NonEmpSpells_NAs <- AllWaves_Merge$f_nunmpsp_dv_NAs + AllWaves_Merge$f_nnmpsp_dv_NAs
AllWaves_Merge$g_NonEmpSpells_NAs <- AllWaves_Merge$g_nunmpsp_dv_NAs + AllWaves_Merge$g_nnmpsp_dv_NAs
AllWaves_Merge$h_NonEmpSpells_NAs <- AllWaves_Merge$h_nunmpsp_dv_NAs + AllWaves_Merge$h_nnmpsp_dv_NAs
AllWaves_Merge$i_NonEmpSpells_NAs <- AllWaves_Merge$i_nunmpsp_dv_NAs + AllWaves_Merge$i_nnmpsp_dv_NAs
AllWaves_Merge$j_NonEmpSpells_NAs <- AllWaves_Merge$j_nunmpsp_dv_NAs + AllWaves_Merge$j_nnmpsp_dv_NAs
AllWaves_Merge$k_NonEmpSpells_NAs <- AllWaves_Merge$k_nunmpsp_dv_NAs + AllWaves_Merge$k_nnmpsp_dv_NAs
AllWaves_Merge$l_NonEmpSpells_NAs <- AllWaves_Merge$l_nunmpsp_dv_NAs + AllWaves_Merge$l_nnmpsp_dv_NAs

#* Random checks [11.04.24] show this merge creates a negligible number of additional missings, because almost all 
#* of the missings for these variables already overlap:
length(which(is.na(AllWaves_Merge$b_nunmpsp_dv_NAs)))
length(which(is.na(AllWaves_Merge$b_nnmpsp_dv_NAs)))
length(which(is.na(AllWaves_Merge$b_NonEmpSpells_NAs)))
length(which(is.na(AllWaves_Merge$i_nunmpsp_dv_NAs)))
length(which(is.na(AllWaves_Merge$i_nnmpsp_dv_NAs)))
length(which(is.na(AllWaves_Merge$i_NonEmpSpells_NAs)))
length(which(is.na(AllWaves_Merge$l_nunmpsp_dv_NAs)))
length(which(is.na(AllWaves_Merge$l_nnmpsp_dv_NAs)))
length(which(is.na(AllWaves_Merge$l_NonEmpSpells_NAs)))

#* ----------------------------------------------------------------
#* -------------- [b - Create the indicators:]
#* ----------------------------------------------------------------

#* I now test the impact that missingness has on the indicators. This is used to inform my decision about which indicators I can reasonably
#* use, covering which time period. To do this I create several different indicators covering different time periods - all waves prior to the
#* wave interviewed (_allwaves); only the specific wave interviewed leading immediately up to the wave prior to that (_onewave); and the last 
#* two waves (_twowaves). For now the wave prefix (_a, b_, c_ e.t.c.) is retained. I only need to do this for every other wave.

#* Because of my prior coding I have an inclusionary and an exclusionary way of creating the indicators. The *exclusionary* (_excl) way ensures that 
#* anyone who is at any point NA will be coded as missing. It's a very rigorous way of excluding any missings whatsoever, but it will mean 
#* losing a lot of good data: someone with data in all waves except one would be coded as missing, for example. The *inclusionary* (_incl) way
#* converts missings to zero, so I only count the number of episodes of non-employment which respondents positively report. This too is very problematic. 

#* -------------- [b.1 - Non-employment spells, all waves:]  

AllWaves_Merge$d_NonEmpSpells_AllWaves_NAs <- AllWaves_Merge$b_NonEmpSpells_NAs + AllWaves_Merge$c_NonEmpSpells_NAs + 
  AllWaves_Merge$d_NonEmpSpells_NAs

AllWaves_Merge$f_NonEmpSpells_AllWaves_NAs <- AllWaves_Merge$b_NonEmpSpells_NAs + AllWaves_Merge$c_NonEmpSpells_NAs + 
  AllWaves_Merge$d_NonEmpSpells_NAs + AllWaves_Merge$e_NonEmpSpells_NAs + AllWaves_Merge$f_NonEmpSpells_NAs

AllWaves_Merge$h_NonEmpSpells_AllWaves_NAs <- AllWaves_Merge$b_NonEmpSpells_NAs + AllWaves_Merge$c_NonEmpSpells_NAs + 
  AllWaves_Merge$d_NonEmpSpells_NAs + AllWaves_Merge$e_NonEmpSpells_NAs + AllWaves_Merge$f_NonEmpSpells_NAs + 
  AllWaves_Merge$g_NonEmpSpells_NAs + AllWaves_Merge$h_NonEmpSpells_NAs

AllWaves_Merge$j_NonEmpSpells_AllWaves_NAs <- AllWaves_Merge$b_NonEmpSpells_NAs + AllWaves_Merge$c_NonEmpSpells_NAs + 
  AllWaves_Merge$d_NonEmpSpells_NAs + AllWaves_Merge$e_NonEmpSpells_NAs + AllWaves_Merge$f_NonEmpSpells_NAs + 
  AllWaves_Merge$g_NonEmpSpells_NAs + AllWaves_Merge$h_NonEmpSpells_NAs + AllWaves_Merge$i_NonEmpSpells_NAs + 
  AllWaves_Merge$j_NonEmpSpells_NAs

AllWaves_Merge$l_NonEmpSpells_AllWaves_NAs <- AllWaves_Merge$b_NonEmpSpells_NAs + AllWaves_Merge$c_NonEmpSpells_NAs + 
  AllWaves_Merge$d_NonEmpSpells_NAs + AllWaves_Merge$e_NonEmpSpells_NAs + AllWaves_Merge$f_NonEmpSpells_NAs + 
  AllWaves_Merge$g_NonEmpSpells_NAs + AllWaves_Merge$h_NonEmpSpells_NAs + AllWaves_Merge$i_NonEmpSpells_NAs + 
  AllWaves_Merge$j_NonEmpSpells_NAs + AllWaves_Merge$k_NonEmpSpells_NAs + AllWaves_Merge$l_NonEmpSpells_NAs

#* -------------- [b.2 - Non-employment spells, past two waves:]  

AllWaves_Merge$d_NonEmpSpells_TwoWaves_NAs <- AllWaves_Merge$c_NonEmpSpells_NAs + AllWaves_Merge$d_NonEmpSpells_NAs
AllWaves_Merge$f_NonEmpSpells_TwoWaves_NAs <- AllWaves_Merge$e_NonEmpSpells_NAs + AllWaves_Merge$f_NonEmpSpells_NAs
AllWaves_Merge$h_NonEmpSpells_TwoWaves_NAs <- AllWaves_Merge$g_NonEmpSpells_NAs + AllWaves_Merge$h_NonEmpSpells_NAs
AllWaves_Merge$j_NonEmpSpells_TwoWaves_NAs <- AllWaves_Merge$i_NonEmpSpells_NAs + AllWaves_Merge$j_NonEmpSpells_NAs
AllWaves_Merge$l_NonEmpSpells_TwoWaves_NAs <- AllWaves_Merge$k_NonEmpSpells_NAs + AllWaves_Merge$l_NonEmpSpells_NAs

#* -------------- [b.3 - Non-employment spells, one wave:]  

AllWaves_Merge$d_NonEmpSpells_OneWave_NAs <- AllWaves_Merge$d_NonEmpSpells_NAs
AllWaves_Merge$f_NonEmpSpells_OneWave_NAs <- AllWaves_Merge$f_NonEmpSpells_NAs
AllWaves_Merge$h_NonEmpSpells_OneWave_NAs <- AllWaves_Merge$h_NonEmpSpells_NAs
AllWaves_Merge$j_NonEmpSpells_OneWave_NAs <- AllWaves_Merge$j_NonEmpSpells_NAs
AllWaves_Merge$l_NonEmpSpells_OneWave_NAs <- AllWaves_Merge$l_NonEmpSpells_NAs

#* ----------------------------------------------------------------
#* -------------- [c - Merge the data into Dat:]
#* ----------------------------------------------------------------

#* I now need to merge the data into Dat. This requires the data to be converted back into long format. There are lots
#* of ways of doing this but the way I do it is as follows. The code for doing this is longer than e.g. if you use dplyr 
#* or other packages, but it's easier to follow and to spot mistakes (for example it allows me to be very transparent about
#* what the variable names are in each wave rather than letting the code do this for you, which can be problematic):

#* Separate non-emp spells data back out by wave: 
NonEmpSpells_W4 <- AllWaves_Merge |> select(pidp, d_NonEmpSpells_AllWaves_NAs, d_NonEmpSpells_TwoWaves_NAs, d_NonEmpSpells_OneWave_NAs)
NonEmpSpells_W6 <- AllWaves_Merge |> select(pidp, f_NonEmpSpells_AllWaves_NAs, f_NonEmpSpells_TwoWaves_NAs, f_NonEmpSpells_OneWave_NAs)
NonEmpSpells_W8 <- AllWaves_Merge |> select(pidp, h_NonEmpSpells_AllWaves_NAs, h_NonEmpSpells_TwoWaves_NAs, h_NonEmpSpells_OneWave_NAs)
NonEmpSpells_W10 <- AllWaves_Merge |> select(pidp, j_NonEmpSpells_AllWaves_NAs, j_NonEmpSpells_TwoWaves_NAs, j_NonEmpSpells_OneWave_NAs)
NonEmpSpells_W12 <- AllWaves_Merge |> select(pidp, l_NonEmpSpells_AllWaves_NAs, l_NonEmpSpells_TwoWaves_NAs, l_NonEmpSpells_OneWave_NAs)

#* I now remove the wave prefixes:
names(NonEmpSpells_W4) <- sub('d_', '', names(NonEmpSpells_W4))
names(NonEmpSpells_W6) <- sub('f_', '', names(NonEmpSpells_W6))
names(NonEmpSpells_W8) <- sub('h_', '', names(NonEmpSpells_W6))
names(NonEmpSpells_W10) <- sub('j_', '', names(NonEmpSpells_W10))
names(NonEmpSpells_W12) <- sub('l_', '', names(NonEmpSpells_W12))

#* Separate Dat out by year:
Dat_W4 <- filter(Dat$variables, year == "2012-13")
Dat_W6 <- filter(Dat$variables, year == "2014-15")
Dat_W8 <- filter(Dat$variables, year == "2016-17")
Dat_W10 <- filter(Dat$variables, year == "2018-19")
Dat_W12 <- filter(Dat$variables, year == "2020-21")
gc() 

#* Merge both dataframes together by pidp. Note that unlike the other merging process (see '0 - Data download.R'), 
#* this *must* be a left_join. Otherwise you introduce loads of NAs into the new data. You will know if the left_join
#* has worked properly just by double-checking that the number of observations in the below are the same as their respective
#* Dat_ prefixed data:
Dat_W4_I <- left_join(Dat_W4, NonEmpSpells_W4, by = "pidp")
Dat_W6_I <- left_join(Dat_W6, NonEmpSpells_W6, by = "pidp")
Dat_W8_I <- left_join(Dat_W8, NonEmpSpells_W8, by = "pidp")
Dat_W10_I <- left_join(Dat_W10, NonEmpSpells_W10, by = "pidp")
Dat_W12_I <- left_join(Dat_W12, NonEmpSpells_W12, by = "pidp")
rm(Dat_W4, Dat_W6, Dat_W8, Dat_W10, Dat_W12)
gc()

#* Merge into Dat$variables:
Dat$variables <- bind_rows(Dat_W4_I, Dat_W6_I, Dat_W8_I, Dat_W10_I, Dat_W12_I)
rm(Dat_W4_I, Dat_W6_I, Dat_W8_I, Dat_W10_I, Dat_W12_I)
gc()

#* Test [11.04.24] shows the data has merged into Dat correctly. I also create a variable which recodes the NAs as
#* minus 1s. The data shows that the best approach, sadly, is to just use the one-wave non-employment spells indicator,
#* as missingness gets very high (and naturally increases over the course of the time series) if you count the number of
#* times respondents are out of work across all the waves. With the one-wave indicator, you get the missingness down to 
#* just around 10% of respondents in the QoW index by Wave 12:
xtabs(~NonEmpSpells_AllWaves_NAs + year, Dat)
xtabs(~NonEmpSpells_TwoWaves_NAs + year, Dat)
xtabs(~NonEmpSpells_OneWave_NAs + year, Dat)
length(which(is.na(Dat$variables$NonEmpSpells_AllWaves_NAs)))
length(which(is.na(Dat$variables$NonEmpSpells_TwoWaves_NAs)))
length(which(is.na(Dat$variables$NonEmpSpells_OneWave_NAs)))

Dat$variables$NonEmpSpells_AllWaves <- Dat$variables$NonEmpSpells_AllWaves_NAs <- 
  case_when(is.na(Dat$variables$NonEmpSpells_AllWaves_NAs) ~ -1, TRUE ~ as.numeric(as.character(Dat$variables$NonEmpSpells_AllWaves_NAs)))
Dat$variables$NonEmpSpells_TwoWaves <- Dat$variables$NonEmpSpells_TwoWaves_NAs <- 
  case_when(is.na(Dat$variables$NonEmpSpells_TwoWaves_NAs) ~ -1, TRUE ~ as.numeric(as.character(Dat$variables$NonEmpSpells_TwoWaves_NAs)))
Dat$variables$NonEmpSpells_OneWave <- Dat$variables$NonEmpSpells_OneWaves_NAs <- 
  case_when(is.na(Dat$variables$NonEmpSpells_OneWave_NAs) ~ -1, TRUE ~ as.numeric(as.character(Dat$variables$NonEmpSpells_OneWave_NAs)))
svytable(~NonEmpSpells_AllWaves + year, Dat) |> prop.table(2) |> round(3)
svytable(~NonEmpSpells_TwoWaves + year, Dat)  |> prop.table(2) |> round(3)
svytable(~NonEmpSpells_OneWave + year, Dat) |> prop.table(2) |> round(3)
svytable(~NonEmpSpells_AllWaves + year, JQ) |> prop.table(2) |> round(3)
svytable(~NonEmpSpells_TwoWaves + year, JQ) |> prop.table(2) |> round(3)
svytable(~NonEmpSpells_OneWave + year, JQ) |> prop.table(2) |> round(3)

#* Saved the above as of [11.04.24]:
# saveRDS(Dat, file = "0 - Dat.RData")

#######################################################################################
################## 2 - Highest and lowest QoW score over time series: #################
#######################################################################################

#* ----------------------------------------------------------------
#* -------------- [a - Prepare the data:]
#* ----------------------------------------------------------------

#* To calculate this I first create a filtered version of Dat which consists purely of QoW 
#* index membership (to identify the non-employed), year, and the JQ index score: 
Dat_Filter <- Dat$variables |> select(pidp, QoW_Index_Member, year, JQ_Index_AF_Score)

#* The below code shows that most of the NAs for the JQ score are caused by not being in 
#* work in that specific wave, so are solveable: 
length(which(is.na(Dat_Filter$JQ_Index_AF_Score)))
length(which(is.na(Dat_Filter$QoW_Index_Member)))
Dat_Filter$JQ_Index_AF_Score_Missing <- case_when(is.na(Dat_Filter$JQ_Index_AF_Score) ~ 1,
                                               TRUE ~ 0)
xtabs(~QoW_Index_Member + JQ_Index_AF_Score_Missing, Dat_Filter)

#* Separate out by year:
Dat_W4 <- filter(Dat_Filter, year == "2012-13")
Dat_W6 <- filter(Dat_Filter, year == "2014-15")
Dat_W8 <- filter(Dat_Filter, year == "2016-17")
Dat_W10 <- filter(Dat_Filter, year == "2018-19")
Dat_W12 <- filter(Dat_Filter, year == "2020-21")
gc() 

#* Rename the variables with an appropriate prefix, and remove the year from each data frame now 
#* it's not needed:
Dat_W4 <- Dat_W4 |> rename(d_QoW_Index_Member = QoW_Index_Member, 
                           d_JQ_Index_AF_Score = JQ_Index_AF_Score)
Dat_W6 <- Dat_W6 |> rename(f_QoW_Index_Member = QoW_Index_Member, 
                           f_JQ_Index_AF_Score = JQ_Index_AF_Score)
Dat_W8 <- Dat_W8 |> rename(h_QoW_Index_Member = QoW_Index_Member, 
                           h_JQ_Index_AF_Score = JQ_Index_AF_Score)
Dat_W10 <- Dat_W10 |> rename(j_QoW_Index_Member = QoW_Index_Member, 
                           j_JQ_Index_AF_Score = JQ_Index_AF_Score)
Dat_W12 <- Dat_W12 |> rename(l_QoW_Index_Member = QoW_Index_Member, 
                           l_JQ_Index_AF_Score = JQ_Index_AF_Score)
Dat_W4 <- Dat_W4 |> select(pidp, d_QoW_Index_Member, d_JQ_Index_AF_Score)
Dat_W6 <- Dat_W6 |> select(pidp, f_QoW_Index_Member, f_JQ_Index_AF_Score)
Dat_W8 <- Dat_W8 |> select(pidp, h_QoW_Index_Member, h_JQ_Index_AF_Score)
Dat_W10 <- Dat_W10 |> select(pidp, j_QoW_Index_Member, j_JQ_Index_AF_Score)
Dat_W12 <- Dat_W12 |> select(pidp, l_QoW_Index_Member, l_JQ_Index_AF_Score)

#* Make people zero rather than NA if they're not in paid work in the time of interview:
Dat_W4$d_JQ_Index_AF_Score_NonWorkZero <- case_when(Dat_W4$d_QoW_Index_Member == 0 ~ 0, 
                                                    TRUE ~ as.numeric(as.character(Dat_W4$d_JQ_Index_AF_Score)))
Dat_W6$f_JQ_Index_AF_Score_NonWorkZero <- case_when(Dat_W6$f_QoW_Index_Member == 0 ~ 0, 
                                                    TRUE ~ as.numeric(as.character(Dat_W6$f_JQ_Index_AF_Score)))
Dat_W8$h_JQ_Index_AF_Score_NonWorkZero <- case_when(Dat_W8$h_QoW_Index_Member == 0 ~ 0, 
                                                    TRUE ~ as.numeric(as.character(Dat_W8$h_JQ_Index_AF_Score)))
Dat_W10$j_JQ_Index_AF_Score_NonWorkZero <- case_when(Dat_W10$j_QoW_Index_Member == 0 ~ 0, 
                                                    TRUE ~ as.numeric(as.character(Dat_W10$j_JQ_Index_AF_Score)))
Dat_W12$l_JQ_Index_AF_Score_NonWorkZero <- case_when(Dat_W12$l_QoW_Index_Member == 0 ~ 0, 
                                                    TRUE ~ as.numeric(as.character(Dat_W12$l_JQ_Index_AF_Score)))

#* Then turn into wide format:
Dat_Wide <- full_join(Dat_W12, Dat_W10, by = "pidp")
Dat_Wide <- full_join(Dat_Wide, Dat_W8, by = "pidp")
Dat_Wide <- full_join(Dat_Wide, Dat_W6, by = "pidp")
Dat_Wide <- full_join(Dat_Wide, Dat_W4, by = "pidp")

#* ----------------------------------------------------------------
#* -------------- [b - Create preliminary indicators:]
#* ----------------------------------------------------------------

#* I first need to create a set of preliminary indicators before adjusting them/amending them and making a decision about how 
#* exclusive/inclusive I want to be about missing values across waves.

#* I create two versions of the indicators, an *exclusive* and *inclusive* one. The exclusive one will code anyone as
#* NA if they don't respond in any *one* wave for the variable, whereas the inclusive one will simply take the highest/lowest
#* of all available data and ignore the NAs:
Dat_Wide <- Dat_Wide |> rowwise() |> mutate(Max_JQ_Incl = max(d_JQ_Index_AF_Score_NonWorkZero, f_JQ_Index_AF_Score_NonWorkZero, 
                                                 h_JQ_Index_AF_Score_NonWorkZero, j_JQ_Index_AF_Score_NonWorkZero,
                                                 l_JQ_Index_AF_Score_NonWorkZero, na.rm = TRUE))
Dat_Wide <- Dat_Wide |> rowwise() |> mutate(Max_JQ_Excl = max(d_JQ_Index_AF_Score_NonWorkZero, f_JQ_Index_AF_Score_NonWorkZero, 
                                                      h_JQ_Index_AF_Score_NonWorkZero, j_JQ_Index_AF_Score_NonWorkZero,
                                                      l_JQ_Index_AF_Score_NonWorkZero))
Dat_Wide <- Dat_Wide |> rowwise() |> mutate(Min_JQ_Incl = min(d_JQ_Index_AF_Score_NonWorkZero, f_JQ_Index_AF_Score_NonWorkZero, 
                                                              h_JQ_Index_AF_Score_NonWorkZero, j_JQ_Index_AF_Score_NonWorkZero,
                                                              l_JQ_Index_AF_Score_NonWorkZero, na.rm = TRUE))
Dat_Wide <- Dat_Wide |> rowwise() |> mutate(Min_JQ_Excl = min(d_JQ_Index_AF_Score_NonWorkZero, f_JQ_Index_AF_Score_NonWorkZero, 
                                                              h_JQ_Index_AF_Score_NonWorkZero, j_JQ_Index_AF_Score_NonWorkZero,
                                                              l_JQ_Index_AF_Score_NonWorkZero))

Dat_Wide <- Dat_Wide |> rowwise() |> mutate(Max_JQ_Incl_nononwork = max(d_JQ_Index_AF_Score, f_JQ_Index_AF_Score, 
                                                              h_JQ_Index_AF_Score, j_JQ_Index_AF_Score,
                                                              l_JQ_Index_AF_Score, na.rm = TRUE))
Dat_Wide <- Dat_Wide |> rowwise() |> mutate(Max_JQ_Excl_nononwork = max(d_JQ_Index_AF_Score, f_JQ_Index_AF_Score, 
                                                              h_JQ_Index_AF_Score, j_JQ_Index_AF_Score,
                                                              l_JQ_Index_AF_Score))
Dat_Wide <- Dat_Wide |> rowwise() |> mutate(Min_JQ_Incl_nononwork = min(d_JQ_Index_AF_Score, f_JQ_Index_AF_Score, 
                                                              h_JQ_Index_AF_Score, j_JQ_Index_AF_Score,
                                                              l_JQ_Index_AF_Score, na.rm = TRUE))
Dat_Wide <- Dat_Wide |> rowwise() |> mutate(Min_JQ_Excl_nononwork = min(d_JQ_Index_AF_Score, f_JQ_Index_AF_Score, 
                                                              h_JQ_Index_AF_Score, j_JQ_Index_AF_Score,
                                                              l_JQ_Index_AF_Score))

length(which(is.infinite(Dat_Wide$QoW_Range_Excl_nononwork)))
length(which(is.na(Dat_Wide$QoW_Range_Excl_nononwork)))
length(which(is.na(Dat_Wide$QoW_Range_Excl)))

#* I also replace the infinite and minus infinite values with NA. These are created in cases where I've not selected na.rm
#* and the only values are NA:
Dat_Wide[sapply(Dat_Wide, is.infinite)] <- NA 

#* I then create a variable for number of waves interviewed in. There are lots of ways to do this but the simplest, though not
#* the most elegant, is to simply temporarily create versions of the relevant JQ index score variables which are zero if NA and 1
#* if a number (including zero), and then add them together at the end:  
Dat_Wide$d_JQ_Index_AF_Score_NonWorkZero_NonMissing <- case_when(Dat_Wide$d_JQ_Index_AF_Score_NonWorkZero >= 0 ~ 1,
                                                                 is.na(Dat_Wide$d_JQ_Index_AF_Score_NonWorkZero) ~ 0)
Dat_Wide$f_JQ_Index_AF_Score_NonWorkZero_NonMissing <- case_when(Dat_Wide$f_JQ_Index_AF_Score_NonWorkZero >= 0 ~ 1,
                                                                 is.na(Dat_Wide$f_JQ_Index_AF_Score_NonWorkZero) ~ 0)
Dat_Wide$h_JQ_Index_AF_Score_NonWorkZero_NonMissing <- case_when(Dat_Wide$h_JQ_Index_AF_Score_NonWorkZero >= 0 ~ 1,
                                                                 is.na(Dat_Wide$h_JQ_Index_AF_Score_NonWorkZero) ~ 0)
Dat_Wide$j_JQ_Index_AF_Score_NonWorkZero_NonMissing <- case_when(Dat_Wide$j_JQ_Index_AF_Score_NonWorkZero >= 0 ~ 1,
                                                                 is.na(Dat_Wide$j_JQ_Index_AF_Score_NonWorkZero) ~ 0)
Dat_Wide$l_JQ_Index_AF_Score_NonWorkZero_NonMissing <- case_when(Dat_Wide$l_JQ_Index_AF_Score_NonWorkZero >= 0 ~ 1,
                                                                 is.na(Dat_Wide$l_JQ_Index_AF_Score_NonWorkZero) ~ 0)
Dat_Wide$WavesInterviewed_Num <- Dat_Wide$d_JQ_Index_AF_Score_NonWorkZero_NonMissing + Dat_Wide$f_JQ_Index_AF_Score_NonWorkZero_NonMissing + 
  Dat_Wide$h_JQ_Index_AF_Score_NonWorkZero_NonMissing + Dat_Wide$j_JQ_Index_AF_Score_NonWorkZero_NonMissing + Dat_Wide$l_JQ_Index_AF_Score_NonWorkZero_NonMissing

#* Tests [12.04.24] show that a surprisingly high proportion of respondents have QoW data for all for five waves, but after that the
#* second highest is people who've been interviewed for just one wave. Consistent with what would be expected everyone who's been 
#* interviewed for one wave has a difference of 0 between their highest and lowest QoW score, but a surprisingly large number of people
#* have the exact same QoW score across several waves. To test the veracity of this I create a dataframe which consists only of people
#* who are (a) interviewed for more than 1 wave and (b) have a difference in QoW of zero. This sub-group seems to consist entirely of
#* people who were either always out of work, or who reported NA data for their QoW at every wave: 
xtabs(~WavesInterviewed_Num, Dat_Wide)

#* I also create dummy variables for whether NA *and* in the QoW index in each given wave, as this consists of people who have missing 
#* job quality data (even despite the imputation) and who we can't infer a job quality score for. This later needs to be accounted for when
#* deciding whether their data is missing or not, as we can't treat these NAs the same as other NAs. The cross-tabs show this affects a small
#* but important number of respondents, and grows as the time series goes on:
Dat_Wide$d_JQ_Score_Missing <- case_when(is.na(Dat_Wide$d_JQ_Index_AF_Score) & Dat_Wide$d_QoW_Index_Member == 1 ~ 1, TRUE ~ 0)
Dat_Wide$f_JQ_Score_Missing <- case_when(is.na(Dat_Wide$f_JQ_Index_AF_Score) & Dat_Wide$f_QoW_Index_Member == 1 ~ 1, TRUE ~ 0)
Dat_Wide$h_JQ_Score_Missing <- case_when(is.na(Dat_Wide$h_JQ_Index_AF_Score) & Dat_Wide$h_QoW_Index_Member == 1 ~ 1, TRUE ~ 0)
Dat_Wide$j_JQ_Score_Missing <- case_when(is.na(Dat_Wide$j_JQ_Index_AF_Score) & Dat_Wide$j_QoW_Index_Member == 1 ~ 1, TRUE ~ 0)
Dat_Wide$l_JQ_Score_Missing <- case_when(is.na(Dat_Wide$l_JQ_Index_AF_Score) & Dat_Wide$l_QoW_Index_Member == 1 ~ 1, TRUE ~ 0)
xtabs(~d_JQ_Score_Missing,Dat_Wide)  
xtabs(~f_JQ_Score_Missing,Dat_Wide)  
xtabs(~h_JQ_Score_Missing,Dat_Wide)    
xtabs(~j_JQ_Score_Missing,Dat_Wide)  
xtabs(~l_JQ_Score_Missing,Dat_Wide)  

Dat_Wide$Num_JQ_Score_Missing <- Dat_Wide$d_JQ_Score_Missing + Dat_Wide$f_JQ_Score_Missing + Dat_Wide$h_JQ_Score_Missing +
  Dat_Wide$j_JQ_Score_Missing + Dat_Wide$l_JQ_Score_Missing

xtabs(~WavesInterviewed_Num + Num_JQ_Score_Missing, Dat_Wide)

#* Finally I create dummies for the number of waves the respondent has QoW scores in: 
Dat_Wide$d_JQ_Score_has <- case_when(is.na(Dat_Wide$d_JQ_Index_AF_Score) ~ 0, Dat_Wide$d_JQ_Index_AF_Score == 0 ~ 0, TRUE ~ 1)
Dat_Wide$f_JQ_Score_has <- case_when(is.na(Dat_Wide$f_JQ_Index_AF_Score) ~ 0, Dat_Wide$f_JQ_Index_AF_Score == 0 ~ 0, TRUE ~ 1)
Dat_Wide$h_JQ_Score_has <- case_when(is.na(Dat_Wide$h_JQ_Index_AF_Score) ~ 0, Dat_Wide$h_JQ_Index_AF_Score == 0 ~ 0, TRUE ~ 1)
Dat_Wide$j_JQ_Score_has <- case_when(is.na(Dat_Wide$j_JQ_Index_AF_Score) ~ 0, Dat_Wide$j_JQ_Index_AF_Score == 0 ~ 0, TRUE ~ 1)
Dat_Wide$l_JQ_Score_has <- case_when(is.na(Dat_Wide$l_JQ_Index_AF_Score) ~ 0, Dat_Wide$l_JQ_Index_AF_Score == 0 ~ 0, TRUE ~ 1)

Dat_Wide$Num_JQ_Score_has <- Dat_Wide$d_JQ_Score_has + Dat_Wide$f_JQ_Score_has + Dat_Wide$h_JQ_Score_has +
  Dat_Wide$j_JQ_Score_has + Dat_Wide$l_JQ_Score_has

#* ----------------------------------------------------------------
#* -------------- [c - Create final indicators:]
#* ----------------------------------------------------------------

#* The above new variables allow me to create a more refined version of the inclusive version of the max and min JQ variables, which exclude 
#* anyone who's interviewed for only one wave, who has no job quality data for any of their waves or only provides job quality data in one
#* wave:
Dat_Wide$Max_JQ_Incl_NAs <- case_when(Dat_Wide$WavesInterviewed_Num <= 1 ~ NA, 
                                      Dat_Wide$WavesInterviewed_Num <= Dat_Wide$Num_JQ_Score_Missing ~ NA, 
                                      TRUE ~ as.numeric(as.character(Dat_Wide$Max_JQ_Incl)))
Dat_Wide$Min_JQ_Incl_NAs <- case_when(Dat_Wide$WavesInterviewed_Num <= 1 ~ NA, 
                                      Dat_Wide$WavesInterviewed_Num <= Dat_Wide$Num_JQ_Score_Missing ~ NA, 
                                      TRUE ~ as.numeric(as.character(Dat_Wide$Min_JQ_Incl)))
length(which(is.na(Dat_Wide$Max_JQ_Incl_NAs)))
length(which(is.na(Dat_Wide$Min_JQ_Incl_NAs)))

Dat_Wide$Max_JQ_Incl_NAs_nononwork <- case_when(Dat_Wide$WavesInterviewed_Num <= 1 ~ NA, 
                                                Dat_Wide$Num_JQ_Score_has == 1 ~ NA,
                                                Dat_Wide$WavesInterviewed_Num <= Dat_Wide$Num_JQ_Score_Missing ~ NA, 
                                      TRUE ~ as.numeric(as.character(Dat_Wide$Max_JQ_Incl_nononwork)))
Dat_Wide$Min_JQ_Incl_NAs_nononwork <- case_when(Dat_Wide$WavesInterviewed_Num <= 1 ~ NA, 
                                                Dat_Wide$Num_JQ_Score_has == 1 ~ NA,
                                                Dat_Wide$WavesInterviewed_Num <= Dat_Wide$Num_JQ_Score_Missing ~ NA, 
                                      TRUE ~ as.numeric(as.character(Dat_Wide$Min_JQ_Incl_nononwork)))
length(which(is.na(Dat_Wide$Max_JQ_Incl_NAs_nononwork)))
length(which(is.na(Dat_Wide$Min_JQ_Incl_NAs_nononwork)))

#* I now [12.04.24] check to see how many in the QoW index specifically in Wave 12 are missing for this data. The data show that only a small
#* proportion (~8%) of respondents in work in Wave 12 have missing data for this indicator. I check this in two ways and the sums add up to the
#* same amount, as they should do:
Dat_Wide$Max_JQ_Incl_NAs_Missing <- case_when(is.na(Dat_Wide$Max_JQ_Incl_NAs) ~ 1, TRUE ~ 0)
Dat_Wide$Min_JQ_Incl_NAs_Missing <- case_when(is.na(Dat_Wide$Min_JQ_Incl_NAs) ~ 1, TRUE ~ 0)
Dat_Wide$Max_JQ_Incl_NAs_nononwork_Missing <- case_when(is.na(Dat_Wide$Max_JQ_Incl_NAs_nononwork) ~ 1, TRUE ~ 0)
Dat_Wide$Min_JQ_Incl_NAs_nononwork_Missing <- case_when(is.na(Dat_Wide$Min_JQ_Incl_NAs_nononwork) ~ 1, TRUE ~ 0)
xtabs(~l_QoW_Index_Member + Max_JQ_Incl_NAs_Missing, Dat_Wide)
xtabs(~l_QoW_Index_Member + Min_JQ_Incl_NAs_Missing, Dat_Wide)
xtabs(~l_QoW_Index_Member + Max_JQ_Incl_NAs_nononwork_Missing, Dat_Wide)
xtabs(~l_QoW_Index_Member + Min_JQ_Incl_NAs_nononwork_Missing, Dat_Wide)

#* Test [22.04.24] for the data:
Dat_Wide$JQ_Diff <- Dat_Wide$Max_JQ_Incl_NAs_nononwork - Dat_Wide$Min_JQ_Incl_NAs_nononwork
Test <- Dat_Wide |> select(Max_JQ_Incl_NAs_nononwork, Min_JQ_Incl_NAs_nononwork, WavesInterviewed_Num, Num_JQ_Score_Missing, JQ_Diff,
                           d_JQ_Index_AF_Score, f_JQ_Index_AF_Score, h_JQ_Index_AF_Score, j_JQ_Index_AF_Score, l_JQ_Index_AF_Score, 
                           d_QoW_Index_Member, f_QoW_Index_Member, h_QoW_Index_Member, j_QoW_Index_Member, l_QoW_Index_Member, Num_JQ_Score_has)

Dat_Wide_Filter <- Dat_Wide |> filter(l_QoW_Index_Member == 1 | l_QoW_Index_Member == 0)
length(which(is.na(Dat_Wide_Filter$Max_JQ_Incl_NAs)))
rm(Dat_Wide_Filter)

#* ----------------------------------------------------------------
#* -------------- [d - Save data and reintroduce into Dat:]
#* ----------------------------------------------------------------

#* The process for introducing these into Dat is very similar as for non-employment spells, but with one extremely important difference: *in each*
#* *wave, respondents with the same personal identifier (pidp) will have the exact same scores on this indicator.* This is the only variable in
#* the entire dataset at the time of writing [12.04.24] that has this property. Analysts should exercise due caution when using it: it is best
#* for single-wave analysis rather than any time series analysis.

#* Separate Dat out by year again:
Dat_W4 <- filter(Dat$variables, year == "2012-13")
Dat_W6 <- filter(Dat$variables, year == "2014-15")
Dat_W8 <- filter(Dat$variables, year == "2016-17")
Dat_W10 <- filter(Dat$variables, year == "2018-19")
Dat_W12 <- filter(Dat$variables, year == "2020-21")
gc() 

#* Filter the wide version of Dat to only the variables I need:
Dat_Wide_Filter <- Dat_Wide |> select(pidp, WavesInterviewed_Num, Num_JQ_Score_Missing, 
                                      Max_JQ_Incl_NAs_Missing, Min_JQ_Incl_NAs_Missing,
                                      Max_JQ_Incl_NAs, Min_JQ_Incl_NAs,
                                      Max_JQ_Excl, Min_JQ_Excl,
                                      Max_JQ_Incl_NAs_nononwork, Min_JQ_Incl_NAs_nononwork,
                                      Max_JQ_Excl_nononwork, Min_JQ_Excl_nononwork,
                                      Max_JQ_Incl_NAs_nononwork_Missing, 
                                      Min_JQ_Incl_NAs_nononwork_Missing,
                                      Max_JQ_Incl_NAs_nononwork, Min_JQ_Incl_NAs_nononwork,
                                      Max_JQ_Excl_nononwork, Min_JQ_Excl_nononwork,
                                      Max_JQ_Incl_NAs_nononwork_Missing, 
                                      Min_JQ_Incl_NAs_nononwork_Missing)

#* Then merge this into each of the waves. Because this is a left_join, the number of observations should remain exactly the same as they are in
#* Dat_W4, Dat_W6, e.t.c. If they aren't then something has gone wrong:
Dat_W4_Merge <- left_join(Dat_W4, Dat_Wide_Filter, by = "pidp")
Dat_W6_Merge <- left_join(Dat_W6, Dat_Wide_Filter, by = "pidp")
Dat_W8_Merge <- left_join(Dat_W8, Dat_Wide_Filter, by = "pidp")
Dat_W10_Merge <- left_join(Dat_W10, Dat_Wide_Filter, by = "pidp")
Dat_W12_Merge <- left_join(Dat_W12, Dat_Wide_Filter, by = "pidp")

#* Random tests [12.04.24] below show the summary stats are consistent here:
xtabs(~l_QoW_Index_Member + Max_JQ_Incl_NAs_Missing, Dat_Wide)
xtabs(~l_QoW_Index_Member + Min_JQ_Incl_NAs_Missing, Dat_Wide)
xtabs(~QoW_Index_Member + Max_JQ_Incl_NAs_Missing, Dat_W12_Merge)
xtabs(~QoW_Index_Member + Min_JQ_Incl_NAs_Missing, Dat_W12_Merge)

xtabs(~d_QoW_Index_Member + Max_JQ_Incl_NAs_Missing, Dat_Wide)
xtabs(~d_QoW_Index_Member + Min_JQ_Incl_NAs_Missing, Dat_Wide)
xtabs(~QoW_Index_Member + Max_JQ_Incl_NAs_Missing, Dat_W4_Merge)
xtabs(~QoW_Index_Member + Min_JQ_Incl_NAs_Missing, Dat_W4_Merge)

xtabs(~d_QoW_Index_Member + Max_JQ_Incl_NAs_nononwork_Missing, Dat_Wide)
xtabs(~d_QoW_Index_Member + Min_JQ_Incl_NAs_nononwork_Missing, Dat_Wide)
xtabs(~QoW_Index_Member + Max_JQ_Incl_NAs_nononwork_Missing, Dat_W12_Merge)
xtabs(~QoW_Index_Member + Min_JQ_Incl_NAs_nononwork_Missing, Dat_W12_Merge)

#* Merge into the original Dat file:
rm(Dat_W4, Dat_W6, Dat_W8, Dat_W10, Dat_W12)
rm(Dat_Wide, Dat_Wide_Filter)
gc()
Dat$variables <- bind_rows(Dat_W4_Merge, Dat_W6_Merge, Dat_W8_Merge, Dat_W10_Merge, Dat_W12_Merge)

#* Test [12.04.24] for identical data works. The data also shows a fairly strong correlation between
#* minimum and maximum QoW scores, although more analysis is needed here and I'd also want to control for 
#* e.g. age factors:
svytable(~scsf3a + year, Dat)
svytable(~Ind_Pension_Imp + year, Dat)
svytable(~Ind_EarningsEquity_Imp + year, Dat)
svytable(~WavesInterviewed_Num + year, Dat)
svytable(~Max_JQ_Incl_NAs + year, Dat)
svytable(~Min_JQ_Incl_NAs + year, Dat)
svytable(~Min_JQ_Incl_NAs + year, Dat)
svytable(~Max_JQ_Incl_NAs_Missing + year, Dat)
svytable(~Max_JQ_Incl_NAs_Missing + year, JQ)
svycor(~Max_JQ_Incl_NAs + Min_JQ_Incl_NAs, JQ, na.rm = TRUE, digits = 7)

#* Saved the above as of [22.04.24]:
saveRDS(Dat, file = "0 - Dat.RData")
