
#######################################################################################
#################### 1 - Economic capital - Create indicators #########################
#######################################################################################

#* ----------------------------------------------------------------
#* -------------- [EC.1 - Percentile distribution of other equivalised household earnings (excl. individual earnings and social benefits):]
#* ----------------------------------------------------------------

#* To calculate this, I start by taking total net household income and deducting the specific individual respondent's 
#* net labour earnings from it. In Understanding Society the variable fihhmnnet1_dv captures household income from
#* all sources.[1] 

#* Start by recoding the household income variable missings e.t.c as NAs: 
length(which(Dat$variables$fihhmnnet1_dv < 0))
length(which(Dat$variables$fihhmnnet1_dv == -9))
length(which(Dat$variables$fihhmnsben_dv < 0))
length(which(Dat$variables$fihhmnsben_dv == -9))
Dat$variables$fihhmnnet1_dv_adj <- replace(Dat$variables$fihhmnnet1_dv, 
                                           Dat$variables$fihhmnnet1_dv %in% c(-9, -8, -2, -1), NA)
Dat$variables$fihhmnsben_dv_adj <- replace(Dat$variables$fihhmnsben_dv, 
                                           Dat$variables$fihhmnsben_dv %in% c(-9, -8, -2, -1), NA)

#* I then calculate household net income, deducting individual labour earnings and social benefits. To ease intelligibility 
#* I present this in annualised form. A quick test [20.04.24] finds that in virtually all cases household income is higher than 
#* labour income, but there are  a tiny number of instances where this isn't the case. Because social benefit income isn't net 
#* there are many more cases where deducting this puts values into the negative bracket. This, again, makes logical sense. Before
#* making these deductions, it's extremely important to convert negatives to zeros. Otherwise you create artificial data (e.g. deducting
#* two negatives from each other, and then deducting a positive value). Either that or you'll have to create a case_when statement with lots
#* of conditions to inform your deductions. When complete I also convert all negatives to zeros in the final variable (HHNetInc_ExclInd_Annual)
#* too, because some have been created from deducting a positive social benefit income from a zero income: 

Dat$variables$fihhmnnet1_dv_adj_annual <- Dat$variables$fihhmnnet1_dv_adj * 12 
Dat$variables$fihhmnsben_dv_adj_annual <- Dat$variables$fihhmnsben_dv_adj * 12
Dat$variables$fihhmnnet1_annadj <- case_when(Dat$variables$fihhmnnet1_dv_adj_annual < 0 ~ 0, TRUE ~ as.numeric(as.character(Dat$variables$fihhmnnet1_dv_adj_annual)))
Dat$variables$fimnlabnet_annadj <- case_when(Dat$variables$fimnlabnet_dv_annual < 0 ~ 0, TRUE ~ as.numeric(as.character(Dat$variables$fimnlabnet_dv_annual)))
Dat$variables$fihhmnsben_annadj <- case_when(Dat$variables$fihhmnsben_dv_adj_annual < 0 ~ 0, TRUE ~ as.numeric(as.character(Dat$variables$fihhmnsben_dv_adj_annual)))

Dat$variables$HHNetInc_ExclInd_Annual <- (Dat$variables$fihhmnnet1_annadj - Dat$variables$fimnlabnet_annadj) - Dat$variables$fihhmnsben_annadj
Dat$variables$HHNetInc_ExclInd_Annual <- case_when(Dat$variables$HHNetInc_ExclInd_Annual < 0 ~ 0, TRUE ~ as.numeric(as.character(Dat$variables$HHNetInc_ExclInd_Annual)))

length(which(Dat$variables$fihhmnnet1_annadj < 0))
length(which(Dat$variables$fimnlabnet_annadj < 0))
length(which(Dat$variables$fihhmnsben_annadj < 0))
length(which(Dat$variables$HHNetInc_ExclInd_Annual < 0))

#* Then equivalise by household income. Before doing this I also adjust the OECD equivalised figure to convert any missing values to NAs: 
length(which(Dat$variables$ieqmoecd_dv < 0))
length(which(Dat$variables$ieqmoecd_dv < 1))
Dat$variables$ieqmoecd_dv_adj <- replace(Dat$variables$ieqmoecd_dv, 
                                         Dat$variables$ieqmoecd_dv %in% c(-9, -8, -7, -2, -1), NA)
Dat$variables$HHNetInc_ExclInd_Annual_OECDEquiv <- Dat$variables$HHNetInc_ExclInd_Annual / Dat$variables$ieqmoecd_dv_adj
summary(Dat$variables$HHNetInc_ExclInd_Annual_OECDEquiv)

#* Having done this, I create an indicator which provides the percentile of each individual's other household earnings in the distribution. Note that 
#* I have to do this manually and separately for every wave in the data. The standard formula for this is: P = (n/N) * 100. 
#* Where n is the number of data points below the point of interest, and N is the total number of data points in the dataset. In my 
#* case the * 100 element isn't needed. 

#* I calculate n for each wave by simply calculating the rank value. It's important to keep NAs in the data, and to follow a "min" approach to dealing
#* with tied values:
Wave4 <- Dat |> filter(DV_Time_Wave4 == 1)
Wave6 <- Dat |> filter(DV_Time_Wave6 == 1)
Wave8 <- Dat |> filter(DV_Time_Wave8 == 1)
Wave10 <- Dat |> filter(DV_Time_Wave10 == 1)
Wave12 <- Dat |> filter(DV_Time_Wave12 == 1)
Wave4$variables$HHNetInc_rank <- rank(Wave4$variables$HHNetInc_ExclInd_Annual_OECDEquiv, na.last = "keep", ties.method = "min")
Wave6$variables$HHNetInc_rank <- rank(Wave6$variables$HHNetInc_ExclInd_Annual_OECDEquiv, na.last = "keep", ties.method = "min")
Wave8$variables$HHNetInc_rank <- rank(Wave8$variables$HHNetInc_ExclInd_Annual_OECDEquiv, na.last = "keep", ties.method = "min")
Wave10$variables$HHNetInc_rank <- rank(Wave10$variables$HHNetInc_ExclInd_Annual_OECDEquiv, na.last = "keep", ties.method = "min")
Wave12$variables$HHNetInc_rank <- rank(Wave12$variables$HHNetInc_ExclInd_Annual_OECDEquiv, na.last = "keep", ties.method = "min")

#* Tests for the data [20.04.24] show it's doing what I want it to. The rank minus 1 gives you the number of values below the data of interest. This isn't
#* always the same as the number of data points below this, as obviously there are cases where several values share the same rank. The
# summary(Wave4$variables$HHNetInc_rank)
# Test <- Wave4$variables |> select(HHNetInc_ExclInd_Annual_OECDEquiv, HHNetInc_rank) |> as.data.frame()
# length(which(Test$HHNetInc_rank < 35276))
# max(Wave4$variables$HHNetInc_rank, na.rm = TRUE)
# rm(Test)
# summary(Wave12$variables$HHNetInc_rank)
# Test <- Wave12$variables |> select(HHNetInc_ExclInd_Annual_OECDEquiv, HHNetInc_rank) |> as.data.frame()
# length(which(Test$HHNetInc_rank < 1234))
# max(Wave12$variables$HHNetInc_rank, na.rm = TRUE)
# rm(Test)

#* I'm now equipped with all the info I need to create the variable for every wave. n (lower case) is HHNetInc_rank minus 1, whilst N (upper case)
#* is the maximum value of HHNetInc_rank. It's easiest to do this separately by wave and then to merge it into the dataset later on: 
Wave4$variables$CS_EC1_EquivHHEarnings <- ((Wave4$variables$HHNetInc_rank - 1) / max(Wave4$variables$HHNetInc_rank, na.rm = TRUE))
Wave6$variables$CS_EC1_EquivHHEarnings <- ((Wave6$variables$HHNetInc_rank - 1) / max(Wave6$variables$HHNetInc_rank, na.rm = TRUE))
Wave8$variables$CS_EC1_EquivHHEarnings <- ((Wave8$variables$HHNetInc_rank - 1) / max(Wave8$variables$HHNetInc_rank, na.rm = TRUE))
Wave10$variables$CS_EC1_EquivHHEarnings <- ((Wave10$variables$HHNetInc_rank - 1) / max(Wave10$variables$HHNetInc_rank, na.rm = TRUE))
Wave12$variables$CS_EC1_EquivHHEarnings <- ((Wave12$variables$HHNetInc_rank - 1) / max(Wave12$variables$HHNetInc_rank, na.rm = TRUE))

#* Merge the data back into Dat, first by selecting only the variables I want to merge in each wave: 
Wave4_merge <- Wave4$variables |> select(pidp, CS_EC1_EquivHHEarnings, HHNetInc_rank) 
Wave6_merge <- Wave6$variables |> select(pidp, CS_EC1_EquivHHEarnings, HHNetInc_rank) 
Wave8_merge <- Wave8$variables |> select(pidp, CS_EC1_EquivHHEarnings, HHNetInc_rank) 
Wave10_merge <- Wave10$variables |> select(pidp, CS_EC1_EquivHHEarnings, HHNetInc_rank) 
Wave12_merge <- Wave12$variables |> select(pidp, CS_EC1_EquivHHEarnings, HHNetInc_rank) 
rm(Wave4, Wave6, Wave8, Wave10, Wave12)
gc()

#* Separate Dat out by year:
Dat_W4 <- filter(Dat$variables, year == "2012-13")
Dat_W6 <- filter(Dat$variables, year == "2014-15")
Dat_W8 <- filter(Dat$variables, year == "2016-17")
Dat_W10 <- filter(Dat$variables, year == "2018-19")
Dat_W12 <- filter(Dat$variables, year == "2020-21")
gc() 

#* Merge both dataframes together by pidp:
Dat_W4_I <- full_join(Dat_W4, Wave4_merge, by = "pidp")
Dat_W6_I <- full_join(Dat_W6, Wave6_merge, by = "pidp")
Dat_W8_I <- full_join(Dat_W8, Wave8_merge, by = "pidp")
Dat_W10_I <- full_join(Dat_W10, Wave10_merge, by = "pidp")
Dat_W12_I <- full_join(Dat_W12, Wave12_merge, by = "pidp")
rm(Wave4_merge, Wave6_merge, Wave8_merge, Wave10_merge, Wave12_merge)
rm(Dat_W4, Dat_W6, Dat_W8, Dat_W10, Dat_W12)
gc()

#* Filter out respondents who don't respond to either individual or household survey:
Wave4_IH_F <- filter(Dat_W4_I, from_hh==1 & from_ind==1)
Wave6_IH_F <- filter(Dat_W6_I, from_hh==1 & from_ind==1)
Wave8_IH_F <- filter(Dat_W8_I, from_hh==1 & from_ind==1)
Wave10_IH_F <- filter(Dat_W10_I, from_hh==1 & from_ind==1)
Wave12_IH_F <- filter(Dat_W12_I, from_hh==1 & from_ind==1)
rm(Dat_W4_I, Dat_W6_I, Dat_W8_I, Dat_W10_I, Dat_W12_I)
gc()

#* Merge the data together:
Dat$variables <- bind_rows(Wave4_IH_F, Wave6_IH_F, Wave8_IH_F, Wave10_IH_F, Wave12_IH_F)
rm(Wave4_IH_F, Wave6_IH_F, Wave8_IH_F, Wave10_IH_F, Wave12_IH_F)
gc()

#* Tests [20.04.24] to see if the merging process has worked:
summary(Dat$variables$CS_EC1_EquivHHEarnings)
svytable(~Ind_Pension_Imp + year, Dat)

#* Saved the above as of [20.04.24]:
saveRDS(Dat, file = "0 - Dat.RData")

#* REFERENCES:
#* [1] Understanding Society, 'Household income variables' accessed 13.04.24,
#* https://www.understandingsociety.ac.uk/documentation/mainstage/user-guides/main-survey-user-guide/household-income-variables/ 

#* ----------------------------------------------------------------
#* -------------- [EC.2 - Individual share of equivalised household earnings:]
#* ----------------------------------------------------------------

#* Prepare the individual non-labour earnings, personal income and investments data. Note that this does 
#* *not* include social benefit income (fimnsben_dv) becuase unlike the others this can't always be argued
#* definitively to be individual income, whereas e.g. investment income has to be individual (pension income
#* at the point of receipt will also be individual, although of course some partners will be eligible for some of
#* their partners' pension income if their partner dies. Income e.g. from rental properties is less clear-cut as that
#* could accrue to a company owned by both partners, but overall this is broadly individual):
length(which(Dat$variables$fimnmisc_dv < 0))
length(which(Dat$variables$fimnprben_dv < 0))
length(which(Dat$variables$fimninvnet_dv < 0))
length(which(Dat$variables$fimnpen_dv < 0))
Dat$variables$fimnmisc_dv_adj <- replace(Dat$variables$fimnmisc_dv, 
                                         Dat$variables$fimnmisc_dv %in% c(-9, -8, -7, -2, -1), NA)
Dat$variables$fimnprben_dv_adj <- replace(Dat$variables$fimnprben_dv, 
                                          Dat$variables$fimnprben_dv %in% c(-9, -8, -7, -2, -1), NA)
Dat$variables$fimninvnet_dv_adj <- replace(Dat$variables$fimninvnet_dv, 
                                           Dat$variables$fimninvnet_dv %in% c(-9, -8, -7, -2, -1), NA)
Dat$variables$fimnpen_dv_adj <- replace(Dat$variables$fimnpen_dv, 
                                        Dat$variables$fimnpen_dv %in% c(-9, -8, -7, -2, -1), NA)

#* Add together into a combined variable:
Dat$variables$Total_NonLabourPersonalIncome <- Dat$variables$fimnmisc_dv_adj + 
  Dat$variables$fimnprben_dv_adj + Dat$variables$fimninvnet_dv_adj + 
  Dat$variables$fimnpen_dv_adj

#* Then turn into an annualised variable:
Dat$variables$Total_NonLabourPersonalIncome_annual <- Dat$variables$Total_NonLabourPersonalIncome * 12

#* Then combine monthly labour income and personal income together into a single variable. For this, I use *net* rather than
#* gross labour income because the other individual income variables are generally assumed or adjusted to be net of tax.[1] 
#* I make use of the annual version of this created for variable EC.1, since this has already removed the inapplicables, missings
#* e.t.c:
Dat$variables$Total_PersonalIncome_annual <- Dat$variables$Total_NonLabourPersonalIncome_annual + Dat$variables$fimnlabnet_dv_annual

#* I then equivalise both this and household net income. Note this isn't strictly necessary as the percentages should be the same
#* either way, but it's useful to have these anyway: 
Dat$variables$Total_PersonalIncome_annual_OECDEquiv <- Dat$variables$Total_PersonalIncome_annual / Dat$variables$ieqmoecd_dv_adj
Dat$variables$HHNetInc_InclInd_Annual_OECDEquiv <- Dat$variables$fihhmnnet1_dv_adj_annual / Dat$variables$ieqmoecd_dv_adj

#* I now calculate the individual's percentage share of household income. I then create the indicator by simply adjusting the 
#* percentage share values by capping values below 0% and above 100%:
Dat$variables$HHIncPctShare <- Dat$variables$Total_PersonalIncome_annual_OECDEquiv / Dat$variables$HHNetInc_InclInd_Annual_OECDEquiv
Dat$variables$CS_EC2_ShareHHIncome <- case_when(Dat$variables$HHIncPctShare < 0 ~ 0, 
                                             Dat$variables$HHIncPctShare > 1 ~ 1,
                                             TRUE ~ as.numeric(as.character(Dat$variables$HHIncPctShare)))
summary(Dat$variables$CS_EC2_ShareHHIncome)

#* Create categorical version of the variable:
Dat$variables$CS_EC2_ShareHHIncome_Cat <- case_when(Dat$variables$CS_EC2_ShareHHIncome < 0.4 ~ 0, 
                                                    Dat$variables$CS_EC2_ShareHHIncome >= 0.4 & Dat$variables$CS_EC2_ShareHHIncome <= 0.6 ~ 0.5,
                                                    Dat$variables$CS_EC2_ShareHHIncome > 0.6 ~ 1)

#* Tests [13.04.24] show the process has worked. Women are much more likely to have a lower share of household income. The tendency however
#* is for many respondents to have a well below 50% share of household income, but this makes sense when you consider that individual income
#* doesn't include benefits income. For those in the JQ index the mean is closer to 50%, whereas once you include everyone else in the 
#* sample it goes well below 50%:
Test <- Dat |> select(CS_EC2_ShareHHIncome, HHIncPctShare, Total_PersonalIncome_annual_OECDEquiv, HHNetInc_InclInd_Annual_OECDEquiv) |> as.data.frame()
rm(Test)

svymean(~CS_EC2_ShareHHIncome, design = JQ, na.rm = TRUE)
svytable(~CS_EC2_ShareHHIncome_Cat + year, Dat) |> prop.table(2)
svytable(~CS_EC2_ShareHHIncome_Cat + DV_Sex, JQ) |> prop.table(2) |> round(3)

svyby(formula = JQ$variables$CS_EC2_ShareHHIncome, by = JQ$variables$year,
      design = JQ, 
      FUN = svymean, 
      na.rm = TRUE, 
      row.names = FALSE)

#* REFERENCES:
#* [1] Understanding Society, 'Individual income variables', accessed 13.04.24,
#* https://www.understandingsociety.ac.uk/documentation/mainstage/user-guides/main-survey-user-guide/individual-income-variables/  

#* ----------------------------------------------------------------
#* -------------- [EC.3 - Housing assets:]
#* ----------------------------------------------------------------

#* For this I use the derived tenure_dv variable, which is drawn from various variables
#* on housing ownership. It's important to use this rather than some of the wave-by-wave 
#* data (eg hsownd, hsowndchk) because this may not account for more recent changes 
#* in subsequent survey questions. This derived variable treats shared ownership as owned
#* with a mortgate, so I also follow this approach.[1] 

#* I go with the following 4-level split. This makes a distinction between private renters
#* and Housing Association / Social renters, because of the entitlement the latter have to
#* right to buy (in most cases, including for Housing Association renters who have the retained
#* right to buy) and their likely greater security of tenancy:
#* [0] Private rented, LA or Housing Association, other;
#* [0.5] Owned with mortgage (incl. shared ownership);
#* [1] Owned outright.

Dat$variables$CS_EC3_HousingAssets <- case_when((Dat$variables$tenure_dv == 3 | Dat$variables$tenure_dv == 4 | Dat$variables$tenure_dv == 5 | Dat$variables$tenure_dv == 6 | Dat$variables$tenure_dv == 7 | Dat$variables$tenure_dv == 8) ~ 0,
                                         Dat$variables$tenure_dv == 2 ~ 0.5,
                                         Dat$variables$tenure_dv == 1 ~ 1)

#* Data check. The data, even with weighting, does seem to over-state the proportion of social 
#* rented properties (which ONS also defines as rented through a Local Authority or housing 
#* association)[2]. In ONS data private rented is slightly higher than social rented, whereas
#* here social rented is markedly more common. There is nothing that can be done about this but I 
#* note it as a limitation:

xtabs(~CS_HousingAssets_AF + year, data = Dat)
svytable(~CS_HousingAssets_AF + year, design = Dat)
svytable(~CS_EC3_HousingAssets + year, design = JQ) |> prop.table(2)

#* REFERENCES:
#* [1] Understanding Society User Support Forum (2022), 
#* 'Support Ticket #1759: Differences between figures for tenure_dv and hsownd',
#* https://iserredex.essex.ac.uk/support/issues/1759
#* [2] ONS (2023), 'Household characteristics by tenure, England and Wales: Census 2021', 19 May 2023,
#* https://www.ons.gov.uk/peoplepopulationandcommunity/housing/articles/householdcharacteristicsbytenureenglandandwales/census2021#tenure-by-employment-status

#######################################################################################
################################# 2 - Save Data #######################################
#######################################################################################

#* Saved the above as of [14.04.24]:
# saveRDS(Dat, file = "0 - Dat.RData")
