
#######################################################################################
##################### 1 - Social capital - Create indicators ##########################
#######################################################################################

#* ----------------------------------------------------------------
#* -------------- [SC.1 - Parental NS-SEC:]
#* ----------------------------------------------------------------

#* I start by creating an _AF suffixed version of NS-SEC. As the leg work has already been done to convert
#* this variable to a 0-1 scale, this is just a case of substututing the -1s for NAs:
xtabs(~CS_ParentalNSSEC_IndAdj + year, Dat) |> prop.table(2)
Dat$variables$CS_SC1_ParentalNSSEC <- replace(Dat$variables$CS_ParentalNSSEC_IndAdj, 
                                            Dat$variables$CS_ParentalNSSEC_IndAdj %in% c(-1), NA)

#* Data check:
prop.table(svytable(~CS_SC1_ParentalNSSEC + year, JQ), 2)
xtabs(~CS_ParentalNSSEC_IndAdj + year, JQ) |> prop.table(2)
prop.table(xtabs(~CS_SC1_ParentalNSSEC + year, JQ), 2)
length(which(is.na(JQ$variables$CS_SC1_ParentalNSSEC)))

#* ----------------------------------------------------------------
#* -------------- [SC.2 - Neighbourhood social cohesion (Wave 12 only):]
#* ----------------------------------------------------------------

#* I adjust the neighbourhood social cohesion variable by replacing any missings from Wave 12 with NAs: 
xtabs(~nbrcoh_dv + year, Dat)
Dat$variables$nbrcoh_dv_adj <- replace(Dat$variables$nbrcoh_dv, 
                                       Dat$variables$nbrcoh_dv %in% c(-9, -7), NA)
Dat$variables$nbrcoh_dv_adj <- case_when(TRUE ~ as.numeric(as.character(Dat$variables$nbrcoh_dv_adj)))

#* Create the indicator. Note that it's not possible to use rescale on Haven labelled variables, so in the 
#* case_when statement above I remove the labels from the variable to make the rescale work:
Dat$variables$CS_SC2_NeighbourhoodSocCohesion <- rescale(Dat$variables$nbrcoh_dv_adj, to = c(0,1))
summary(Dat$variables$CS_SC2_NeighbourhoodSocCohesion)

#* Data check:
svytable(~CS_SC2_NeighbourhoodSocCohesion + year, JQ) |> prop.table(2)
svytable(~nbrcoh_dv_adj + year, JQ) |> prop.table(2)

#* ----------------------------------------------------------------
#* -------------- [SC.3 - Num. prior non-employment spells:
#* ----------------------------------------------------------------

#* Because of issues with missing values I opt to only use the one-wave non-employment spells variable. 
#* Missingness is high in earlier waves but goes down over the course of the time series:

Dat$variables$NonEmpSpells_OneWave_Missing <- case_when(is.na(Dat$variables$NonEmpSpells_OneWave_NAs) ~ 1, TRUE ~ 0)
xtabs(~NonEmpSpells_OneWave_Missing + year, JQ) |> prop.table(2)

#* To create the indicator, I first cap cases where there are two or more non-employment spells, since the 
#* number of people with moe than 2 spells is extremely small and their presence in the sample has the effect of
#* making the other values much lower than they should be:
Dat$variables$NonEmpSpells_OneWave_NAs_adj <- case_when(Dat$variables$NonEmpSpells_OneWave_NAs >= 2 ~ 2,
                                                        TRUE ~ as.numeric(as.character(Dat$variables$NonEmpSpells_OneWave_NAs)))
Dat$variables$NonEmpSpells_OneWave_NAs_adj_rescaled <- rescale(Dat$variables$NonEmpSpells_OneWave_NAs_adj, to = c(0,1))
Dat$variables$CS_SC3_NumNonEmpSpells <- item.reverse(Dat$variables$NonEmpSpells_OneWave_NAs_adj_rescaled, min = 0, max = 1)

summary(Dat$variables$CS_SC3_NumNonEmpSpells)
svytable(~CS_SC3_NumNonEmpSpells + year, JQ) |> prop.table(2)
svytable(~NonEmpSpells_OneWave_NAs + year, JQ) |> prop.table(2)

#* ----------------------------------------------------------------
#* -------------- [SC.4 - QoW Capability Set (Wave 12 only):
#* ----------------------------------------------------------------

#* First calculate a range of JQ scores. This is done using the variable which excludes non-work spells:
Dat$variables$JQ_range <- Dat$variables$Max_JQ_Incl_NAs_nononwork - Dat$variables$Min_JQ_Incl_NAs_nononwork
summary(Dat$variables$JQ_range)
summary(Dat$variables$Max_JQ_Incl_NAs_nononwork)
summary(Dat$variables$JQ_Index_AF_Score)

#* Note, importantly, that the range of JQ scores is never exactly zero. This reflects the fact that
#* only those with more than 1 period of work are represented in the data, and it's virtually impossible
#* for someone to report the exact same QoW score across two waves:
summary(Dat$variables$JQ_range)
length(which(Dat$variables$JQ_range == 0))

#* Rescale both variables to a 0-to-0.5 scale:
Dat$variables$JQ_range_resc <- rescale(Dat$variables$JQ_range, to = c(0,0.5))
Dat$variables$Max_JQ_Incl_NAs_nononwork_resc <- rescale(Dat$variables$Max_JQ_Incl_NAs_nononwork, to = c(0,0.5))

#* Create indicator:
Dat$variables$CS_SC4_QoWCapabilitySet <- Dat$variables$JQ_range_resc + Dat$variables$Max_JQ_Incl_NAs_nononwork_resc
summary(Dat$variables$CS_SC4_QoWCapabilitySet)

#* Data checks [22.04.24]: 
svycor(~JQ_Index_AF_Score_rescale + CS_SC4_QoWCapabilitySet, Dat, na.rm = TRUE, digits = 5)
svycor(~JQ_Index_AF_Score_rescale + CS_SC4_QoWCapabilitySet, JQ, na.rm = TRUE, digits = 5)
svycor(~JQ_Index_AF_Score_rescale + CS_SC4_QoWCapabilitySet, Wave12, na.rm = TRUE, digits = 5)

svycor(~JQ_Index_AF_Score_rescale + JQ_range, Dat, na.rm = TRUE, digits = 5)
svycor(~JQ_Index_AF_Score_rescale + JQ_range, JQ, na.rm = TRUE, digits = 5)
svycor(~JQ_Index_AF_Score_rescale + JQ_range, Wave12, na.rm = TRUE, digits = 5)

svycor(~JQ_Index_AF_Score_rescale + Max_JQ_Incl_NAs_nononwork, Dat, na.rm = TRUE, digits = 5)
svycor(~JQ_Index_AF_Score_rescale + Max_JQ_Incl_NAs_nononwork, JQ, na.rm = TRUE, digits = 5)
svycor(~JQ_Index_AF_Score_rescale + Max_JQ_Incl_NAs_nononwork, Wave12, na.rm = TRUE, digits = 5)

ggsurvey(Wave12, aes(x = Max_JQ_Incl_NAs_nononwork_resc, y = JQ_range_resc)) +
  geom_point(size = 1, colour = "#44546A") + geom_smooth(method = "glm") + xlim(0,0.5) + ylim(0,0.5)

ggsurvey(Wave12, aes(x = JQ_Index_AF_Score_rescale, y = CS_SC4_QoWCapabilitySet)) +
  geom_point(size = 1, colour = "#44546A") + geom_smooth(method = "glm") + xlim(0,100) + ylim(0,1)

#######################################################################################
################################# 2 - Save Data #######################################
#######################################################################################

#* Saved the above as of [22.04.24]:
# saveRDS(Dat, file = "0 - Dat.RData")
