
#######################################################################################
############################ 1 - Create sub-dimensions: ###############################
#######################################################################################

#* I create two versions of the summary variable, an all waves one (_allwaves) excluding 
#* some of the indicators, and a wave 12 one (_wave12). All of them are rescaled from 0-100:

#* ----------------------------------------------------------------
#* -------------- [EC - Economic Capital:]
#* ----------------------------------------------------------------

#* This one is the same for all:

Dat$variables$CS1_EconomicCapital_AllWaves <- Dat$variables$CS_EC1_EquivHHEarnings + Dat$variables$CS_EC2_ShareHHIncome + Dat$variables$CS_EC3_HousingAssets
summary(Dat$variables$CS1_EconomicCapital_AllWaves)  
  
Dat$variables$CS1_EconomicCapital_AllWaves <- rescale(Dat$variables$CS1_EconomicCapital_AllWaves, to = c(0,100)) 
summary(Dat$variables$CS1_EconomicCapital_AllWaves)

#* ----------------------------------------------------------------
#* -------------- [SC - Social Capital:]
#* ----------------------------------------------------------------

#* All waves version:
Dat$variables$CS2_SocialCapital_AllWaves <- Dat$variables$CS_SC1_ParentalNSSEC + Dat$variables$CS_SC3_NumNonEmpSpells
summary(Dat$variables$CS2_SocialCapital_AllWaves)  

Dat$variables$CS2_SocialCapital_AllWaves <- rescale(Dat$variables$CS2_SocialCapital_AllWaves, to = c(0,100)) 
summary(Dat$variables$CS2_SocialCapital_AllWaves)

#* Wave12 version:
Dat$variables$CS2_SocialCapital_Wave12 <- Dat$variables$CS_SC1_ParentalNSSEC + Dat$variables$CS_SC2_NeighbourhoodSocCohesion + Dat$variables$CS_SC3_NumNonEmpSpells + Dat$variables$CS_SC4_QoWCapabilitySet
summary(Dat$variables$CS2_SocialCapital_Wave12)  

Dat$variables$CS2_SocialCapital_Wave12 <- rescale(Dat$variables$CS2_SocialCapital_Wave12, to = c(0,100)) 
summary(Dat$variables$CS2_SocialCapital_Wave12)

#* ----------------------------------------------------------------
#* -------------- [CC - Cultural and Human Capital:]
#* ----------------------------------------------------------------

#* All waves version:
Dat$variables$CS3_CulturalandHumanCapital_AllWaves <- Dat$variables$CS_CC1_HighestQual + Dat$variables$CS_CC2_PerceivedSelfEfficacy
summary(Dat$variables$CS3_CulturalandHumanCapital_AllWaves)  

Dat$variables$CS3_CulturalandHumanCapital_AllWaves <- rescale(Dat$variables$CS3_CulturalandHumanCapital_AllWaves, to = c(0,100)) 
summary(Dat$variables$CS2_SocialCapital_AllWaves)

#* Wave12 version:
Dat$variables$CS3_CulturalandHumanCapital_Wave12 <- Dat$variables$CS_CC1_HighestQual + Dat$variables$CS_CC2_PerceivedSelfEfficacy + Dat$variables$CS_CC3_CivilParticipation
summary(Dat$variables$CS3_CulturalandHumanCapital_Wave12)  

Dat$variables$CS3_CulturalandHumanCapital_Wave12 <- rescale(Dat$variables$CS3_CulturalandHumanCapital_Wave12, to = c(0,100)) 
summary(Dat$variables$CS3_CulturalandHumanCapital_Wave12)

#######################################################################################
######################### 2 - Create capability set: ##################################
#######################################################################################

#* All waves version:
Dat$variables$CS_Index_Score <- Dat$variables$CS1_EconomicCapital_AllWaves + Dat$variables$CS2_SocialCapital_AllWaves + Dat$variables$CS3_CulturalandHumanCapital_AllWaves
summary(Dat$variables$CS_Index_Score)

Dat$variables$CS_Index_Score <- rescale(Dat$variables$CS_Index_Score, to = c(0,100)) 
summary(Dat$variables$CS_Index_Score)

#* Wave 12 version:
Dat$variables$CS_Index_Score_Wave12 <- Dat$variables$CS1_EconomicCapital_AllWaves + Dat$variables$CS2_SocialCapital_Wave12 + Dat$variables$CS3_CulturalandHumanCapital_Wave12
summary(Dat$variables$CS_Index_Score_Wave12)

Dat$variables$CS_Index_Score_Wave12 <- rescale(Dat$variables$CS_Index_Score_Wave12, to = c(0,100)) 
summary(Dat$variables$CS_Index_Score_Wave12)

#######################################################################################
######################### 3 - Check for missing values: ###############################
#######################################################################################

#* Create missing value variables:
Dat$variables$CS1_EconomicCapital_AllWaves_Missing <- case_when(is.na(Dat$variables$CS1_EconomicCapital_AllWaves) ~ 1, TRUE ~ 0)
Dat$variables$CS2_SocialCapital_AllWaves_Missing <- case_when(is.na(Dat$variables$CS2_SocialCapital_AllWaves) ~ 1, TRUE ~ 0)
Dat$variables$CS2_SocialCapital_Wave12_Missing <- case_when(is.na(Dat$variables$CS2_SocialCapital_Wave12) ~ 1, TRUE ~ 0)
Dat$variables$CS3_CulturalandHumanCapital_AllWaves_Missing <- case_when(is.na(Dat$variables$CS3_CulturalandHumanCapital_AllWaves) ~ 1, TRUE ~ 0)
Dat$variables$CS3_CulturalandHumanCapital_Wave12_Missing <- case_when(is.na(Dat$variables$CS3_CulturalandHumanCapital_Wave12) ~ 1, TRUE ~ 0)
Dat$variables$CS_Index_Score_Missing <- case_when(is.na(Dat$variables$CS_Index_Score) ~ 1, TRUE ~ 0)
Dat$variables$CS_Index_Score_Wave12_Missing <- case_when(is.na(Dat$variables$CS_Index_Score_Wave12) ~ 1, TRUE ~ 0)

#* Check for missing values. Missingness is quite high for social capital, which is a problem which may need to be dealt with
#* in future through e.g. imputation:
xtabs(~CS1_EconomicCapital_AllWaves_Missing + year, JQ) |> prop.table(2)
xtabs(~CS2_SocialCapital_AllWaves_Missing + year, JQ) |> prop.table(2)
xtabs(~CS2_SocialCapital_Wave12_Missing + year, JQ) |> prop.table(2)
xtabs(~CS3_CulturalandHumanCapital_AllWaves_Missing + year, JQ) |> prop.table(2)
xtabs(~CS3_CulturalandHumanCapital_Wave12_Missing + year, JQ) |> prop.table(2)
xtabs(~CS_Index_Score_Missing + year, JQ) |> prop.table(2)
xtabs(~CS_Index_Score_Wave12_Missing + year, JQ) |> prop.table(2)
  
#######################################################################################
############################ 3 - Save data frame: #####################################
#######################################################################################

#* Saved as of [23.04.24]:
# saveRDS(Dat, file = "0 - Dat.RData")
