
#######################################################################################
############################## 1 - Data pre-preparation: ###############################
#######################################################################################
 
#* ---------- [a] Missing values for self-employed: ppen --> ppreg

#* You lose very few values from self-employed ppen contributors at all. The unweighted data shows
#* something similar too. Obviously Wave 12 has no ppen data:
svytable(~ Dat$variables$ppen + jbsemp, design = Dat)
svytable(~ Data$ppen + jbsemp, design = Dat)
svytable(~ Dat$variables$ppen + year, design = Dat)

#* You also lose very few values from ppreg as well. As the second cross-tab shows all the people who are inapplicable
#* in ppreg don't contribute to the personal pension in ppen, and all the people who score 1-4 in ppreg say they contribute
#* to a pension (only about 131 values who say ppen = 1 are missing).
svytable(~ Dat$variables$ppreg + jbsemp, design = Dat)
svytable(~ Dat$variables$ppreg + ppen, design = Dat)
xtabs(~ppreg + ppen, data = Dat$variables)

#* I take the approach of coding "irregularly" respondents as the "worst" rating. Only those who are regularly contributing
#* are coded "best." Both (a) employees who don't contribute to, or don't have, a workplace pension and (b) self-employed 
#* can be coded in this way. 

#* ---------- [b] Missing values for employees: jbpen --> jbpenm

#* Everyone who says their employer has a pension scheme gives an answer on whether they contribute it. So I lose no data
#* by using both for my indicator. 
svytable(~ Dat$variables$jbpen + jbpenm, design = Dat)

#* Whilst the vast majority of employees are able to answer the question of whether they have an employer pension scheme, 
#* a few thousand across the time series either don't know / are inapplicable / or weren't asked the question:
svytable(~ Dat$variables$jbpen + jbpenm + year, design = Dat)
svytable(~ Dat$variables$jbpen + jbsemp, design = Dat)

#* The data shows that of these, a small minority of these do contribute to a personal pension, but most don't. It also
#* shows that in Wave 6, several hundred employees were routed into inapplicable even though they should have been asked this question
#* purely by virtue of being an employee. As of [19.07.23], I have raised a support ticket about this[1]. I am still 
#* awaiting a full response as of [26.09.23]. This is not a major issue, and in any event can be dealt with through
#* a similar imputation process as I use to create the wave 12 data:
svytable(~ Dat$variables$jbpen + ppen + jbsemp, design = Dat)
svytable(~ Dat$variables$jbpen + jbsemp + year, design = Dat)
xtabs(~ Dat$variables$jbpen + jbsemp + year, data = Dat$variables)

#* It follows from the above that the vast majority of those who are inapplicable for jbpenm are so because they don't have a
#* workplace pension:
svytable(~ Dat$variables$jbpen + Dat$variables$jbpenm + jbsemp, design = Dat)

#* ---------- [c] Missing values for employees: ppen --> ppreg 

#* *8,968* employees have a personal pension. Note that this doesn't include any employees in Wave 12, due to the data being 
#* discontinued:
svytable(~ Dat$variables$ppen + jbsemp, design = Dat)

#* Of these, a majority  do contribute regularly (ppreg = 2) vs. a sizeable minority who never contribute, 
#* contribute irregularly or have stopped contributing:
svytable(~ Dat$variables$ppreg + jbsemp, design = Dat)

#* Of those who contribute regularly, the majority actually already say they have an employer pension scheme. 
#* Of these most are members of their employer pension scheme. And of these a narrow majority contribute regularly 
#* to the pension:  
svytable(~ Dat$variables$ppen + jbpen, design = Dat)
svytable(~ Dat$variables$ppen + jbpenm, design = Dat)
svytable(~ Dat$variables$ppreg + jbpenm, design = Dat)

#* In other words, only several hundred employees in Waves 4, 6, 8 and 10 don't contribute to an employer pension contribute regularly
#* to a personal pension - this is just 17% of all those employees who contribute regularly to a personal pension. So the
#* decision to code employees as "best" for ppen only improves the scores of a tiny minority of employees vs. what they'd have
#* been if we'd have just used jbpen and jbpenm.   

#* REFERENCES:
#* [1] Understanding Society user support forum, 19.07.23, 'Employee (jbpen + jbpenm) and personal (ppen + ppreg) pensions 
#* in Understanding Society - query re. some wave data.' Support #1941, 
#* https://iserredex.essex.ac.uk/support/issues/1941 

#######################################################################################
################################## 2 - Create indicator: ##############################
#######################################################################################

#* I face a choice here re. how to treat the small minority of missing values re. employees. Several options, not
#* mutually exclusive:
#* [1] Re-code don't know employees (-1) as not having an employee pension, since - because they don't know - we 
#* could assume there isn't one at their workplace;
#* [2] Do the same as above for the inapplicable (-8) employees in Wave 6;
#* [3] Code employees based on their response to ppen and ppreg, even if they have missing data for jbpen and
#* jbpenm;
#* [4] Don't mark people who say DK/refusal/etc for ppen and ppreg as missing, if they have sufficient data on 
#* jbpen and jbpenm;

#* I opt to do [3-4], but not [1-2]. In effect this means adopting exclusionary (don't have, ie != X) rather than 
#* inclusionary (have, ie == X) criteria for many of the below variables. 

#* I create a 3-level variable here. The use of a middle score for personal pension contributions is justified by 
#* the fact that in practice, very few employers contribute to personal pensions. So we can say that these individuals
#* are missing out on maximising their contributions. Obviously future changes to these arrangements would allow for a
#* higher score to be given:
#* *Best = 2.* [2a] Employees who have, and are members of, a workplace pension scheme; 
#* *Middle = 1.* [1a] Employees who don't say they have a workplace pension scheme (incl. DKs, etc), but have and contribute 
#* regularly to a personal pension; [1b] Employees who have a workplace pension but don't say they are a member of it
#* (incl. DKs, etc), but have and contribute regularly to a personal pension; [1c] Self-employed who have and contribute regularly
#* to a workplace pension. 
#* *Worst = 0.* [0a] Employees who either don't have a workplace pension or aren't a member of it, and don't have a personal pension; 
#* [0b] Employees who either don't have a workplace pension or aren't a member of it, do have a personal pension, but never contribute (1), 
#* contribute irregularly (3) or have stopped contributing (4) to their personal pension; [0c] Self-employed who don't have a personal 
#* pension; [0d] Self-employed who do have a personal pension but never contribute (1), contribute irregularly (3) or have stopped 
#* contributing (4) to their personal pension. 

Dat$variables$Ind_Pension <- case_when(Dat$variables$jbsemp == 1 & Dat$variables$jbpen == 1 & Dat$variables$jbpenm == 1 ~ 2, 
                                             #* [2a]  
                                             Dat$variables$jbsemp == 1 & Dat$variables$jbpen != 1 & (Dat$variables$ppen == 1 & Dat$variables$ppreg == 2) ~ 1, 
                                             #* [1a]
                                             Dat$variables$jbsemp == 1 & Dat$variables$jbpen == 1 & Dat$variables$jbpenm != 1 & (Dat$variables$ppen == 1 & Dat$variables$ppreg == 2) ~ 1, 
                                             #* [1b]
                                             Dat$variables$jbsemp == 2 & (Dat$variables$ppen == 1 & Dat$variables$ppreg == 2) ~ 1, 
                                             #* [1c]
                                             Dat$variables$jbsemp == 1 & (Dat$variables$jbpen == 2 | Dat$variables$jbpenm == 2) & Dat$variables$ppen == 2 ~ 0, 
                                             #* [0a]
                                             Dat$variables$jbsemp == 1 & (Dat$variables$jbpen == 2 | Dat$variables$jbpenm == 2) & 
                                               Dat$variables$ppen == 1 & (Dat$variables$ppreg == 1 | Dat$variables$ppreg == 3 | Dat$variables$ppreg == 4) ~ 0,
                                             #* [0b]
                                             Dat$variables$jbsemp == 2 & Dat$variables$ppen == 2 ~ 0, 
                                             #* [0c]
                                             Dat$variables$jbsemp == 2 & Dat$variables$ppen == 1 & (Dat$variables$ppreg == 1 | Dat$variables$ppreg == 3 | Dat$variables$ppreg == 4) ~ 0, 
                                             #* [0d]
                                             TRUE ~ -1)

#######################################################################################
############################# 3 - Analysis and visualisation: #########################
#######################################################################################

#* ---------- [a] Generate filters for the data:
JQ <- Dat |> filter(Dat$variables$index == "Quality of Work")
Employees <- Dat |> filter(Dat$variables$jbsemp == 1)
SelfEmployed <- Dat |> filter(Dat$variables$jbsemp == 2)

#* ---------- [b] Some quality checks:
#* [1] Some people who aren't members of their pension scheme score 1 on Ind_Pension (this is correct, since these 
#* will have a personal pension);
#* [2] Everyone who's a member of the pension scheme scores 1 on Ind_Pension (this should be the case);
#* [3] The vast majority of the self-employed score 0 on Ind_Pension, whilst the majority of those in employment 
#* score 2;
#* [4] Everyone in the workless index scores 0 on Ind_Pension (this stacks up).

# svytable(~ Dat$variables$Ind_Pension + jbpen, design = Dat)
# svytable(~ Dat$variables$Ind_Pension + jbpenm, design = Dat)
# svytable(~ Dat$variables$Ind_Pension + Dat$variables$index, design = Dat)
# svytable(~ Dat$variables$Ind_Pension + jbsemp, design = Dat)
# svytable(~ JQ$variables$Ind_Pension + JQ$variables$year, design = JQ)
# svytable(~ Employees$variables$Ind_Pension + Employees$variables$year, design = Employees)
# svytable(~ SelfEmployed$variables$Ind_Pension + SelfEmployed$variables$year, design = SelfEmployed)

#* Time series proportional table:
prop.table(svytable((~Ind_Pension + year),JQ), margin=2)

#######################################################################################
###################### 5 - Save the indicator into the survey: ########################
#######################################################################################

#* Saved the above as of [26.09.23]:
saveRDS(Dat, file = "0 - Dat.RData")

Dat <- readRDS("0 - Dat.RData")
Dat$variables$Ind_Pension
