
#######################################################################################
################################# 1 - PRE-PREPARATION: ################################
#######################################################################################

setwd("INSERT UKHLS WORKING DIRECTORY HERE")
library(ggthemes)
library(tidyverse)
library(readr)
library(dplyr)
library(epiDisplay)
library(gmodels)
library(ggplot2)
library(scales)
library(tidyr)
library(survey)
library(imputeTS)
library(srvyr)
library(ggpmisc)
library(questionr)
library(gridExtra)
library(sjmisc)
library(haven)
library(tidyverse)
library(editData)
library(lubridate)

#######################################################################################
############### 2 - DOWNLOAD RELEVANT DATA FILES FOR EACH WAVE: #######################
#######################################################################################

#* [1] I opt to only use the Understanding Society waves for data on continuous employment. 
#* This can be downloaded from the same folder as the index as a whole:

UKHLS_2_2010_11 <- read_dta('b_indresp.dta') |>
  select(pidp, b_jbstat, b_empchk, b_jbsamr, b_intdatd_dv, b_intdatm_dv, b_intdaty_dv, 
         b_jbbgd, b_jbbgm, b_jbbgy, b_age_dv, b_ff_jbstat, b_ff_ivlolw, b_ff_everint, 
         b_jbsemp, b_jbhas, b_jboff, b_ff_emplw, b_employ)
UKHLS_3_2011_12 <- read_dta('c_indresp.dta') |>
  select(pidp, c_jbstat, c_empchk, c_jbsamr, c_intdatd_dv, c_intdatm_dv, c_intdaty_dv, 
         c_jbbgd, c_jbbgm, c_jbbgy, c_age_dv, c_ff_jbstat, c_ff_ivlolw, c_ff_everint, 
         c_jbsemp, c_jbhas, c_jboff, c_ff_emplw, c_employ)
UKHLS_4_2012_13 <- read_dta('d_indresp.dta') |>
  select(pidp, d_jbstat, d_empchk, d_jbsamr, d_intdatd_dv, d_intdatm_dv, d_intdaty_dv, 
         d_jbbgd, d_jbbgm, d_jbbgy, d_age_dv, d_ff_jbstat, d_ff_ivlolw, d_ff_everint, 
         d_jbsemp,  d_jbhas, d_jboff, d_ff_emplw, d_employ)
UKHLS_5_2013_14 <- read_dta('e_indresp.dta') |>
  select(pidp, e_jbstat, e_empchk, e_jbsamr, e_intdatd_dv, e_intdatm_dv, e_intdaty_dv, 
         e_jbbgd, e_jbbgm, e_jbbgy, e_age_dv, e_ff_jbstat, e_ff_ivlolw, e_ff_everint, 
         e_jbsemp,  e_jbhas, e_jboff, e_ff_emplw, e_employ)
UKHLS_6_2014_15 <- read_dta('f_indresp.dta') |>
  select(pidp, f_jbstat, f_empchk, f_jbsamr, f_intdatd_dv, f_intdatm_dv, f_intdaty_dv, 
         f_jbbgd, f_jbbgm, f_jbbgy, f_age_dv, f_ff_jbstat, f_ff_ivlolw, 
         f_jbsemp,  f_jbhas, f_jboff, f_ff_emplw, f_employ) 
UKHLS_7_2015_16 <- read_dta('g_indresp.dta') |>
  select(pidp, g_jbstat, g_empchk, g_jbsamr, g_intdatd_dv, g_intdatm_dv, g_intdaty_dv, 
         g_jbbgd, g_jbbgm, g_jbbgy, g_age_dv, g_ff_jbstat, g_ff_ivlolw, 
         g_jbsemp,  g_jbhas, g_jboff, g_ff_emplw, g_employ)
UKHLS_8_2016_17 <- read_dta('h_indresp.dta') |> 
  select(pidp, h_jbstat, h_empchk, h_jbsamr, h_intdatd_dv, h_intdatm_dv, h_intdaty_dv,
         h_jbbgd, h_jbbgm, h_jbbgy, h_age_dv, h_ff_jbstat, h_ff_ivlolw, 
         h_jbsemp,  h_jbhas, h_jboff, h_ff_emplw, h_employ)
UKHLS_9_2017_18 <- read_dta('i_indresp.dta') |>
  select(pidp, i_jbstat, i_empchk, i_jbsamr, i_intdatd_dv, i_intdatm_dv, i_intdaty_dv, 
         i_jbbgd, i_jbbgm, i_jbbgy, i_age_dv, i_ff_jbstat, i_ff_ivlolw, 
         i_jbsemp,  i_jbhas, i_jboff, i_ff_emplw, i_employ)
UKHLS_10_2018_19 <- read_dta('j_indresp.dta') |> 
  select(pidp, j_jbstat, j_empchk, j_jbsamr, j_intdatd_dv, j_intdatm_dv, j_intdaty_dv,
         j_jbbgd, j_jbbgm, j_jbbgy, j_age_dv, j_ff_jbstat, j_ff_ivlolw, 
         j_jbsemp,  j_jbhas, j_jboff, j_ff_emplw, j_employ)
UKHLS_11_2019_20 <- read_dta('k_indresp.dta') |> 
  select(pidp, k_jbstat, k_empchk, k_jbsamr, k_intdatd_dv, k_intdatm_dv, k_intdaty_dv,
         k_jbbgd, k_jbbgm, k_jbbgy, k_age_dv, k_ff_jbstat, k_ff_ivlolw, 
         k_jbsemp,  k_jbhas, k_jboff, k_ff_emplw, k_employ)
UKHLS_12_2020_21 <- read_dta('l_indresp.dta') |> 
  select(pidp, l_jbstat, l_empchk, l_jbsamr, l_intdatd_dv, l_intdatm_dv, l_intdaty_dv,
         l_jbbgd, l_jbbgm, l_jbbgy, l_age_dv, l_ff_jbstat, l_ff_ivlolw, 
         l_jbsemp,  l_jbhas, l_jboff, l_ff_emplw, l_employ)

gc()

#* [2] Add in indsamp datasets:
#* Note that unlike the rest of the QoW index, I bring in data from the indsamp dataset
#* to create the Continuous Employment indicator. This is because indsamp contains crucial
#* info on whether the respndent answered the wave immediately prior to the one they were in.
#* This enables me to confirm whether, when they say they were continuously employed since the 
#* "last wave", what wave they were actually referring to:
Wave2_Indsamp <- read_dta('b_indsamp.dta') |> 
  select(pidp, b_finloc, b_iviolw)
Wave3_Indsamp <- read_dta('c_indsamp.dta') |> 
  select(pidp, c_finloc, c_iviolw)
Wave4_Indsamp <- read_dta('d_indsamp.dta') |> 
  select(pidp, d_finloc, d_iviolw)
Wave5_Indsamp <- read_dta('e_indsamp.dta') |> 
  select(pidp, e_finloc, e_iviolw)
Wave6_Indsamp <- read_dta('f_indsamp.dta') |> 
  select(pidp, f_finloc, f_iviolw)
Wave7_Indsamp <- read_dta('g_indsamp.dta') |> 
  select(pidp, g_finloc, g_iviolw)
Wave8_Indsamp <- read_dta('h_indsamp.dta') |> 
  select(pidp, h_finloc, h_iviolw)
Wave9_Indsamp <- read_dta('i_indsamp.dta') |> 
  select(pidp, i_finloc, i_iviolw)
Wave10_Indsamp <- read_dta('j_indsamp.dta') |> 
  select(pidp, j_finloc, j_iviolw)
Wave11_Indsamp <- read_dta('k_indsamp.dta') |> 
  select(pidp, k_finloc, k_iviolw)
Wave12_Indsamp <- read_dta('l_indsamp.dta') |> 
  select(pidp, l_finloc, l_iviolw)

#* [3] Filter out to cases where finloc == 1. This is in line with Understanding
#* Society guidance in order to make the personal identifier unique in the 
#* dataset:[1]
 
Wave2_Indsamp_Filter <- filter(Wave2_Indsamp, b_finloc == 1)
Wave3_Indsamp_Filter <- filter(Wave3_Indsamp, c_finloc == 1)
Wave4_Indsamp_Filter <- filter(Wave4_Indsamp, d_finloc == 1)
Wave5_Indsamp_Filter <- filter(Wave5_Indsamp, e_finloc == 1)
Wave6_Indsamp_Filter <- filter(Wave6_Indsamp, f_finloc == 1)
Wave7_Indsamp_Filter <- filter(Wave7_Indsamp, g_finloc == 1)
Wave8_Indsamp_Filter <- filter(Wave8_Indsamp, h_finloc == 1)
Wave9_Indsamp_Filter <- filter(Wave9_Indsamp, i_finloc == 1)
Wave10_Indsamp_Filter <- filter(Wave10_Indsamp, j_finloc == 1)
Wave11_Indsamp_Filter <- filter(Wave11_Indsamp, k_finloc == 1)
Wave12_Indsamp_Filter <- filter(Wave12_Indsamp, l_finloc == 1)

#* REFERENCES:
#* [1] Understanding Society (14 November 2022), 'Main Survey User Guide', p. 25: 
#* https://www.understandingsociety.ac.uk/documentation/mainstage/dataset-documentation/variable/jbhas

#######################################################################################
###################### 3 - CREATE DATE VARIABLES FROM INTERVIEW DATES: ################
#######################################################################################

UKHLS_2_2010_11$b_date <- as.Date(with(UKHLS_2_2010_11, paste(b_intdaty_dv, b_intdatm_dv, b_intdatd_dv,sep="-")),
                                  "%Y-%m-%d")
UKHLS_3_2011_12$c_date <- as.Date(with(UKHLS_3_2011_12, paste(c_intdaty_dv, c_intdatm_dv, c_intdatd_dv,sep="-")),
                                  "%Y-%m-%d")
UKHLS_4_2012_13$d_date <- as.Date(with(UKHLS_4_2012_13, paste(d_intdaty_dv, d_intdatm_dv, d_intdatd_dv,sep="-")),
                                  "%Y-%m-%d")
UKHLS_5_2013_14$e_date <- as.Date(with(UKHLS_5_2013_14, paste(e_intdaty_dv, e_intdatm_dv, e_intdatd_dv,sep="-")),
                                  "%Y-%m-%d")
UKHLS_6_2014_15$f_date <- as.Date(with(UKHLS_6_2014_15, paste(f_intdaty_dv, f_intdatm_dv, f_intdatd_dv,sep="-")),
                                  "%Y-%m-%d")
UKHLS_7_2015_16$g_date <- as.Date(with(UKHLS_7_2015_16, paste(g_intdaty_dv, g_intdatm_dv, g_intdatd_dv,sep="-")),
                                  "%Y-%m-%d")
UKHLS_8_2016_17$h_date <- as.Date(with(UKHLS_8_2016_17, paste(h_intdaty_dv, h_intdatm_dv, h_intdatd_dv,sep="-")),
                                  "%Y-%m-%d")
UKHLS_9_2017_18$i_date <- as.Date(with(UKHLS_9_2017_18, paste(i_intdaty_dv, i_intdatm_dv, i_intdatd_dv,sep="-")),
                                  "%Y-%m-%d")
UKHLS_10_2018_19$j_date <- as.Date(with(UKHLS_10_2018_19, paste(j_intdaty_dv, j_intdatm_dv, j_intdatd_dv,sep="-")),
                                   "%Y-%m-%d")
UKHLS_11_2019_20$k_date <- as.Date(with(UKHLS_11_2019_20, paste(k_intdaty_dv, k_intdatm_dv, k_intdatd_dv,sep="-")),
                                   "%Y-%m-%d")
UKHLS_12_2020_21$l_date <- as.Date(with(UKHLS_12_2020_21, paste(l_intdaty_dv, l_intdatm_dv, l_intdatd_dv,sep="-")),
                                   "%Y-%m-%d")

#######################################################################################
############################# 4 - ADD SOME EXTRA VARIABLES: ###########################
#######################################################################################

#* [1 QoW Index Member:] to track those who are in the QoW Index:

UKHLS_2_2010_11$b_QoW_Index_Member <- case_when(UKHLS_2_2010_11$b_jbhas == 1 ~ 1,
                                                UKHLS_2_2010_11$b_jboff == 1 ~ 1,
                                                TRUE ~ 0)
UKHLS_3_2011_12$c_QoW_Index_Member <- case_when(UKHLS_3_2011_12$c_jbhas == 1 ~ 1,
                                               UKHLS_3_2011_12$c_jboff == 1 ~ 1,
                                               TRUE ~ 0)
UKHLS_4_2012_13$d_QoW_Index_Member <- case_when(UKHLS_4_2012_13$d_jbhas == 1 ~ 1,
                                               UKHLS_4_2012_13$d_jboff == 1 ~ 1,
                                               TRUE ~ 0)
UKHLS_5_2013_14$c_QoW_Index_Member <- case_when(UKHLS_5_2013_14$e_jbhas == 1 ~ 1,
                                               UKHLS_5_2013_14$e_jboff == 1 ~ 1,
                                               TRUE ~ 0)
UKHLS_6_2014_15$f_QoW_Index_Member <- case_when(UKHLS_6_2014_15$f_jbhas == 1 ~ 1,
                                               UKHLS_6_2014_15$f_jboff == 1 ~ 1,
                                               TRUE ~ 0)
UKHLS_7_2015_16$g_QoW_Index_Member <- case_when(UKHLS_7_2015_16$g_jbhas == 1 ~ 1,
                                               UKHLS_7_2015_16$g_jboff == 1 ~ 1,
                                               TRUE ~ 0)
UKHLS_8_2016_17$h_QoW_Index_Member <- case_when(UKHLS_8_2016_17$h_jbhas == 1 ~ 1,
                                               UKHLS_8_2016_17$h_jboff == 1 ~ 1,
                                               TRUE ~ 0)
UKHLS_9_2017_18$i_QoW_Index_Member <- case_when(UKHLS_9_2017_18$i_jbhas == 1 ~ 1,
                                               UKHLS_9_2017_18$i_jboff == 1 ~ 1,
                                               TRUE ~ 0)
UKHLS_10_2018_19$j_QoW_Index_Member <- case_when(UKHLS_10_2018_19$j_jbhas == 1 ~ 1,
                                                UKHLS_10_2018_19$j_jboff == 1 ~ 1,
                                               TRUE ~ 0)
UKHLS_11_2019_20$k_QoW_Index_Member <- case_when(UKHLS_11_2019_20$k_jbhas == 1 ~ 1,
                                                 UKHLS_11_2019_20$k_jboff == 1 ~ 1,
                                                 TRUE ~ 0)
UKHLS_12_2020_21$l_QoW_Index_Member <- case_when(UKHLS_12_2020_21$l_jbhas == 1 ~ 1,
                                                 UKHLS_12_2020_21$l_jboff == 1 ~ 1,
                                                 TRUE ~ 0)

#* Note [13.07.23] that this is the same filtering process used to filter the data frames out, as the below
#* test code demonstrates:

#* UKHLS_3_2011_12_Test1 <- filter(UKHLS_3_2011_12, (c_jbhas == 1 | c_jboff == 1))
#* UKHLS_3_2011_12_Test2 <- filter(UKHLS_3_2011_12, UKHLS_3_2011_12$c_QoW_Index_Member == 1)
#* identical(UKHLS_3_2011_12_Test1, UKHLS_3_2011_12_Test2)
#* rm(UKHLS_3_2011_12_Test1, UKHLS_3_2011_12_Test2)

gc()

#######################################################################################
####################### 5 - MERGE BASED ON PERSON IDENTIFIER: #########################
#######################################################################################

#* [1 - Merge data:] The below code generates five data frames with all the data I need.
#* Note that at this point, I could also merge all of the data frames together, as I do with
#* the wider JQ index. However this would add confusion and make subsequent syntax much harder
#* to follow, so I retain the waves as five data frames:

#* [a] Everyone in Wave 2-4 (so 3 waves total);
#* [b] ... Waves 4-6;
#* [c] ... Waves 6-8;
#* [d] ... Waves 8-10;
#* [e] ... Waves 10-12;

Wave4_to_2 <- full_join(UKHLS_4_2012_13, UKHLS_3_2011_12, by = "pidp")
Wave4_to_2 <- full_join(Wave4_to_2, UKHLS_2_2010_11, by = "pidp")                    
Wave4_to_2 <- full_join(Wave4_to_2, Wave4_Indsamp_Filter, by = "pidp")
Wave4_to_2 <- full_join(Wave4_to_2, Wave3_Indsamp_Filter, by = "pidp")
Wave4_to_2 <- full_join(Wave4_to_2, Wave2_Indsamp_Filter, by = "pidp")

Wave6_to_4 <- full_join(UKHLS_6_2014_15, UKHLS_5_2013_14, by = "pidp")
Wave6_to_4 <- full_join(Wave6_to_4, UKHLS_4_2012_13, by = "pidp")                    
Wave6_to_4 <- full_join(Wave6_to_4, Wave6_Indsamp_Filter, by = "pidp")
Wave6_to_4 <- full_join(Wave6_to_4, Wave5_Indsamp_Filter, by = "pidp")
Wave6_to_4 <- full_join(Wave6_to_4, Wave4_Indsamp_Filter, by = "pidp")

Wave8_to_6 <- full_join(UKHLS_8_2016_17, UKHLS_7_2015_16, by = "pidp")
Wave8_to_6 <- full_join(Wave8_to_6, UKHLS_6_2014_15, by = "pidp")                    
Wave8_to_6 <- full_join(Wave8_to_6, Wave8_Indsamp_Filter, by = "pidp")
Wave8_to_6 <- full_join(Wave8_to_6, Wave7_Indsamp_Filter, by = "pidp")
Wave8_to_6 <- full_join(Wave8_to_6, Wave6_Indsamp_Filter, by = "pidp")

Wave10_to_8 <- full_join(UKHLS_10_2018_19, UKHLS_9_2017_18, by = "pidp")
Wave10_to_8 <- full_join(Wave10_to_8, UKHLS_8_2016_17, by = "pidp")                    
Wave10_to_8 <- full_join(Wave10_to_8, Wave10_Indsamp_Filter, by = "pidp")
Wave10_to_8 <- full_join(Wave10_to_8, Wave9_Indsamp_Filter, by = "pidp")
Wave10_to_8 <- full_join(Wave10_to_8, Wave8_Indsamp_Filter, by = "pidp")

Wave12_to_10 <- full_join(UKHLS_12_2020_21, UKHLS_11_2019_20, by = "pidp")
Wave12_to_10 <- full_join(Wave12_to_10, UKHLS_10_2018_19, by = "pidp")                    
Wave12_to_10 <- full_join(Wave12_to_10, Wave12_Indsamp_Filter, by = "pidp")
Wave12_to_10 <- full_join(Wave12_to_10, Wave11_Indsamp_Filter, by = "pidp")
Wave12_to_10 <- full_join(Wave12_to_10, Wave10_Indsamp_Filter, by = "pidp")

rm(UKHLS_2_2010_11, UKHLS_3_2011_12, UKHLS_4_2012_13, UKHLS_5_2013_14, 
   UKHLS_6_2014_15, UKHLS_7_2015_16, UKHLS_8_2016_17, UKHLS_9_2017_18, 
   UKHLS_10_2018_19, UKHLS_11_2019_20, UKHLS_12_2020_21)
rm(Wave2_Indsamp, Wave3_Indsamp, Wave4_Indsamp, Wave5_Indsamp, 
   Wave6_Indsamp, Wave7_Indsamp, Wave8_Indsamp, Wave9_Indsamp,
   Wave10_Indsamp, Wave11_Indsamp, Wave12_Indsamp)
rm(Wave2_Indsamp_Filter, Wave3_Indsamp_Filter, Wave4_Indsamp_Filter,
   Wave5_Indsamp_Filter, Wave6_Indsamp_Filter, Wave7_Indsamp_Filter,
   Wave8_Indsamp_Filter, Wave9_Indsamp_Filter, Wave10_Indsamp_Filter,
   Wave11_Indsamp_Filter, Wave12_Indsamp_Filter)

#* [2 - Check for missing values:] The above process creates NAs wherever someone in Wave T
#* didn't respond in Wave T-1/T-2, and vice-versa. The below code [26.09.23] shows that there 
#* are some features to the NAs which are created:
#* [a] Within a given data frame, he number of NAs is the same for every single variable 
#* in the same wave (ie those which share the same w_ prefix): 
sum(is.na(Wave4_to_2$d_jbbgd))
sum(is.na(Wave4_to_2$d_jbbgm))
sum(is.na(Wave4_to_2$d_jbsemp))
sum(is.na(Wave4_to_2$d_QoW_Index_Member))
sum(is.na(Wave4_to_2$b_jbsemp))
sum(is.na(Wave4_to_2$b_QoW_Index_Member))
sum(is.na(Wave4_to_2$b_jbstat))
#* [b] But the number of NAs for w_prefixed data isn't the same across data frames. Ie the d_
#* prefixed data has a different number of NAs in the Wave4_to_2 vs. the Wave6_to_4 grouping:
sum(is.na(Wave6_to_4$d_jbbgd))
sum(is.na(Wave6_to_4$d_jbsemp))
#* [c] The exception to the above rules is any data gathered from the indsamp dataset: there
#* are a lower number of NAs here. So the eg the d_prefixed data in indsamp has the same number
#* of NAs as other d_prefixed indsamp data, but a much lower number of NAs than d_prefixed data.
#* This makes sense, and is in line with what Understanding Society documentation would suggest,
#* since indsamp "includes current interview outcome for anyone enumerated in the last interview 
#* wave, for example, whether they have responded, couldn’t be contacted or refused, or were 
#* ineligible."[1] In other words, more people who didn't respond to a given wave are included 
#* in the indsamp dataset just because they were enumerated in that wave, ie were part of that 
#* wave sample:  
sum(is.na(Wave4_to_2$d_iviolw))
sum(is.na(Wave4_to_2$c_iviolw))
sum(is.na(Wave4_to_2$b_iviolw))
sum(is.na(Wave4_to_2$b_finloc))
sum(is.na(Wave4_to_2$c_finloc))
sum(is.na(Wave4_to_2$d_finloc))

#* Later on in this analysis, these NAs are eventually converted into data (usually coded 0). 

#* A large amount of the effect of this non-response is counter-acted by imputing values based on 
#* what people say in their current wave (Wave T). I calculate the effect of these later on in my
#* analysis (see below sections).

gc()

#* REFERENCES:
#* [1] Understanding Society (14 November 2022), 'Main Survey User Guide', p. 25: 
#* https://www.understandingsociety.ac.uk/documentation/mainstage/dataset-documentation/variable/jbhas

#######################################################################################
#################### 6 - CHECK LENGTH OF TIME BETWEEN SURVEYS: ########################
#######################################################################################

#* Understanding Society is clear that "A wave consists of a 24-monthly samples with 
#* participants interviewed at regular 1-year intervals."[1] Because interviews are 
#* carried out over two years, it should be noted that changes over time are likely to
#* be slightly smoothed unless you split up by the year of interview - although Understanding
#* Society has a means to do this, I opt not to do so because (a) I am already analysing changes
#* over time using pairs of waves (Wave 12 vs. Wave 10, Wave 10 vs. Wave 8, etc) so there are few
#* overlapping years and (b) there is a sophisticated and well-designed weighting method so long as you
#* keep respondents in the waves they're in.

#* Nevertheless, I wanted to check how much variance there is in interview times between waves: whilst
#* Understanding Society obviously aims to interview at 1-year intervals, there will obviously
#* be some give here. Quite obviously, this can only be done for those who respond to both waves in a
#* given pair: we don't know what the response rate would have been for non-responders, and whether 
#* that would be systematically different. 

#* [1] Generate number of days between interviews:

#* There are two ways of doing this. Rather than duplicating the below code ad infinitum, I instead
#* provide two choices of how to code the data below to get different time intervals. So you have to 
#* pick one of these and then run the below. There is also a third choice of looking at Wave T vs.
#* Wave T-2, but for simplicity I don't do this below:
 
#* [a] Wave T vs. Wave T-1:
Wave4_to_2$time_between_interviews <- Wave4_to_2$d_date - Wave4_to_2$c_date
Wave6_to_4$time_between_interviews <- Wave6_to_4$f_date - Wave6_to_4$e_date
Wave8_to_6$time_between_interviews <- Wave8_to_6$h_date - Wave8_to_6$g_date
Wave10_to_8$time_between_interviews <- Wave10_to_8$j_date - Wave10_to_8$i_date
Wave12_to_10$time_between_interviews <- Wave12_to_10$l_date - Wave12_to_10$k_date

#* [b] Wave T-1 vs. Wave T-2:
Wave4_to_2$time_between_interviews <- Wave4_to_2$c_date - Wave4_to_2$b_date
Wave6_to_4$time_between_interviews <- Wave6_to_4$e_date - Wave6_to_4$d_date
Wave8_to_6$time_between_interviews <- Wave8_to_6$g_date - Wave8_to_6$f_date
Wave10_to_8$time_between_interviews <- Wave10_to_8$i_date - Wave10_to_8$h_date
Wave12_to_10$time_between_interviews <- Wave12_to_10$k_date - Wave12_to_10$j_date

#* [2] Track average time between interview dates. For choice a the time difference
#* ranges from 355 to 370 days. For choice b it is a markedly consistent 367-368
#* days:
mean(Wave4_to_2$time_between_interviews, na.rm = TRUE)
mean(Wave6_to_4$time_between_interviews, na.rm = TRUE)
mean(Wave8_to_6$time_between_interviews, na.rm = TRUE)
mean(Wave10_to_8$time_between_interviews, na.rm = TRUE)
mean(Wave12_to_10$time_between_interviews, na.rm = TRUE)

#* [3] The IQR is more variable. For choice a this ranges from 24 to 66 days, whilst
#* for choice b it ranges from 21-41 days:
IQR(Wave4_to_2$time_between_interviews, na.rm = TRUE)
IQR(Wave6_to_4$time_between_interviews, na.rm = TRUE)
IQR(Wave8_to_6$time_between_interviews, na.rm = TRUE)
IQR(Wave10_to_8$time_between_interviews, na.rm = TRUE)
IQR(Wave12_to_10$time_between_interviews, na.rm = TRUE)

#* [4] The crucial point, from the data tables below, is that the number of respondents 
#* who are +/- 6 months from their interview is extremely small: in the *low double digits*
#* *or single digits* for all pairs of waves. This is important, since - if we want to equate
#* waves with years - it means that virtually every respondent has been interviewed closer to 1
#* year of their last interview than either 0 or 2 years. So if one were forced to allocate them
#* into either a Worst, Middle or Best indicator score, they would have to opt for the one they would be in
#* even if we didn't know about their waves. This informs how I generate the indicator in the subsequent
#* sections. 

#* It should, however, be apparent from the above that we can't quite equate "waves" with "years." Being
#* continuously employed since the previous wave, or for two waves in a row, doesn't quite mean that
#* they've been continuously employed for 1 or 2 years. I reflect this in the way I communicate the 
#* indicator in my papers. With a different set of survey questions, or a more rigid time interval between
#* interviews (although the latter is extremely hard to achieve in practice in any national survey anywhere), 
#* it may be possible to adopt a more sophisticated approach for future analyses. However, I maintain 
#* that the below is the best we can get at the moment: it is a solid *indicator* of having been 
#* continuously employed for long enough to have accrued the legal rights associated with this 
#* continuous employment. 

#* ------ Data tables = Wave 4 to 2:
Wave4_to_2$time_between_interviews_6_months_below <- case_when (
  Wave4_to_2$time_between_interviews < 183 ~ "Below 183 days",
  Wave4_to_2$time_between_interviews > 182 ~ "Above 182 days")
Wave4_to_2$time_between_interviews_2_months_below <- case_when (
  Wave4_to_2$time_between_interviews < 305 ~ "Below 305 days",
  Wave4_to_2$time_between_interviews > 304 ~ "Above 304 days")
Wave4_to_2$time_between_interviews_1_month_below <- case_when (
  Wave4_to_2$time_between_interviews < 335 ~ "Below 335 days",
  Wave4_to_2$time_between_interviews > 334 ~ "Above 334 days")
Wave4_to_2$time_between_interviews_1_month_above <- case_when (
  Wave4_to_2$time_between_interviews < 395 ~ "Below 395 days",
  Wave4_to_2$time_between_interviews > 394 ~ "Above 394 days")
Wave4_to_2$time_between_interviews_2_months_above <- case_when (
  Wave4_to_2$time_between_interviews < 425 ~ "Below 425 days",
  Wave4_to_2$time_between_interviews > 424 ~ "Above 424 days")
Wave4_to_2$time_between_interviews_6_months_above <- case_when (
  Wave4_to_2$time_between_interviews < 548 ~ "Below 548 days",
  Wave4_to_2$time_between_interviews > 547 ~ "Above 547 days")

xtabs(~ time_between_interviews_6_months_below, data=Wave4_to_2)
xtabs(~ time_between_interviews_2_months_below, data=Wave4_to_2)
xtabs(~ time_between_interviews_1_month_below, data=Wave4_to_2)
xtabs(~ time_between_interviews_1_month_above, data=Wave4_to_2)
xtabs(~ time_between_interviews_2_months_above, data=Wave4_to_2)
xtabs(~ time_between_interviews_6_months_above, data=Wave4_to_2)

#* ------ Data tables = Wave 6 to 4:
Wave6_to_4$time_between_interviews_6_months_below <- case_when (
  Wave6_to_4$time_between_interviews < 183 ~ "Below 183 days",
  Wave6_to_4$time_between_interviews > 182 ~ "Above 182 days")
Wave6_to_4$time_between_interviews_2_months_below <- case_when (
  Wave6_to_4$time_between_interviews < 305 ~ "Below 305 days",
  Wave6_to_4$time_between_interviews > 304 ~ "Above 304 days")
Wave6_to_4$time_between_interviews_1_month_below <- case_when (
  Wave6_to_4$time_between_interviews < 335 ~ "Below 335 days",
  Wave6_to_4$time_between_interviews > 334 ~ "Above 334 days")
Wave6_to_4$time_between_interviews_1_month_above <- case_when (
  Wave6_to_4$time_between_interviews < 395 ~ "Below 395 days",
  Wave6_to_4$time_between_interviews > 394 ~ "Above 394 days")
Wave6_to_4$time_between_interviews_2_months_above <- case_when (
  Wave6_to_4$time_between_interviews < 425 ~ "Below 425 days",
  Wave6_to_4$time_between_interviews > 424 ~ "Above 424 days")
Wave6_to_4$time_between_interviews_6_months_above <- case_when (
  Wave6_to_4$time_between_interviews < 548 ~ "Below 548 days",
  Wave6_to_4$time_between_interviews > 547 ~ "Above 547 days")

xtabs(~ time_between_interviews_6_months_below, data=Wave6_to_4)
xtabs(~ time_between_interviews_2_months_below, data=Wave6_to_4)
xtabs(~ time_between_interviews_1_month_below, data=Wave6_to_4)
xtabs(~ time_between_interviews_1_month_above, data=Wave6_to_4)
xtabs(~ time_between_interviews_2_months_above, data=Wave6_to_4)
xtabs(~ time_between_interviews_6_months_above, data=Wave6_to_4)

#* ------ Data tables = Wave 8 to 6:
Wave8_to_6$time_between_interviews_6_months_below <- case_when (
  Wave8_to_6$time_between_interviews < 183 ~ "Below 183 days",
  Wave8_to_6$time_between_interviews > 182 ~ "Above 182 days")
Wave8_to_6$time_between_interviews_2_months_below <- case_when (
  Wave8_to_6$time_between_interviews < 305 ~ "Below 305 days",
  Wave8_to_6$time_between_interviews > 304 ~ "Above 304 days")
Wave8_to_6$time_between_interviews_1_month_below <- case_when (
  Wave8_to_6$time_between_interviews < 335 ~ "Below 335 days",
  Wave8_to_6$time_between_interviews > 334 ~ "Above 334 days")
Wave8_to_6$time_between_interviews_1_month_above <- case_when (
  Wave8_to_6$time_between_interviews < 395 ~ "Below 395 days",
  Wave8_to_6$time_between_interviews > 394 ~ "Above 394 days")
Wave8_to_6$time_between_interviews_2_months_above <- case_when (
  Wave8_to_6$time_between_interviews < 425 ~ "Below 425 days",
  Wave8_to_6$time_between_interviews > 424 ~ "Above 424 days")
Wave8_to_6$time_between_interviews_6_months_above <- case_when (
  Wave8_to_6$time_between_interviews < 548 ~ "Below 548 days",
  Wave8_to_6$time_between_interviews > 547 ~ "Above 547 days")

xtabs(~ time_between_interviews_6_months_below, data=Wave8_to_6)
xtabs(~ time_between_interviews_2_months_below, data=Wave8_to_6)
xtabs(~ time_between_interviews_1_month_below, data=Wave8_to_6)
xtabs(~ time_between_interviews_1_month_above, data=Wave8_to_6)
xtabs(~ time_between_interviews_2_months_above, data=Wave8_to_6)
xtabs(~ time_between_interviews_6_months_above, data=Wave8_to_6)

#* ------ Data tables = Wave 10 to 8:
Wave10_to_8$time_between_interviews_6_months_below <- case_when (
  Wave10_to_8$time_between_interviews < 183 ~ "Below 183 days",
  Wave10_to_8$time_between_interviews > 182 ~ "Above 182 days")
Wave10_to_8$time_between_interviews_2_months_below <- case_when (
  Wave10_to_8$time_between_interviews < 305 ~ "Below 305 days",
  Wave10_to_8$time_between_interviews > 304 ~ "Above 304 days")
Wave10_to_8$time_between_interviews_1_month_below <- case_when (
  Wave10_to_8$time_between_interviews < 335 ~ "Below 335 days",
  Wave10_to_8$time_between_interviews > 334 ~ "Above 334 days")
Wave10_to_8$time_between_interviews_1_month_above <- case_when (
  Wave10_to_8$time_between_interviews < 395 ~ "Below 395 days",
  Wave10_to_8$time_between_interviews > 394 ~ "Above 394 days")
Wave10_to_8$time_between_interviews_2_months_above <- case_when (
  Wave10_to_8$time_between_interviews < 425 ~ "Below 425 days",
  Wave10_to_8$time_between_interviews > 424 ~ "Above 424 days")
Wave10_to_8$time_between_interviews_6_months_above <- case_when (
  Wave10_to_8$time_between_interviews < 548 ~ "Below 548 days",
  Wave10_to_8$time_between_interviews > 547 ~ "Above 547 days")

xtabs(~ time_between_interviews_6_months_below, data=Wave10_to_8)
xtabs(~ time_between_interviews_2_months_below, data=Wave10_to_8)
xtabs(~ time_between_interviews_1_month_below, data=Wave10_to_8)
xtabs(~ time_between_interviews_1_month_above, data=Wave10_to_8)
xtabs(~ time_between_interviews_2_months_above, data=Wave10_to_8)
xtabs(~ time_between_interviews_6_months_above, data=Wave10_to_8)

#* ------ Data tables = Wave 12 to 10:
Wave12_to_10$time_between_interviews_6_months_below <- case_when (
  Wave12_to_10$time_between_interviews < 183 ~ "Below 183 days",
  Wave12_to_10$time_between_interviews > 182 ~ "Above 182 days")
Wave12_to_10$time_between_interviews_2_months_below <- case_when (
  Wave12_to_10$time_between_interviews < 305 ~ "Below 305 days",
  Wave12_to_10$time_between_interviews > 304 ~ "Above 304 days")
Wave12_to_10$time_between_interviews_1_month_below <- case_when (
  Wave12_to_10$time_between_interviews < 335 ~ "Below 335 days",
  Wave12_to_10$time_between_interviews > 334 ~ "Above 334 days")
Wave12_to_10$time_between_interviews_1_month_above <- case_when (
  Wave12_to_10$time_between_interviews < 395 ~ "Below 395 days",
  Wave12_to_10$time_between_interviews > 394 ~ "Above 394 days")
Wave12_to_10$time_between_interviews_2_months_above <- case_when (
  Wave12_to_10$time_between_interviews < 425 ~ "Below 425 days",
  Wave12_to_10$time_between_interviews > 424 ~ "Above 424 days")
Wave12_to_10$time_between_interviews_6_months_above <- case_when (
  Wave12_to_10$time_between_interviews < 548 ~ "Below 548 days",
  Wave12_to_10$time_between_interviews > 547 ~ "Above 547 days")

xtabs(~ time_between_interviews_6_months_below, data=Wave12_to_10)
xtabs(~ time_between_interviews_2_months_below, data=Wave12_to_10)
xtabs(~ time_between_interviews_1_month_below, data=Wave12_to_10)
xtabs(~ time_between_interviews_1_month_above, data=Wave12_to_10)
xtabs(~ time_between_interviews_2_months_above, data=Wave12_to_10)
xtabs(~ time_between_interviews_6_months_above, data=Wave12_to_10)

#######################################################################################
########################## 7 - CHECK FOR MISSING VALUES: ##############################
#######################################################################################

#* [1] I first recode N/As as missing: The best way to do this is with Dplyr's mutate_all
#* and coalesce functions, to replace the N/As with zeros across each data frame. Zero isn't
#* a value for any of my data points so I can safely use that (note that this function only
#* allows you to replace N/As with 0). 

#* Note that the time variables will make the coalesce function not work, so let's remove
#* these first using subset(). Further note that if uou apply this code twice, you'll get an 
#* error because (obviously) the subset variables have removed the old data:
 
Wave4_to_2 <- subset(Wave4_to_2, select = -c(b_date, c_date, d_date, time_between_interviews,
                                               time_between_interviews_6_months_below,
                                               time_between_interviews_6_months_above,
                                               time_between_interviews_1_month_above,
                                               time_between_interviews_1_month_below,
                                               time_between_interviews_2_months_above,
                                               time_between_interviews_2_months_below))
Wave6_to_4 <- subset(Wave6_to_4, select = -c(d_date, e_date, f_date, time_between_interviews,
                                               time_between_interviews_6_months_below,
                                               time_between_interviews_6_months_above,
                                               time_between_interviews_1_month_above,
                                               time_between_interviews_1_month_below,
                                               time_between_interviews_2_months_above,
                                               time_between_interviews_2_months_below))
Wave8_to_6 <- subset(Wave8_to_6, select = -c(f_date, g_date, h_date, time_between_interviews,
                                               time_between_interviews_6_months_below,
                                               time_between_interviews_6_months_above,
                                               time_between_interviews_1_month_above,
                                               time_between_interviews_1_month_below,
                                               time_between_interviews_2_months_above,
                                               time_between_interviews_2_months_below))
Wave10_to_8 <- subset(Wave10_to_8, select = -c(h_date, i_date, j_date, time_between_interviews,
                                                 time_between_interviews_6_months_below,
                                                 time_between_interviews_6_months_above,
                                                 time_between_interviews_1_month_above,
                                                 time_between_interviews_1_month_below,
                                                 time_between_interviews_2_months_above,
                                                 time_between_interviews_2_months_below))
Wave12_to_10 <- subset(Wave12_to_10, select = -c(j_date, k_date, l_date, time_between_interviews,
                                                   time_between_interviews_6_months_below,
                                                   time_between_interviews_6_months_above,
                                                   time_between_interviews_1_month_above,
                                                   time_between_interviews_1_month_below,
                                                   time_between_interviews_2_months_above,
                                                   time_between_interviews_2_months_below))

#* Then we can coalesce the N/As into zeros:
Wave4_to_2 <- mutate_all(Wave4_to_2, ~coalesce(.,0))
Wave6_to_4 <- mutate_all(Wave6_to_4, ~coalesce(.,0))
Wave8_to_6 <- mutate_all(Wave8_to_6, ~coalesce(.,0))
Wave10_to_8 <- mutate_all(Wave10_to_8, ~coalesce(.,0))
Wave12_to_10 <- mutate_all(Wave12_to_10, ~coalesce(.,0))

#* [2] I now look at the relationship between the ff_ prefixed 
#* *ff_emplw*, *jbsamr* and the wave responses. Basically this is about understanding
#* what waves are referred to in ff_prefixed data does to my analysis, since ff_ won't 
#* necessarily mean the wave immediately prior: it means the last interview, so could 
#* be any wave. I carry out several checks here...

#* ------ *Jbsamr:* 

#* This is the most important one to check. Jbsamr is the most important variable for
#* the creation of this indicator: it asks respondents whether they have worked continuously
#* with the same employer since the last time they were interviewed. But as-worded, this 
#* encompasses some respondents who won't have been interviewed in the previous wave. 

#* The below data shows that only a handful of these need to be re-coded:

xtabs(~Wave4_to_2$d_jbsamr + Wave4_to_2$d_iviolw)
xtabs(~Wave6_to_4$f_jbsamr + Wave6_to_4$f_iviolw)
xtabs(~Wave8_to_6$h_jbsamr + Wave8_to_6$h_iviolw)
xtabs(~Wave10_to_8$j_jbsamr + Wave10_to_8$j_iviolw)
xtabs(~Wave12_to_10$l_jbsamr + Wave12_to_10$l_iviolw)

#* If it turns out respondents to jbsamr haven't been interviewed in a previous wave, there
#* are then two routes to getting the data. The syntax in the next section works through
#* these different issues:
#* [i] If they say they *have* worked continuously (jbsamr = 1), then they can be 
#* assigned the highest score (2). This is because by definition, they will have worked
#* continuously for at least two waves.
#* [ii] If they say they *haven't* worked continuously (jbsamr = 2), I opt for the middle
#* score (1). 

#* ------ *Empchk:* 

#* This is also a crucial question. It is asked only of those who were in paid employment (ff_empLW = 1) 
#* *and* who were employees, self-employed, on furlough or temporarily laid-off (ff_jbstat = 1|2|12|13)
#* the last time they were interviewed. So it tells us if they have been in continuous paid employment 
#* since this prior interview. If they say no in Wave T (empchk = 2), then under certain conditions we 
#* can automatically code them as the worst score (0) for Continuous Employment.   

#* The challenges with Empchk are similar to those with Jbsamr: the "last time we interviewed you" doesn't
#* necessarily mean the previous wave. The tabs below show that a similar (though not identical) number 
#* have this problem as with Jbsamr. Exactly as before, the problem is easy to solve if empchk = 1 
#* (equates to best score = 2). It's more onerous if empchk = 2:

xtabs(~Wave4_to_2$d_empchk + Wave4_to_2$d_iviolw)
xtabs(~Wave6_to_4$f_empchk + Wave6_to_4$e_iviolw)
xtabs(~Wave8_to_6$h_empchk + Wave8_to_6$g_iviolw)
xtabs(~Wave10_to_8$j_empchk + Wave10_to_8$i_iviolw)
xtabs(~Wave12_to_10$l_empchk + Wave12_to_10$k_iviolw)

#* ------ *Other ff_ data:*

#* As a general rule, I opt to avoid further use of either direct ff_ variables, or other variables
#* (other than the ones above) which are worded based on an ff_. Because my five data frames include
#* data from three-wave groupings, there is enough non_ff data to create a comprehensive continuous
#* employment indicator. 

#* The below code gives a taste of how ff_ data and data on the same variable in the wave immediately
#* prior don't match up:

# xtabs(~Wave4_to_2$c_jbstat + Wave4_to_2$d_ff_jbstat)
# xtabs(~Wave12_to_10$k_jbstat + Wave12_to_10$l_ff_jbstat)

gc()

#* REFERENCES:
#* [1] Understanding Society (2022), 'Main survey user guide', pp. 31-32, 
#* https://doc.ukdataservice.ac.uk/doc/6931/mrdoc/pdf/6931_waves1_to_12_user_guide.pdf

#######################################################################################
############################# 8 - GENERATE VARIABLES: #################################
#######################################################################################

#* [a] Jbstat adjustment - Employees who state elsewhere that they're apprentices, temp
#* workers, unemployed, etc: 

#* [Wave 4 to 2:]
Wave4_to_2$d_tempemployee <- case_when(Wave4_to_2$d_jbsemp == 1 & 
                                         (Wave4_to_2$d_jbstat == 3 | Wave4_to_2$d_jbstat == 9 | 
                                          Wave4_to_2$d_jbstat == 10 | Wave4_to_2$d_jbstat == 11 | 
                                          Wave4_to_2$d_jbstat == 12 | Wave4_to_2$d_jbstat == 13) ~ 1,
                                       TRUE ~ 0)

Wave4_to_2$c_tempemployee <- case_when(Wave4_to_2$c_jbsemp == 1 & 
                                         (Wave4_to_2$c_jbstat == 3 | Wave4_to_2$c_jbstat == 9 | 
                                            Wave4_to_2$c_jbstat == 10 | Wave4_to_2$c_jbstat == 11 | 
                                            Wave4_to_2$c_jbstat == 12 | Wave4_to_2$c_jbstat == 13) ~ 1,
                                       TRUE ~ 0)

Wave4_to_2$b_tempemployee <- case_when(Wave4_to_2$b_jbsemp == 1 & 
                                         (Wave4_to_2$b_jbstat == 3 | Wave4_to_2$b_jbstat == 9 | 
                                            Wave4_to_2$b_jbstat == 10 | Wave4_to_2$b_jbstat == 11 | 
                                            Wave4_to_2$b_jbstat == 12 | Wave4_to_2$b_jbstat == 13) ~ 1,
                                       TRUE ~ 0)

#* [Wave 6 to 4:]

Wave6_to_4$f_tempemployee <- case_when(Wave6_to_4$f_jbsemp == 1 & 
                                         (Wave6_to_4$f_jbstat == 3 | Wave6_to_4$f_jbstat == 9 | 
                                            Wave6_to_4$f_jbstat == 10 | Wave6_to_4$f_jbstat == 11 | 
                                            Wave6_to_4$f_jbstat == 12 | Wave6_to_4$f_jbstat == 13) ~ 1,
                                       TRUE ~ 0)

Wave6_to_4$e_tempemployee <- case_when(Wave6_to_4$e_jbsemp == 1 & 
                                         (Wave6_to_4$e_jbstat == 3 | Wave6_to_4$e_jbstat == 9 | 
                                            Wave6_to_4$e_jbstat == 10 | Wave6_to_4$e_jbstat == 11 | 
                                            Wave6_to_4$e_jbstat == 12 | Wave6_to_4$e_jbstat == 13) ~ 1,
                                       TRUE ~ 0)

Wave6_to_4$d_tempemployee <- case_when(Wave6_to_4$d_jbsemp == 1 & 
                                         (Wave6_to_4$d_jbstat == 3 | Wave6_to_4$d_jbstat == 9 | 
                                            Wave6_to_4$d_jbstat == 10 | Wave6_to_4$d_jbstat == 11 | 
                                            Wave6_to_4$d_jbstat == 12 | Wave6_to_4$d_jbstat == 13) ~ 1,
                                       TRUE ~ 0)

#* [Wave 8 to 6:]

Wave8_to_6$h_tempemployee <- case_when(Wave8_to_6$h_jbsemp == 1 & 
                                         (Wave8_to_6$h_jbstat == 3 | Wave8_to_6$h_jbstat == 9 | 
                                            Wave8_to_6$h_jbstat == 10 | Wave8_to_6$h_jbstat == 11 | 
                                            Wave8_to_6$h_jbstat == 12 | Wave8_to_6$h_jbstat == 13) ~ 1,
                                       TRUE ~ 0)

Wave8_to_6$g_tempemployee <- case_when(Wave8_to_6$g_jbsemp == 1 & 
                                         (Wave8_to_6$g_jbstat == 3 | Wave8_to_6$g_jbstat == 9 | 
                                            Wave8_to_6$g_jbstat == 10 | Wave8_to_6$g_jbstat == 11 | 
                                            Wave8_to_6$g_jbstat == 12 | Wave8_to_6$g_jbstat == 13) ~ 1,
                                       TRUE ~ 0)

Wave8_to_6$f_tempemployee <- case_when(Wave8_to_6$f_jbsemp == 1 & 
                                         (Wave8_to_6$f_jbstat == 3 | Wave8_to_6$f_jbstat == 9 | 
                                            Wave8_to_6$f_jbstat == 10 | Wave8_to_6$f_jbstat == 11 | 
                                            Wave8_to_6$f_jbstat == 12 | Wave8_to_6$f_jbstat == 13) ~ 1,
                                       TRUE ~ 0)

#* [Wave 10 to 8:]

Wave10_to_8$j_tempemployee <- case_when(Wave10_to_8$j_jbsemp == 1 & 
                                          (Wave10_to_8$j_jbstat == 3 | Wave10_to_8$j_jbstat == 9 | 
                                             Wave10_to_8$j_jbstat == 10 | Wave10_to_8$j_jbstat == 11 | 
                                             Wave10_to_8$j_jbstat == 12 | Wave10_to_8$j_jbstat == 13) ~ 1,
                                        TRUE ~ 0)

Wave10_to_8$i_tempemployee <- case_when(Wave10_to_8$i_jbsemp == 1 & 
                                          (Wave10_to_8$i_jbstat == 3 | Wave10_to_8$i_jbstat == 9 | 
                                             Wave10_to_8$i_jbstat == 10 | Wave10_to_8$i_jbstat == 11 | 
                                             Wave10_to_8$i_jbstat == 12 | Wave10_to_8$i_jbstat == 13) ~ 1,
                                        TRUE ~ 0)

Wave10_to_8$h_tempemployee <- case_when(Wave10_to_8$h_jbsemp == 1 & 
                                          (Wave10_to_8$h_jbstat == 3 | Wave10_to_8$h_jbstat == 9 | 
                                             Wave10_to_8$h_jbstat == 10 | Wave10_to_8$h_jbstat == 11 | 
                                             Wave10_to_8$h_jbstat == 12 | Wave10_to_8$h_jbstat == 13) ~ 1,
                                        TRUE ~ 0)

#* [Wave 12 to 10:]

Wave12_to_10$l_tempemployee <- case_when(Wave12_to_10$l_jbsemp == 1 & 
                                           (Wave12_to_10$l_jbstat == 3 | Wave12_to_10$l_jbstat == 9 | 
                                              Wave12_to_10$l_jbstat == 10 | Wave12_to_10$l_jbstat == 11 | 
                                              Wave12_to_10$l_jbstat == 12 | Wave12_to_10$l_jbstat == 13) ~ 1,
                                         TRUE ~ 0)

Wave12_to_10$k_tempemployee <- case_when(Wave12_to_10$k_jbsemp == 1 & 
                                           (Wave12_to_10$k_jbstat == 3 | Wave12_to_10$k_jbstat == 9 | 
                                              Wave12_to_10$k_jbstat == 10 | Wave12_to_10$k_jbstat == 11 | 
                                              Wave12_to_10$k_jbstat == 12 | Wave12_to_10$k_jbstat == 13) ~ 1,
                                         TRUE ~ 0)

Wave12_to_10$j_tempemployee <- case_when(Wave12_to_10$j_jbsemp == 1 & 
                                           (Wave12_to_10$j_jbstat == 3 | Wave12_to_10$j_jbstat == 9 | 
                                              Wave12_to_10$j_jbstat == 10 | Wave12_to_10$j_jbstat == 11 | 
                                              Wave12_to_10$j_jbstat == 12 | Wave12_to_10$j_jbstat == 13) ~ 1,
                                         TRUE ~ 0)

#* I now recode variables, starting with Wave 4. Where the function refers to zeros 
#* this refers to N/As; these are subsequently re-coded as -1 in the code. For the 
#* purpose of this code I keep the prefix for the specific wave (w_), to minimise
#* confusion with the subsequent syntax. 

#* The indicator categories comprise the following subgroups:

#* *Worst = 0.* [a] Employees who haven't been continuously employed (w/ same employer) for 
#* 1 wave; [b] Self-employed in current wave; [c] Not continuously in paid work for 1 wave; [d] Employee 
#* in current wave but elsewhere describes self as unemployed, govt training scheme, unpaid family business, 
#* on apprenticeship, on furlough, or temporarily laid off; [e] Not in paid employment in current wave.

#* *Middle = 1.* [a] Employees who have been continuously employed for 1 wave, but not in Wave T-2 or say something in Wave T-2
#* which shows they weren't continuously employed; [b] Employee in current wave but self-employed in previous wave; [c] Employee
#* in current wave but not continuously in paid work at previous wave; [d] Employee in current and previous waves but
#* elsewhere describes self as unemployed, on govt training scheme, unpaid family business, on apprenticeship, on furlough, 
#* or temporarily laid off in previous wave; [e] Employee in current wave who hasn't worked continuously with the same employer 
#* since  last interview, but didn't reply in Wave T-1; [f] Employee in current wave who hasn't been
#* in continuous paid employment since last interview, but didn't reply in Wave T-1. 

#* *Best = 2.* [a] Employees in both waves - who don't elsewhere in survey describe themselves as unemployed, on 
#* govt training scheme, unpaid family business, on apprenticeship, on furlough or temporary laid off - who have responded
#* to both Wave T and T-1 and have been continuously employed with the same employer for both interviews; [b] Employees in current
#* wave - who meet the same conditions as in 2a - but who weren't interviewed in Wave T-1, but said they were continuously employed
#* since last interview. 

#* Note that criteria [0d / 1d] doesn't identify the self-employed or employees from jbstat: they are instead identified
#* using jbsamr [0b / 1b]. This is to be consistent with the identification process for the rest of the index: jbsamr is the best 
#* process for identifying employees and the self-employed since it's a simple binary question. However, I am forced to use jbstat 
#* to identify those amongst the employees (jbsamr = 1) who it would appear don't have the rights associated with employment because of 
#* what they say about their status there - eg if they're on a training scheme, an apprentice, describe self as unemployed, etc. In 
#* practice only a tiny handful of employees - around several dozen each wave - are identified this way. 

#* Effort has been made to make categories as mutually exclusive as possible, but the variable based on whether in paid employment (employ) won't
#* necessarily be so. This is because I need to reconcile my preferred approach to routing people (based on binary variable like the above)
#* with the way Understanding Society routes them. A key variable they use for jbsamr and empchk is employ: whether "in paid employment." 
#* I don't use this to create my QoW index for good reasons: the question wording could be misconstrued as excluding the self-employed. Instead
#* I identify QoW index members based chiefly on whether they did paid work last week "either as an employee or self-employed" (jbhas). 
#* The below code shows that employ excludes a further 983 people, of which a disproportionate number (about 212) are self-employed, than
#* my QoW index approach. My exclusion approach is better for most of the variables in my index, since they're routed based on jbsemp 
#* (employee or self-employed) and jbsemp itself is only asked of those who fulfil the exact same conditions as for my index (jbhas = 1 or
#* jboff = 1):
 
# xtabs(~Wave4_to_2$d_employ + Wave4_to_2$d_jbsemp) 
# xtabs(~Wave4_to_2$d_QoW_Index_Member + Wave4_to_2$d_jbsemp) 
# xtabs(~Wave4_to_2$d_employ + Wave4_to_2$d_QoW_Index_Member)

#* Nevertheless, I have made sure to make [1a], [1b], [1c], [2a] and [2b] mutually exclusive by stipulating that employees must meet any of 
#* the criteria specified in [0d] and [1d]. This isn't always necessary for some case_when statements (it depends on the order in which you 
#* apply the conditions), but it makes the categorisation of respondents as clear as it possibly can be.

#* Employ is necessary even though the routing of jbsamr includes empchk, and I use employ = 2 as a criteria. 

#* Further note that there is no requirement to have responded to Wave T-2 (ie c_iviolw for the Wave 4 to 2 dataset) for any of the variables.
#* For categories [0] and [2], this makes intuitive sense: if someone scores worst in wave T [0] then there is no need to check later waves; 
#* whilst if someone says they're continuously employed at Wave T-1 [2] then they've been continuously employed for over 2 waves regardless of
#* whether they replied to the previous wave. It is only for the Middle [1] category that some assumptions are being made. The net effect of these
#* is to be make a slightly more generous set of assumptions about category [1]. 

#* A central reason for higher levels of response in earlier waves is the lack of a fed forward job status variable (ff_jbstat): there are many proxies
#* / missing values in earlier waves but these go down markedly, likely due to (a) attrition and (b) people getting more chances to answer a jbstat question
#* from a prior wave. To partly get around this, category [1e] and [1f] do make a (generous) assumption for those who say they weren't continuously employed 
#* from the last time they were interview, but who weren't interviewed in Wave T-1: I code them as middle (1). I know from their responses that at one point
#* between Wave T and the last interview (which could be several years) they lost their job or changed employer, but that could have been >2 waves ago or <1
#* wave ago. I split across the middle and allocate them a 1. In practice this affects a very small proportion of respondents. 

#* I also [1a] allocate a [1] score to some people who were continuously employed in Wave T and responded in Wave T-1, but who had a break in their employment
#* at Wave T-2 (eg insecure work, unemployment, not continuously employed for same employer, etc). This is because many of these respondents won't have been 
#* asked about continuous employment in Wave T-1 due to this prior status, and so initially appear as missing due to not being part of the population asked
#* the question. A more generous approach would be to convert everyone who wasn't asked the continuous employment question as =1 (w_jbsamr != 1). But this would
#* include people who didn't respond to the question in the previous wave, rather than just those who were ineligible for who gave a response in Wave T-2 which 
#* reveals their true status.

#* It should be noted [18.07.23] that the unweighted figures here show varying levels of non-response and indicator scores over the course of the time series:
#* far more respondents report continuous employment by Wave 12 than did in Wave 4. Once weighting is introduced, the trend becomes completely consistent: there is
#* a stable 15% non-response, and a stable 60-62%/10-12%/30%-32% 2/1/0 score allocation, across the weighted time series.

#* Comments nested in the code below apply the above logic to the syntax:

Wave4_to_2$d_Ind_ContinuousEmployment <- case_when(Wave4_to_2$d_iviolw == 1 & Wave4_to_2$d_jbsamr == 2 ~ 0, 
                                                         #* [0a] Interviewed at previous wave AND not continuously w/ same employer since last interview;
                                                         Wave4_to_2$d_jbsemp == 2 ~ 0, 
                                                         #* [0b] Self-employed in current wave;
                                                         Wave4_to_2$d_iviolw == 1 & Wave4_to_2$d_employ == 2 ~ 0, 
                                                         #* [0c] Interviewed in previous wave AND not continuously in paid work since last interview; 
                                                         Wave4_to_2$d_jbsemp == 1 & Wave4_to_2$d_tempemployee == 1 ~ 0,
                                                         #* [0d] Employee in current wave but unemployed, govt training scheme, unpaid family business, on apprenticeship, on furlough, or temporarily laid off; 
                                                         Wave4_to_2$d_employ == 2 ~ 0,
                                                         #* [0e] Not in paid employment in current wave;
                                                         Wave4_to_2$d_iviolw == 1 & Wave4_to_2$d_jbsamr == 1 & Wave4_to_2$d_jbsemp == 1 & Wave4_to_2$d_tempemployee != 1 &
                                                           Wave4_to_2$c_jbsamr != 1 &
                                                           (Wave4_to_2$b_jbsemp == 2 | Wave4_to_2$b_employ == 2 | Wave4_to_2$b_jbsamr == 2 | Wave4_to_2$b_tempemployee == 1) ~ 1,
                                                         #* [1a] Employees continuously employed for 1 wave, but either not continuously employed in Wave T-2 or uncertainty as to status; 
                                                         Wave4_to_2$d_jbsemp == 1 & Wave4_to_2$d_tempemployee != 1 & 
                                                           Wave4_to_2$c_jbsemp == 2 ~ 1, 
                                                         #* [1b] Employee in current wave but self-employed in previous wave;
                                                         Wave4_to_2$d_iviolw == 1 & Wave4_to_2$d_jbsemp == 1 & Wave4_to_2$d_tempemployee != 1 & 
                                                           Wave4_to_2$c_employ == 2 ~ 1, 
                                                         #* [1c] Employee in current wave, but not continuously in paid employment at previous wave;
                                                         Wave4_to_2$d_jbsemp == 1 & Wave4_to_2$d_tempemployee != 1 & 
                                                           Wave4_to_2$c_jbsemp == 1 & Wave4_to_2$c_tempemployee == 1 ~ 1,  
                                                         #* [1d] Employee in current and previous waves but elsewhere describes self as unemployed, on govt training scheme, unpaid 
                                                         #* family business, on apprenticeship, on furlough, or temporarily laid off in previous wave;  
                                                         Wave4_to_2$d_jbsamr == 2 & Wave4_to_2$d_jbsemp == 1 & Wave4_to_2$d_tempemployee != 1 & Wave4_to_2$d_iviolw != 1 ~ 1,
                                                         #* [1e] Employee in current wave who hasn't worked continuously with the same employer since  last interview, but didn't reply in Wave T-1;  
                                                         Wave4_to_2$d_empchk == 2 & Wave4_to_2$d_jbsemp == 1 & Wave4_to_2$d_tempemployee != 1 & Wave4_to_2$d_iviolw != 1 ~ 1,
                                                         #* [1f] Employee in current wave who hasn't been in continuous paid employment since last interview, but didn't reply in Wave T-1;
                                                         Wave4_to_2$d_employ == 1 & Wave4_to_2$d_jbsemp == 1 & Wave4_to_2$d_tempemployee != 1 & 
                                                           Wave4_to_2$c_employ == 2 ~ 1, 
                                                         #* [1g] Employee in paid employment in current wave who wasn't in paid employment in previous wave;
                                                         Wave4_to_2$d_jbsemp == 1 & Wave4_to_2$d_tempemployee != 1 & Wave4_to_2$d_jbsamr == 1 & Wave4_to_2$d_iviolw == 1 &
                                                           Wave4_to_2$c_jbsemp == 1 & Wave4_to_2$c_tempemployee != 1 & Wave4_to_2$c_jbsamr == 1 ~ 2,
                                                         #* [2a] Employees in both waves - who don't elsewhere in survey describe themselves as unemployed, on 
                                                         #* govt training scheme, unpaid family business, on apprenticeship, on furlough or temporary laid off - who have responded
                                                         #* to both Wave T and T-1 and have been continuously employed with the same employer for both interviews;
                                                         Wave4_to_2$d_jbsamr == 1 & Wave4_to_2$d_jbsemp == 1 & Wave4_to_2$d_tempemployee != 1 & Wave4_to_2$d_iviolw != 1 ~ 2, 
                                                         #* [2b] Employees in current wave - who meet the same conditions as in 3a - but who weren't interviewed in Wave T-1, but
                                                         #* said they were continuously employed since last interview. 
                                                         TRUE ~ -1)

Wave6_to_4$f_Ind_ContinuousEmployment <- case_when(Wave6_to_4$f_iviolw == 1 & Wave6_to_4$f_jbsamr == 2 ~ 0, 
                                                         #* [0a] Interviewed at previous wave AND not continuously w/ same employer since last interview;
                                                         Wave6_to_4$f_jbsemp == 2 ~ 0, 
                                                         #* [0b] Self-employed in current wave;
                                                         Wave6_to_4$f_iviolw == 1 & Wave6_to_4$f_employ == 2 ~ 0, 
                                                         #* [0c] Interviewed in previous wave AND not continuously in paid work since last interview; 
                                                         Wave6_to_4$f_jbsemp == 1 & Wave6_to_4$f_tempemployee == 1 ~ 0,
                                                         #* [0d] Employee in current wave but unemployed, govt training scheme, unpaid family business, on apprenticeship, on furlough, or temporarily laid off; 
                                                         Wave6_to_4$f_employ == 2 ~ 0,
                                                         #* [0e] Not in paid employment in current wave;
                                                         Wave6_to_4$f_iviolw == 1 & Wave6_to_4$f_jbsamr == 1 & Wave6_to_4$f_jbsemp == 1 & Wave6_to_4$f_tempemployee != 1 &
                                                           Wave6_to_4$e_jbsamr != 1 &
                                                         (Wave6_to_4$d_jbsemp == 2 | Wave6_to_4$d_employ == 2 | Wave6_to_4$d_jbsamr == 2 | Wave6_to_4$d_tempemployee == 1) ~ 1,
                                                         #* [1a] Employees continuously employed for 1 wave, but either not continuously employed in Wave T-2 or uncertainty as to status; 
                                                         Wave6_to_4$f_jbsemp == 1 & Wave6_to_4$f_tempemployee != 1 & 
                                                           Wave6_to_4$e_jbsemp == 2 ~ 1, 
                                                         #* [1b] Employee in current wave but self-employed in previous wave;
                                                         Wave6_to_4$f_iviolw == 1 & Wave6_to_4$f_jbsemp == 1 & Wave6_to_4$f_tempemployee != 1 & 
                                                           Wave6_to_4$e_employ == 2 ~ 1, 
                                                         #* [1c] Employee in current wave, but not continuously in paid employment at previous wave;
                                                         Wave6_to_4$f_jbsemp == 1 & Wave6_to_4$f_tempemployee != 1 & 
                                                           Wave6_to_4$e_jbsemp == 1 & Wave6_to_4$e_tempemployee == 1 ~ 1,  
                                                         #* [1d] Employee in current and previous waves but elsewhere describes self as unemployed, on govt training scheme, unpaid 
                                                         #* family business, on apprenticeship, on furlough, or temporarily laid off in previous wave;  
                                                         Wave6_to_4$f_jbsamr == 2 & Wave6_to_4$f_jbsemp == 1 & Wave6_to_4$f_tempemployee != 1 & Wave6_to_4$f_iviolw != 1 ~ 1,
                                                         #* [1e] Employee in current wave who hasn't worked continuously with the same employer since  last interview, but didn't reply in Wave T-1;  
                                                         Wave6_to_4$f_empchk == 2 & Wave6_to_4$f_jbsemp == 1 & Wave6_to_4$f_tempemployee != 1 & Wave6_to_4$f_iviolw != 1 ~ 1,
                                                         #* [1f] Employee in current wave who hasn't been in continuous paid employment since last interview, but didn't reply in Wave T-1;
                                                         Wave6_to_4$f_employ == 1 & Wave6_to_4$f_jbsemp == 1 & Wave6_to_4$f_tempemployee != 1 & 
                                                           Wave6_to_4$e_employ == 2 ~ 1, 
                                                         #* [1g] Employee in paid employment in current wave who wasn't in paid employment in previous wave;
                                                         Wave6_to_4$f_jbsemp == 1 & Wave6_to_4$f_tempemployee != 1 & Wave6_to_4$f_jbsamr == 1 & Wave6_to_4$f_iviolw == 1 &
                                                           Wave6_to_4$e_jbsemp == 1 & Wave6_to_4$e_tempemployee != 1 & Wave6_to_4$e_jbsamr == 1 ~ 2,
                                                         #* [2a] Employees in both waves - who don't elsewhere in survey describe themselves as unemployed, on 
                                                         #* govt training scheme, unpaid family business, on apprenticeship, on furlough or temporary laid off - who have responded
                                                         #* to both Wave T and T-1 and have been continuously employed with the same employer for both interviews;
                                                         Wave6_to_4$f_jbsamr == 1 & Wave6_to_4$f_jbsemp == 1 & Wave6_to_4$f_tempemployee != 1 & Wave6_to_4$f_iviolw != 1 ~ 2, 
                                                         #* [2b] Employees in current wave - who meet the same conditions as in 3a - but who weren't interviewed in Wave T-1, but
                                                         #* said they were continuously employed since last interview. 
                                                         TRUE ~ -1)

Wave8_to_6$h_Ind_ContinuousEmployment <- case_when(Wave8_to_6$h_iviolw == 1 & Wave8_to_6$h_jbsamr == 2 ~ 0, 
                                                         #* [0a] Interviewed at previous wave AND not continuously w/ same employer since last interview;
                                                         Wave8_to_6$h_jbsemp == 2 ~ 0, 
                                                         #* [0b] Self-employed in current wave;
                                                         Wave8_to_6$h_iviolw == 1 & Wave8_to_6$h_employ == 2 ~ 0, 
                                                         #* [0c] Interviewed in previous wave AND not continuously in paid work since last interview; 
                                                         Wave8_to_6$h_jbsemp == 1 & Wave8_to_6$h_tempemployee == 1 ~ 0,
                                                         #* [0d] Employee in current wave but unemployed, govt training scheme, unpaid family business, on apprenticeship, on furlough, or temporarily laid off; 
                                                         Wave8_to_6$h_employ == 2 ~ 0,
                                                         #* [0e] Not in paid employment in current wave;
                                                         Wave8_to_6$h_iviolw == 1 & Wave8_to_6$h_jbsamr == 1 & Wave8_to_6$h_jbsemp == 1 & Wave8_to_6$h_tempemployee != 1 &
                                                           Wave8_to_6$g_jbsamr != 1 &
                                                           (Wave8_to_6$f_jbsemp == 2 | Wave8_to_6$f_employ == 2 | Wave8_to_6$f_jbsamr == 2 | Wave8_to_6$f_tempemployee == 1) ~ 1,
                                                         #* [1a] Employees continuously employed for 1 wave, but either not continuously employed in Wave T-2 or uncertainty as to status; 
                                                         Wave8_to_6$h_jbsemp == 1 & Wave8_to_6$h_tempemployee != 1 & 
                                                           Wave8_to_6$g_jbsemp == 2 ~ 1, 
                                                         #* [1b] Employee in current wave but self-employed in previous wave;
                                                         Wave8_to_6$h_iviolw == 1 & Wave8_to_6$h_jbsemp == 1 & Wave8_to_6$h_tempemployee != 1 & 
                                                           Wave8_to_6$g_employ == 2 ~ 1, 
                                                         #* [1c] Employee in current wave, but not continuously in paid employment at previous wave;
                                                         Wave8_to_6$h_jbsemp == 1 & Wave8_to_6$h_tempemployee != 1 & 
                                                           Wave8_to_6$g_jbsemp == 1 & Wave8_to_6$g_tempemployee == 1 ~ 1,  
                                                         #* [1d] Employee in current and previous waves but elsewhere describes self as unemployed, on govt training scheme, unpaid 
                                                         #* family business, on apprenticeship, on furlough, or temporarily laid off in previous wave;  
                                                         Wave8_to_6$h_jbsamr == 2 & Wave8_to_6$h_jbsemp == 1 & Wave8_to_6$h_tempemployee != 1 & Wave8_to_6$h_iviolw != 1 ~ 1,
                                                         #* [1e] Employee in current wave who hasn't worked continuously with the same employer since  last interview, but didn't reply in Wave T-1;  
                                                         Wave8_to_6$h_empchk == 2 & Wave8_to_6$h_jbsemp == 1 & Wave8_to_6$h_tempemployee != 1 & Wave8_to_6$h_iviolw != 1 ~ 1,
                                                         #* [1f] Employee in current wave who hasn't been in continuous paid employment since last interview, but didn't reply in Wave T-1;
                                                         Wave8_to_6$h_employ == 1 & Wave8_to_6$h_jbsemp == 1 & Wave8_to_6$h_tempemployee != 1 & 
                                                           Wave8_to_6$g_employ == 2 ~ 1, 
                                                         #* [1g] Employee in paid employment in current wave who wasn't in paid employment in previous wave;
                                                         Wave8_to_6$h_jbsemp == 1 & Wave8_to_6$h_tempemployee != 1 & Wave8_to_6$h_jbsamr == 1 & Wave8_to_6$h_iviolw == 1 &
                                                           Wave8_to_6$g_jbsemp == 1 & Wave8_to_6$g_tempemployee != 1 & Wave8_to_6$g_jbsamr == 1 ~ 2,
                                                         #* [2a] Employees in both waves - who don't elsewhere in survey describe themselves as unemployed, on 
                                                         #* govt training scheme, unpaid family business, on apprenticeship, on furlough or temporary laid off - who have responded
                                                         #* to both Wave T and T-1 and have been continuously employed with the same employer for both interviews;
                                                         Wave8_to_6$h_jbsamr == 1 & Wave8_to_6$h_jbsemp == 1 & Wave8_to_6$h_tempemployee != 1 & Wave8_to_6$h_iviolw != 1 ~ 2, 
                                                         #* [2b] Employees in current wave - who meet the same conditions as in 3a - but who weren't interviewed in Wave T-1, but
                                                         #* said they were continuously employed since last interview. 
                                                         TRUE ~ -1)

Wave10_to_8$j_Ind_ContinuousEmployment <- case_when(Wave10_to_8$j_iviolw == 1 & Wave10_to_8$j_jbsamr == 2 ~ 0, 
                                                          #* [0a] Interviewed at previous wave AND not continuously w/ same employer since last interview;
                                                          Wave10_to_8$j_jbsemp == 2 ~ 0, 
                                                          #* [0b] Self-employed in current wave;
                                                          Wave10_to_8$j_iviolw == 1 & Wave10_to_8$j_employ == 2 ~ 0, 
                                                          #* [0c] Interviewed in previous wave AND not continuously in paid work since last interview; 
                                                          Wave10_to_8$j_jbsemp == 1 & Wave10_to_8$j_tempemployee == 1 ~ 0,
                                                          #* [0d] Employee in current wave but unemployed, govt training scheme, unpaid family business, on apprenticeship, on furlough, or temporarily laid off; 
                                                          Wave10_to_8$j_employ == 2 ~ 0,
                                                          #* [0e] Not in paid employment in current wave;
                                                          Wave10_to_8$j_iviolw == 1 & Wave10_to_8$j_jbsamr == 1 & Wave10_to_8$j_jbsemp == 1 & Wave10_to_8$j_tempemployee != 1 &
                                                            Wave10_to_8$i_jbsamr != 1 &
                                                            (Wave10_to_8$h_jbsemp == 2 | Wave10_to_8$h_employ == 2 | Wave10_to_8$h_jbsamr == 2 | Wave10_to_8$h_tempemployee == 1) ~ 1,
                                                          #* [1a] Employees continuously employed for 1 wave, but either not continuously employed in Wave T-2 or uncertainty as to status; 
                                                          Wave10_to_8$j_jbsemp == 1 & Wave10_to_8$j_tempemployee != 1 & 
                                                            Wave10_to_8$i_jbsemp == 2 ~ 1, 
                                                          #* [1b] Employee in current wave but self-employed in previous wave;
                                                          Wave10_to_8$j_iviolw == 1 & Wave10_to_8$j_jbsemp == 1 & Wave10_to_8$j_tempemployee != 1 & 
                                                            Wave10_to_8$i_employ == 2 ~ 1, 
                                                          #* [1c] Employee in current wave, but not continuously in paid employment at previous wave;
                                                          Wave10_to_8$j_jbsemp == 1 & Wave10_to_8$j_tempemployee != 1 & 
                                                            Wave10_to_8$i_jbsemp == 1 & Wave10_to_8$i_tempemployee == 1 ~ 1,  
                                                          #* [1d] Employee in current and previous waves but elsewhere describes self as unemployed, on govt training scheme, unpaid 
                                                          #* family business, on apprenticeship, on furlough, or temporarily laid off in previous wave;  
                                                          Wave10_to_8$j_jbsamr == 2 & Wave10_to_8$j_jbsemp == 1 & Wave10_to_8$j_tempemployee != 1 & Wave10_to_8$j_iviolw != 1 ~ 1,
                                                          #* [1e] Employee in current wave who hasn't worked continuously with the same employer since  last interview, but didn't reply in Wave T-1;  
                                                          Wave10_to_8$j_empchk == 2 & Wave10_to_8$j_jbsemp == 1 & Wave10_to_8$j_tempemployee != 1 & Wave10_to_8$j_iviolw != 1 ~ 1,
                                                          #* [1f] Employee in current wave who hasn't been in continuous paid employment since last interview, but didn't reply in Wave T-1;
                                                          Wave10_to_8$j_employ == 1 & Wave10_to_8$j_jbsemp == 1 & Wave10_to_8$j_tempemployee != 1 & 
                                                            Wave10_to_8$i_employ == 2 ~ 1, 
                                                          #* [1g] Employee in paid employment in current wave who wasn't in paid employment in previous wave;
                                                          Wave10_to_8$j_jbsemp == 1 & Wave10_to_8$j_tempemployee != 1 & Wave10_to_8$j_jbsamr == 1 & Wave10_to_8$j_iviolw == 1 &
                                                            Wave10_to_8$i_jbsemp == 1 & Wave10_to_8$i_tempemployee != 1 & Wave10_to_8$i_jbsamr == 1 ~ 2,
                                                          #* [2a] Employees in both waves - who don't elsewhere in survey describe themselves as unemployed, on 
                                                          #* govt training scheme, unpaid family business, on apprenticeship, on furlough or temporary laid off - who have responded
                                                          #* to both Wave T and T-1 and have been continuously employed with the same employer for both interviews;
                                                          Wave10_to_8$j_jbsamr == 1 & Wave10_to_8$j_jbsemp == 1 & Wave10_to_8$j_tempemployee != 1 & Wave10_to_8$j_iviolw != 1 ~ 2, 
                                                          #* [2b] Employees in current wave - who meet the same conditions as in 3a - but who weren't interviewed in Wave T-1, but
                                                          #* said they were continuously employed since last interview. 
                                                          TRUE ~ -1)

Wave12_to_10$l_Ind_ContinuousEmployment <- case_when(Wave12_to_10$l_iviolw == 1 & Wave12_to_10$l_jbsamr == 2 ~ 0, 
                                                           #* [0a] Interviewed at previous wave AND not continuously w/ same employer since last interview;
                                                           Wave12_to_10$l_jbsemp == 2 ~ 0, 
                                                           #* [0b] Self-employed in current wave;
                                                           Wave12_to_10$l_iviolw == 1 & Wave12_to_10$l_employ == 2 ~ 0, 
                                                           #* [0c] Interviewed in previous wave AND not continuously in paid work since last interview; 
                                                           Wave12_to_10$l_jbsemp == 1 & Wave12_to_10$l_tempemployee == 1 ~ 0,
                                                           #* [0d] Employee in current wave but unemployed, govt training scheme, unpaid family business, on apprenticeship, on furlough, or temporarily laid off; 
                                                           Wave12_to_10$l_employ == 2 ~ 0,
                                                           #* [0e] Not in paid employment in current wave;
                                                           Wave12_to_10$l_iviolw == 1 & Wave12_to_10$l_jbsamr == 1 & Wave12_to_10$l_jbsemp == 1 & Wave12_to_10$l_tempemployee != 1 &
                                                             Wave12_to_10$k_jbsamr != 1 &
                                                             (Wave12_to_10$j_jbsemp == 2 | Wave12_to_10$j_employ == 2 | Wave12_to_10$j_jbsamr == 2 | Wave12_to_10$j_tempemployee == 1) ~ 1,
                                                           #* [1a] Employees continuously employed for 1 wave, but either not continuously employed in Wave T-2 or uncertainty as to status; 
                                                           Wave12_to_10$l_jbsemp == 1 & Wave12_to_10$l_tempemployee != 1 & 
                                                             Wave12_to_10$k_jbsemp == 2 ~ 1, 
                                                           #* [1b] Employee in current wave but self-employed in previous wave;
                                                           Wave12_to_10$l_iviolw == 1 & Wave12_to_10$l_jbsemp == 1 & Wave12_to_10$l_tempemployee != 1 & 
                                                             Wave12_to_10$k_employ == 2 ~ 1, 
                                                           #* [1c] Employee in current wave, but not continuously in paid employment at previous wave;
                                                           Wave12_to_10$l_jbsemp == 1 & Wave12_to_10$l_tempemployee != 1 & 
                                                             Wave12_to_10$k_jbsemp == 1 & Wave12_to_10$k_tempemployee == 1 ~ 1,  
                                                           #* [1d] Employee in current and previous waves but elsewhere describes self as unemployed, on govt training scheme, unpaid 
                                                           #* family business, on apprenticeship, on furlough, or temporarily laid off in previous wave;  
                                                           Wave12_to_10$l_jbsamr == 2 & Wave12_to_10$l_jbsemp == 1 & Wave12_to_10$l_tempemployee != 1 & Wave12_to_10$l_iviolw != 1 ~ 1,
                                                           #* [1e] Employee in current wave who hasn't worked continuously with the same employer since  last interview, but didn't reply in Wave T-1;  
                                                           Wave12_to_10$l_empchk == 2 & Wave12_to_10$l_jbsemp == 1 & Wave12_to_10$l_tempemployee != 1 & Wave12_to_10$l_iviolw != 1 ~ 1,
                                                           #* [1f] Employee in current wave who hasn't been in continuous paid employment since last interview, but didn't reply in Wave T-1;
                                                           Wave12_to_10$l_employ == 1 & Wave12_to_10$l_jbsemp == 1 & Wave12_to_10$l_tempemployee != 1 & 
                                                             Wave12_to_10$k_employ == 2 ~ 1, 
                                                           #* [1g] Employee in paid employment in current wave who wasn't in paid employment in previous wave;
                                                           Wave12_to_10$l_jbsemp == 1 & Wave12_to_10$l_tempemployee != 1 & Wave12_to_10$l_jbsamr == 1 & Wave12_to_10$l_iviolw == 1 &
                                                             Wave12_to_10$k_jbsemp == 1 & Wave12_to_10$k_tempemployee != 1 & Wave12_to_10$k_jbsamr == 1 ~ 2,
                                                           #* [2a] Employees in both waves - who don't elsewhere in survey describe themselves as unemployed, on 
                                                           #* govt training scheme, unpaid family business, on apprenticeship, on furlough or temporary laid off - who have responded
                                                           #* to both Wave T and T-1 and have been continuously employed with the same employer for both interviews;
                                                           Wave12_to_10$l_jbsamr == 1 & Wave12_to_10$l_jbsemp == 1 & Wave12_to_10$l_tempemployee != 1 & Wave12_to_10$l_iviolw != 1 ~ 2, 
                                                           #* [2b] Employees in current wave - who meet the same conditions as in 3a - but who weren't interviewed in Wave T-1, but
                                                           #* said they were continuously employed since last interview. 
                                                           TRUE ~ -1)

#* Check for effectiveness of filters [15.07.23]: 

# xtabs(~Wave4_to_2$d_iviolw + Wave4_to_2$d_jbsamr + Wave4_to_2$d_Ind_ContinuousEmployment)
# #*[0a - Passed] All self-employed in current wave coded 0;
# xtabs(~Wave4_to_2$d_jbsemp + Wave4_to_2$d_Ind_ContinuousEmployment) 
# #*[0b - Passed] Everyone d_iviolw == 1 and d_jbsamr == 2 coded 0;
# xtabs(~Wave4_to_2$d_iviolw + Wave4_to_2$d_empchk + Wave4_to_2$d_Ind_ContinuousEmployment) 
# #* [0c - Passed]
# xtabs(~Wave4_to_2$d_tempemployee + Wave4_to_2$d_jbsemp + Wave4_to_2$d_Ind_ContinuousEmployment) 
# #* [0d - Passed]
# xtabs(~Wave4_to_2$c_jbsamr + Wave4_to_2$d_jbsamr + Wave4_to_2$d_Ind_ContinuousEmployment)
# 
# xtabs(~Wave4_to_2$d_jbsamr + Wave4_to_2$d_iviolw + Wave4_to_2$d_Ind_ContinuousEmployment)
# 
# xtabs(~Wave4_to_2$d_iviolw + Wave4_to_2$c_jbsamr)
# 
# xtabs(~Wave4_to_2$d_empchk + Wave4_to_2$d_iviolw)
# 
# xtabs(~Wave4_to_2$b_jbstat + Wave4_to_2$d_Ind_ContinuousEmployment + Wave4_to_2$d_QoW_Index_Member)
# 
# xtabs(~Wave4_to_2$d_Ind_ContinuousEmployment + Wave4_to_2$d_jbstat + Wave4_to_2$d_QoW_Index_Member)
# 
# xtabs(~Wave4_to_2$d_jbsamr + Wave4_to_2$d_iviolw + Wave4_to_2$d_empchk)
# 
# xtabs(~Wave4_to_2$d_jbsamr + Wave4_to_2$d_iviolw + Wave4_to_2$d_jbsamr)

#######################################################################################
##################### 9 - CHECK AGAINST THE JQ INDEX: #################################
#######################################################################################

#* [1] To see how many unassigned values I have, I need to now check against the JQ index:

xtabs(~ d_Ind_ContinuousEmployment + d_QoW_Index_Member, data=Wave4_to_2)
# xtabs(~ d_jbstat + d_QoW_Index_Member, data=Wave4_to_2)
# xtabs(~ d_ff_jbstat + d_QoW_Index_Member, data=Wave4_to_2)

xtabs(~ f_Ind_ContinuousEmployment + f_QoW_Index_Member, data=Wave6_to_4)
# xtabs(~ f_jbstat + f_QoW_Index_Member, data=Wave6_to_4)
# xtabs(~ f_ff_jbstat + f_QoW_Index_Member, data=Wave6_to_4)

xtabs(~ h_Ind_ContinuousEmployment + h_QoW_Index_Member, data=Wave8_to_6)
# xtabs(~ h_jbstat + h_QoW_Index_Member, data=Wave8_to_6)
# xtabs(~ h_ff_jbstat + h_QoW_Index_Member, data=Wave8_to_6)

xtabs(~ j_Ind_ContinuousEmployment + j_QoW_Index_Member, data=Wave10_to_8)
# xtabs(~ j_jbstat + j_QoW_Index_Member, data=Wave10_to_8)
# xtabs(~ j_ff_jbstat + j_QoW_Index_Member, data=Wave10_to_8)

xtabs(~ l_Ind_ContinuousEmployment + l_QoW_Index_Member, data=Wave12_to_10)
# xtabs(~ l_jbstat + l_QoW_Index_Member, data=Wave12_to_10)
# xtabs(~ l_ff_jbstat + l_QoW_Index_Member, data=Wave12_to_10)

#* [2] Save xtabs as a CSV [optional]: 
# write.csv((xtabs(~ d_Ind_ContinuousEmployment + d_QoW_Index_Member, data=Wave4_to_2)), "Wave 4 - Continuous Employment by QoW Index.csv")
# write.csv((xtabs(~ f_Ind_ContinuousEmployment + f_QoW_Index_Member, data=Wave6_to_4)), "Wave 6 - Continuous Employment by QoW Index.csv")
# write.csv((xtabs(~ h_Ind_ContinuousEmployment + h_QoW_Index_Member, data=Wave8_to_6)), "Wave 8 - Continuous Employment by QoW Index.csv")
# write.csv((xtabs(~ j_Ind_ContinuousEmployment + j_QoW_Index_Member, data=Wave10_to_8)), "Wave 10 - Continuous Employment by QoW Index.csv")
# write.csv((xtabs(~ l_Ind_ContinuousEmployment + l_QoW_Index_Member, data=Wave12_to_10)), "Wave 12 - Continuous Employment by QoW Index.csv")

gc()

#######################################################################################
###################### 10 - PREPARE TO EXPORT TO OTHER DATA FRAMES: ####################
#######################################################################################

#* [1] First I need to prepare the data for filtering by creating a new data frame, which
#* just consists of the variables I want:

Wave4ContinuousEmployment <- Wave4_to_2 |>
  select(pidp, d_Ind_ContinuousEmployment, d_tempemployee, d_QoW_Index_Member)

Wave6ContinuousEmployment <- Wave6_to_4 |>
  select(pidp, f_Ind_ContinuousEmployment, f_tempemployee, f_QoW_Index_Member)

Wave8ContinuousEmployment <- Wave8_to_6 |>
  select(pidp, h_Ind_ContinuousEmployment, h_tempemployee, h_QoW_Index_Member)

Wave10ContinuousEmployment <- Wave10_to_8 |>
  select(pidp, j_Ind_ContinuousEmployment, j_tempemployee, j_QoW_Index_Member)

Wave12ContinuousEmployment <- Wave12_to_10 |>
  select(pidp, l_Ind_ContinuousEmployment, l_tempemployee, l_QoW_Index_Member)

#######################################################################################
########################## 11 - SAVE DATA FOR FUTURE DOWNLOAD: ########################
#######################################################################################

#* In future sessions I just need to set the working directory and download the dtas 
# * from here:
write_dta(Wave4ContinuousEmployment, file.path(getwd(), "0 - Wave4ContinuousEmployment.dta"))
write_dta(Wave6ContinuousEmployment, file.path(getwd(), "0 - Wave6ContinuousEmployment.dta"))
write_dta(Wave8ContinuousEmployment, file.path(getwd(), "0 - Wave8ContinuousEmployment.dta"))
write_dta(Wave10ContinuousEmployment, file.path(getwd(), "0 - Wave10ContinuousEmployment.dta"))
write_dta(Wave12ContinuousEmployment, file.path(getwd(), "0 - Wave12ContinuousEmployment.dta"))

#* Data check [17.07.23]. Download above from working directory and check:
# Wave4_to_2 <- read_dta('0 - Wave4ContinuousEmployment.dta')
# Wave6_to_4 <- read_dta('0 - Wave6ContinuousEmployment.dta')
# Wave8_to_6 <- read_dta('0 - Wave8ContinuousEmployment.dta')
# Wave10_to_8 <- read_dta('0 - Wave10ContinuousEmployment.dta')
# Wave12_to_10 <- read_dta('0 - Wave12ContinuousEmployment.dta')

