
#######################################################################################
############################## 1 - Data pre-preparation: ##############################
#######################################################################################

#* Some peoples' answers to Wkaut1-4 will be missing / inapplicable (so minuses). I
#* don't mis-record the data by adding these together. 

#* In practice this only affects a tiny number of the values in the dataset, as per the 
#* below. It's never more than double digits and never in any category except -1 (don't know) 
#* or -2 (refusal): 

svytable(~ Dat$variables$wkaut1 + Dat$variables$wkaut2,
         design = Dat)
svytable(~ Dat$variables$wkaut1 + Dat$variables$wkaut3,
         design = Dat)
svytable(~ Dat$variables$wkaut1 + Dat$variables$wkaut4,
         design = Dat)
svytable(~ Dat$variables$wkaut1 + Dat$variables$wkaut5,
         design = Dat)
svytable(~ Dat$variables$wkaut2 + Dat$variables$wkaut3,
         design = Dat)
svytable(~ Dat$variables$wkaut2 + Dat$variables$wkaut4,
         design = Dat)
svytable(~ Dat$variables$wkaut3 + Dat$variables$wkaut4,
         design = Dat)
svytable(~ Dat$variables$wkaut5 + Dat$variables$wkaut2,
         design = Dat)
svytable(~ Dat$variables$wkaut5 + Dat$variables$wkaut3,
         design = Dat)
svytable(~ Dat$variables$wkaut5 + Dat$variables$wkaut4,
         design = Dat)

#* To get around this, I remove values which are missing on any ONE of these variables.
#* This is fortunately very easy to do, since the lowest legitimate value on the 4 composite variables
#* is [5]. So any values below 5 will be removed ex post facto.

#######################################################################################
################################# 2 - Create indicator: ###############################
#######################################################################################

#* First convert the missing / NA/ inapplicables into unusual scores. I recode these individually
#* as follows. I deliberately recode with a decimal point because that way, we can track where 
#* these go:
Dat$variables$wkaut1_adj <- replace(Dat$variables$wkaut1,
                                Dat$variables$wkaut1 %in% c(-11,-10,-9,-8,-7,-2,-1), 0.1)

Dat$variables$wkaut2_adj <- replace(Dat$variables$wkaut2,
                                Dat$variables$wkaut2 %in% c(-11,-10,-9,-8,-7,-2,-1), 0.1)

Dat$variables$wkaut3_adj <- replace(Dat$variables$wkaut3,
                                Dat$variables$wkaut3 %in% c(-11,-10,-9,-8,-7,-2,-1), 0.1)

Dat$variables$wkaut4_adj <- replace(Dat$variables$wkaut4,
                                Dat$variables$wkaut4 %in% c(-11,-10,-9,-8,-7,-2,-1), 0.1)

Dat$variables$wkaut5_adj <- replace(Dat$variables$wkaut5,
                                Dat$variables$wkaut5 %in% c(-11,-10,-9,-8,-7,-2,-1), 0.1)

#* Then add up all the autonomy results:
Dat$variables$combinedautonomy <- Dat$variables$wkaut1_adj + Dat$variables$wkaut2_adj + 
  Dat$variables$wkaut3_adj + Dat$variables$wkaut4_adj + Dat$variables$wkaut5_adj
  
#* Note [21.07.23] that there are very few missings in the data. Where there are missings in the QoW index, 
#* they tend to be all missing (thus coded 0.5): there are very few cases of people asking one but
#* not all questions about autonomy. Further note [06.08.23] the updated code calculating weighted means
#* for autonomy by the JQ index, employees and self-employed:
JQ <- Dat |> filter(Dat$variables$index == "Quality of Work")
svytable(~combinedautonomy + jbsemp, design = JQ)
svyby(formula = ~combinedautonomy, by = ~year,
      design = JQ, 
      FUN = svymean, 
      na.rm = TRUE, row.names = FALSE)
svyby(formula = ~combinedautonomy, by = ~year,
      design = Employees, 
      FUN = svymean, 
      na.rm = TRUE, row.names = FALSE)
svyby(formula = ~combinedautonomy, by = ~year,
      design = SelfEmployed, 
      FUN = svymean, 
      na.rm = TRUE, row.names = FALSE)

#* Then create the variable. Automatically code any with values below 4 as 0. Note that this score is 
#* inverted, ie lower values equate to better indicator scores:
Dat$variables$Ind_Autonomy <- case_when(Dat$variables$combinedautonomy < 5 ~ -1,
                                              (Dat$variables$combinedautonomy == 5 | Dat$variables$combinedautonomy == 6 | Dat$variables$combinedautonomy == 7 | Dat$variables$combinedautonomy == 8 | Dat$variables$combinedautonomy == 9) ~ 2,
                                               (Dat$variables$combinedautonomy == 10 | Dat$variables$combinedautonomy == 11 | Dat$variables$combinedautonomy == 12 | Dat$variables$combinedautonomy == 13 | Dat$variables$combinedautonomy == 14 | Dat$variables$combinedautonomy == 15) ~ 1,
                                               (Dat$variables$combinedautonomy == 16 | Dat$variables$combinedautonomy == 17 | Dat$variables$combinedautonomy == 18 | Dat$variables$combinedautonomy == 19 | Dat$variables$combinedautonomy == 20) ~ 0, 
                                              TRUE ~ -1)

#######################################################################################
########################## 3 - Visualisation and tabulation: ##########################
#######################################################################################

#* ------------- [a] Create filters and time series

#* The data shows [21.07.23] a slight decline in self-employed autonomy over the time series, 
#* but no consistent trend re. employee autonomy. A low proportion have the Worst score, 
#* esp. for self-employed. 

#* Create filtered JQ index:
JQ <- Dat |> filter(Dat$variables$index == "Quality of Work")
Employees <- Dat |> filter(Dat$variables$jbsemp == 1)
SelfEmployed <- Dat |> filter(Dat$variables$jbsemp == 2)

#* Full data, both groups:
prop.table(svytable((~Ind_Autonomy + year),JQ), margin=2)
prop.table(svytable((~Ind_Autonomy + year),Employees), margin=2)
prop.table(svytable((~Ind_Autonomy + year),SelfEmployed), margin=2)

#* Employees and self-employed:
svytable(~Ind_Autonomy + year, design = Employees)
svytable(~Ind_Autonomy + year, design = SelfEmployed)

#* ------------- [b] Test vs. weighted mean results

#* I now compare if the Alkire-Foster style cut-off approach gives different results vs.
#* if you just use a mean. I first turn all -1s into NAs:
Dat$variables$combinedautonomy_NAs <- replace(Dat$variables$combinedautonomy, 
                                              Dat$variables$combinedautonomy %in% c(-1), NA)

#* Then re-create the filtered JQ index to apply the above:
JQ <- Dat |> filter(Dat$variables$index == "Quality of Work")
Employees <- Dat |> filter(Dat$variables$jbsemp == 1)
SelfEmployed <- Dat |> filter(Dat$variables$jbsemp == 2)

#* Calculate survey means. Note lower score = higher QoW for these means, because I 
#* haven't inverted the scores for this. The data is broadly consistent: no clear trend for
#* employees, but a decline in self-employed scores (with the outlier of Wave 6): 
svyby(formula = ~combinedautonomy_NAs, by = ~year,
      design = JQ,
      FUN = svymean,
      na.rm = TRUE,
      row.names = FALSE)
svyby(formula = ~combinedautonomy_NAs, by = ~year,
      design = Employees,
      FUN = svymean,
      na.rm = TRUE,
      row.names = FALSE)
svyby(formula = ~combinedautonomy_NAs, by = ~year,
      design = SelfEmployed,
      FUN = svymean,
      na.rm = TRUE,
      row.names = FALSE)

#######################################################################################
###################### 4 - SAVE THE INDICATOR INTO THE SURVEY: ########################
#######################################################################################

#* Saved the above as of [26.09.23]:
saveRDS(Dat, file = "0 - Dat.RData")

Dat <- readRDS("0 - Dat.RData")
Dat$variables$Ind_Autonomy

