
#######################################################################################
############################# 1 - Data pre-preparation: ###############################
#######################################################################################

#* The below tables confirm the self-employed aren't asked this question (this isn't made
#* clear on the UKHLS variable search webpages, but it is stated in the questionnaires
#* themselves):
svytable(~jbsemp + tujbpl, design = Dat)
svytable(~jbsemp + tuin1, design = Dat)

#* In Waves 4-10, Understanding Society didn't ask people if they were members of a trade 
#* union or staff association unless they first said they had a trade union or staff association
#* in their workplace. So we only know, of the subset of people with a recognised union or staff
#* association, how many are members of it.[1] From Wave 12, the question was changed so the union 
#* membership question is not quite so contingent on it: people who have a workplace union/association
#* are asked if they're members of *that* union, whereas those who don't are asked if they're members of
#* *a* union.[2] A small number (>350) respondents in Wave 12 are members of a union but have no recognised 
#* union/staff association at the workplace.

#* Because of this discrepancy, this variable makes use only of the question on union or staff association 
#* membership (tujbpl). I discount the possibility of creating a categorical variable using both variables,
#* eg by coding people as "best" if they're both members of a union and have an employer-recognised union. 
#* Even the amended (Wave 12) wording of tuin1 isn't quite satisfactory, since it won't capture people who
#* have an employer-recognised union or staff association, aren't a member of that union, but are members of
#* another union.
svytable(~tujbpl + tuin1, design = Dat)

#* REFERENCES:
#* [1] Understanding Society (2014), UK Household Longitudinal Study Mainstage Questionnaire - Wave 4, , pp. 276-277, 
#* https://www.understandingsociety.ac.uk/sites/default/files/downloads/documentation/mainstage/questionnaire/wave-4/Wave_4_Questionnaire_Consultation_v03_2.pdf?q=5896c74241785e83462be861b5dfc1b09eafbf45
#* [2] Understanding Society (2022), UK Household Longitudinal Study Mainstage Questionnaire - Wave 12, pp. 486-487, 
#* https://www.understandingsociety.ac.uk/sites/default/files/downloads/documentation/mainstage/questionnaire/wave-12/W12-questionnaire-consultation.pdf

#######################################################################################
################################# 2 - Create indicator: ###############################
#######################################################################################

#* Start by automatically recoding the self-employed to no union or staff association
#* at workplace (tujbpl == 2): 
Dat$variables$tujbpl_adj <- case_when(Dat$variables$jbsemp == 2 ~ 2,
                                  TRUE ~ as.numeric(as.character(Dat$variables$tujbpl)))

#* Then create the indicator: 
Dat$variables$Ind_CollectiveVoice <- case_when(Dat$variables$tujbpl_adj == 1 ~ 2,
                                                   Dat$variables$tujbpl_adj == 2 ~ 0,
                                                   TRUE ~ -1) 

#######################################################################################
########################## 3 - Visualisation and tabulation: ##########################
#######################################################################################

#* Create filtered JQ index:
JQ <- Dat |> filter(Dat$variables$index == "Quality of Work")
Employees <- Dat |> filter(Dat$variables$jbsemp == 1)
SelfEmployed <- Dat |> filter(Dat$variables$jbsemp == 2)

#* Proportional table time series:
prop.table(svytable((~Ind_CollectiveVoice + year),JQ), margin=2)
prop.table(svytable((~Ind_CollectiveVoice + year),Employees), margin=2)
prop.table(svytable((~Ind_CollectiveVoice + year),SelfEmployed), margin=2)

#######################################################################################
###################### 4 - SAVE THE INDICATOR INTO THE SURVEY: ########################
#######################################################################################

#* Saved the above as of [26.09.23]:
saveRDS(Dat, file = "0 - Dat.RData")

Dat <- readRDS("0 - Dat.RData")
Dat$variables$Ind_CollectiveVoice
