
#######################################################################################
############################# 1 - Data pre-preparation: ###############################
#######################################################################################

#* Note that there is 100% consistency between responses in the flexibility data. This is
#* because these questions are all asked as part of a matrix in the same survey question:
svytable(~jbflex1 + jbsemp, design = Dat)
svytable(~jbflex2 + jbsemp, design = Dat)
svytable(~jbflex3 + jbsemp, design = Dat)
svytable(~jbflex4 + jbsemp, design = Dat)
svytable(~jbflex5 + jbsemp, design = Dat)
svytable(~jbflex6 + jbsemp, design = Dat)
svytable(~jbflex7 + jbsemp, design = Dat)
svytable(~jbflex8 + jbsemp, design = Dat)

#* Note that zero hours contracts and on-call working were also added to the matrix in
#* Wave 8, but I do not include these as they suggest poor rather than good flexibility.

#######################################################################################
################################# 2 - Create indicator: ###############################
#######################################################################################

#* Because there's absolute consistency between the missing values, I don't need to do 
#* anything to recode them: all the negatives will just add on to each other and I can then
#* exclude them ex post facto. This is different from other composite indicators like autonomy. 
  
#* So that means I just need to add them together:
Dat$variables$combinedflexibility <- Dat$variables$jbflex1 +Dat$variables$jbflex2 +
  Dat$variables$jbflex3 + Dat$variables$jbflex4 + Dat$variables$jbflex5 +
  Dat$variables$jbflex6 + Dat$variables$jbflex7 + Dat$variables$jbflex8
  
#* Test [06.08.23] for what trend looks like if you go with a cardinal flexibility score rather
#* than cut-offs:
Dat$variables$combinedflexibility_nonegative <- case_when(Dat$variables$combinedflexibility < 0 ~ -1,
                                                         TRUE ~ as.numeric(as.character(Dat$variables$combinedflexibility)))
Dat$variables$combinedflexibility_nonegative_NAs <- replace(Dat$variables$combinedflexibility_nonegative,
                                                       Dat$variables$combinedflexibility_nonegative %in% c(-1), NA)

#* Above saved as of [6.10.23]:
# saveRDS(Dat, file = "0 - Dat.RData")

#* Analysis of 'raw' flexibiity trends by year:
svyby(formula = ~combinedflexibility_nonegative, by = ~year,
      design = JQ, 
      FUN = svymean, 
      na.rm = TRUE, row.names = FALSE)

#* Then I need to create a variable with this new variable included. Note [21.07.23] that
#* self-employed are coded missing in this variable, and are only assigned a score in this
#* dimension based on working hours. I apply this later, during the index creation stage:
Dat$variables$Ind_Flexibility <- case_when((Dat$variables$combinedflexibility == 0) ~ 0,
                                                 (Dat$variables$combinedflexibility == 1 | Dat$variables$combinedflexibility == 2) ~ 1,
                                                 (Dat$variables$combinedflexibility > 2) ~ 2,
                                                 (Dat$variables$combinedflexibility < 0) ~ -1,
                                                 TRUE ~ -1)

#######################################################################################
########################## 3 - Visualisation and tabulation: ##########################
#######################################################################################

#* Re-add filters:
JQ <- Dat |> filter(Dat$variables$index == "Quality of Work")
Employees <- Dat |> filter(Dat$variables$jbsemp == 1)
SelfEmployed <- Dat |> filter(Dat$variables$jbsemp == 2)

#* Proportional table time series:
prop.table(svytable((~Ind_Flexibility + year),JQ), margin=2)
prop.table(svytable((~Ind_Flexibility + year),Employees), margin=2)
prop.table(svytable((~Ind_Flexibility + year),SelfEmployed), margin=2)

#######################################################################################
###################### 4 - Save the indicator into the survey: ########################
#######################################################################################

#* Saved the above as of [26.09.23]:
saveRDS(Dat, file = "0 - Dat.RData")

Dat <- readRDS("0 - Dat.RData")
Dat$variables$Ind_Flexibility