
#######################################################################################
############################# 1 - Data pre-preparation: ###############################
#######################################################################################

#* Note that the only people who report their hours as zero are 65 people in j2hrs. By
#* definition these will be added to jbhrs or jshrs people who either have missing values
#* or report >0 hours worked, so there should be nobody in my index who literally works 
#* zero hours. 

# length(which(Dat$variables$jbhrs==0))
# length(which(Dat$variables$jbot==0))
# length(which(Dat$variables$jshrs==0))
# length(which(Dat$variables$j2hrs==0))
# length(which(Dat$variables$jbhrs==-1))
# length(which(Dat$variables$jbot==-1))
# length(which(Dat$variables$jshrs==-1))
# length(which(Dat$variables$j2hrs==-1))
# length(which(Dat$variables$jbhrs==-2))
# length(which(Dat$variables$jbot==-2))
# length(which(Dat$variables$jshrs==-2))
# length(which(Dat$variables$j2hrs==-2))
# length(which(Dat$variables$jbhrs==-7))
# length(which(Dat$variables$jbot==-7))
# length(which(Dat$variables$jshrs==-7))
# length(which(Dat$variables$j2hrs==-7))
# length(which(Dat$variables$jbhrs==-9))
# length(which(Dat$variables$jbot==-9))
# length(which(Dat$variables$jshrs==-9))
# length(which(Dat$variables$j2hrs==-9))
# length(which(Dat$variables$jbhrs==-10))
# length(which(Dat$variables$jbot==-10))
# length(which(Dat$variables$jshrs==-10))
# length(which(Dat$variables$j2hrs==-10))
# length(which(Dat$variables$jbhrs==-11))
# length(which(Dat$variables$jbot==-11))
# length(which(Dat$variables$jshrs==-11))
# length(which(Dat$variables$j2hrs==-11))

#* Note that as of Wave 12 Understanding Society has asked a question on whether employees 
#* (though not self-employed) would like to work more, fewer or about the same hours 
#* per week.[1] As this wasn't asked in any prior wave I it isn't used in the QoW 
#* index.

#* REFERENCES
#* [1] Understanding Society, 'jbhrcpr: change hours work per week',
#* https://www.understandingsociety.ac.uk/documentation/mainstage/dataset-documentation/variable/jbhrcpr

#######################################################################################
########################### 1 - Prepare the hours variable: ###########################
#######################################################################################

#* --------------- [a] Account for missing/inapplicable/etc:

#* I need to prepare the hours variables in the same way I did as for the Earnings 
#* Equity indicator. For excessive hours, however, I also include the overtime data
#* for employees as well (jbot). 

#* First recode inapplicable and proxy as zero. The proxy recoding is because j2hrs
#* has a large number of proxies:
Dat$variables$jbhrs_adj <- case_when(Dat$variables$jbhrs == -7 ~ 0,
                                      Dat$variables$jbhrs == -8 ~ 0,
                                      TRUE ~ as.numeric(as.character(Dat$variables$jbhrs)))
Dat$variables$jshrs_adj <- case_when(Dat$variables$jshrs == -7 ~ 0,
                                      Dat$variables$jshrs == -8 ~ 0,
                                      TRUE ~ as.numeric(as.character(Dat$variables$jshrs)))
Dat$variables$j2hrs_adj <- case_when(Dat$variables$j2hrs == -7 ~ 0,
                                      Dat$variables$j2hrs == -8 ~ 0,
                                      TRUE ~ as.numeric(as.character(Dat$variables$j2hrs)))
Dat$variables$jbot_adj <- case_when(Dat$variables$jbot == -7 ~ 0,
                                      Dat$variables$jbot == -8 ~ 0,
                                      TRUE ~ as.numeric(as.character(Dat$variables$jbot)))

#* Then recode the rest as NAs, so that someone who is NA in any one of them is 
#* removed from the indicator:
Dat$variables$jbhrs_adj <- replace(Dat$variables$jbhrs_adj,
                                   Dat$variables$jbhrs_adj %in% c(-1, -2, -9, -10, -11), NA)
Dat$variables$jshrs_adj <- replace(Dat$variables$jshrs_adj,
                                   Dat$variables$jshrs_adj %in% c(-1, -2, -9, -10, -11), NA)
Dat$variables$j2hrs_adj <- replace(Dat$variables$j2hrs_adj,
                                   Dat$variables$j2hrs_adj %in% c(-1, -2, -9, -10, -11), NA)
Dat$variables$jbot_adj <- replace(Dat$variables$jbot_adj,
                                   Dat$variables$jbot_adj %in% c(-1, -2, -9, -10, -11), NA)

#* --------------- [b] Convert j2hrs into a weekly variable:

#* Now also convert j2hrs to a weekly rather than a monthly variable, as j2hrs is supposed to
#* be hours normally worked per month in second jobs:
Dat$variables$j2hrs_adj_weekly <- (Dat$variables$j2hrs_adj * 12) / 52

#* --------------- [c] Add all four together:

#* Now add all four together. Note that jbhrs and jshrs are already mutually exclusive, because
#* they're only asked of employees vs. self-employed: 
Dat$variables$labhrs_adj_weekly <- Dat$variables$jbhrs_adj + Dat$variables$jshrs_adj + 
  Dat$variables$j2hrs_adj_weekly + Dat$variables$jbot_adj

#* --------------- [d] Remove some extreme outliers:

#* There are six cases where the weekly hours worked comes out at higher than 130. The
#* max is 180 - a physicaly impossible number of hours to work a week. This contrasts with the
#* earnings equity variable where nobody works more than 126 hours.
max(Dat$variables$labhrs_adj_weekly, na.rm = TRUE)
Dat$variables$labhrs_adj_test <- case_when(Dat$variables$labhrs_adj_weekly >= 126 ~ 1,
                                           TRUE ~ 0)
svytable(~labhrs_adj_test, design = Dat)

#* Although the number of outliers is so negligible as to be pointless to correct, I
#* nevertheless remove them from the index:
Dat$variables$labhrs_adj_weekly_NAs <- case_when(Dat$variables$labhrs_adj_weekly >= 126 ~ -1,
                                                 TRUE ~ as.numeric(as.character(Dat$variables$labhrs_adj_weekly)))
Dat$variables$labhrs_adj_weekly_NAs <- replace(Dat$variables$labhrs_adj_weekly_NAs, 
                                               Dat$variables$labhrs_adj_weekly_NAs %in% c(-1), NA)

#* On a final note, note the existence of several hundred people in the QoW index who report zero
#* working hours (their wages will be corrected for for the Earnings Equity indicator). However,
#* I opt to keep these in the Excessive Hours indicator:
length(which(JQ$variables$labhrs_adj_weekly_NAs == 0))
length(which(Dat$variables$labhrs_adj_weekly_NAs == 0))

#* Saved labhrs_adj_weekly_NAs as of [06.10.23]
# saveRDS(Dat, file = "0 - Dat.RData")

#######################################################################################
################################# 2 - Create indicator: ###############################
#######################################################################################

#* The upper-level cut-off is justified by the UK's Working Time Directive, but there's some debate
#* over what the mid-level cut-off should be. To inform this, I look at the ONS's average actual 
#* weekly working hours for full-time workers.[1] This currently stands at about 36.5 hours, having
#* fallen steadily over the decades from 38 hours in the early-1990s. 

#* I set a mid-level cut-off slightly above this, at > 37 hours. This will be higher than many (good)
#* contracts stipulate in their working hours. The 36.5-37 hour cut-off is very delicate: whether you go
#* for 36.5, 37 inclusive or above 37 determines whether the Middle or the High score is the since largest
#* group for working hours:
Dat$variables$Ind_ExcessiveHours <- case_when(Dat$variables$labhrs_adj_weekly_NAs > 48 ~ 0,
                                                    (Dat$variables$labhrs_adj_weekly_NAs <= 48 & Dat$variables$labhrs_adj_weekly_NAs > 37) ~ 1,
                                              Dat$variables$labhrs_adj_weekly_NAs <= 37 ~ 2,
                                              TRUE ~ -1)

#* REFERENCES: 
#* [1] ONS (2023), 'Average actual weekly hours of work for full-time workers 
#* (seasonally adjusted)', 
#* https://www.ons.gov.uk/employmentandlabourmarket/peopleinwork/earningsandworkinghours/timeseries/ybuy/lms

#######################################################################################
########################## 3 - VISUALISATION AND TABULATION: ##########################
#######################################################################################

#* Create filtered JQ index:
JQ <- Dat |> filter(Dat$variables$index == "Quality of Work")
Employees <- Dat |> filter(Dat$variables$jbsemp == 1)
SelfEmployed <- Dat |> filter(Dat$variables$jbsemp == 2)

#* Full data, both groups:
prop.table(svytable((~Ind_ExcessiveHours + year),JQ), margin=2)
prop.table(svytable((~Ind_ExcessiveHours + year),Employees), margin=2)
prop.table(svytable((~Ind_ExcessiveHours + year),SelfEmployed), margin=2)

#* Distribution of self-employed vs. employee hours:
ggsurvey(Employees, aes(x = Employees$variables$labhrs_weekly)) +
  geom_histogram (binwidth=1, fill = '#CD6253') +
  xlim(1, 100) +
  theme_economist()
ggsurvey(SelfEmployed, aes(x = SelfEmployed$variables$labhrs_weekly)) +
  geom_histogram (binwidth=1, fill = '#CD6253') +
  xlim(1, 100) +
  theme_economist()
ggsurvey(SelfEmployed, aes(x = SelfEmployed$variables$jshrs_recodetozero)) +
  geom_histogram (binwidth=1, fill = '#CD6253') +
  xlim(1, 100) +
  theme_economist()
ggsurvey(SelfEmployed, aes(x = SelfEmployed$variables$j2hrs_recodetozero)) +
  geom_histogram (binwidth=1, fill = '#CD6253') +
  xlim(1, 100) +
  theme_economist()
ggsurvey(Employees, aes(x = Employees$variables$j2hrs_recodetozero)) +
  geom_histogram (binwidth=1, fill = '#CD6253') +
  xlim(1, 100) +
  theme_economist()

#######################################################################################
###################### 4 - SAVE THE INDICATOR INTO THE SURVEY: ########################
#######################################################################################

#* Saved the above as of [26.09.23]:
saveRDS(Dat, file = "0 - Dat.RData")

Dat <- readRDS("0 - Dat.RData")
Dat$variables$Ind_ExcessiveHours
