
#* Install packages and set working directory:
setwd("INSERT UKHLS WORKING DIRECTORY HERE")
library(haven) #* For read_dta();
library(dplyr) #* For select();
library(stats) #* For logistic regressions and other models;
library(pollster) #* For summary stats / time series / cross-tabs when using weights (not survey design objects).

#* Sunsetted packages:
# library(labelled) #* Pulling labels out of SOCs to use them as descriptors;

#* Change options:
# options(scipen = 999)

##########################################################################
##########################################################################
####### [1] Download Labour Force Surveys
##########################################################################
##########################################################################

#* Some commentary on LFS variables:
#* [1] The person weight variables (PWT) don't always match with the year in question, despite what the 
#* documentation says. For example the 2012 user guide says the weight for surveys of that year should be 
#* PWT11. The user guide from the UKDA webpage for the Q1 2012 LFS is the 2011 user guide, and this says 
#* it should be PWT11. In fact it is PWT18. For the correct weight, always refer to the latest user guide
#* at the time from the ONS website,[1] and not to any user guides in the UKDS webpage. At the time of 
#* writing [23.10.23], this is the 2022 'Details of LFS Variables' user guide.[2]
#* [2] The industry in second job (ICD2) is only available in the Secure Access dataset.
#* [3] The ICDM variable isn't in the Q1 2017 Labour Force Survey, for some reason. 

#* Variables to add to previous waves, if needed:
#* [1] Ethnicity EUL version;
#* [2] SOC in 2009 and 2010 versions;
#* [3] NS-SEC in 2009 and 2010 versions;
#* [4] Govt office region from Q1 2016;
#* [5] SIC of second job from Q1 2016.

LFS_2009_Q1 <- read_dta("lfsp_jm09_end_user.dta") |> 
  select(PWT14, IOUTCOME, #* Person weight, respondent/interview details; 
         ICDM, INDC07M, INDS07M, INDC07S, SECTOR, PUBLICR, #* SOC, industry, public/private sector, NS-SEC;
         MANAGER, SOLOR, #* Managerial duties; 
         ILODEFR, INECAC05, STATR,  WRKING, JBAWAY, #* Job status, employee/self-employed;
         TTUSHR, #* Hours worked;
         SEX, AGE, GOVTOF, #* Individual characteristics;
         ACCDNT, WCHJB) #* Work accidents and illness.

LFS_2010_Q1 <- read_dta("lfsp_jm10_end_user.dta") |> 
  select(PWT14, IOUTCOME, #* Person weight, respondent/interview details; 
         ICDM, INDC07M, INDS07M, INDC07S, SECTOR, PUBLICR, #* SOC, industry, public/private sector, NS-SEC;
         MANAGER, SOLOR, #* Managerial duties; 
         ILODEFR, INECAC05, STATR,  WRKING, JBAWAY, #* Job status, employee/self-employed;
         TTUSHR, #* Hours worked;
         SEX, AGE, GOVTOF, #* Individual characteristics;
         ACCDNT, ILLWK, HOW1CAUS, HOW2CAUS, HOW3CAUS, WCHJB, WCHJB3) #* Work accidents and illness.

LFS_2011_Q1 <- read_dta("lfsp_jm11_end_user.dta") |> 
  select(PWT14, IOUTCOME, #* Person weight, respondent/interview details; 
         SOC10M, ICDM, INDC07M, INDS07M, INDC07S, SECTOR, PUBLICR, NSECM10, NSECMJ10, #* SOC, industry, public/private sector, NS-SEC;
         MANAGER, SOLOR, #* Managerial duties; 
         ILODEFR, INECAC05, STATR,  WRKING, JBAWAY, #* Job status, employee/self-employed;
         TTUSHR, #* Hours worked;
         SEX, AGE, GOVTOF, #* Individual characteristics;
         ACCDNT, ILLWRK, HOW1CAUS, HOW2CAUS, HOW3CAUS, WCHJB, WCHJB3) #* Work accidents and illness.

LFS_2012_Q1 <- read_dta("lfsp_jm12_end_user.dta") |> 
  select(PWT18, IOUTCOME, #* Person weight, respondent/interview details; 
         SOC10M, ICDM, INDC07M, INDS07M, INDC07S, SECTOR, PUBLICR, NSECM10, NSECMJ10, #* SOC, industry, public/private sector, NS-SEC;
         MANAGER, SOLOR, #* Managerial duties; 
         ILODEFR, INECAC05, STATR,  WRKING, JBAWAY, #* Job status, employee/self-employed;
         TTUSHR, #* Hours worked;
         ETHUKEUL, SEX, AGE, GOVTOF, #* Individual characteristics;
         ACCDNT, ILLWRK, HOW1CAUS, HOW2CAUS, HOW3CAUS, WCHJB, WCHJB3) #* Work accidents and illness.

LFS_2013_Q1 <- read_dta("lfsp_jm13_end_user.dta") |> 
  select(PWT18, IOUTCOME, #* Person weight, respondent/interview details; 
         SOC10M, ICDM, INDC07M, INDS07M, INDC07S, SECTOR, PUBLICR, NSECM10, NSECMJ10, #* SOC, industry, public/private sector, NS-SEC;
         MANAGER, SOLOR, #* Managerial duties; 
         ILODEFR, INECAC05, STATR,  WRKING, JBAWAY, #* Job status, employee/self-employed;
         TTUSHR, #* Hours worked;
         ETHUKEUL, SEX, AGE, GOVTOF, #* Individual characteristics;
         ACCDNT, HOW1CAUS, HOW2CAUS, HOW3CAUS, WCHJB) #* Work accidents and illness.

LFS_2014_Q1 <- read_dta("lfsp_jm14_end_user.dta") |> 
  select(PWT18, IOUTCOME, #* Person weight, respondent/interview details; 
         SOC10M, ICDM, INDC07M, INDS07M, INDC07S, SECTOR, PUBLICR, NSECM10, NSECMJ10, #* SOC, industry, public/private sector, NS-SEC;
         MANAGER, SOLOR, #* Managerial duties; 
         ILODEFR, INECAC05, STATR,  WRKING, JBAWAY, #* Job status, employee/self-employed;
         TTUSHR, #* Hours worked;
         ETHUKEUL, SEX, AGE, GOVTOF, #* Individual characteristics;
         ACCDNT, ILLWRK, WCHJB, WCHJB3) #* Work accidents and illness.

LFS_2015_Q1 <- read_dta("lfsp_jm15_eul.dta") |> 
  select(PWT18, IOUTCOME, #* Person weight, respondent/interview details; 
         SOC10M, INDC07M, INDS07M, INDC07S, SECTOR, PUBLICR, NSECM10, NSECMJ10, #* SOC, industry, public/private sector, NS-SEC;
         MANAGER, SOLOR, #* Managerial duties; 
         ILODEFR, INECAC05, STATR,  WRKING, JBAWAY, #* Job status, employee/self-employed;
         TTUSHR, #* Hours worked;
         ETHUKEUL, SEX, AGE, GOVTOF, #* Individual characteristics;
         ACCDNT, ILLWRK, WCHJB, WCHJB3) #* Work accidents and illness.

LFS_2016_Q1 <- read_dta("lfsp_jm16_eul.dta") |> 
  select(PWT18, IOUTCOME, #* Person weight, respondent/interview details; 
         SOC10M, INDC07M, INDS07M, SECTOR, PUBLICR, NSECM10, NSECMJ10, #* SOC, industry, public/private sector, NS-SEC;
         MANAGER, SOLOR, #* Managerial duties; 
         ILODEFR, INECAC05, STATR,  WRKING, JBAWAY, #* Job status, employee/self-employed;
         TTUSHR, #* Hours worked;
         ETHUKEUL, SEX, AGE, #* Individual characteristics;
         ACCDNT, ILLWRK, WCHJB, WCHJB3) #* Work accidents and illness.

LFS_2017_Q1 <- read_dta("lfsp_jm17_eul.dta") |> 
  select(PWT18, IOUTCOME, #* Person weight, respondent/interview details; 
         SOC10M, INDC07M, INDS07M, SECTOR, PUBLICR, NSECM10, NSECMJ10, #* SOC, industry, public/private sector, NS-SEC;
         MANAGER, SOLOR, #* Managerial duties; 
         ILODEFR, INECAC05, STATR,  WRKING, JBAWAY, #* Job status, employee/self-employed;
         TTUSHR, #* Hours worked;
         ETHUKEUL, SEX, AGE, #* Individual characteristics;
         ACCDNT, ILLWRK, WCHJB, WCHJB3) #* Work accidents and illness.

LFS_2018_Q1 <- read_dta("lfsp_jm18_eul.dta") |> 
  select(PWT18, IOUTCOME, #* Person weight, respondent/interview details; 
         SOC10M, INDC07M, INDS07M, SECTOR, PUBLICR, NSECM10, NSECMJ10, #* SOC, industry, public/private sector, NS-SEC;
         MANAGER, SOLOR, #* Managerial duties; 
         ILODEFR, INECAC05, STATR,  WRKING, JBAWAY, #* Job status, employee/self-employed;
         TTUSHR, #* Hours worked;
         ETHUKEUL, SEX, AGE, #* Individual characteristics;
         ACCDNT, ILLWRK, WCHJB, WCHJB3) #* Work accidents and illness.

LFS_2019_Q1 <- read_dta("lfsp_jm19_eul_pwt18.dta") |> 
  select(PWT18, IOUTCOME, #* Person weight, respondent/interview details; 
         SOC10M, INDC07M, INDS07M, SECTOR, PUBLICR, NSECM10, NSECMJ10, #* SOC, industry, public/private sector, NS-SEC;
         MANAGER, SOLOR, #* Managerial duties; 
         ILODEFR, INECAC05, STATR,  WRKING, JBAWAY, #* Job status, employee/self-employed;
         TTUSHR, #* Hours worked;
         ETHUKEUL, SEX, AGE, #* Individual characteristics;
         ACCDNT, ILLWRK, WCHJB, WCHJB3) #* Work accidents and illness.

LFS_2020_Q1 <- read_dta("lfsp_jm20_eul_pwt22.dta") |> 
  select(PWT22, IOUTCOME, #* Person weight, respondent/interview details; 
         SOC10M, INDC07M, INDS07M, SECTOR, PUBLICR, NSECM10, NSECMJ10, #* SOC, industry, public/private sector, NS-SEC;
         MANAGER, SOLOR, #* Managerial duties; 
         ILODEFR, INECAC05, STATR,  WRKING, JBAWAY, #* Job status, employee/self-employed;
         TTUSHR, #* Hours worked;
         ETHUKEUL, SEX, AGE, #* Individual characteristics;
         ACCDNT, ILLWRK, WCHJB, WCHJB3) #* Work accidents and illness.

LFS_2021_Q1 <- read_dta("lfsp_jm21_eul_pwt22.dta") |> 
  select(PWT22, IOUTCOME, #* Person weight, respondent/interview details; 
         SOC20M, INDC07M, INDS07M, SECTOR, PUBLICR, NSECM20, NSECMJ20, #* SOC, industry, public/private sector, NS-SEC;
         MANAGER, SOLOR, #* Managerial duties; 
         ILODEFR, INECAC05, STATR,  WRKING, JBAWAY, #* Job status, employee/self-employed;
         TTUSHR, #* Hours worked;
         ETHUKEUL, SEX, AGE, #* Individual characteristics;
         ACCDNT, ILLWRK, WCHJB, WCHJB3) #* Work accidents and illness.

LFS_2022_Q1 <- read_dta("lfsp_jm22_eul_pwt22.dta") |> 
  select(PWT22, IOUTCOME, #* Person weight, respondent/interview details; 
         SOC20M, INDC07M, INDS07M, SECTOR, PUBLICR, NSECM20, NSECMJ20, #* SOC, industry, public/private sector, NS-SEC;
         MANAGER, SOLOR, #* Managerial duties; 
         ILODEFR, INECAC05, STATR,  WRKING, JBAWAY, #* Job status, employee/self-employed;
         TTUSHR, #* Hours worked;
         ETHUKEUL, SEX, AGE, #* Individual characteristics;
         ACCDNT, ILLWRK, WCHJB, WCHJB3) #* Work accidents and illness.

#* REFERENCES:
#* [1] ONS (2023), 'Labour Force Survey - user guidance'
#* Last revised 9 October 2023.
#* [2] ONS (2022), 'Labour Force Survey User Guide Volume 3: Details of LFS Variables 2022',
#* Version 1 - July to September 2022.

##########################################################################
##########################################################################
####### [2] Merge Labour Force Surveys together 
##########################################################################
##########################################################################

#* Add a year variable: 
LFS_2009_Q1$year <- "2009"
LFS_2010_Q1$year <- "2010"
LFS_2011_Q1$year <- "2011"
LFS_2012_Q1$year <- "2012"
LFS_2013_Q1$year <- "2013"
LFS_2014_Q1$year <- "2014"
LFS_2015_Q1$year <- "2015"
LFS_2016_Q1$year <- "2016"
LFS_2017_Q1$year <- "2017"
LFS_2018_Q1$year <- "2018"
LFS_2019_Q1$year <- "2019"
LFS_2020_Q1$year <- "2020"
LFS_2021_Q1$year <- "2021"
LFS_2022_Q1$year <- "2022"

#* Make weight names consistent:
LFS_2009_Q1 <- LFS_2009_Q1 |> rename(PWT = PWT14)
LFS_2010_Q1 <- LFS_2010_Q1 |> rename(PWT = PWT14)
LFS_2011_Q1 <- LFS_2011_Q1 |> rename(PWT = PWT14)
LFS_2012_Q1 <- LFS_2012_Q1 |> rename(PWT = PWT18)
LFS_2013_Q1 <- LFS_2013_Q1 |> rename(PWT = PWT18)
LFS_2014_Q1 <- LFS_2014_Q1 |> rename(PWT = PWT18)
LFS_2015_Q1 <- LFS_2015_Q1 |> rename(PWT = PWT18)
LFS_2016_Q1 <- LFS_2016_Q1 |> rename(PWT = PWT18)
LFS_2017_Q1 <- LFS_2017_Q1 |> rename(PWT = PWT18)
LFS_2018_Q1 <- LFS_2018_Q1 |> rename(PWT = PWT18)
LFS_2019_Q1 <- LFS_2019_Q1 |> rename(PWT = PWT18)
LFS_2020_Q1 <- LFS_2020_Q1 |> rename(PWT = PWT22)
LFS_2021_Q1 <- LFS_2021_Q1 |> rename(PWT = PWT22)
LFS_2022_Q1 <- LFS_2022_Q1 |> rename(PWT = PWT22)

#* Merge data together:
LFS <- bind_rows(LFS_2009_Q1, LFS_2010_Q1, LFS_2011_Q1, LFS_2012_Q1, LFS_2013_Q1,
                 LFS_2014_Q1, LFS_2015_Q1, LFS_2016_Q1, LFS_2017_Q1, LFS_2018_Q1,
                 LFS_2019_Q1, LFS_2020_Q1, LFS_2021_Q1, LFS_2022_Q1)

#* Remove data:
rm(LFS_2009_Q1, LFS_2010_Q1, LFS_2011_Q1, LFS_2012_Q1, LFS_2013_Q1,
    LFS_2014_Q1, LFS_2015_Q1, LFS_2016_Q1, LFS_2017_Q1, LFS_2018_Q1,
    LFS_2019_Q1, LFS_2020_Q1, LFS_2021_Q1, LFS_2022_Q1)
gc()

#* Note that I have deliberately removed the ILLWRK variable from Q1 2009 and Q1 2013. This will therefore return
#* an NA for those years. This is because of a coding error for ILLWRK. As the documentation states:[1]

#*--- "A routing error for JM08 and JM09 rendered the ILLWRK variable for these quarters inaccurate. The variable was
#*--- rerun in AJ10 to account for this and users are advised to use data from the quarter only. The variable
#*--- frequency will return to JM quarters only from JM11. Not asked in JM13 but asked again in JM14 and JM15."

#* Despite what the LFS states, there is in fact no ILLWRK Variable in AJ10.  

#* Further note that the SIC of the second job (INDC07S) also ceases to be available in the general access version 
#* of the LFS from Q1 2015.

#* REFERENCES:
#* Labour Force Survey (2022), 'Details of LFS variables 2022', p. 367,
#* https://www.ons.gov.uk/employmentandlabourmarket/peopleinwork/employmentandemployeetypes/methodologies/labourforcesurveyuserguidance#2022-update

##########################################################################
##########################################################################
####### [2] Create QoW index member variables and check missingness for variables:
##########################################################################
##########################################################################

#* Create QoW Index Member variables: 
LFS$QoW_Index_Member <- case_when(LFS$WRKING == 1 | LFS$JBAWAY == 1 ~ 1,
                                  LFS$WRKING == 2 | LFS$WRKING == -9 | LFS$JBAWAY == 2 | LFS$JBAWAY == 3 ~ 0,
                                     TRUE ~ -1)

# Wave4$QoW_Index_Member <- case_when(Wave4$d_jbhas == 1 | Wave4$d_jboff == 1 ~ 1,
#                                     Wave4$d_jbhas == 2 | Wave4$d_jbhas == -8 | Wave4$d_jboff == 2 | Wave4$d_jboff == 3 ~ 0,
#                                     TRUE ~ -1)

##########################################################################
##########################################################################
####### [3] Create SICs and accidents/injuries variables:
##########################################################################
##########################################################################

#* -----------------------------------------------
#* -----------------------------------------------
#* [a] Create accidents and injuries variables 
#* -----------------------------------------------
#* -----------------------------------------------

#* Create variables: 
LFS$WorkAccident_MainJob <- case_when(LFS$ACCDNT == 1 & LFS$WCHJB == 1 ~ 1,
                                      LFS$ACCDNT == 2 ~ 0)
LFS$WorkIllness_MainJob <- case_when(LFS$ILLWRK == 1 & LFS$WCHJB3 == 1 ~ 1,
                                     LFS$ILLWRK == 2 ~ 0)

#* Missingness. For Q1 2012, there are a fair few "does not apply" responses (-9) of people who 
#* weren't contacted in the quarter the question was asked. I believe these can be interpreted 
#* as MCAR but I've emailed the ONS to check this:
xtabs(~WorkAccident_MainJob + year + QoW_Index_Member, LFS)
xtabs(~ACCDNT + QoW_Index_Member, LFS)

xtabs(~WorkIllness_MainJob + year + QoW_Index_Member, LFS)
xtabs(~ILLWRK + QoW_Index_Member, LFS)

#* Cross-tab of work accidents and work illnesses. Within those who have accidents/illnesses (which
#* is a very small proportion anyway), there is actually very low correlation: the vast majority of 
#* people who report a work accident don't report a work illness, or vice-versa (the prompts in the 
#* LFS question ensure this):
xtabs(~WorkAccident_MainJob + WorkIllness_MainJob + 
        QoW_Index_Member, LFS)

#* -----------------------------------------------
#* -----------------------------------------------
#* [b] Filter to population of interest 
#* -----------------------------------------------
#* -----------------------------------------------

#* Filter data:
LFS_Filter <- filter(LFS, 
                     (WorkAccident_MainJob == 1 | WorkIllness_MainJob == 1) |
                       (WorkAccident_MainJob == 0 & QoW_Index_Member == 1) |
                       (WorkIllness_MainJob == 0 & QoW_Index_Member == 1))

#* Note the above process does contain some people who are no longer in 
#* work, where there is still a match between the individual and the SIC
#* of the main job:
xtabs(~WorkAccident_MainJob + WorkIllness_MainJob + QoW_Index_Member, LFS_Filter)

#* Delete LFS and clear memory:
rm(LFS)
gc()

#* -----------------------------------------------
#* -----------------------------------------------
#* [c] Create shortened SIC variables - Main job
#* -----------------------------------------------
#* -----------------------------------------------

#* First, I should create two abbreviated SIC variables: one creating 3-digit SICs and
#* another even smaller 2-digit SICs. Before doing this, it's very important to add a "0" 
#* to those SOC categories which start with "0." Because the LFS uploads its SIC data as a 
#* numerical variable, the 0 is removed for these and these variables have 3 digits, rather 
#* than the 4 digits you need for SICs. Unless you do this first, you end up miscategorising
#* these SOCs into the wrong 2-digit SIC category, and creating whole new non-existent 3-digit
#* SICs (and you end up with a labour force with nobody working in agriculture or mining!).

#* To do this, you need to use a case_when function on the character (not numeric!) version of the
#* INDO7M version of the variable:

LFS_Filter$INDC07M_Char <- as.character(LFS_Filter$INDC07M)
LFS_Filter$INDC07M_Amend <- case_when(nchar(LFS_Filter$INDC07M_Char) == 3 ~ str_pad(LFS_Filter$INDC07M_Char, width = 4, pad = "0"),
                                      TRUE ~ as.character(LFS_Filter$INDC07M_Char))
LFS_Filter$INDC07M_3Digit <- substr(LFS_Filter$INDC07M_Amend, 1,3)
LFS_Filter$INDC07M_2Digit <- substr(LFS_Filter$INDC07M_Amend, 1,2)
LFS_Filter$INDC07M_1Digit <- substr(LFS_Filter$INDC07M_Amend, 1,1)

#* The below code produces a data frame combining all the data, and is a useful reference for 
#* manually checking the process has worked:
TabA <- as.data.frame((LFS_Filter$INDC07M_Amend))
TabB <- as.data.frame(LFS_Filter$INDC07M_3Digit)
TabC <- as.data.frame(LFS_Filter$INDC07M_2Digit)
TabABC <- bind_cols(TabA, TabB, TabC)

rm(TabA, TabB, TabC, TabABC)
gc()

#* -----------------------------------------------
#* -----------------------------------------------
#* [d] Get population size for the SICs 
#* -----------------------------------------------
#* -----------------------------------------------

#* I use Health and Safety Executive figures for the workplace fatality data, over the past six years, 
#* broken down by major SIC (so at a higher level than 2 digit SICs). 

LFS_Fatality_Filter <- filter(LFS_Filter, 
                              year == 2014 | year == 2015 | year == 2016 | year == 2017 | 
                                year == 2018 | year == 2019)
PopData <- crosstab(LFS_Fatality_Filter, INDC07M_2Digit, INDC07M_1Digit, PWT) |> print(n = 300) |> as.data.frame()
 
#* Saved the above as of [1.11.23]:
# write.csv(PopData, "0 - LFS Fatality Filter Population Data.csv")

#* -----------------------------------------------
#* -----------------------------------------------
#* [e] Merge some low-sample SICs together
#* -----------------------------------------------
#* -----------------------------------------------

#* Even with the (large) LFS sample I'm dealing with some SICs evidently need to be merged. I 
#* do this in a way that's, so far as is possible, consistent with the way the Health and Safety 
#* Executive merge their SICs:

xtabs(~INDC07M_2Digit + QoW_Index_Member, LFS_Filter) |> write.csv("2-digit SICs.csv")

#* These can be merged with a simple case_when statement. The same case_when statement will have 
#* to be run on the Understanding Society data before it's merged:

LFS_Filter$INDC07M_2Digit_Merge <- case_when(LFS_Filter$INDC07M_2Digit == "01" ~ "01to03",
                                             LFS_Filter$INDC07M_2Digit == "02" ~ "01to03",
                                             LFS_Filter$INDC07M_2Digit == "03" ~ "01to03",
                                             LFS_Filter$INDC07M_2Digit == "05" ~ "05to09",
                                             LFS_Filter$INDC07M_2Digit == "06" ~ "05to09",
                                             LFS_Filter$INDC07M_2Digit == "07" ~ "05to09",
                                             LFS_Filter$INDC07M_2Digit == "08" ~ "05to09",
                                             LFS_Filter$INDC07M_2Digit == "09" ~ "05to09",
                                             LFS_Filter$INDC07M_2Digit == "12" ~ "12and15and32",
                                             LFS_Filter$INDC07M_2Digit == "15" ~ "12and15and32",
                                             LFS_Filter$INDC07M_2Digit == "32" ~ "12and15and32",
                                             LFS_Filter$INDC07M_2Digit == "36" ~ "36and37",
                                             LFS_Filter$INDC07M_2Digit == "37" ~ "36and37",
                                             LFS_Filter$INDC07M_2Digit == "38" ~ "38and39",
                                             LFS_Filter$INDC07M_2Digit == "39" ~ "38and39",
                                             LFS_Filter$INDC07M_2Digit == "97" ~ "97and98",
                                             LFS_Filter$INDC07M_2Digit == "98" ~ "97and98",
                                             TRUE ~ as.character(LFS_Filter$INDC07M_2Digit))
                                             
#* Note that the use of quotations above is due to the variable being a character. Strictly-speaking,
#* this likely isn't necessary because, as the below code shows, you get the same results regardless,
#* but I do this anyway for completeness/clarity:
length(which(LFS_Filter$INDC07M_2Digit == 12))
length(which(LFS_Filter$INDC07M_2Digit == "12"))

#* -----------------------------------------------
#* -----------------------------------------------
#* [f] Create merge for larger SEC group by year
#* -----------------------------------------------
#* -----------------------------------------------

#* For individual pairs of years, to monitor changes over time, I instead have to use the larger SIC categories
#* below. One set of these is merged (18-21, ie categories R-U), which is consistent with HSE reporting of 
#* fatalities data, due to a low N for two of these categories. None of the other categories are merged:

xtabs(~INDS07M + year, LFS_Filter) |> write.csv("0 - Larger SIC categories by year.csv")

LFS_Filter$INDS07M <- as.character(LFS_Filter$INDS07M)

LFS_Filter$INDS07M_Merge <- case_when(LFS_Filter$INDS07M == "18" ~ "18to21",
                                LFS_Filter$INDS07M == "19" ~ "18to21",
                                LFS_Filter$INDS07M == "20" ~ "18to21",
                                LFS_Filter$INDS07M == "21" ~ "18to21",
                                TRUE ~ as.character(LFS_Filter$INDS07M))
                  
#* -----------------------------------------------
#* -----------------------------------------------
#* [f] Create LFS filters for pairs of years
#* -----------------------------------------------
#* -----------------------------------------------

#* Note the use of different filter pairs for wave 4 for illness, due the work illnesses question 
#* not being asked in the 2013 sample:

LFS_Filter_Wave4_Accidents <- filter(LFS_Filter, year == 2012 | year == 2013)
LFS_Filter_Wave4_Illnesses <- filter(LFS_Filter, year == 2011 | year == 2012)
LFS_Filter_Wave6 <- filter(LFS_Filter, year == 2014 | year == 2015)
LFS_Filter_Wave8 <- filter(LFS_Filter, year == 2016 | year == 2017)
LFS_Filter_Wave10 <- filter(LFS_Filter, year == 2018 | year == 2019)
LFS_Filter_Wave12 <- filter(LFS_Filter, year == 2020 | year == 2021)

#* -----------------------------------------------
#* -----------------------------------------------
#* [g] Compare industrial composition in Understanding Society vs. LFS
#* -----------------------------------------------
#* -----------------------------------------------

prop.table(svytable(~INDC07M_2Digit_Merge + QoW_Index_Member, JQ)) |> as.data.frame() |>
  write_csv("0 - All Waves - Understanding Society Industrial Composition.csv")

prop.table(svytable(~INDC07M_2Digit_Merge + QoW_Index_Member, JQ)) |> as.data.frame() |>
  write_csv("0 - All Waves - Understanding Society Industrial Composition.csv")


#* -----------------------------------------------
#* -----------------------------------------------
#* [h] Save the data
#* -----------------------------------------------
#* -----------------------------------------------

#* Data saved as of [3.11.23]:
# saveRDS(LFS_Filter, file = "0 - LFS_Filter.RData")

##########################################################################
##########################################################################
####### [4] Data checks
##########################################################################
##########################################################################

#* Download file:
LFS_Filter <- readRDS("0 - LFS_Filter.RData")

#* -----------------------------------------------
#* -----------------------------------------------
#* [a] Check implications of an alternative way of calculating QoW index membership
#* -----------------------------------------------
#* -----------------------------------------------

#* Note [30.10.23] that an alternative way to create the QoW index member variable in the LFS would be to use 
#* the derived ILODEFR variable  (this is how the ONS did it in their emails to me). This is derived from 
#* the variable INECAC05, which itself is derived from a range of other variables and is the basis for lots of
#* useful national statistics such as ILO Unemployment. However, I prefer to base it on the binary variables above,
#* since that best matches with the way I select it for Understanding Society. 

#* The below code shows the difference is very marginal anyway, with a ~700-respondent difference in the two 
#* categories in the cross-tab. Later on, the ILODEFR-based definition leads to a slightly higher number of missings, 
#* but again this is very marginal (<~200):
LFS$QoW_Index_Member_Alt <- case_when(LFS$ILODEFR == 1 ~ 1,
                                              (LFS$ILODEFR == 2 | LFS$ILODEFR == 3 | LFS$ILODEFR == 4) ~ 0)
xtabs(~QoW_Index_Member + QoW_Index_Member_Alt, LFS)

#* -----------------------------------------------
#* -----------------------------------------------
#* [b] Check if missing responses are Missing Completely at Random 
#* -----------------------------------------------
#* -----------------------------------------------

#* As noted above, there are a significant number (~7,000-8,000) of missings for the work accidents and work 
#* illnesses variables in the LFS. The ONS have advised me that this is caused by the ONS practice of bringing forward 
#* respondents from another quarter if they didn't answer the question in that previous quarter. By my reading, the 
#* problem is that those brought forward respondents won't have been asked the health and safety questions since these are only asked
#* in Q1. The ONS have said, "there is no reason to assume that the characteristics of people whose data are brought forward are
#* any different to those who respond."[1] Because of this, the data can be assumed to be Missing Completely at Random (MCAR).

#* To verify this, I cross-tabulate the relevant IOUTCOME response (IOUTCOME = 6) against some basic descriptive characteristics:
#* NS-SEC, sex, region, etc. The results, filtered to QoW index membership, so strong similarities with the full respondent (IOUTCOME = 1)
#* data:
QoWLFS <- filter(LFS, QoW_Index_Member == 1)
prop.table(xtabs(~NSECM10 + IOUTCOME, QoWLFS), 2) |> round(2)
prop.table(xtabs(~SEX + IOUTCOME, QoWLFS), 2) |>  round(2)
prop.table(xtabs(~GOVTOF + IOUTCOME, QoWLFS), 2) |>  round(2)

#* REFERENCES:
#* [1] Email reply from Office for National Statistics Social Surveys team,
#* 27 October 2023.

#* -----------------------------------------------
#* -----------------------------------------------
#* [c] Check for inclusion of self-employed workers 
#* -----------------------------------------------
#* -----------------------------------------------

#* There is good coverage of self-employed. The below cross-tabs show there are 77k
#* self-employed workers in the data and there is almost total info on them for work
#* accidents. As with employees, there is less coverage for work illness just because 
#* of the exclusion of three years of LFS data for this, so this is no cause for concern.
#* Almost all self-employed report an SIC, with very few missings.

xtabs(~STATR, LFS_Filter)
xtabs(~STATR + WorkAccident_MainJob, LFS_Filter)
xtabs(~STATR + WorkIllness_MainJob, LFS_Filter)
xtabs(~STATR + INDC07M_2Digit, LFS_Filter)

#* -----------------------------------------------
#* -----------------------------------------------
#* [d] Check issues with cut-off-based way of calculating health and safety 
#* -----------------------------------------------
#* -----------------------------------------------

#* There are issues with this due to the (reported) issues with the Labour Force Survey
#* data on work accidents in later waves of the LFS. This is only really an issue for the
#* work accidents data, as the below code demonstrates:

JQ$variables$HealthChk <- case_when(JQ$variables$D7_HealthandSafety_AF < 0.5 ~ 1,
                                    JQ$variables$D7_HealthandSafety_AF >= 0.5 ~ 0)
svytable(~HealthChk + year, JQ)

JQ$variables$HealthChk <- case_when(JQ$variables$Ind_WorkFatalities < 1 ~ 1,
                                    JQ$variables$Ind_WorkFatalities >= 1 ~ 0)
svytable(~HealthChk + year, JQ)

JQ$variables$HealthChk <- case_when(JQ$variables$Ind_WorkAccidents < 1 ~ 1,
                                    JQ$variables$Ind_WorkAccidents >= 1 ~ 0)
svytable(~HealthChk + year, JQ)

JQ$variables$HealthChk <- case_when(JQ$variables$Ind_WorkIllness < 1 ~ 1,
                                    JQ$variables$Ind_WorkIllness >= 1 ~ 0)
svytable(~HealthChk + year, JQ)

#* When presenting the data, I:
#* [1] Only use Wave 12 data for analysis of the <0.5 dimensional scores;
#* [2] Present the time series trends in each indicator in terms of mean scores 
#* in this dimension.

#* -----------------------------------------------
#* -----------------------------------------------
#* [e] Check industrial composition in Understanding Society vs. LFS
#* -----------------------------------------------
#* -----------------------------------------------

svytable(~INDS07M_Merge + QoW_Index_Member, Wave12) |> as.data.frame() |>
  write.csv("0 - Understanding Society Industrial Composition.csv")

##########################################################################
##########################################################################
####### [3] Calculate accidents and illnesses matrices:
##########################################################################
##########################################################################

#* -----------------------------------------------
#* -----------------------------------------------
#* [a] Rates of accidents and illnesses - all years combined 
#* -----------------------------------------------
#* -----------------------------------------------

#* Risk rates for 2-digit SICs:
Tab1a <- crosstab(LFS_Filter, INDC07M_2Digit_Merge, WorkAccident_MainJob, PWT) |> print(n = 300) |> as.data.frame() 
Tab1a <- Tab1a |> rename(WorkAccident_0_AllWaves = "0",
                         WorkAccident_1_AllWaves = "1",
                         WorkAccident_N_AllWaves = n)
Tab1b <- crosstab(LFS_Filter, INDC07M_2Digit_Merge, WorkIllness_MainJob, PWT) |> print(n = 300) |> as.data.frame()
Tab1b <- Tab1b |> rename(WorkIllness_0_AllWaves = "0",
                         WorkIllness_1_AllWaves = "1",
                         WorkIllness_N_AllWaves = n)
Tab1 <- full_join(Tab1a, Tab1b)
Tab1$Num_WorkAccidents_AllWaves <- (Tab1$WorkAccident_N_AllWaves / 100) * Tab1$WorkAccident_1_AllWaves
Tab1$Num_WorkIllnesses_AllWaves <- (Tab1$WorkIllness_N_AllWaves / 100) * Tab1$WorkIllness_1_AllWaves
Tab1$WorkAccidents_Per100k_AllWaves <- Tab1$Num_WorkAccidents_AllWaves / (Tab1$WorkAccident_N_AllWaves / 100000)
Tab1$WorkIllnesses_Per100k_AllWaves <- Tab1$Num_WorkIllnesses_AllWaves / (Tab1$WorkIllness_N_AllWaves / 100000)

#* Saved as of [02.11.23]:  
write.csv(Tab1, "0 - LFS All Years Combined - Work Accidents and Illness by 2-digit SIC.csv")

#* -----------------------------------------------
#* -----------------------------------------------
#* [b] Rates of accidents - Wave 4
#* -----------------------------------------------
#* -----------------------------------------------

#* As noted earlier, the accidents and illnesses data are calculated separately for Wave 4:

Tab1 <- crosstab(LFS_Filter_Wave4_Accidents, INDS07M_Merge, WorkAccident_MainJob, PWT) |> print(n = 300) |> as.data.frame() 
Tab1 <- Tab1 |> rename(WorkAccident_0 = "0",
                         WorkAccident_1 = "1",
                         WorkAccident_N = n)
Tab1$Num_WorkAccidents <- (Tab1$WorkAccident_N / 100) * Tab1$WorkAccident_1
Tab1$WorkAccidents_Per100k <- Tab1$Num_WorkAccidents / (Tab1$WorkAccident_N / 100000)

#* Saved as of [02.11.23]:  
write.csv(Tab1, "0 - Wave 4 - Work Accidents by larger SIC categories.csv")

#* -----------------------------------------------
#* -----------------------------------------------
#* [c] Rates of illness - Wave 4
#* -----------------------------------------------
#* -----------------------------------------------

#* As noted earlier, the accidents and illnesses data are calculated separately for Wave 4:

Tab1 <- crosstab(LFS_Filter_Wave4_Illnesses, INDS07M_Merge, WorkIllness_MainJob, PWT) |> print(n = 300) |> as.data.frame()
Tab1 <- Tab1 |> rename(WorkIllness_0 = "0",
                         WorkIllness_1 = "1",
                         WorkIllness_N = n)
Tab1$Num_WorkIllnesses <- (Tab1$WorkIllness_N / 100) * Tab1$WorkIllness_1
Tab1$WorkIllnesses_Per100k <- Tab1$Num_WorkIllnesses / (Tab1$WorkIllness_N / 100000)

#* Saved as of [02.11.23]:  
write.csv(Tab1, "0 - Wave 4 - Work Illnesses by larger SIC categories.csv")

#* -----------------------------------------------
#* -----------------------------------------------
#* [d] Rates of accidents and illnesses - Wave 6
#* -----------------------------------------------
#* -----------------------------------------------

Tab1a <- crosstab(LFS_Filter_Wave6, INDS07M_Merge, WorkAccident_MainJob, PWT) |> print(n = 300) |> as.data.frame() 
Tab1a <- Tab1a |> rename(WorkAccident_0 = "0",
                         WorkAccident_1 = "1",
                         WorkAccident_N = n)
Tab1b <- crosstab(LFS_Filter_Wave6, INDS07M_Merge, WorkIllness_MainJob, PWT) |> print(n = 300) |> as.data.frame()
Tab1b <- Tab1b |> rename(WorkIllness_0 = "0",
                         WorkIllness_1 = "1",
                         WorkIllness_N = n)
Tab1 <- full_join(Tab1a, Tab1b)
Tab1$Num_WorkAccidents <- (Tab1$WorkAccident_N / 100) * Tab1$WorkAccident_1
Tab1$Num_WorkIllnesses <- (Tab1$WorkIllness_N / 100) * Tab1$WorkIllness_1
Tab1$WorkAccidents_Per100k <- Tab1$Num_WorkAccidents / (Tab1$WorkAccident_N / 100000)
Tab1$WorkIllnesses_Per100k <- Tab1$Num_WorkIllnesses / (Tab1$WorkIllness_N / 100000)

#* Saved as of [02.11.23]:  
write.csv(Tab1, "0 - Wave 6 - Work Accidents and Illnesses by larger SIC categories.csv")

#* -----------------------------------------------
#* -----------------------------------------------
#* [e] Rates of accidents and illnesses - Wave 8
#* -----------------------------------------------
#* -----------------------------------------------

Tab1a <- crosstab(LFS_Filter_Wave8, INDS07M_Merge, WorkAccident_MainJob, PWT) |> print(n = 300) |> as.data.frame() 
Tab1a <- Tab1a |> rename(WorkAccident_0 = "0",
                         WorkAccident_1 = "1",
                         WorkAccident_N = n)
Tab1b <- crosstab(LFS_Filter_Wave8, INDS07M_Merge, WorkIllness_MainJob, PWT) |> print(n = 300) |> as.data.frame()
Tab1b <- Tab1b |> rename(WorkIllness_0 = "0",
                         WorkIllness_1 = "1",
                         WorkIllness_N = n)
Tab1 <- full_join(Tab1a, Tab1b)
Tab1$Num_WorkAccidents <- (Tab1$WorkAccident_N / 100) * Tab1$WorkAccident_1
Tab1$Num_WorkIllnesses <- (Tab1$WorkIllness_N / 100) * Tab1$WorkIllness_1
Tab1$WorkAccidents_Per100k <- Tab1$Num_WorkAccidents / (Tab1$WorkAccident_N / 100000)
Tab1$WorkIllnesses_Per100k <- Tab1$Num_WorkIllnesses / (Tab1$WorkIllness_N / 100000)

#* Saved as of [02.11.23]:  
write.csv(Tab1, "0 - Wave 8 - Work Accidents and Illnesses by larger SIC categories.csv")

#* -----------------------------------------------
#* -----------------------------------------------
#* [f] Rates of accidents and illnesses - Wave 10
#* -----------------------------------------------
#* -----------------------------------------------

Tab1a <- crosstab(LFS_Filter_Wave10, INDS07M_Merge, WorkAccident_MainJob, PWT) |> print(n = 300) |> as.data.frame() 
Tab1a <- Tab1a |> rename(WorkAccident_0 = "0",
                         WorkAccident_1 = "1",
                         WorkAccident_N = n)
Tab1b <- crosstab(LFS_Filter_Wave10, INDS07M_Merge, WorkIllness_MainJob, PWT) |> print(n = 300) |> as.data.frame()
Tab1b <- Tab1b |> rename(WorkIllness_0 = "0",
                         WorkIllness_1 = "1",
                         WorkIllness_N = n)
Tab1 <- full_join(Tab1a, Tab1b)
Tab1$Num_WorkAccidents <- (Tab1$WorkAccident_N / 100) * Tab1$WorkAccident_1
Tab1$Num_WorkIllnesses <- (Tab1$WorkIllness_N / 100) * Tab1$WorkIllness_1
Tab1$WorkAccidents_Per100k <- Tab1$Num_WorkAccidents / (Tab1$WorkAccident_N / 100000)
Tab1$WorkIllnesses_Per100k <- Tab1$Num_WorkIllnesses / (Tab1$WorkIllness_N / 100000)

#* Saved as of [02.11.23]:  
write.csv(Tab1, "0 - Wave 10 - Work Accidents and Illnesses by larger SIC categories.csv")

#* -----------------------------------------------
#* -----------------------------------------------
#* [g] Rates of accidents and illnesses - Wave 12
#* -----------------------------------------------
#* -----------------------------------------------

Tab1a <- crosstab(LFS_Filter_Wave12, INDS07M_Merge, WorkAccident_MainJob, PWT) |> print(n = 300) |> as.data.frame() 
Tab1a <- Tab1a |> rename(WorkAccident_0 = "0",
                         WorkAccident_1 = "1",
                         WorkAccident_N = n)
Tab1b <- crosstab(LFS_Filter_Wave12, INDS07M_Merge, WorkIllness_MainJob, PWT) |> print(n = 300) |> as.data.frame()
Tab1b <- Tab1b |> rename(WorkIllness_0 = "0",
                         WorkIllness_1 = "1",
                         WorkIllness_N = n)
Tab1 <- full_join(Tab1a, Tab1b)
Tab1$Num_WorkAccidents <- (Tab1$WorkAccident_N / 100) * Tab1$WorkAccident_1
Tab1$Num_WorkIllnesses <- (Tab1$WorkIllness_N / 100) * Tab1$WorkIllness_1
Tab1$WorkAccidents_Per100k <- Tab1$Num_WorkAccidents / (Tab1$WorkAccident_N / 100000)
Tab1$WorkIllnesses_Per100k <- Tab1$Num_WorkIllnesses / (Tab1$WorkIllness_N / 100000)

#* Saved as of [02.11.23]:  
write.csv(Tab1, "0 - Wave 12 - Work Accidents and Illnesses by larger SIC categories.csv")

##########################################################################
##########################################################################
####### [4] Incorporate into Understanding Society
##########################################################################
##########################################################################

#* -----------------------------------------------
#* -----------------------------------------------
#* [a] Download CSVs 
#* -----------------------------------------------
#* -----------------------------------------------

#* Download CSVs:
AllWaves_AccidentsIllnesses <- read.csv("0 - LFS All Years Combined - Work Accidents and Illness by 2-digit SIC.csv")
AllWaves_Fatalities <- read.csv("0 - HSE Fatality Matrix by 2-digit SIC.csv")
W4_Accidents <- read.csv("0 - Wave 4 - Work Accidents by larger SIC categories.csv")
W4_Illnesses <- read.csv("0 - Wave 4 - Work Illnesses by larger SIC categories.csv")
W6_AccidentsIllnesses <- read.csv("0 - Wave 6 - Work Accidents and Illnesses by larger SIC categories.csv")
W8_AccidentsIllnesses <- read.csv("0 - Wave 8 - Work Accidents and Illnesses by larger SIC categories.csv")
W10_AccidentsIllnesses <- read.csv("0 - Wave 10 - Work Accidents and Illnesses by larger SIC categories.csv")
W12_AccidentsIllnesses <- read.csv("0 - Wave 12 - Work Accidents and Illnesses by larger SIC categories.csv")

#* I also take the opportunity to delete the 'X' columns from all the data frames:
AllWaves_AccidentsIllnesses <- subset(AllWaves_AccidentsIllnesses, select = -c(X))
W4_Accidents <- subset(W4_Accidents, select = -c(X))
W4_Illnesses <- subset(W4_Illnesses, select = -c(X))
W6_AccidentsIllnesses <- subset(W6_AccidentsIllnesses, select = -c(X))
W8_AccidentsIllnesses <- subset(W8_AccidentsIllnesses, select = -c(X))
W10_AccidentsIllnesses <- subset(W10_AccidentsIllnesses, select = -c(X))
W12_AccidentsIllnesses <- subset(W12_AccidentsIllnesses, select = -c(X))

#* -----------------------------------------------
#* -----------------------------------------------
#* [b] Align SIC classifications in Understanding Society
#* -----------------------------------------------
#* -----------------------------------------------

#* First download Understanding Society (see "0 - Data download" syntax), and align the SIC codes with how 
#* they're coded in the LFS. Note, for housekeeping, that the number of missing SICs amongst those in paid work
#* in Understanding Society is very low:
xtabs(~jbsic07_cc + year, JQ)
xtabs(~jbsic07_cc + year, Dat)

#* Align the 2-digit SIC names and variables with what's in the LFS, first by converting to character and then by
#* copying the same variable names. Note that I also convert all inapplicables, d/ks, missings to -1 as well, so
# they don't align wit the missing values in the LFS matrices and are therefore accidentally converted into a value:
Dat$variables$INDC07M_2Digit <- as.character(Dat$variables$jbsic07_cc)
Dat$variables$INDC07M_2Digit_Merge <- case_when(Dat$variables$INDC07M_2Digit == "01" ~ "01to03",
                                                Dat$variables$INDC07M_2Digit == "02" ~ "01to03",
                                                Dat$variables$INDC07M_2Digit == "03" ~ "01to03",
                                                Dat$variables$INDC07M_2Digit == "05" ~ "05to09",
                                                Dat$variables$INDC07M_2Digit == "06" ~ "05to09",
                                                Dat$variables$INDC07M_2Digit == "07" ~ "05to09",
                                                Dat$variables$INDC07M_2Digit == "08" ~ "05to09",
                                                Dat$variables$INDC07M_2Digit == "09" ~ "05to09",
                                                Dat$variables$INDC07M_2Digit == "12" ~ "12and15and32",
                                                Dat$variables$INDC07M_2Digit == "15" ~ "12and15and32",
                                                Dat$variables$INDC07M_2Digit == "32" ~ "12and15and32",
                                                Dat$variables$INDC07M_2Digit == "36" ~ "36and37",
                                                Dat$variables$INDC07M_2Digit == "37" ~ "36and37",
                                                Dat$variables$INDC07M_2Digit == "38" ~ "38and39",
                                                Dat$variables$INDC07M_2Digit == "39" ~ "38and39",
                                                Dat$variables$INDC07M_2Digit == "97" ~ "97and98",
                                                Dat$variables$INDC07M_2Digit == "98" ~ "97and98",
                                                Dat$variables$INDC07M_2Digit == "-9" ~ "-1",
                                                Dat$variables$INDC07M_2Digit == "-8" ~ "-1",
                                                Dat$variables$INDC07M_2Digit == "-2" ~ "-1",
                                             TRUE ~ as.character(Dat$variables$INDC07M_2Digit))

#* I now also create major SIC categories in Understanding Society, to align with those in the LFS. This process
#* is more onerous because there is no ready-made variable in Understanding Society with large SIC categories. 
#* I therefore merge it manually like so. To make this easier, the variable is retained as a numeric and then 
#* converted to character ex post facto to add the "18to21" category:
Dat$variables$INDS07M <- case_when(Dat$variables$jbsic07_cc >= 1 & Dat$variables$jbsic07_cc <= 3 ~ 1,
                                   Dat$variables$jbsic07_cc >= 5 & Dat$variables$jbsic07_cc <= 9 ~ 2, 
                                   Dat$variables$jbsic07_cc >= 10 & Dat$variables$jbsic07_cc <= 33 ~ 3, 
                                   Dat$variables$jbsic07_cc == 35 ~ 4,
                                   Dat$variables$jbsic07_cc >= 36 & Dat$variables$jbsic07_cc <= 39 ~ 5,
                                   Dat$variables$jbsic07_cc >= 41 & Dat$variables$jbsic07_cc <= 43 ~ 6,
                                   Dat$variables$jbsic07_cc >= 45 & Dat$variables$jbsic07_cc <= 47 ~ 7,
                                   Dat$variables$jbsic07_cc >= 49 & Dat$variables$jbsic07_cc <= 53 ~ 8, 
                                   Dat$variables$jbsic07_cc >= 55 & Dat$variables$jbsic07_cc <= 56 ~ 9,
                                   Dat$variables$jbsic07_cc >= 58 & Dat$variables$jbsic07_cc <= 63 ~ 10,
                                   Dat$variables$jbsic07_cc >= 64 & Dat$variables$jbsic07_cc <= 66 ~ 11,
                                   Dat$variables$jbsic07_cc == 68 ~ 12,
                                   Dat$variables$jbsic07_cc >= 69 & Dat$variables$jbsic07_cc <= 75 ~ 13,
                                   Dat$variables$jbsic07_cc >= 77 & Dat$variables$jbsic07_cc <= 82 ~ 14,
                                   Dat$variables$jbsic07_cc == 84 ~ 15,
                                   Dat$variables$jbsic07_cc == 85 ~ 16,
                                   Dat$variables$jbsic07_cc >= 86 & Dat$variables$jbsic07_cc <= 88 ~ 17,
                                   Dat$variables$jbsic07_cc >= 90 & Dat$variables$jbsic07_cc <= 93 ~ 18,
                                   Dat$variables$jbsic07_cc >= 94 & Dat$variables$jbsic07_cc <= 96 ~ 19,
                                   Dat$variables$jbsic07_cc >= 97 & Dat$variables$jbsic07_cc <= 98 ~ 20,
                                   Dat$variables$jbsic07_cc == 99 ~ 21,
                                   TRUE ~ as.numeric(Dat$variables$jbsic07_cc))

#* Then convert to character and merge the final 4 categories together, consistent with the LFS:
Dat$variables$INDS07M_Merge <- as.character(Dat$variables$INDS07M)
Dat$variables$INDS07M_Merge <- case_when(Dat$variables$INDS07M_Merge == "18" ~ "18to21",
                                         Dat$variables$INDS07M_Merge == "19" ~ "18to21",
                                         Dat$variables$INDS07M_Merge == "20" ~ "18to21",
                                         Dat$variables$INDS07M_Merge == "21" ~ "18to21",
                                         Dat$variables$INDS07M_Merge == "-9" ~ "-1",
                                         Dat$variables$INDS07M_Merge == "-8" ~ "-1",
                                         Dat$variables$INDS07M_Merge == "-2" ~ "-1",
                                         TRUE ~ as.character(Dat$variables$INDS07M_Merge))

#* -----------------------------------------------
#* -----------------------------------------------
#* [d] Separate Waves - add SIC health and safety risks to Understanding Society
#* -----------------------------------------------
#* -----------------------------------------------

#* Separate out by year:
Dat_W4 <- filter(Dat$variables, year == "2012-13")
Dat_W6 <- filter(Dat$variables, year == "2014-15")
Dat_W8 <- filter(Dat$variables, year == "2016-17")
Dat_W10 <- filter(Dat$variables, year == "2018-19")
Dat_W12 <- filter(Dat$variables, year == "2020-21")

#* Join the data together:
Dat_W4_Join <- left_join(Dat_W4, W4_Accidents, by = "INDS07M_Merge")
Dat_W4_Join <- left_join(Dat_W4_Join, W4_Illnesses, by = "INDS07M_Merge")
Dat_W6_Join <- left_join(Dat_W6, W6_AccidentsIllnesses, by = "INDS07M_Merge")
Dat_W8_Join <- left_join(Dat_W8, W8_AccidentsIllnesses, by = "INDS07M_Merge")
Dat_W10_Join <- left_join(Dat_W10, W10_AccidentsIllnesses, by = "INDS07M_Merge")
Dat_W12_Join <- left_join(Dat_W12, W12_AccidentsIllnesses, by = "INDS07M_Merge")

#* Join data together:
Dat$variables <- bind_rows(Dat_W4_Join, Dat_W6_Join, Dat_W8_Join, Dat_W10_Join, Dat_W12_Join)

#* Remove redundant data frames:
rm(Dat_W4, Dat_W4_Join, Dat_W6, Dat_W6_Join, 
   Dat_W8, Dat_W8_Join, Dat_W10, Dat_W10_Join,
   Dat_W12, Dat_W12_Join)
gc()

#* -----------------------------------------------
#* -----------------------------------------------
#* [e] Combined Waves - add SIC health and safety risks; and fatality data
#* -----------------------------------------------
#* -----------------------------------------------

#* Separate out Dat from the survey design, and merge the data. Then add it
#* back in:
Dat_AllWaves <- Dat$variables
Dat_AllWaves_Join <- left_join(Dat_AllWaves, AllWaves_AccidentsIllnesses, by = "INDC07M_2Digit_Merge")

#* I also now add fatalities data, using the same process:
Dat_AllWaves_Join <- left_join(Dat_AllWaves_Join, AllWaves_Fatalities, by = "INDC07M_2Digit_Merge")

#* Then return to the dataset:
Dat$variables <- Dat_AllWaves_Join

#* Remove redundant data frames:
rm(Dat_AllWaves, Dat_AllWaves_Join)
gc()

#* -----------------------------------------------
#* -----------------------------------------------
#* [f] Check data:
#* -----------------------------------------------
#* -----------------------------------------------

#* The data shows a rise in illnesses (which is consistent with what the LFS data
#* shows), but a fall in accidents:
svyby(formula = ~WorkAccidents_Per100k, by = ~year,
      design = JQ, 
      FUN = svymean, 
      na.rm = TRUE, 
      row.names = FALSE)
svyby(formula = ~WorkIllnesses_Per100k, by = ~year,
      design = JQ, 
      FUN = svymean, 
      na.rm = TRUE, 
      row.names = FALSE)
svyby(formula = ~Fatalities_per_100000, by = ~year,
      design = JQ, 
      FUN = svymean, 
      na.rm = TRUE, 
      row.names = FALSE)

#* The combined data obviously doesn't show this. What's encouraging is
#* that even though they're derived using larger data (2-digit SICs rather than
#* large SIC categories), the means lie somewhere between each other:
svyby(formula = ~WorkAccidents_Per100k_AllWaves, by = ~year,
      design = JQ, 
      FUN = svymean, 
      na.rm = TRUE, 
      row.names = FALSE)
svyby(formula = ~WorkIllnesses_Per100k_AllWaves, by = ~year,
      design = JQ, 
      FUN = svymean, 
      na.rm = TRUE, 
      row.names = FALSE)

#* The data by region is also remarkably consistent across the two methods 
#* of calculating sub-group differences:
svyby(formula = ~WorkAccidents_Per100k_AllWaves, by = ~DV_Region_All,
      design = JQ, 
      FUN = svymean, 
      na.rm = TRUE, 
      row.names = FALSE)
svyby(formula = ~WorkIllnesses_Per100k_AllWaves, by = ~DV_Region_All,
      design = JQ, 
      FUN = svymean, 
      na.rm = TRUE, 
      row.names = FALSE)
svyby(formula = ~WorkAccidents_Per100k, by = ~DV_Region_All,
      design = JQ, 
      FUN = svymean, 
      na.rm = TRUE, 
      row.names = FALSE)
svyby(formula = ~WorkIllnesses_Per100k, by = ~DV_Region_All,
      design = JQ, 
      FUN = svymean, 
      na.rm = TRUE, 
      row.names = FALSE)

#* Ethnicity and sex data. Rates of work accidents higher yet rates of illness
#* lower in Bangladeshi community. Again, data shows that comparisons very similar
#* whether you do it using all waves or wave-by-wave:
svyby(formula = ~WorkAccidents_Per100k, by = ~DV_Ethnicity_UK,
      design = JQ, 
      FUN = svymean, 
      na.rm = TRUE, 
      row.names = FALSE)
svyby(formula = ~WorkIllnesses_Per100k, by = ~DV_Ethnicity_UK,
      design = JQ, 
      FUN = svymean, 
      na.rm = TRUE, 
      row.names = FALSE)

#* Data shows higher rates of workplace accidents for men, and lower rates of work
#* illnesses:
svyby(formula = ~WorkAccidents_Per100k, by = ~DV_Sex,
      design = JQ, 
      FUN = svymean, 
      na.rm = TRUE, 
      row.names = FALSE)
svyby(formula = ~WorkIllnesses_Per100k, by = ~DV_Sex,
      design = JQ, 
      FUN = svymean, 
      na.rm = TRUE, 
      row.names = FALSE)

#* -----------------------------------------------
#* -----------------------------------------------
#* [g] Create work accidents indicator
#* -----------------------------------------------
#* -----------------------------------------------

#* I opt for a continuous rather than a categorical scale for work fatalities, accidents and illnesses.
#* First I standardise them by converting them into standard units. I then rescale the standard unit scores
#* to a 0-2 scale, and then reverse the scales so that a higher score = better, ie lower incidence rates.
#* I do this specifically for people in the QoW index rather than for Dat as a whole, although given that
#* everyone in Dat is NA for this variable it shouldn't cause any differences from just using na.rm.

#* First convert to standard units:
FatalitiesMean <- svymean(Dat$variables$Fatalities_per_100000, design = Dat, na.rm = TRUE)
FatalitiesSD <- svysd(~ Dat$variables$Fatalities_per_100000, design = Dat, na.rm = TRUE)
Dat$variables$FatalitiesStandardUnits <- (Dat$variables$Fatalities_per_100000 - FatalitiesMean) / FatalitiesSD

AccidentsMean <- svymean(Dat$variables$WorkAccidents_Per100k, design = Dat, na.rm = TRUE)
AccidentsSD <- svysd(~Dat$variables$WorkAccidents_Per100k, design = Dat, na.rm = TRUE)
Dat$variables$AccidentsStandardUnits <- (Dat$variables$WorkAccidents_Per100k - AccidentsMean) / AccidentsSD

IllnessesMean <- svymean(Dat$variables$WorkIllnesses_Per100k, design = Dat, na.rm = TRUE)
IllnessesSD <- svysd(~ Dat$variables$WorkIllnesses_Per100k, design = Dat, na.rm = TRUE)
Dat$variables$IllnessesStandardUnits <- (Dat$variables$WorkIllnesses_Per100k - IllnessesMean) / IllnessesSD

#* Create indicators:
Dat$variables$Ind_WorkFatalities <- rescale(Dat$variables$FatalitiesStandardUnits) * 2
Dat$variables$Ind_WorkFatalities <- item.reverse(Dat$variables$Ind_WorkFatalities, min = 0, max = 2)

Dat$variables$Ind_WorkAccidents <- rescale(Dat$variables$WorkAccidents_Per100k) * 2
Dat$variables$Ind_WorkAccidents <- item.reverse(Dat$variables$Ind_WorkAccidents, min = 0, max = 2)

Dat$variables$Ind_WorkIllness <- rescale(Dat$variables$WorkIllnesses_Per100k) * 2
Dat$variables$Ind_WorkIllness <- item.reverse(Dat$variables$Ind_WorkIllness, min = 0, max = 2)

#* Data shows process has worked:
svyby(formula = ~Ind_WorkFatalities, by = ~year,
      design = JQ, 
      FUN = svymean, 
      na.rm = TRUE, 
      row.names = FALSE)

svyby(formula = ~Ind_WorkAccidents, by = ~year,
      design = JQ, 
      FUN = svymean, 
      na.rm = TRUE, 
      row.names = FALSE)

svyby(formula = ~Ind_WorkIllness, by = ~year,
      design = JQ, 
      FUN = svymean, 
      na.rm = TRUE, 
      row.names = FALSE)

#* -----------------------------------------------
#* -----------------------------------------------
#* [h] Save data
#* -----------------------------------------------
#* -----------------------------------------------

#* Saved the above as of [25.11.23]:
# saveRDS(Dat, file = "0 - Dat.RData")
