
#* *Note on setting seed for imputation:* I set a specific seed for the imputation below to enable replication. For other
#* analysis authors may wish to substitute for another seed or remove "seed =" in the imputation functions.

#######################################################################################
######## 1 - Create dependent variables and prepare indicators for imputation #########
#######################################################################################

#* ----------- [a] Create an imp flag, and convert all missing indicator data to NAs:

#* First I create a separate imputation flag variable for all those values marked -1. I then convert 
#* the -1s to NAs. All the R imputation packages work by treating NA as the data which needs imputing,
#* so it's important to have an "NA" version of the data. Note that the imputation flags for the 
#* continuous variables are treated differently:

Dat$variables$Ind_EarningsSufficiency_ImpFlag <- case_when(Dat$variables$Ind_EarningsSufficiency == -1 ~ 1, TRUE ~ 0)
Dat$variables$Ind_EarningsSufficiency_NAs <- replace(Dat$variables$Ind_EarningsSufficiency, Dat$variables$Ind_EarningsSufficiency %in% c(-1), NA)

Dat$variables$Ind_EarningsEquity_ImpFlag <- case_when(Dat$variables$Ind_EarningsEquity == -1 ~ 1, TRUE ~ 0)
Dat$variables$Ind_EarningsEquity_NAs <- replace(Dat$variables$Ind_EarningsEquity,  Dat$variables$Ind_EarningsEquity %in% c(-1), NA)

Dat$variables$Ind_Pension_ImpFlag <- case_when(Dat$variables$Ind_Pension == -1 & Dat$variables$year != "2020-21" ~ 1, TRUE ~ 0)
Dat$variables$Ind_Pension_NAs <- replace(Dat$variables$Ind_Pension, Dat$variables$Ind_Pension %in% c(-1), NA)

Dat$variables$Ind_ContinuousEmployment_ImpFlag <- case_when(Dat$variables$Ind_ContinuousEmployment == -1 ~ 1, TRUE ~ 0)
Dat$variables$Ind_ContinuousEmployment_NAs <- replace(Dat$variables$Ind_ContinuousEmployment, Dat$variables$Ind_ContinuousEmployment %in% c(-1), NA)

Dat$variables$Ind_CompositeSecurity_ImpFlag <- case_when(Dat$variables$Ind_CompositeSecurity == -1 ~ 1, TRUE ~ 0)
Dat$variables$Ind_CompositeSecurity_NAs <- replace(Dat$variables$Ind_CompositeSecurity, Dat$variables$Ind_CompositeSecurity %in% c(-1), NA)

Dat$variables$Ind_Autonomy_ImpFlag <- case_when(Dat$variables$Ind_Autonomy == -1 ~ 1, TRUE ~ 0)
Dat$variables$Ind_Autonomy_NAs <- replace(Dat$variables$Ind_Autonomy, Dat$variables$Ind_Autonomy %in% c(-1), NA)

Dat$variables$Ind_CollectiveVoice_ImpFlag <- case_when(Dat$variables$Ind_CollectiveVoice == -1 ~ 1, TRUE ~ 0)
Dat$variables$Ind_CollectiveVoice_NAs <- replace(Dat$variables$Ind_CollectiveVoice, Dat$variables$Ind_CollectiveVoice %in% c(-1), NA)

Dat$variables$Ind_Flexibility_ImpFlag <- case_when(Dat$variables$DV_SelfEmployed == 0 & Dat$variables$Ind_Flexibility == -1 ~ 1, TRUE ~ 0)
Dat$variables$Ind_Flexibility_NAs <- replace(Dat$variables$Ind_Flexibility, Dat$variables$Ind_Flexibility %in% c(-1), NA)

Dat$variables$Ind_ExcessiveHours_ImpFlag <- case_when(Dat$variables$Ind_ExcessiveHours == -1 ~ 1, TRUE ~ 0)
Dat$variables$Ind_ExcessiveHours_NAs <- replace(Dat$variables$Ind_ExcessiveHours, Dat$variables$Ind_ExcessiveHours %in% c(-1), NA)

Dat$variables$Ind_ManagerialDuties_ImpFlag <- case_when(Dat$variables$Ind_ManagerialDuties == -1 ~ 1, TRUE ~ 0)
Dat$variables$Ind_ManagerialDuties_NAs <- replace(Dat$variables$Ind_ManagerialDuties, Dat$variables$Ind_ManagerialDuties %in% c(-1), NA)

Dat$variables$Ind_ShortTermProspects_ImpFlag <- case_when(Dat$variables$Ind_ShortTermProspects == -1 ~ 1, TRUE ~ 0)
Dat$variables$Ind_ShortTermProspects_NAs <- replace(Dat$variables$Ind_ShortTermProspects, Dat$variables$Ind_ShortTermProspects %in% c(-1), NA)

Dat$variables$Ind_LongTermProspects_ImpFlag <- case_when(is.na(Dat$variables$Ind_LongTermProspects) ~ 1, TRUE ~ 0)
Dat$variables$Ind_LongTermProspects_NAs <- replace(Dat$variables$Ind_LongTermProspects, Dat$variables$Ind_LongTermProspects %in% c(-1), NA)

Dat$variables$Ind_WorkFatalities_ImpFlag <-  case_when(is.na(Dat$variables$Ind_WorkFatalities) ~ 1, TRUE ~ 0)
Dat$variables$Ind_WorkFatalities_NAs <- replace(Dat$variables$Ind_WorkFatalities, Dat$variables$Ind_WorkFatalities %in% c(-1), NA)

Dat$variables$Ind_WorkAccidents_ImpFlag <- case_when(is.na(Dat$variables$Ind_WorkAccidents) ~ 1, TRUE ~ 0)
Dat$variables$Ind_WorkAccidents_NAs <- replace(Dat$variables$Ind_WorkAccidents, Dat$variables$Ind_WorkAccidents %in% c(-1), NA)

Dat$variables$Ind_WorkIllness_ImpFlag <- case_when(is.na(Dat$variables$Ind_WorkIllness) ~ 1, TRUE ~ 0)
Dat$variables$Ind_WorkIllness_NAs <- replace(Dat$variables$Ind_WorkIllness, Dat$variables$Ind_WorkIllness %in% c(-1), NA)

#* I also do the same for the parental NS-SEC Capability Set indicator. As with the other Conversion Factor
#* and Capability Set indicators, the version of this with 'NAs' in it is just the _AF suffixed version:
Dat$variables$CS_ParentalNSSEC_ImpFlag <- case_when(Dat$variables$CS_ParentalNSSEC == -1 ~ 1, TRUE ~ 0)

#* At present, self-employed are coded '0' in impflag for flexibility (since they aren't asked the question) and 
#* the wave 12 missings for Pension are coded '0'. Both decisions make sense for some kinds of analysis, but not 
#* for others. I therefore create two additional variables which code these specifically as NAs: 
Dat$variables$Ind_Pension_ImpFlag_Wave12NAs <- case_when(Dat$variables$Ind_Pension_ImpFlag == 0 & Dat$variables$year == "2020-21" ~ 0.5, 
                                                         TRUE ~ as.numeric(as.character(Dat$variables$Ind_Pension_ImpFlag)))
Dat$variables$Ind_Pension_ImpFlag_Wave12NAs <- replace(Dat$variables$Ind_Pension_ImpFlag_Wave12NAs, Dat$variables$Ind_Pension_ImpFlag_Wave12NAs %in% c(0.5), NA)

Dat$variables$Ind_Flexibility_ImpFlag_SelfEmpNAs <- case_when(Dat$variables$Ind_Flexibility_ImpFlag == 0 & Dat$variables$DV_SelfEmployed == 1 ~ 0.5,
                                                              TRUE ~ as.numeric(as.character(Dat$variables$Ind_Flexibility_ImpFlag)))
Dat$variables$Ind_Flexibility_ImpFlag_SelfEmpNAs <- replace(Dat$variables$Ind_Flexibility_ImpFlag_SelfEmpNAs, Dat$variables$Ind_Flexibility_ImpFlag_SelfEmpNAs %in% c(0.5), NA)

Dat$variables$Ind_Pension_ImpFlag_InclWave12 <- case_when(Dat$variables$Ind_Pension_ImpFlag == 0 & Dat$variables$Ind_Pension == -1 & Dat$variables$year == "2020-21" ~ 1,
                                                          TRUE ~ as.numeric(as.character(Dat$variables$Ind_Pension_ImpFlag)))

#* ----------- [b] Prepare predictor variables 

#* It's then important to create dummmy variables for each of my predictors for the imputation, and
#* to convert the rest to NAs. Otherwise values which Understanding Society usually uses for NA,
#* D/Ks, etc (-8, -1) will be treated as predictors. 

#* At each of these stages I (a) create binary variables and (b) convert any missing data to NAs. 
#* Later on I also create categorical variables which combine some of the categories together
#* (eg ethnicity), but these don't make it into the data frame for imputation.

#* These are given the DV_ prefix because they will form dependent variables in my subsequent 
#* analysis.

#* Sex:
Dat$variables$DV_Sex <- case_when(Dat$variables$sex_dv == 2 ~ 1, 
                                  Dat$variables$sex_dv == 1 ~ 0,
                                  TRUE ~ -1)
Dat$variables$DV_Sex <- replace(Dat$variables$DV_Sex, 
                                Dat$variables$DV_Sex %in% c(-1), NA)

Dat$variables$DV_Sex_label <- case_when(Dat$variables$DV_Sex == 1 ~ "Female",
                                        Dat$variables$DV_Sex == 0 ~ "Male")

#* Part-time (<16 hours; note the definition of "part time" in literature varies):  

Dat$variables$DV_PartTime <- case_when(Dat$variables$labhrs_adj_weekly < 16 ~ 1, 
                                       Dat$variables$labhrs_adj_weekly >= 16 ~ 0)

Dat$variables$DV_PartTime_label <- case_when(Dat$variables$DV_PartTime == 1 ~ "Part-time (<16hrs)", 
                                             Dat$variables$DV_PartTime >= 0 ~ "Not part-time (>=16 hours")

#* Types of non-standard employment relations:
Dat$variables$DV_JobType <- case_when(Dat$variables$DV_SelfEmployed == 0 & Dat$variables$JQ_Index_AF_Score_Wave12_quintile == 1 &! Dat$variables$DV_ZeroHours == 1 &! Dat$variables$DV_GigEconomy == 1 ~ "Employee Q1 (worst QoW)",
                                      Dat$variables$DV_SelfEmployed == 0 & Dat$variables$JQ_Index_AF_Score_Wave12_quintile == 2 &! Dat$variables$DV_ZeroHours == 1 &! Dat$variables$DV_GigEconomy == 1 ~ "Employee Q2",
                                      Dat$variables$DV_SelfEmployed == 0 & Dat$variables$JQ_Index_AF_Score_Wave12_quintile == 3 &! Dat$variables$DV_ZeroHours == 1 &! Dat$variables$DV_GigEconomy == 1 ~ "Employee Q3",
                                      Dat$variables$DV_SelfEmployed == 0 & Dat$variables$JQ_Index_AF_Score_Wave12_quintile == 4 &! Dat$variables$DV_ZeroHours == 1 &! Dat$variables$DV_GigEconomy == 1 ~ "Employee Q4",
                                      Dat$variables$DV_SelfEmployed == 0 & Dat$variables$JQ_Index_AF_Score_Wave12_quintile == 5 &! Dat$variables$DV_ZeroHours == 1 &! Dat$variables$DV_GigEconomy == 1 ~ "Employee Q5 (best QoW)",
                                      Dat$variables$DV_SelfEmployed == 1 &! Dat$variables$DV_ZeroHours == 1 &! Dat$variables$DV_GigEconomy == 1 ~ "Self employed",
                                      Dat$variables$DV_ZeroHours == 1 ~ "Zero hours",
                                      Dat$variables$DV_GigEconomy == 1 ~ "Gig economy")

#* White British / N Irish: 
Dat$variables$DV_Ethnicity_UK <- case_when(Dat$variables$ethn_dv == 1 ~ 1,
                                           Dat$variables$ethn_dv == -9 ~ -1,
                                           TRUE ~ 0)
Dat$variables$DV_Ethnicity_UK <- replace(Dat$variables$DV_Ethnicity_UK, 
                                         Dat$variables$DV_Ethnicity_UK %in% c(-1), NA)
#* White Irish: 
Dat$variables$DV_Ethnicity_Irish <- case_when(Dat$variables$ethn_dv == 2 ~ 1,
                                              Dat$variables$ethn_dv == -9 ~ -1,
                                              TRUE ~ 0)
Dat$variables$DV_Ethnicity_Irish <- replace(Dat$variables$DV_Ethnicity_Irish, 
                                            Dat$variables$DV_Ethnicity_Irish %in% c(-1), NA)
#* Other White: 
Dat$variables$DV_Ethnicity_OtherWhite <- case_when(Dat$variables$ethn_dv == 4 ~ 1,
                                                   Dat$variables$ethn_dv == -9 ~ -1,
                                                   TRUE ~ 0)
Dat$variables$DV_Ethnicity_OtherWhite <- replace(Dat$variables$DV_Ethnicity_OtherWhite, 
                                                 Dat$variables$DV_Ethnicity_OtherWhite %in% c(-1), NA)
#* Mixed: 
Dat$variables$DV_Ethnicity_Mixed <- case_when((Dat$variables$ethn_dv == 5 | Dat$variables$ethn_dv == 6 |
                                                 Dat$variables$ethn_dv == 7 | Dat$variables$ethn_dv == 8) ~ 1,
                                              Dat$variables$ethn_dv == -9 ~ -1,
                                              TRUE ~ 0)
Dat$variables$DV_Ethnicity_Mixed <- replace(Dat$variables$DV_Ethnicity_Mixed, 
                                            Dat$variables$DV_Ethnicity_Mixed %in% c(-1), NA)
#* Indian:
Dat$variables$DV_Ethnicity_Indian <- case_when(Dat$variables$ethn_dv == 9 ~ 1,
                                               Dat$variables$ethn_dv == -9 ~ -1,
                                               TRUE ~ 0)
Dat$variables$DV_Ethnicity_Indian <- replace(Dat$variables$DV_Ethnicity_Indian, 
                                             Dat$variables$DV_Ethnicity_Indian %in% c(-1), NA)
#* Pakistani:
Dat$variables$DV_Ethnicity_Pakistani <- case_when(Dat$variables$ethn_dv == 10 ~ 1,
                                                  Dat$variables$ethn_dv == -9 ~ -1,
                                                  TRUE ~ 0)
Dat$variables$DV_Ethnicity_Pakistani <- replace(Dat$variables$DV_Ethnicity_Pakistani, 
                                                Dat$variables$DV_Ethnicity_Pakistani %in% c(-1), NA)
#* Bangladeshi:
Dat$variables$DV_Ethnicity_Bangladeshi <- case_when(Dat$variables$ethn_dv == 11 ~ 1,
                                                    Dat$variables$ethn_dv == -9 ~ -1,
                                                    TRUE ~ 0)
Dat$variables$DV_Ethnicity_Bangladeshi <- replace(Dat$variables$DV_Ethnicity_Bangladeshi, 
                                                  Dat$variables$DV_Ethnicity_Bangladeshi %in% c(-1), NA)
#* Chinese:
Dat$variables$DV_Ethnicity_Chinese <- case_when(Dat$variables$ethn_dv == 12 ~ 1,
                                                Dat$variables$ethn_dv == -9 ~ -1,
                                                TRUE ~ 0)
Dat$variables$DV_Ethnicity_Chinese <- replace(Dat$variables$DV_Ethnicity_Chinese, 
                                              Dat$variables$DV_Ethnicity_Chinese %in% c(-1), NA)
#* Black Caribbean:
Dat$variables$DV_Ethnicity_BlackCaribbean <- case_when(Dat$variables$ethn_dv == 14 ~ 1,
                                                       Dat$variables$ethn_dv == -9 ~ -1,
                                                       TRUE ~ 0)
Dat$variables$DV_Ethnicity_BlackCaribbean <- replace(Dat$variables$DV_Ethnicity_BlackCaribbean, 
                                                     Dat$variables$DV_Ethnicity_BlackCaribbean %in% c(-1), NA)
#* Black African:
Dat$variables$DV_Ethnicity_BlackAfrican <- case_when((Dat$variables$ethn_dv == 15 | Dat$variables$ethn_dv == 56) ~ 1,
                                                     Dat$variables$ethn_dv == -9 ~ -1,
                                                     TRUE ~ 0)
Dat$variables$DV_Ethnicity_BlackAfrican <- replace(Dat$variables$DV_Ethnicity_BlackAfrican, 
                                                   Dat$variables$DV_Ethnicity_BlackAfrican %in% c(-1), NA)
#* All:
Dat$variables$DV_Ethnicity_All <- case_when(Dat$variables$ethn_dv == 1 ~ 1,
                                            Dat$variables$ethn_dv == 2 ~ 2,
                                            Dat$variables$ethn_dv == 4 ~ 3,
                                            (Dat$variables$ethn_dv == 5 | Dat$variables$ethn_dv == 6 |
                                               Dat$variables$ethn_dv == 7 | Dat$variables$ethn_dv == 8) ~ 4,
                                            Dat$variables$ethn_dv == 9 ~ 5,
                                            Dat$variables$ethn_dv == 10 ~ 6,
                                            Dat$variables$ethn_dv == 11 ~ 7,
                                            Dat$variables$ethn_dv == 12 ~ 8,
                                            Dat$variables$ethn_dv == 14 ~ 9,
                                            (Dat$variables$ethn_dv == 15 | Dat$variables$ethn_dv == 56) ~ 10,
                                            Dat$variables$ethn_dv < 1 ~ -1,
                                            TRUE ~ 0)
Dat$variables$DV_Ethnicity_All <- replace(Dat$variables$DV_Ethnicity_All,
                                          Dat$variables$DV_Ethnicity_All %in% c(-1), NA) 
Dat$variables$DV_Ethnicity_All_Label <- factor(Dat$variables$DV_Ethnicity_All, 
                                         levels = c(1,2,3,4,5,6,7,8,9,10,0),
                                         labels = c("UK","Irish","Gypsy or Irish traveller","Mixed",
                                                    "Indian","Pakistani","Bangladeshi","Chinese",
                                                    "Caribbean","African","Other"))

#* All Regions:
Dat$variables$DV_Region_All <- replace(Dat$variables$gor_dv,
                                       Dat$variables$gor_dv %in% c(-9), NA)                                            

Dat$variables$DV_Region_All_Label <- factor(Dat$variables$DV_Region_All, 
                                               levels = c(1,2,3,4,5,6,7,8,9,10,11,12),
                                               labels = c("North East","North West","Yorkshire & Humber","East Mids",
                                                          "West Mids","East of England","London","South East",
                                                          "South West","Wales","Scotland","Northern Ireland"))
#* North:
Dat$variables$DV_Region_North <- case_when((Dat$variables$gor_dv == 1 | Dat$variables$gor_dv == 2 |
                                              Dat$variables$gor_dv == 3) ~ 1,
                                           Dat$variables$gor_dv == -9 ~ -1,
                                           TRUE ~ 0)
Dat$variables$DV_Region_North <- replace(Dat$variables$DV_Region_North,
                                         Dat$variables$DV_Region_North %in% c(-1), NA)                                            
#* North East:
Dat$variables$DV_Region_NorthEast <- case_when(Dat$variables$gor_dv == 1 ~ 1,
                                               Dat$variables$gor_dv == -9 ~ -1,
                                               TRUE ~ 0)
Dat$variables$DV_Region_NorthEast <- replace(Dat$variables$DV_Region_NorthEast,
                                             Dat$variables$DV_Region_NorthEast %in% c(-1), NA) 
#* North West:
Dat$variables$DV_Region_NorthWest <- case_when(Dat$variables$gor_dv == 2 ~ 1,
                                               Dat$variables$gor_dv == -9 ~ -1,
                                               TRUE ~ 0)
Dat$variables$DV_Region_NorthWest <- replace(Dat$variables$DV_Region_NorthWest,
                                             Dat$variables$DV_Region_NorthWest %in% c(-1), NA) 
#* Yorks & Humber:
Dat$variables$DV_Region_YorksHumber <- case_when(Dat$variables$gor_dv == 3 ~ 1,
                                                 Dat$variables$gor_dv == -9 ~ -1,
                                                 TRUE ~ 0)
Dat$variables$DV_Region_YorksHumber <- replace(Dat$variables$DV_Region_YorksHumber,
                                               Dat$variables$DV_Region_YorksHumber %in% c(-1), NA) 
#* East Midlands:
Dat$variables$DV_Region_EastMids <- case_when(Dat$variables$gor_dv == 4 ~ 1,
                                              Dat$variables$gor_dv == -9 ~ -1,
                                              TRUE ~ 0)
Dat$variables$DV_Region_EastMids <- replace(Dat$variables$DV_Region_EastMids,
                                            Dat$variables$DV_Region_EastMids %in% c(-1), NA) 
#* West Midlands:
Dat$variables$DV_Region_WestMids <- case_when(Dat$variables$gor_dv == 5 ~ 1,
                                              Dat$variables$gor_dv == -9 ~ -1,
                                              TRUE ~ 0)
Dat$variables$DV_Region_WestMids <- replace(Dat$variables$DV_Region_WestMids,
                                            Dat$variables$DV_Region_WestMids %in% c(-1), NA) 
#* East of England:
Dat$variables$DV_Region_East <- case_when(Dat$variables$gor_dv == 6 ~ 1,
                                          Dat$variables$gor_dv == -9 ~ -1,
                                          TRUE ~ 0)
Dat$variables$DV_Region_East <- replace(Dat$variables$DV_Region_East,
                                        Dat$variables$DV_Region_East %in% c(-1), NA) 
#* London:
Dat$variables$DV_Region_London <- case_when(Dat$variables$gor_dv == 7 ~ 1,
                                            Dat$variables$gor_dv == -9 ~ -1,
                                            TRUE ~ 0)
Dat$variables$DV_Region_London <- replace(Dat$variables$DV_Region_London,
                                          Dat$variables$DV_Region_London %in% c(-1), NA)                                            
#* South East:
Dat$variables$DV_Region_SouthEast <- case_when(Dat$variables$gor_dv == 8 ~ 1,
                                               Dat$variables$gor_dv == -9 ~ -1,
                                               TRUE ~ 0)
Dat$variables$DV_Region_SouthEast <- replace(Dat$variables$DV_Region_SouthEast,
                                             Dat$variables$DV_Region_SouthEast %in% c(-1), NA)   
#* South West:
Dat$variables$DV_Region_SouthWest <- case_when(Dat$variables$gor_dv == 9 ~ 1,
                                               Dat$variables$gor_dv == -9 ~ -1,
                                               TRUE ~ 0)
Dat$variables$DV_Region_SouthWest <- replace(Dat$variables$DV_Region_SouthWest,
                                             Dat$variables$DV_Region_SouthWest %in% c(-1), NA)
#* Wales:
Dat$variables$DV_Region_Wales <- case_when(Dat$variables$gor_dv == 10 ~ 1,
                                           Dat$variables$gor_dv == -9 ~ -1,
                                           TRUE ~ 0)
Dat$variables$DV_Region_Wales <- replace(Dat$variables$DV_Region_Wales,
                                         Dat$variables$DV_Region_Wales %in% c(-1), NA)  
#* Scotland:
Dat$variables$DV_Region_Scotland <- case_when(Dat$variables$gor_dv == 11 ~ 1,
                                              Dat$variables$gor_dv == -9 ~ -1,
                                              TRUE ~ 0)
Dat$variables$DV_Region_Scotland <- replace(Dat$variables$DV_Region_Scotland,
                                            Dat$variables$DV_Region_Scotland %in% c(-1), NA)  
#* Northern Ireland:
Dat$variables$DV_Region_NorthernIreland <- case_when(Dat$variables$gor_dv == 12 ~ 1,
                                                     Dat$variables$gor_dv == -9 ~ -1,
                                                     TRUE ~ 0)
Dat$variables$DV_Region_NorthernIreland <- replace(Dat$variables$DV_Region_NorthernIreland,
                                                   Dat$variables$DV_Region_NorthernIreland %in% c(-1), NA)  

#* All ages (numerical):
Dat$variables$DV_Age_All_Num <- case_when(Dat$variables$age_dv < 0 ~ -1,
                                    TRUE ~ as.numeric(as.character(Dat$variables$age_dv)))
Dat$variables$DV_Age_All_Num <- replace(Dat$variables$DV_Age_All_Num,
                                    Dat$variables$DV_Age_All_Num %in% c(-1), NA)  

#* Numerical age squared:
Dat$variables$DV_Age_All_Num_Squared <- Dat$variables$DV_Age_All_Num * Dat$variables$DV_Age_All_Num

#* All ages (categorical):
Dat$variables$DV_Age_All <- case_when((Dat$variables$age_dv >= 16 & Dat$variables$age_dv <= 25) ~ 1,
                                      (Dat$variables$age_dv >= 26 & Dat$variables$age_dv <= 35) ~ 2,
                                      (Dat$variables$age_dv >= 36 & Dat$variables$age_dv <= 45) ~ 3,
                                      (Dat$variables$age_dv >= 46 & Dat$variables$age_dv <= 55) ~ 4,
                                      (Dat$variables$age_dv  >= 56 & Dat$variables$age_dv <= 65) ~ 5,
                                       Dat$variables$age_dv >= 66 ~ 6, 
                                       TRUE ~ -1)
Dat$variables$DV_Age_All <- replace(Dat$variables$DV_Age_All,
                                    Dat$variables$DV_Age_All %in% c(-1), NA)  
Dat$variables$DV_Age_All_Label <- factor(Dat$variables$DV_Age_All, 
                                               levels = c(1,2,3,4,5,6),
                                               labels = c("Aged 16-25","Aged 26-35","Aged 36-45","Aged 46-55",
                                                          "Aged 56-65", "Aged 66+"))

#* Young:
Dat$variables$DV_Age_Young <- case_when((Dat$variables$age_dv > 14 & Dat$variables$age_dv < 25) ~ 1,
                                        Dat$variables$age_dv < 0 ~ -1,
                                        TRUE ~ 0)
Dat$variables$DV_Age_Young <- replace(Dat$variables$DV_Age_Young,
                                      Dat$variables$DV_Age_Young %in% c(-1), NA) 
#* Prime Working Age:
Dat$variables$DV_Age_PrimeWorkingAge <- case_when((Dat$variables$age_dv > 24 & Dat$variables$age_dv < 55) ~ 1,
                                                  Dat$variables$age_dv < 0 ~ -1,
                                                  TRUE ~ 0)
Dat$variables$DV_Age_PrimeWorkingAge <- replace(Dat$variables$DV_Age_PrimeWorkingAge,
                                                Dat$variables$DV_Age_PrimeWorkingAge %in% c(-1), NA) 
#* Near Retirement:
Dat$variables$DV_Age_NearRetirement <- case_when((Dat$variables$age_dv > 54 & Dat$variables$age_dv < 65) ~ 1,
                                                 Dat$variables$age_dv < 0 ~ -1,
                                                 TRUE ~ 0)
Dat$variables$DV_Age_NearRetirement <- replace(Dat$variables$DV_Age_NearRetirement,
                                               Dat$variables$DV_Age_NearRetirement %in% c(-1), NA) 
#* Post Retirement:
Dat$variables$DV_Age_PostRetirement <- case_when(Dat$variables$age_dv > 64 ~ 1,
                                                 Dat$variables$age_dv < 0 ~ -1,
                                                 TRUE ~ 0)
Dat$variables$DV_Age_PostRetirement <- replace(Dat$variables$DV_Age_PostRetirement,
                                               Dat$variables$DV_Age_PostRetirement %in% c(-1), NA) 
#* Self Employed
Dat$variables$DV_SelfEmployed <- case_when(Dat$variables$jbsemp == 2 ~ 1,
                                           Dat$variables$jbsemp < 0 ~ -1,
                                           TRUE ~ 0)
Dat$variables$DV_SelfEmployed <- replace(Dat$variables$DV_SelfEmployed,
                                         Dat$variables$DV_SelfEmployed %in% c(-1), NA) 

#* Employee
Dat$variables$DV_Employee <- case_when(Dat$variables$jbsemp == 1 ~ 1,
                                           Dat$variables$jbsemp < 0 ~ -1,
                                           TRUE ~ 0)
Dat$variables$DV_Employee <- replace(Dat$variables$DV_Employee,
                                         Dat$variables$DV_Employee %in% c(-1), NA) 

#* Number of employees/workers in workplace:
Dat$variables$DV_JbJsSize <- case_when(Dat$variables$DV_SelfEmployed == 1 & Dat$variables$jsboss == 2 ~ 1,
                                       Dat$variables$DV_SelfEmployed == 1 & Dat$variables$jsboss != 2 ~ as.numeric(as.character(Dat$variables$jssize)),
                                       Dat$variables$DV_SelfEmployed == 0 & Dat$variables$jbsize == 10 ~ 3,
                                       Dat$variables$DV_SelfEmployed == 0 & Dat$variables$jbsize == 11 ~ 4,
                                       Dat$variables$DV_SelfEmployed == 0 & (Dat$variables$jbsize != 10 & Dat$variables$jbsize != 11) ~ as.numeric(as.character(Dat$variables$jbsize)),
                                       TRUE ~ -1)
Dat$variables$DV_JbJsSize <- case_when(Dat$variables$DV_JbJsSize < 0 ~ -1,
                                       TRUE ~ as.numeric(as.character(Dat$variables$DV_JbJsSize)))
Dat$variables$DV_JbJsSize <- replace(Dat$variables$DV_JbJsSize,
                                     Dat$variables$DV_JbJsSize %in% c(-1), NA) 

#* 2012-13
Dat$variables$DV_Time_Wave4 <- case_when(Dat$variables$year == "2012-13" ~ 1, TRUE ~ 0)

#* 2014-15
Dat$variables$DV_Time_Wave6 <- case_when(Dat$variables$year == "2014-15" ~ 1, TRUE ~ 0)

#* 2016-17
Dat$variables$DV_Time_Wave8 <- case_when(Dat$variables$year == "2016-17" ~ 1, TRUE ~ 0)

#* 2018-19
Dat$variables$DV_Time_Wave10 <- case_when(Dat$variables$year == "2018-19" ~ 1, TRUE ~ 0)

#* 2020-21:
Dat$variables$DV_Time_Wave12 <- case_when(Dat$variables$year == "2020-21" ~ 1, TRUE ~ 0)

#* Number of unemployment spells since last interview. Because so few people in QoW index were 
#* unemployed >1 times since last interview, this is just a dummy variable which is 1 if they were
#* unemployed 1 or more times and 0 if they weren't:
Dat$variables$DV_PrevUnemployed <- case_when(Dat$variables$nunmpsp_dv == 0 ~ 0,
                                             Dat$variables$nunmpsp_dv >= 1 ~ 1)

#* Temporary MVA Pension due to no ppen in Wave 12:
Dat$variables$Ind_Pension_NAs_MVA <- case_when(Dat$variables$wave == "12" & Dat$variables$QoW_Index_Member == 1 ~ 0.1,
                                               TRUE ~ as.numeric(as.character(Dat$variables$Ind_Pension_NAs)))
Dat$variables$Ind_Pension_MVA <- case_when(Dat$variables$wave == "12" & Dat$variables$QoW_Index_Member == 1 ~ 0.1,
                                           TRUE ~ as.numeric(as.character(Dat$variables$Ind_Pension)))

#* Temporary MVA Flexibility due to no Self Employed data:
Dat$variables$Ind_Flexibility_NAs_MVA <- case_when(Dat$variables$DV_SelfEmployed == 1 & Dat$variables$QoW_Index_Member == 1 ~ 0.1,
                                               TRUE ~ as.numeric(as.character(Dat$variables$Ind_Flexibility_NAs)))
Dat$variables$Ind_Flexibility_MVA <- case_when(Dat$variables$DV_SelfEmployed == 1 & Dat$variables$QoW_Index_Member == 1 ~ 0.1,
                                           TRUE ~ as.numeric(as.character(Dat$variables$Ind_Flexibility)))

#* ----------- [c] Save predictor variables: 

#* All the above syntax now saved as of [20.12.23]:
saveRDS(Dat, file = "0 - Dat.RData")

#######################################################################################
############################## 2 - Missingness tests ##################################
#######################################################################################

#* Below is most of the syntax for my 'Appendix A - Missing values and weighting methods
#* in Understanding Society - An Overview.' Note flexibility is a % of employees only,
#* and not the JQ index as a whole, as this indicator excludes the self-employed.

#* ----------- [a] Weighted % missing values by indicator: 
Tab1 <- prop.table(svytable((~Ind_EarningsSufficiency_ImpFlag + year),JQ), margin=2) |> round(3) |> as_tibble()
Tab1$Indicator <- "Earnings Sufficiency"
Tab1 <- Tab1 |> rename(Prop = Ind_EarningsSufficiency_ImpFlag)
  
Tab2 <- prop.table(svytable((~Ind_EarningsEquity_ImpFlag + year),JQ), margin=2) |> round(3) |> as_tibble() 
Tab2$Indicator <- "Earnings Equity"
Tab2 <- Tab2 |> rename(Prop = Ind_EarningsEquity_ImpFlag)

Tab3 <- prop.table(svytable((~Ind_Pension_ImpFlag + year), JQ), margin=2) |> round(3) |> as_tibble()
Tab3$Indicator <- "Pension"
Tab3 <- Tab3 |> rename(Prop = Ind_Pension_ImpFlag)

Tab4 <- prop.table(svytable((~Ind_ContinuousEmployment_ImpFlag + year),JQ), margin=2) |> round(3) |> as_tibble()
Tab4$Indicator <- "Continuous Employment"
Tab4 <- Tab4 |> rename(Prop = Ind_ContinuousEmployment_ImpFlag)

Tab5 <- prop.table(svytable((~Ind_CompositeSecurity_ImpFlag + year),JQ), margin=2) |> round(3) |> as_tibble()
Tab5$Indicator <- "Composite Security"
Tab5 <- Tab5 |> rename(Prop = Ind_CompositeSecurity_ImpFlag)

Tab6 <- prop.table(svytable((~Ind_Autonomy_ImpFlag + year),JQ), margin=2) |> round(3) |> as_tibble()
Tab6$Indicator <- "Autonomy"
Tab6 <- Tab6 |> rename(Prop = Ind_Autonomy_ImpFlag)

Tab7 <- prop.table(svytable((~Ind_CollectiveVoice_ImpFlag + year), JQ), margin=2) |> round(3) |> as_tibble()
Tab7$Indicator <- "Collective Voice"
Tab7 <- Tab7 |> rename(Prop = Ind_CollectiveVoice_ImpFlag)

Tab8 <- prop.table(svytable((~Ind_Flexibility_ImpFlag + year),Employees), margin=2) |> round(3) |> as_tibble()
Tab8$Indicator <- "Flexibility" #* Note this is employees only for flexibility. 
Tab8 <- Tab8 |> rename(Prop = Ind_Flexibility_ImpFlag)

Tab9 <- prop.table(svytable((~Ind_ExcessiveHours_ImpFlag + year),JQ), margin=2) |> round(3) |> as_tibble()
Tab9$Indicator <- "Excessive Hours" 
Tab9 <- Tab9 |> rename(Prop = Ind_ExcessiveHours_ImpFlag)

Tab10 <- prop.table(svytable((~Ind_ManagerialDuties_ImpFlag + year),JQ), margin=2) |> round(3) |> as_tibble()
Tab10$Indicator <- "Managerial Duties" 
Tab10 <- Tab10 |> rename(Prop = Ind_ManagerialDuties_ImpFlag)

Tab11 <- prop.table(svytable((~Ind_ShortTermProspects_ImpFlag + year),JQ), margin=2) |> round(3) |> as_tibble()
Tab11$Indicator <- "Short-term Prospects" 
Tab11 <- Tab11 |> rename(Prop = Ind_ShortTermProspects_ImpFlag)

Tab12 <- prop.table(svytable((~Ind_LongTermProspects_ImpFlag + year),JQ), margin=2) |> round(3) |> as_tibble()
Tab12$Indicator <- "Long-term Prospects" 
Tab12 <- Tab12 |> rename(Prop = Ind_LongTermProspects_ImpFlag)

Tab13 <- prop.table(svytable((~Ind_WorkFatalities_ImpFlag + year),JQ), margin=2) |> round(3) |> as_tibble()
Tab13$Indicator <- "Work Fatalities" 
Tab13 <- Tab13 |> rename(Prop = Ind_WorkFatalities_ImpFlag)

Tab14 <- prop.table(svytable((~Ind_WorkAccidents_ImpFlag + year),JQ), margin=2) |> round(3) |> as_tibble()
Tab14$Indicator <- "Work Accidents" 
Tab14 <- Tab14 |> rename(Prop = Ind_WorkAccidents_ImpFlag)

Tab15 <- prop.table(svytable((~Ind_WorkIllness_ImpFlag + year),JQ), margin=2) |> round(3) |> as_tibble()
Tab15$Indicator <- "Work Illness" 
Tab15 <- Tab15 |> rename(Prop = Ind_WorkIllness_ImpFlag)

Tab <- bind_rows(Tab1, Tab2, Tab3, Tab4, Tab5, Tab6, Tab7, Tab8, Tab9,
                 Tab10, Tab11, Tab12, Tab13, Tab14, Tab15)
Tab <- Tab |> filter(Prop == 1)

#* ----------- [b] Unweighted % missing values by indicator: 
Tab1 <- prop.table(xtabs((~Ind_EarningsSufficiency_ImpFlag + year),JQ), margin=2) |> round(3) |> as_tibble()
Tab1$Indicator <- "Earnings Sufficiency"
Tab1 <- Tab1 |> rename(Prop = Ind_EarningsSufficiency_ImpFlag)

Tab2 <- prop.table(xtabs((~Ind_EarningsEquity_ImpFlag + year),JQ), margin=2) |> round(3) |> as_tibble() 
Tab2$Indicator <- "Earnings Equity"
Tab2 <- Tab2 |> rename(Prop = Ind_EarningsEquity_ImpFlag)

Tab3 <- prop.table(xtabs((~Ind_Pension_ImpFlag + year), JQ), margin=2) |> round(3) |> as_tibble()
Tab3$Indicator <- "Pension"
Tab3 <- Tab3 |> rename(Prop = Ind_Pension_ImpFlag)

Tab4 <- prop.table(xtabs((~Ind_ContinuousEmployment_ImpFlag + year),JQ), margin=2) |> round(3) |> as_tibble()
Tab4$Indicator <- "Continuous Employment"
Tab4 <- Tab4 |> rename(Prop = Ind_ContinuousEmployment_ImpFlag)

Tab5 <- prop.table(xtabs((~Ind_CompositeSecurity_ImpFlag + year),JQ), margin=2) |> round(3) |> as_tibble()
Tab5$Indicator <- "Composite Security"
Tab5 <- Tab5 |> rename(Prop = Ind_CompositeSecurity_ImpFlag)

Tab6 <- prop.table(xtabs((~Ind_Autonomy_ImpFlag + year),JQ), margin=2) |> round(3) |> as_tibble()
Tab6$Indicator <- "Autonomy"
Tab6 <- Tab6 |> rename(Prop = Ind_Autonomy_ImpFlag)

Tab7 <- prop.table(xtabs((~Ind_CollectiveVoice_ImpFlag + year), JQ), margin=2) |> round(3) |> as_tibble()
Tab7$Indicator <- "Collective Voice"
Tab7 <- Tab7 |> rename(Prop = Ind_CollectiveVoice_ImpFlag)

Tab8 <- prop.table(xtabs((~Ind_Flexibility_ImpFlag + year),Employees), margin=2) |> round(3) |> as_tibble()
Tab8$Indicator <- "Flexibility" #* Note this is employees only for flexibility. 
Tab8 <- Tab8 |> rename(Prop = Ind_Flexibility_ImpFlag)

Tab9 <- prop.table(xtabs((~Ind_ExcessiveHours_ImpFlag + year),JQ), margin=2) |> round(3) |> as_tibble()
Tab9$Indicator <- "Excessive Hours" 
Tab9 <- Tab9 |> rename(Prop = Ind_ExcessiveHours_ImpFlag)

Tab10 <- prop.table(xtabs((~Ind_ManagerialDuties_ImpFlag + year),JQ), margin=2) |> round(3) |> as_tibble()
Tab10$Indicator <- "Managerial Duties" 
Tab10 <- Tab10 |> rename(Prop = Ind_ManagerialDuties_ImpFlag)

Tab11 <- prop.table(xtabs((~Ind_ShortTermProspects_ImpFlag + year),JQ), margin=2) |> round(3) |> as_tibble()
Tab11$Indicator <- "Short-term Prospects" 
Tab11 <- Tab11 |> rename(Prop = Ind_ShortTermProspects_ImpFlag)

Tab12 <- prop.table(xtabs((~Ind_LongTermProspects_ImpFlag + year),JQ), margin=2) |> round(3) |> as_tibble()
Tab12$Indicator <- "Long-term Prospects" 
Tab12 <- Tab12 |> rename(Prop = Ind_LongTermProspects_ImpFlag)

Tab13 <- prop.table(xtabs((~Ind_WorkFatalities_ImpFlag + year),JQ), margin=2) |> round(3) |> as_tibble()
Tab13$Indicator <- "Work Fatalities" 
Tab13 <- Tab13 |> rename(Prop = Ind_WorkFatalities_ImpFlag)

Tab14 <- prop.table(xtabs((~Ind_WorkAccidents_ImpFlag + year),JQ), margin=2) |> round(3) |> as_tibble()
Tab14$Indicator <- "Work Accidents" 
Tab14 <- Tab14 |> rename(Prop = Ind_WorkAccidents_ImpFlag)

Tab15 <- prop.table(xtabs((~Ind_WorkIllness_ImpFlag + year),JQ), margin=2) |> round(3) |> as_tibble()
Tab15$Indicator <- "Work Illness" 
Tab15 <- Tab15 |> rename(Prop = Ind_WorkIllness_ImpFlag)

Tab <- bind_rows(Tab1, Tab2, Tab3, Tab4, Tab5, Tab6, Tab7, Tab8, Tab9,
                 Tab10, Tab11, Tab12, Tab13, Tab14, Tab15)
Tab <- Tab |> filter(Prop == 1)

#* ----------- [c] Cumulative missing:

#* Create separate data frame of missing data, broken down by wave. Note the use of the
#* NA_MVA suffixed data for pension and flexibility:
Missing_JQ <- JQ$variables |> select(Ind_EarningsSufficiency_NAs, Ind_EarningsEquity_NAs, 
                                     Ind_Pension_NAs_MVA, 
                                     Ind_ContinuousEmployment_NAs, Ind_CompositeSecurity_NAs,
                                     Ind_Autonomy_NAs, Ind_CollectiveVoice_NAs, 
                                     Ind_Flexibility_NAs_MVA, Ind_ExcessiveHours_NAs,
                                     Ind_ManagerialDuties_NAs, Ind_ShortTermProspects_NAs,
                                     Ind_LongTermProspects_NAs, Ind_WorkFatalities_NAs, 
                                     Ind_WorkAccidents_NAs, Ind_WorkIllness_NAs)
Missing_Wave4 <- Wave4$variables |> select(Ind_EarningsSufficiency_NAs, Ind_EarningsEquity_NAs, 
                                           Ind_Pension_NAs_MVA, 
                                           Ind_ContinuousEmployment_NAs, Ind_CompositeSecurity_NAs,
                                           Ind_Autonomy_NAs, Ind_CollectiveVoice_NAs, 
                                           Ind_Flexibility_NAs_MVA, Ind_ExcessiveHours_NAs,
                                           Ind_ManagerialDuties_NAs, Ind_ShortTermProspects_NAs,
                                           Ind_LongTermProspects_NAs, Ind_WorkFatalities_NAs, 
                                           Ind_WorkAccidents_NAs, Ind_WorkIllness_NAs)
Missing_Wave6 <- Wave6$variables |> select(Ind_EarningsSufficiency_NAs, Ind_EarningsEquity_NAs, 
                                           Ind_Pension_NAs_MVA, 
                                           Ind_ContinuousEmployment_NAs, Ind_CompositeSecurity_NAs,
                                           Ind_Autonomy_NAs, Ind_CollectiveVoice_NAs, 
                                           Ind_Flexibility_NAs_MVA, Ind_ExcessiveHours_NAs,
                                           Ind_ManagerialDuties_NAs, Ind_ShortTermProspects_NAs,
                                           Ind_LongTermProspects_NAs, Ind_WorkFatalities_NAs, 
                                           Ind_WorkAccidents_NAs, Ind_WorkIllness_NAs)
Missing_Wave8 <- Wave8$variables |> select(Ind_EarningsSufficiency_NAs, Ind_EarningsEquity_NAs, 
                                           Ind_Pension_NAs_MVA, 
                                           Ind_ContinuousEmployment_NAs, Ind_CompositeSecurity_NAs,
                                           Ind_Autonomy_NAs, Ind_CollectiveVoice_NAs, 
                                           Ind_Flexibility_NAs_MVA, Ind_ExcessiveHours_NAs,
                                           Ind_ManagerialDuties_NAs, Ind_ShortTermProspects_NAs,
                                           Ind_LongTermProspects_NAs, Ind_WorkFatalities_NAs, 
                                           Ind_WorkAccidents_NAs, Ind_WorkIllness_NAs)
Missing_Wave10 <- Wave10$variables |> select(Ind_EarningsSufficiency_NAs, Ind_EarningsEquity_NAs, 
                                             Ind_Pension_NAs_MVA, 
                                             Ind_ContinuousEmployment_NAs, Ind_CompositeSecurity_NAs,
                                             Ind_Autonomy_NAs, Ind_CollectiveVoice_NAs, 
                                             Ind_Flexibility_NAs_MVA, Ind_ExcessiveHours_NAs,
                                             Ind_ManagerialDuties_NAs, Ind_ShortTermProspects_NAs,
                                             Ind_LongTermProspects_NAs, Ind_WorkFatalities_NAs, 
                                             Ind_WorkAccidents_NAs, Ind_WorkIllness_NAs)
Missing_Wave12 <- Wave12$variables |> select(Ind_EarningsSufficiency_NAs, Ind_EarningsEquity_NAs, 
                                             Ind_Pension_NAs_MVA, 
                                             Ind_ContinuousEmployment_NAs, Ind_CompositeSecurity_NAs,
                                             Ind_Autonomy_NAs, Ind_CollectiveVoice_NAs, 
                                             Ind_Flexibility_NAs_MVA, Ind_ExcessiveHours_NAs,
                                             Ind_ManagerialDuties_NAs, Ind_ShortTermProspects_NAs,
                                             Ind_LongTermProspects_NAs, Ind_WorkFatalities_NAs, 
                                             Ind_WorkAccidents_NAs, Ind_WorkIllness_NAs)

#* Download the full MD pattern cross-tabulations into CSVs:
write.csv(md.pattern(Missing_JQ, rotate.names = TRUE), "All Waves - MD Pattern.csv")
write.csv(md.pattern(Missing_Wave4, rotate.names = TRUE), "Wave 4 - MD Pattern.csv")
write.csv(md.pattern(Missing_Wave6, rotate.names = TRUE), "Wave 6 - MD Pattern.csv")
write.csv(md.pattern(Missing_Wave8, rotate.names = TRUE), "Wave 8 - MD Pattern.csv")
write.csv(md.pattern(Missing_Wave10, rotate.names = TRUE), "Wave 10 - MD Pattern.csv")
write.csv(md.pattern(Missing_Wave12, rotate.names = TRUE), "Wave 12 - MD Pattern.csv")

#* Visualise data:
PatternofMissingness <- read.csv('ZZ - Paper 2 - CSV Data for Figure B.1 - Pattern of Missingness.csv')

PatternofMissingness$Wave <- as_factor(PatternofMissingness$Wave)
PatternofMissingness$Wave <- fct_recode(PatternofMissingness$Wave, 
                                        "Wave 4" = "Wave 4",
                                        "Wave 6" = "Wave 6",
                                        "Wave 8" = "Wave 8", 
                                        "Wave 10" = "Wave 10",
                                        "Wave 12" = "Wave 12")

ggplot(PatternofMissingness, aes(x = NumMissingIndicators, y = Percent, colour = Wave, group = Wave)) +
  geom_line(size = 1) +
  geom_point(size = 2) +
  scale_x_discrete(limits = c("0 Indicators", "1 Indicator", " 2 Indicators", "3 Indicators", "4 Indicators", "5 Indicators", 
                              "6 Indicators", "7 Indicators", "8 Indicators", "9 Indicators", "10 Indicators", 
                              "11 Indicators", "12 Indicators", "13 Indicators", "14 Indicators", "15 Indicators")) +
  scale_y_continuous(labels = scales::percent, limits = c(0,0.8)) + 
  labs(y = "",
       fill = "",
       x = "",
       title = "") +
  geom_text(aes(label=Percent.Label), position=position_dodge(width=0.5), hjust = "outward") +
  theme_economist()

#######################################################################################
################### 3 - Identify auxiliary variables as predictors ####################
#######################################################################################

#* Before commencing these, it's advisable to remove all unnecessary data frames and clear the 
#* working memory:
rm(Dat)
gc()

#* ----------------------------------------------------------------
#* -------------- [a - Table A.3 - Ordered logit model of N# indicators missing:]
#* ----------------------------------------------------------------

logit1 <- svy_vglm(formula = factor(Indicators_Missing) ~ CF_CaringResponsibilities_AF + CF_DependentChildren_AF + CF_NonWorkingHHMembers_AF + #* Analysis variables;
                     CF_LongStandingIllness_AF + CF_RecentPhysicalHealth_AF + CF_RecentMentalHealth_AF + 
                     CS_HighestQualification_AF + CS_HousingAssets_AF + CS_PersonalIncomeSufficiency_AF +
                     CS_EquivalisedHHoldInc_WithBenefits_AF + 
                     CS_ParentalNSSEC_AF + 
                     DV_Age_All_Num + DV_Age_All_Num_Squared + #* Auxiliary variables. 
                     DV_Sex +  DV_Ethnicity_All + DV_Region_All + DV_SelfEmployed +
                     DV_IndividualNSSEC + DV_JbJsSize + year + labhrs_adj_weekly_NAs +
                     DV_Sex * DV_Ethnicity_All + #* Interaction terms.
                     DV_Sex * DV_Age_All_Num,
                   design = JQ, family = propodds(), na.action = na.omit)
summary(logit1)

#* ----------------------------------------------------------------
#* -------------- [b - Table A.4 - Logistic regression of missingness for Ind_Pension:]
#* ----------------------------------------------------------------

logit2 <- svyglm(formula = Ind_Pension_ImpFlag_InclWave12 ~ CF_CaringResponsibilities_AF + CF_DependentChildren_AF + CF_NonWorkingHHMembers_AF + #* Analysis variables;
                   CF_LongStandingIllness_AF + CF_RecentPhysicalHealth_AF + CF_RecentMentalHealth_AF +
                   CS_HighestQualification_AF + CS_HousingAssets_AF + CS_PersonalIncomeSufficiency_AF +
                   CS_EquivalisedHHoldInc_MinusBenefits_AF + CS_EquivalisedHHoldInc_WithBenefits_AF +
                   CS_ParentalNSSEC_AF +
                   DV_Age_All_Num + DV_Age_All_Num_Squared + #* Auxiliary variables.
                   DV_Sex + DV_Ethnicity_All + DV_Region_All + DV_SelfEmployed +
                   DV_IndividualNSSEC + DV_JbJsSize + year + labhrs_adj_weekly_NAs +
                   DV_Sex * DV_Ethnicity_All + #* Interaction terms.
                   DV_Sex * DV_Age_All_Num,
                 family = quasibinomial, design = JQ, na.action = na.omit)
summary(logit2)

#* Pseudo- R-squared of models does work for a logistic regression, but not for an 
#* ordered logit model:
psrsq(logit1, method = c("Cox-Snell"))
psrsq(logit1, method = c("Nagelkerke"))

#* ----------------------------------------------------------------
#* -------------- [c - Table A.5 - Indicator scores - Ordered logit model of Pension:]
#* ----------------------------------------------------------------

#* Year removed due to missings in wave 12:

logit3 <- svy_vglm(formula = factor(Ind_Pension_NAs) ~ CF_CaringResponsibilities_AF + CF_DependentChildren_AF + CF_NonWorkingHHMembers_AF + #* Analysis variables;
                   CF_LongStandingIllness_AF + CF_RecentPhysicalHealth_AF + CF_RecentMentalHealth_AF + 
                   CS_HighestQualification_AF + CS_HousingAssets_AF + CS_PersonalIncomeSufficiency_AF +
                   CS_EquivalisedHHoldInc_MinusBenefits_AF + CS_EquivalisedHHoldInc_WithBenefits_AF + 
                     CS_ParentalNSSEC_AF + 
                   DV_Age_All_Num + DV_Age_All_Num_Squared + #* Auxiliary variables. 
                   DV_Sex +  DV_Ethnicity_All + DV_Region_All + DV_SelfEmployed +
                     DV_IndividualNSSEC + DV_JbJsSize + labhrs_adj_weekly_NAs +
                     DV_Sex * DV_Ethnicity_All + #* Interaction terms.
                     DV_Sex * DV_Age_All_Num,
                     design = JQ, family = propodds())
summary(logit3)

#* ----------------------------------------------------------------
#* -------------- [c - Table A.6 - Indicator scores - Ordered logit model of Continuous Employment:]
#* ----------------------------------------------------------------

#* Employees only; self-employed therefore removed:

logit4 <- svy_vglm(formula = factor(Ind_ContinuousEmployment_NAs) ~ CF_CaringResponsibilities_AF + CF_DependentChildren_AF + CF_NonWorkingHHMembers_AF + #* Analysis variables;
                     CF_LongStandingIllness_AF + CF_RecentPhysicalHealth_AF + CF_RecentMentalHealth_AF + 
                     CS_HighestQualification_AF + CS_HousingAssets_AF + CS_PersonalIncomeSufficiency_AF +
                     CS_EquivalisedHHoldInc_MinusBenefits_AF + CS_EquivalisedHHoldInc_WithBenefits_AF + 
                     CS_ParentalNSSEC_AF + 
                     DV_Age_All_Num + DV_Age_All_Num_Squared + #* Auxiliary variables. 
                     DV_Sex +  DV_Ethnicity_All + DV_Region_All + 
                     DV_IndividualNSSEC + DV_JbJsSize + year + labhrs_adj_weekly_NAs +
                     DV_Sex * DV_Ethnicity_All + #* Interaction terms.
                     DV_Sex * DV_Age_All_Num,
                   design = Employees, family = propodds())
summary(logit4)

#* ----------------------------------------------------------------
#* -------------- [d - Table A.7 - Indicator scores - Logistic regression of Collective Voice:]
#* ----------------------------------------------------------------

#* Employees only; self-employed therefore removed. Because it's a binary indicator I temporarily
#* recode collective voice onto a 0-1 scale:

Employees$variables$Ind_CollectiveVoice_NAs <- case_when(Employees$variables$Ind_CollectiveVoice_NAs == 2 ~ 1,
                                                         Employees$variables$Ind_CollectiveVoice_NAs == 0 ~ 0)

logit5 <- svy_vglm(formula = Ind_CollectiveVoice_NAs ~ CF_CaringResponsibilities_AF + CF_DependentChildren_AF + CF_NonWorkingHHMembers_AF + #* Analysis variables;
                   CF_LongStandingIllness_AF + CF_RecentPhysicalHealth_AF + CF_RecentMentalHealth_AF +
                   CS_HighestQualification_AF + CS_HousingAssets_AF + CS_PersonalIncomeSufficiency_AF +
                   CS_EquivalisedHHoldInc_MinusBenefits_AF + CS_EquivalisedHHoldInc_WithBenefits_AF +
                   CS_ParentalNSSEC_AF +
                   DV_Age_All_Num + DV_Age_All_Num_Squared + #* Auxiliary variables.
                   DV_Sex + DV_Ethnicity_All + DV_Region_All +
                   DV_IndividualNSSEC + DV_JbJsSize + year + labhrs_adj_weekly_NAs +
                   DV_Sex * DV_Ethnicity_All + #* Interaction terms.
                   DV_Sex * DV_Age_All_Num,
                 family = quasibinomial, design = Employees, na.action = na.omit)
summary(logit5)

#* ----------------------------------------------------------------
#* -------------- [e - Table A.8 - Indicator scores - Ordered logit model of Flexibility:]
#* ----------------------------------------------------------------

#* Employees only; self-employed therefore removed:

logit6 <- svy_vglm(formula = factor(Ind_Flexibility_NAs) ~ CF_CaringResponsibilities_AF + CF_DependentChildren_AF + CF_NonWorkingHHMembers_AF + #* Analysis variables;
                     CF_LongStandingIllness_AF + CF_RecentPhysicalHealth_AF + CF_RecentMentalHealth_AF + 
                     CS_HighestQualification_AF + CS_HousingAssets_AF + CS_PersonalIncomeSufficiency_AF +
                     CS_EquivalisedHHoldInc_MinusBenefits_AF + CS_EquivalisedHHoldInc_WithBenefits_AF + 
                     CS_ParentalNSSEC_AF + 
                     DV_Age_All_Num + DV_Age_All_Num_Squared + #* Auxiliary variables. 
                     DV_Sex +  DV_Ethnicity_All + DV_Region_All + 
                     DV_IndividualNSSEC + DV_JbJsSize + year + labhrs_adj_weekly_NAs +
                     DV_Sex * DV_Ethnicity_All + #* Interaction terms.
                     DV_Sex * DV_Age_All_Num,
                   design = Employees, family = propodds())
summary(logit6)

#######################################################################################
########################### 4 - Create imputation filters #############################
#######################################################################################

#* I only need three filters for the imputation. They can be further filtered at the imputation
#* stage itself: 

Imp_JQ <- JQ$variables |> select(hidp, pidp,
                                 Ind_EarningsEquity_NAs, Ind_EarningsEquity_ImpFlag,
                                 Ind_Pension_NAs, Ind_Pension_ImpFlag,
                                 Ind_ContinuousEmployment_NAs, Ind_ContinuousEmployment_ImpFlag, 
                                 Ind_CompositeSecurity_NAs, Ind_CompositeSecurity_ImpFlag,
                                 Ind_Autonomy_NAs, Ind_Autonomy_ImpFlag, 
                                 Ind_CollectiveVoice_NAs, Ind_CollectiveVoice_ImpFlag,
                                 Ind_Flexibility_NAs, Ind_Flexibility_ImpFlag,
                                 Ind_ExcessiveHours_NAs, Ind_ExcessiveHours_ImpFlag,
                                 Ind_ManagerialDuties_NAs, Ind_ManagerialDuties_ImpFlag,
                                 Ind_ShortTermProspects_NAs, Ind_ShortTermProspects_ImpFlag,
                                 CF_CaringResponsibilities_AF, CF_DependentChildren_AF, CF_NonWorkingHHMembers_AF, 
                                 CF_LongStandingIllness_AF, CF_RecentPhysicalHealth_AF, CF_RecentMentalHealth_AF, 
                                 CS_HighestQualification_AF, CS_HousingAssets_AF, CS_PersonalIncomeSufficiency_AF,
                                 CS_EquivalisedHHoldInc_MinusBenefits_AF, CS_EquivalisedHHoldInc_WithBenefits_AF, 
                                 CS_ParentalNSSEC_AF, 
                                 DV_Age_All_Num, DV_Age_All_Num_Squared, 
                                 DV_Sex,  DV_Ethnicity_All, DV_Region_All, DV_SelfEmployed, 
                                 DV_IndividualNSSEC, DV_JbJsSize, labhrs_adj_weekly_NAs,
                                 year) 

Imp_Employees <- Employees$variables |> select(hidp, pidp,
                                 Ind_EarningsEquity_NAs, Ind_EarningsEquity_ImpFlag,
                                 Ind_Pension_NAs, Ind_Pension_ImpFlag,
                                 Ind_ContinuousEmployment_NAs, Ind_ContinuousEmployment_ImpFlag, 
                                 Ind_CompositeSecurity_NAs, Ind_CompositeSecurity_ImpFlag,
                                 Ind_Autonomy_NAs, Ind_Autonomy_ImpFlag, 
                                 Ind_CollectiveVoice_NAs, Ind_CollectiveVoice_ImpFlag,
                                 Ind_Flexibility_NAs, Ind_Flexibility_ImpFlag,
                                 Ind_ExcessiveHours_NAs, Ind_ExcessiveHours_ImpFlag,
                                 Ind_ManagerialDuties_NAs, Ind_ManagerialDuties_ImpFlag,
                                 Ind_ShortTermProspects_NAs, Ind_ShortTermProspects_ImpFlag,
                                 CF_CaringResponsibilities_AF, CF_DependentChildren_AF, CF_NonWorkingHHMembers_AF, 
                                 CF_LongStandingIllness_AF, CF_RecentPhysicalHealth_AF, CF_RecentMentalHealth_AF, 
                                 CS_HighestQualification_AF, CS_HousingAssets_AF, CS_PersonalIncomeSufficiency_AF,
                                 CS_EquivalisedHHoldInc_MinusBenefits_AF, CS_EquivalisedHHoldInc_WithBenefits_AF, 
                                 CS_ParentalNSSEC_AF, 
                                 DV_Age_All_Num, DV_Age_All_Num_Squared, 
                                 DV_Sex,  DV_Ethnicity_All, DV_Region_All, DV_SelfEmployed, 
                                 DV_IndividualNSSEC, DV_JbJsSize, labhrs_adj_weekly_NAs,
                                 year) 

Imp_SelfEmployed <- SelfEmployed$variables |> select(hidp, pidp,
                                 Ind_EarningsEquity_NAs, Ind_EarningsEquity_ImpFlag, 
                                 Ind_Pension_NAs, Ind_Pension_ImpFlag, 
                                 Ind_ContinuousEmployment_NAs, Ind_ContinuousEmployment_ImpFlag, 
                                 Ind_CompositeSecurity_NAs, Ind_CompositeSecurity_ImpFlag,
                                 Ind_Autonomy_NAs, Ind_Autonomy_ImpFlag, 
                                 Ind_CollectiveVoice_NAs, Ind_CollectiveVoice_ImpFlag,
                                 Ind_Flexibility_NAs, Ind_Flexibility_ImpFlag,
                                 Ind_ExcessiveHours_NAs, Ind_ExcessiveHours_ImpFlag,
                                 Ind_ManagerialDuties_NAs, Ind_ManagerialDuties_ImpFlag,
                                 Ind_ShortTermProspects_NAs, Ind_ShortTermProspects_ImpFlag,
                                 CF_CaringResponsibilities_AF, CF_DependentChildren_AF, CF_NonWorkingHHMembers_AF, 
                                 CF_LongStandingIllness_AF, CF_RecentPhysicalHealth_AF, CF_RecentMentalHealth_AF, 
                                 CS_HighestQualification_AF, CS_HousingAssets_AF, CS_PersonalIncomeSufficiency_AF,
                                 CS_EquivalisedHHoldInc_MinusBenefits_AF, CS_EquivalisedHHoldInc_WithBenefits_AF, 
                                 CS_ParentalNSSEC_AF, 
                                 DV_Age_All_Num, DV_Age_All_Num_Squared, 
                                 DV_Sex,  DV_Ethnicity_All, DV_Region_All, DV_SelfEmployed, 
                                 DV_IndividualNSSEC, DV_JbJsSize, labhrs_adj_weekly_NAs,
                                 year) 

#* Convert to factors: 
Imp_JQ$Ind_EarningsEquity_NAs <- as.factor(Imp_JQ$Ind_EarningsEquity_NAs)
Imp_JQ$Ind_Pension_NAs <- as.factor(Imp_JQ$Ind_Pension_NAs)
Imp_JQ$Ind_ContinuousEmployment_NAs <- as.factor(Imp_JQ$Ind_ContinuousEmployment_NAs)
Imp_JQ$Ind_CompositeSecurity_NAs <- as.factor(Imp_JQ$Ind_CompositeSecurity_NAs)
Imp_JQ$Ind_Autonomy_NAs <- as.factor(Imp_JQ$Ind_Autonomy_NAs)
Imp_JQ$Ind_CollectiveVoice_NAs <- as.factor(Imp_JQ$Ind_CollectiveVoice_NAs)
Imp_JQ$Ind_Flexibility_NAs <- as.factor(Imp_JQ$Ind_Flexibility_NAs)
Imp_JQ$Ind_ExcessiveHours_NAs <- as.factor(Imp_JQ$Ind_ExcessiveHours_NAs)
Imp_JQ$Ind_ManagerialDuties_NAs <- as.factor(Imp_JQ$Ind_ManagerialDuties_NAs)
Imp_JQ$Ind_ShortTermProspects_NAs <- as.factor(Imp_JQ$Ind_ShortTermProspects_NAs)
Imp_JQ$CF_CaringResponsibilities_AF <- as.factor(Imp_JQ$CF_CaringResponsibilities_AF)
Imp_JQ$CF_DependentChildren_AF <- as.factor(Imp_JQ$CF_DependentChildren_AF)
Imp_JQ$CF_NonWorkingHHMembers_AF <- as.factor(Imp_JQ$CF_NonWorkingHHMembers_AF)
Imp_JQ$CF_LongStandingIllness_AF <- as.factor(Imp_JQ$CF_LongStandingIllness_AF)
Imp_JQ$CF_RecentPhysicalHealth_AF <- as.factor(Imp_JQ$CF_RecentPhysicalHealth_AF)
Imp_JQ$CF_RecentMentalHealth_AF <- as.factor(Imp_JQ$CF_RecentMentalHealth_AF)
Imp_JQ$CS_HighestQualification_AF <- as.factor(Imp_JQ$CS_HighestQualification_AF)
Imp_JQ$CS_HousingAssets_AF <- as.factor(Imp_JQ$CS_HousingAssets_AF)
Imp_JQ$CS_PersonalIncomeSufficiency_AF <- as.factor(Imp_JQ$CS_PersonalIncomeSufficiency_AF)
Imp_JQ$CS_EquivalisedHHoldInc_MinusBenefits_AF <- as.factor(Imp_JQ$CS_EquivalisedHHoldInc_MinusBenefits_AF)
Imp_JQ$CS_EquivalisedHHoldInc_WithBenefits_AF <- as.factor(Imp_JQ$CS_EquivalisedHHoldInc_WithBenefits_AF)
Imp_JQ$CS_ParentalNSSEC_AF <- as.factor(Imp_JQ$CS_ParentalNSSEC_AF)
Imp_JQ$DV_Sex <- as.factor(Imp_JQ$DV_Sex)
Imp_JQ$DV_Ethnicity_All <- as.factor(Imp_JQ$DV_Ethnicity_All)
Imp_JQ$DV_Region_All <- as.factor(Imp_JQ$DV_Region_All)
Imp_JQ$DV_SelfEmployed <- as.factor(Imp_JQ$DV_SelfEmployed)
Imp_JQ$DV_IndividualNSSEC <- as.factor(Imp_JQ$DV_IndividualNSSEC)
Imp_JQ$DV_JbJsSize <- as.factor(Imp_JQ$DV_JbJsSize)
Imp_JQ$year <- as.factor(Imp_JQ$year)

Imp_Employees$Ind_EarningsEquity_NAs <- as.factor(Imp_Employees$Ind_EarningsEquity_NAs)
Imp_Employees$Ind_Pension_NAs <- as.factor(Imp_Employees$Ind_Pension_NAs)
Imp_Employees$Ind_ContinuousEmployment_NAs <- as.factor(Imp_Employees$Ind_ContinuousEmployment_NAs)
Imp_Employees$Ind_CompositeSecurity_NAs <- as.factor(Imp_Employees$Ind_CompositeSecurity_NAs)
Imp_Employees$Ind_Autonomy_NAs <- as.factor(Imp_Employees$Ind_Autonomy_NAs)
Imp_Employees$Ind_CollectiveVoice_NAs <- as.factor(Imp_Employees$Ind_CollectiveVoice_NAs)
Imp_Employees$Ind_Flexibility_NAs <- as.factor(Imp_Employees$Ind_Flexibility_NAs)
Imp_Employees$Ind_ExcessiveHours_NAs <- as.factor(Imp_Employees$Ind_ExcessiveHours_NAs)
Imp_Employees$Ind_ManagerialDuties_NAs <- as.factor(Imp_Employees$Ind_ManagerialDuties_NAs)
Imp_Employees$Ind_ShortTermProspects_NAs <- as.factor(Imp_Employees$Ind_ShortTermProspects_NAs)
Imp_Employees$CF_CaringResponsibilities_AF <- as.factor(Imp_Employees$CF_CaringResponsibilities_AF)
Imp_Employees$CF_DependentChildren_AF <- as.factor(Imp_Employees$CF_DependentChildren_AF)
Imp_Employees$CF_NonWorkingHHMembers_AF <- as.factor(Imp_Employees$CF_NonWorkingHHMembers_AF)
Imp_Employees$CF_LongStandingIllness_AF <- as.factor(Imp_Employees$CF_LongStandingIllness_AF)
Imp_Employees$CF_RecentPhysicalHealth_AF <- as.factor(Imp_Employees$CF_RecentPhysicalHealth_AF)
Imp_Employees$CF_RecentMentalHealth_AF <- as.factor(Imp_Employees$CF_RecentMentalHealth_AF)
Imp_Employees$CS_HighestQualification_AF <- as.factor(Imp_Employees$CS_HighestQualification_AF)
Imp_Employees$CS_HousingAssets_AF <- as.factor(Imp_Employees$CS_HousingAssets_AF)
Imp_Employees$CS_PersonalIncomeSufficiency_AF <- as.factor(Imp_Employees$CS_PersonalIncomeSufficiency_AF)
Imp_Employees$CS_EquivalisedHHoldInc_MinusBenefits_AF <- as.factor(Imp_Employees$CS_EquivalisedHHoldInc_MinusBenefits_AF)
Imp_Employees$CS_EquivalisedHHoldInc_WithBenefits_AF <- as.factor(Imp_Employees$CS_EquivalisedHHoldInc_WithBenefits_AF)
Imp_Employees$CS_ParentalNSSEC_AF <- as.factor(Imp_Employees$CS_ParentalNSSEC_AF)
Imp_Employees$DV_Sex <- as.factor(Imp_Employees$DV_Sex)
Imp_Employees$DV_Ethnicity_All <- as.factor(Imp_Employees$DV_Ethnicity_All)
Imp_Employees$DV_Region_All <- as.factor(Imp_Employees$DV_Region_All)
Imp_Employees$DV_SelfEmployed <- as.factor(Imp_Employees$DV_SelfEmployed)
Imp_Employees$DV_IndividualNSSEC <- as.factor(Imp_Employees$DV_IndividualNSSEC)
Imp_Employees$DV_JbJsSize <- as.factor(Imp_Employees$DV_JbJsSize)
Imp_Employees$year <- as.factor(Imp_Employees$year)

Imp_SelfEmployed$Ind_EarningsEquity_NAs <- as.factor(Imp_SelfEmployed$Ind_EarningsEquity_NAs)
Imp_SelfEmployed$Ind_Pension_NAs <- as.factor(Imp_SelfEmployed$Ind_Pension_NAs)
Imp_SelfEmployed$Ind_ContinuousEmployment_NAs <- as.factor(Imp_SelfEmployed$Ind_ContinuousEmployment_NAs)
Imp_SelfEmployed$Ind_CompositeSecurity_NAs <- as.factor(Imp_SelfEmployed$Ind_CompositeSecurity_NAs)
Imp_SelfEmployed$Ind_Autonomy_NAs <- as.factor(Imp_SelfEmployed$Ind_Autonomy_NAs)
Imp_SelfEmployed$Ind_CollectiveVoice_NAs <- as.factor(Imp_SelfEmployed$Ind_CollectiveVoice_NAs)
Imp_SelfEmployed$Ind_Flexibility_NAs <- as.factor(Imp_SelfEmployed$Ind_Flexibility_NAs)
Imp_SelfEmployed$Ind_ExcessiveHours_NAs <- as.factor(Imp_SelfEmployed$Ind_ExcessiveHours_NAs)
Imp_SelfEmployed$Ind_ManagerialDuties_NAs <- as.factor(Imp_SelfEmployed$Ind_ManagerialDuties_NAs)
Imp_SelfEmployed$Ind_ShortTermProspects_NAs <- as.factor(Imp_SelfEmployed$Ind_ShortTermProspects_NAs)
Imp_SelfEmployed$CF_CaringResponsibilities_AF <- as.factor(Imp_SelfEmployed$CF_CaringResponsibilities_AF)
Imp_SelfEmployed$CF_DependentChildren_AF <- as.factor(Imp_SelfEmployed$CF_DependentChildren_AF)
Imp_SelfEmployed$CF_NonWorkingHHMembers_AF <- as.factor(Imp_SelfEmployed$CF_NonWorkingHHMembers_AF)
Imp_SelfEmployed$CF_LongStandingIllness_AF <- as.factor(Imp_SelfEmployed$CF_LongStandingIllness_AF)
Imp_SelfEmployed$CF_RecentPhysicalHealth_AF <- as.factor(Imp_SelfEmployed$CF_RecentPhysicalHealth_AF)
Imp_SelfEmployed$CF_RecentMentalHealth_AF <- as.factor(Imp_SelfEmployed$CF_RecentMentalHealth_AF)
Imp_SelfEmployed$CS_HighestQualification_AF <- as.factor(Imp_SelfEmployed$CS_HighestQualification_AF)
Imp_SelfEmployed$CS_HousingAssets_AF <- as.factor(Imp_SelfEmployed$CS_HousingAssets_AF)
Imp_SelfEmployed$CS_PersonalIncomeSufficiency_AF <- as.factor(Imp_SelfEmployed$CS_PersonalIncomeSufficiency_AF)
Imp_SelfEmployed$CS_EquivalisedHHoldInc_MinusBenefits_AF <- as.factor(Imp_SelfEmployed$CS_EquivalisedHHoldInc_MinusBenefits_AF)
Imp_SelfEmployed$CS_EquivalisedHHoldInc_WithBenefits_AF <- as.factor(Imp_SelfEmployed$CS_EquivalisedHHoldInc_WithBenefits_AF)
Imp_SelfEmployed$CS_ParentalNSSEC_AF <- as.factor(Imp_SelfEmployed$CS_ParentalNSSEC_AF)
Imp_SelfEmployed$DV_Sex <- as.factor(Imp_SelfEmployed$DV_Sex)
Imp_SelfEmployed$DV_Ethnicity_All <- as.factor(Imp_SelfEmployed$DV_Ethnicity_All)
Imp_SelfEmployed$DV_Region_All <- as.factor(Imp_SelfEmployed$DV_Region_All)
Imp_SelfEmployed$DV_SelfEmployed <- as.factor(Imp_SelfEmployed$DV_SelfEmployed)
Imp_SelfEmployed$DV_IndividualNSSEC <- as.factor(Imp_SelfEmployed$DV_IndividualNSSEC)
Imp_SelfEmployed$DV_JbJsSize <- as.factor(Imp_SelfEmployed$DV_JbJsSize)
Imp_SelfEmployed$year <- as.factor(Imp_SelfEmployed$year)

#######################################################################################
################################### 5 - Impute data ###################################
#######################################################################################

#* ----------------------------------------------------------------
#* -------------- [a - Combined Employees & Self Employed variables:
#* ----------------------------------------------------------------

#* The below works for both employees and self-employed. It reduces missingness to 0, and 
#* the results all make sense given the regression outputs above. 

#* Run code:

Imp <- mice(Imp_JQ,
            m = 1, 
            pred = quickpred(Imp_JQ,
                             include = c('DV_SelfEmployed'),
                             exclude = c('pidp', 'hidp', 
                                         'Ind_EarningsEquity_NAs', 'Ind_EarningsEquity_ImpFlag', 
                                         'Ind_Pension_NAs', 'Ind_Pension_ImpFlag',
                                         'Ind_ContinuousEmployment_NAs', 'Ind_ContinuousEmployment_ImpFlag', 
                                         'Ind_CompositeSecurity_NAs', 'Ind_CompositeSecurity_ImpFlag',
                                         'Ind_Autonomy_NAs', 'Ind_Autonomy_ImpFlag', 
                                         'Ind_CollectiveVoice_NAs', 'Ind_CollectiveVoice_ImpFlag',
                                         'Ind_Flexibility_NAs', 'Ind_Flexibility_ImpFlag',
                                         'Ind_ExcessiveHours_NAs', 'Ind_ExcessiveHours_ImpFlag',
                                         'Ind_ManagerialDuties_NAs', 'Ind_ManagerialDuties_ImpFlag',
                                         'Ind_ShortTermProspects_NAs', 'Ind_ShortTermProspects_ImpFlag')), 
            seed = 1138, maxit = 25, method = c("","","pmm","","","","","","pmm","","pmm","","","","","","pmm","","pmm","pmm",
                                                "pmm","pmm","pmm","pmm","pmm","pmm","pmm","pmm","pmm","pmm","pmm","pmm","pmm",
                                                "pmm","pmm","pmm","pmm","pmm","pmm","pmm", "pmm","pmm","pmm","pmm")) 

#* Save and re-download data. Last done as of [25.11.23]:
# Imp_Data <- complete(Imp,1)
# saveRDS(Imp_Data,'231125 - Imp_JQ Imputed data.RData')
Imp_Data <- readRDS('231125 - Imp_JQ Imputed data.RData')

#* Check for NAs:
length(which(is.na(Imp_Data$Ind_EarningsEquity_NAs)))  
length(which(is.na(JQ$variables$Ind_EarningsEquity_NAs)))
length(which(is.na(Imp_Data$Ind_CompositeSecurity_NAs)))  
length(which(is.na(JQ$variables$Ind_CompositeSecurity_NAs)))
length(which(is.na(Imp_Data$variables$Ind_Autonomy_NAs)))
length(which(is.na(JQ$variables$Ind_Autonomy_NAs)))
length(which(is.na(Imp_Data$variables$Ind_ExcessiveHours_NAs)))
length(which(is.na(JQ$variables$Ind_ExcessiveHours_NAs)))
length(which(is.na(Imp_Data$variables$Ind_ManagerialDuties_NAs)))
length(which(is.na(JQ$variables$Ind_ManagerialDuties_NAs)))
length(which(is.na(Imp_Data$variables$Ind_ShortTermProspects_NAs)))
length(which(is.na(JQ$variables$Ind_ShortTermProspects_NAs)))

#* Difference between imputed and non-imputed data:
xtabs(~Ind_EarningsEquity_NAs + Ind_EarningsEquity_ImpFlag + DV_SelfEmployed, Imp_Data)
xtabs(~Ind_CompositeSecurity_NAs + Ind_CompositeSecurity_ImpFlag + DV_SelfEmployed, Imp_Data)
xtabs(~Ind_Autonomy_NAs + Ind_Autonomy_ImpFlag + DV_SelfEmployed, Imp_Data)
xtabs(~Ind_ExcessiveHours_NAs + Ind_ExcessiveHours_ImpFlag + DV_SelfEmployed, Imp_Data)
xtabs(~Ind_ManagerialDuties_NAs + Ind_ManagerialDuties_ImpFlag + DV_SelfEmployed, Imp_Data)
xtabs(~Ind_ShortTermProspects_NAs + Ind_ShortTermProspects_ImpFlag + DV_SelfEmployed, Imp_Data)

#* Difference between imputed and non-imputed data. Note that this may just reflect the
#* different composition of employees vs. self employed within the missings, however. In 
#* any event, it's similar. As the regression analysis would suggest, there is a tendency
#* for lower values to be imputed:
prop.table(xtabs(~Ind_EarningsEquity_NAs + Ind_EarningsEquity_ImpFlag, Imp_Data),2)
prop.table(xtabs(~Ind_CompositeSecurity_NAs + Ind_CompositeSecurity_ImpFlag, Imp_Data),2)
prop.table(xtabs(~Ind_Autonomy_NAs + Ind_Autonomy_ImpFlag, Imp_Data),2)
prop.table(xtabs(~Ind_ExcessiveHours_NAs + Ind_ExcessiveHours_ImpFlag, Imp_Data),2)
prop.table(xtabs(~Ind_ManagerialDuties_NAs + Ind_ManagerialDuties_ImpFlag, Imp_Data),2)
prop.table(xtabs(~Ind_ShortTermProspects_NAs + Ind_ShortTermProspects_ImpFlag, Imp_Data),2)

#* Trends over time. Despite the above tendency, this all has minimal effect on trends:
prop.table(xtabs(~Ind_EarningsEquity_NAs + year, Imp_Data), 2)
prop.table(xtabs(~Ind_EarningsEquity_NAs + year, JQ), 2)
prop.table(xtabs(~Ind_CompositeSecurity_NAs + year, Imp_Data), 2)
prop.table(xtabs(~Ind_CompositeSecurity_NAs + year, JQ), 2)
prop.table(xtabs(~Ind_Autonomy_NAs + year, Imp_Data), 2)
prop.table(xtabs(~Ind_Autonomy_NAs + year, JQ), 2)
prop.table(xtabs(~Ind_ExcessiveHours_NAs + year, Imp_Data), 2)
prop.table(xtabs(~Ind_ExcessiveHours_NAs + year, JQ), 2)
prop.table(xtabs(~Ind_ManagerialDuties_NAs + year, Imp_Data), 2)
prop.table(xtabs(~Ind_ManagerialDuties_NAs + year, JQ), 2)
prop.table(xtabs(~Ind_ShortTermProspects_NAs + year, Imp_Data), 2)
prop.table(xtabs(~Ind_ShortTermProspects_NAs + year, JQ), 2)

#* ----------------------------------------------------------------
#* -------------- [b - Employee only variables:
#* ----------------------------------------------------------------

#* Works well for all of them except pension:
Imp <- mice(Imp_Employees,
            m = 1, 
            pred = quickpred(Imp_Employees,
                             exclude = c('pidp', 'hidp', 
                                         'Ind_EarningsEquity_NAs', 'Ind_EarningsEquity_ImpFlag', 
                                         'Ind_Pension_NAs', 'Ind_Pension_ImpFlag',
                                         'Ind_ContinuousEmployment_NAs', 'Ind_ContinuousEmployment_ImpFlag', 
                                         'Ind_CompositeSecurity_NAs', 'Ind_CompositeSecurity_ImpFlag',
                                         'Ind_Autonomy_NAs', 'Ind_Autonomy_ImpFlag', 
                                         'Ind_CollectiveVoice_NAs', 'Ind_CollectiveVoice_ImpFlag',
                                         'Ind_Flexibility_NAs', 'Ind_Flexibility_ImpFlag',
                                         'Ind_ExcessiveHours_NAs', 'Ind_ExcessiveHours_ImpFlag',
                                         'Ind_ManagerialDuties_NAs', 'Ind_ManagerialDuties_ImpFlag',
                                         'Ind_ShortTermProspects_NAs', 'Ind_ShortTermProspects_ImpFlag')), 
            seed = 1138, maxit = 25, method = c("","","","","pmm","","pmm","","","","","","pmm","","pmm","","","","","pmm",
                                                "","pmm","pmm","pmm","pmm","pmm","pmm","pmm","pmm","pmm","pmm","pmm","pmm",
                                                "pmm","pmm","pmm","pmm","pmm","pmm","pmm", "pmm","pmm","pmm","pmm")) 

#* Save and re-download data:
# Imp_Data <- complete(Imp,1)
# saveRDS(Imp_Data,'231015 - Imp_Employees Imputed data.RData')
Imp_Data <- readRDS('231015 - Imp_Employees Imputed data.RData')

#* Check for NAs:
# length(which(is.na(Imp_Data$Ind_Pension_NAs)))  
# length(which(is.na(Employees$variables$Ind_Pension_NAs)))
length(which(is.na(Imp_Data$Ind_ContinuousEmployment_NAs)))  
length(which(is.na(Employees$variables$Ind_ContinuousEmployment_NAs)))
length(which(is.na(Imp_Data$variables$Ind_CollectiveVoice_NAs)))
length(which(is.na(Employees$variables$Ind_CollectiveVoice_NAs)))
length(which(is.na(Imp_Data$variables$Ind_Flexibility_NAs)))
length(which(is.na(Employees$variables$Ind_Flexibility_NAs)))

#* Difference between imputed and non-imputed data:
# xtabs(~Ind_Pension_NAs + Ind_Pension_ImpFlag, Imp_Data)
xtabs(~Ind_ContinuousEmployment_NAs + Ind_ContinuousEmployment_ImpFlag, Imp_Data)
xtabs(~Ind_CollectiveVoice_NAs + Ind_CollectiveVoice_ImpFlag, Imp_Data)
xtabs(~Ind_Flexibility_NAs + Ind_Flexibility_ImpFlag, Imp_Data)

#* Difference between imputed and non-imputed data:
# prop.table(xtabs(~Ind_Pension_NAs + Ind_Pension_ImpFlag, Imp_Data),2)
prop.table(xtabs(~Ind_ContinuousEmployment_NAs + Ind_ContinuousEmployment_ImpFlag, Imp_Data),2)
prop.table(xtabs(~Ind_CollectiveVoice_NAs + Ind_CollectiveVoice_ImpFlag, Imp_Data),2)
prop.table(xtabs(~Ind_Flexibility_NAs + Ind_Flexibility_ImpFlag, Imp_Data),2)

#* Trends over time. Despite the above tendency, this all has minimal effect on trends:
# prop.table(xtabs(~Ind_Pension_NAs + year, Imp_Data), 2)
# prop.table(xtabs(~Ind_Pension_NAs + year, Employees), 2)
prop.table(xtabs(~Ind_ContinuousEmployment_NAs + year, Imp_Data), 2)
prop.table(xtabs(~Ind_ContinuousEmployment_NAs + year, Employees), 2)
prop.table(xtabs(~Ind_CollectiveVoice_NAs + year, Imp_Data), 2)
prop.table(xtabs(~Ind_CollectiveVoice_NAs + year, Employees), 2)
prop.table(xtabs(~Ind_Flexibility_NAs + year, Imp_Data), 2)
prop.table(xtabs(~Ind_Flexibility_NAs + year, Employees), 2)

#* ----------------------------------------------------------------
#* -------------- [c - Self employed: Pension
#* ----------------------------------------------------------------

Imp <- mice(Imp_SelfEmployed,
            m = 1, 
            pred = quickpred(Imp_SelfEmployed,
                             exclude = c('pidp', 'hidp', 
                                         'Ind_EarningsEquity_NAs', 'Ind_EarningsEquity_ImpFlag', 
                                         'Ind_Pension_NAs', 'Ind_Pension_ImpFlag',
                                         'Ind_ContinuousEmployment_NAs', 'Ind_ContinuousEmployment_ImpFlag', 
                                         'Ind_CompositeSecurity_NAs', 'Ind_CompositeSecurity_ImpFlag',
                                         'Ind_Autonomy_NAs', 'Ind_Autonomy_ImpFlag', 
                                         'Ind_CollectiveVoice_NAs', 'Ind_CollectiveVoice_ImpFlag',
                                         'Ind_Flexibility_NAs', 'Ind_Flexibility_ImpFlag',
                                         'Ind_ExcessiveHours_NAs', 'Ind_ExcessiveHours_ImpFlag',
                                         'Ind_ManagerialDuties_NAs', 'Ind_ManagerialDuties_ImpFlag',
                                         'Ind_ShortTermProspects_NAs', 'Ind_ShortTermProspects_ImpFlag')), 
            seed = 1138, maxit = 25, method = c("","","","","pmm","","","","","","","","","","","","","","","",
                                                "","pmm","pmm","pmm","pmm","pmm","pmm","pmm","pmm","pmm","pmm","pmm","pmm",
                                                "pmm","pmm","pmm","pmm","pmm","pmm","pmm", "pmm","pmm","pmm","pmm")) 

#* Save and re-download data:
# Imp_Data <- complete(Imp,1)
# saveRDS(Imp_Data,'231015 - Imp_SelfEmployed Imputed data.RData')
Imp_Data <- readRDS('231015 - Imp_SelfEmployed Imputed data.RData')

#* Check for NAs:
length(which(is.na(Imp_Data$Ind_Pension_NAs)))  
length(which(is.na(SelfEmployed$variables$Ind_Pension_NAs)))

#* Difference between imputed and non-imputed data:
xtabs(~Ind_Pension_NAs + Ind_Pension_ImpFlag, Imp_Data)

#* Difference between imputed and non-imputed data:
prop.table(xtabs(~Ind_Pension_NAs + Ind_Pension_ImpFlag, Imp_Data),2)

#* Trends over time. Despite the above tendency, this all has minimal effect on trends:
prop.table(xtabs(~Ind_Pension_NAs + year, Imp_Data), 2)
prop.table(xtabs(~Ind_Pension_NAs + year, SelfEmployed), 2)

#* ----------------------------------------------------------------
#* -------------- [d - Employee: Wave 12 Pension
#* ----------------------------------------------------------------

#* Create a specific filter for Pension == 0 | == 1: 
Imp_JQ_Pension <- filter(Imp_JQ, is.na(Ind_Pension_NAs) | Ind_Pension_NAs != 2)

#* Then filter to employees only:
Imp_Employees_Pension <- filter(Imp_JQ_Pension, DV_SelfEmployed == 0)

#* Convert to factors:
Imp_Employees_Pension$Ind_EarningsEquity_NAs <- as.factor(Imp_Employees_Pension$Ind_EarningsEquity_NAs)
Imp_Employees_Pension$Ind_Pension_NAs <- as.factor(Imp_Employees_Pension$Ind_Pension_NAs)
Imp_Employees_Pension$Ind_ContinuousEmployment_NAs <- as.factor(Imp_Employees_Pension$Ind_ContinuousEmployment_NAs)
Imp_Employees_Pension$Ind_CompositeSecurity_NAs <- as.factor(Imp_Employees_Pension$Ind_CompositeSecurity_NAs)
Imp_Employees_Pension$Ind_Autonomy_NAs <- as.factor(Imp_Employees_Pension$Ind_Autonomy_NAs)
Imp_Employees_Pension$Ind_CollectiveVoice_NAs <- as.factor(Imp_Employees_Pension$Ind_CollectiveVoice_NAs)
Imp_Employees_Pension$Ind_Flexibility_NAs <- as.factor(Imp_Employees_Pension$Ind_Flexibility_NAs)
Imp_Employees_Pension$Ind_ExcessiveHours_NAs <- as.factor(Imp_Employees_Pension$Ind_ExcessiveHours_NAs)
Imp_Employees_Pension$Ind_ManagerialDuties_NAs <- as.factor(Imp_Employees_Pension$Ind_ManagerialDuties_NAs)
Imp_Employees_Pension$Ind_ShortTermProspects_NAs <- as.factor(Imp_Employees_Pension$Ind_ShortTermProspects_NAs)
Imp_Employees_Pension$CF_CaringResponsibilities_AF <- as.factor(Imp_Employees_Pension$CF_CaringResponsibilities_AF)
Imp_Employees_Pension$CF_DependentChildren_AF <- as.factor(Imp_Employees_Pension$CF_DependentChildren_AF)
Imp_Employees_Pension$CF_NonWorkingHHMembers_AF <- as.factor(Imp_Employees_Pension$CF_NonWorkingHHMembers_AF)
Imp_Employees_Pension$CF_LongStandingIllness_AF <- as.factor(Imp_Employees_Pension$CF_LongStandingIllness_AF)
Imp_Employees_Pension$CF_RecentPhysicalHealth_AF <- as.factor(Imp_Employees_Pension$CF_RecentPhysicalHealth_AF)
Imp_Employees_Pension$CF_RecentMentalHealth_AF <- as.factor(Imp_Employees_Pension$CF_RecentMentalHealth_AF)
Imp_Employees_Pension$CS_HighestQualification_AF <- as.factor(Imp_Employees_Pension$CS_HighestQualification_AF)
Imp_Employees_Pension$CS_HousingAssets_AF <- as.factor(Imp_Employees_Pension$CS_HousingAssets_AF)
Imp_Employees_Pension$CS_PersonalIncomeSufficiency_AF <- as.factor(Imp_Employees_Pension$CS_PersonalIncomeSufficiency_AF)
Imp_Employees_Pension$CS_EquivalisedHHoldInc_MinusBenefits_AF <- as.factor(Imp_Employees_Pension$CS_EquivalisedHHoldInc_MinusBenefits_AF)
Imp_Employees_Pension$CS_EquivalisedHHoldInc_WithBenefits_AF <- as.factor(Imp_Employees_Pension$CS_EquivalisedHHoldInc_WithBenefits_AF)
Imp_Employees_Pension$CS_ParentalNSSEC_AF <- as.factor(Imp_Employees_Pension$CS_ParentalNSSEC_AF)
Imp_Employees_Pension$DV_Sex <- as.factor(Imp_Employees_Pension$DV_Sex)
Imp_Employees_Pension$DV_Ethnicity_All <- as.factor(Imp_Employees_Pension$DV_Ethnicity_All)
Imp_Employees_Pension$DV_Region_All <- as.factor(Imp_Employees_Pension$DV_Region_All)
Imp_Employees_Pension$DV_SelfEmployed <- as.factor(Imp_Employees_Pension$DV_SelfEmployed)
Imp_Employees_Pension$DV_IndividualNSSEC <- as.factor(Imp_Employees_Pension$DV_IndividualNSSEC)
Imp_Employees_Pension$DV_JbJsSize <- as.factor(Imp_Employees_Pension$DV_JbJsSize)
Imp_Employees_Pension$year <- as.factor(Imp_Employees_Pension$year)

#* Do the imputation:
Imp <- mice(Imp_Employees_Pension,
            m = 1, 
            pred = quickpred(Imp_Employees_Pension,
                             exclude = c('pidp', 'hidp', 
                                         'Ind_EarningsEquity_NAs', 'Ind_EarningsEquity_ImpFlag', 
                                         'Ind_Pension_NAs', 'Ind_Pension_ImpFlag',
                                         'Ind_ContinuousEmployment_NAs', 'Ind_ContinuousEmployment_ImpFlag', 
                                         'Ind_CompositeSecurity_NAs', 'Ind_CompositeSecurity_ImpFlag',
                                         'Ind_Autonomy_NAs', 'Ind_Autonomy_ImpFlag', 
                                         'Ind_CollectiveVoice_NAs', 'Ind_CollectiveVoice_ImpFlag',
                                         'Ind_Flexibility_NAs', 'Ind_Flexibility_ImpFlag',
                                         'Ind_ExcessiveHours_NAs', 'Ind_ExcessiveHours_ImpFlag',
                                         'Ind_ManagerialDuties_NAs', 'Ind_ManagerialDuties_ImpFlag',
                                         'Ind_ShortTermProspects_NAs', 'Ind_ShortTermProspects_ImpFlag')), 
            seed = 1138, maxit = 25, method = c("","","","","pmm","","","","","","","","","","","","","","","",
                                                "","pmm","pmm","pmm","pmm","pmm","pmm","pmm","pmm","pmm","pmm","pmm","pmm",
                                                "pmm","pmm","pmm","pmm","pmm","pmm","pmm", "pmm","pmm","pmm","pmm")) 

#* Save and re-download data:
# Imp_Data <- complete(Imp,1)
# saveRDS(Imp_Data,'231015 - Imp_Employees_Pension Imputed data.RData')
Imp_Data <- readRDS('231015 - Imp_Employees_Pension Imputed data.RData')

#* Check for NAs:
length(which(is.na(Imp_Data$Ind_Pension_NAs)))  
length(which(is.na(Employees$variables$Ind_Pension_NAs)))

#* Difference between imputed and non-imputed data:
xtabs(~Ind_Pension_NAs + Ind_Pension_ImpFlag, Imp_Data)

#* Difference between imputed and non-imputed data:
prop.table(xtabs(~Ind_Pension_NAs + Ind_Pension_ImpFlag, Imp_Data),2)

#* Trends over time:
prop.table(xtabs(~Ind_Pension_NAs + year, Imp_Data), 2)
prop.table(xtabs(~Ind_Pension_NAs + year, Employees), 2)

#######################################################################################
############################## 5 - Merge imputed data #################################
#######################################################################################

#* ----------------------------------------------------------------
#* -------------- [a - Merge JQ data (employee and self employed)
#* ----------------------------------------------------------------

#* Open merged data:
JQ_Imp <- readRDS('231125 - Imp_JQ Imputed data.RData')

#* Rename the specific variables I want transferring over:
JQ_Imp$Ind_EarningsEquity_Imp <- JQ_Imp$Ind_EarningsEquity_NAs
JQ_Imp$Ind_CompositeSecurity_Imp <- JQ_Imp$Ind_CompositeSecurity_NAs
JQ_Imp$Ind_Autonomy_Imp <- JQ_Imp$Ind_Autonomy_NAs
JQ_Imp$Ind_ExcessiveHours_Imp <- JQ_Imp$Ind_ExcessiveHours_NAs
JQ_Imp$Ind_ManagerialDuties_Imp <- JQ_Imp$Ind_ManagerialDuties_NAs
JQ_Imp$Ind_ShortTermProspects_Imp <- JQ_Imp$Ind_ShortTermProspects_NAs

#* Recode year:
JQ_Imp$year <- as.character(JQ_Imp$year)

#* Select the specific variables I want to merge in:
JQ_Imp <- JQ_Imp |> select(pidp, year, Ind_EarningsEquity_Imp, Ind_CompositeSecurity_Imp, 
                           Ind_Autonomy_Imp, Ind_ExcessiveHours_Imp, Ind_ManagerialDuties_Imp,
                           Ind_ShortTermProspects_Imp)

#* Merge together:
Dat_Merge <- right_join(JQ_Imp, Dat$variables, by = c("pidp", "year"))
Wave4LW  <- filter(Wave4, (d_jbhas == 2 &! (d_jboff == -2 | d_jboff == -1 | d_jboff == 1)))

#* This shows process has worked.  
JQ <- filter(Dat_Merge, QoW_Index_Member == 1)
length(which(is.na(JQ$Ind_EarningsEquity_Imp)))
length(which(is.na(JQ$Ind_CompositeSecurity_Imp)))
length(which(is.na(JQ$Ind_Autonomy_Imp)))
length(which(is.na(JQ$Ind_ExcessiveHours_Imp)))
length(which(is.na(JQ$Ind_ManagerialDuties_Imp)))
length(which(is.na(JQ$DV_SelfEmployed)))
length(which(is.na(JQ$DV_Region)))
length(which(is.na(JQ$DV_Sex)))
length(which(is.na(JQ$CS_ParentalNSSEC)))
xtabs(~Ind_EarningsEquity_NAs + year, JQ)

JQ <- filter(Dat, QoW_Index_Member == 1)
length(which(is.na(JQ$DV_SelfEmployed)))
length(which(is.na(JQ$DV_Region)))
length(which(is.na(JQ$DV_Sex)))
xtabs(~Ind_EarningsEquity_NAs + year, JQ)
xtabs(~Ind_EarningsEquity_Imp + year, Dat_Merge)

#* ----------------------------------------------------------------
#* -------------- [b - Merge Employee-only data
#* ----------------------------------------------------------------

#* Open merged data:
JQ_Imp <- readRDS('231015 - Imp_Employees Imputed data.RData')

#* Rename the specific variables I want transferring over:
JQ_Imp$Ind_Pension_OtherWavesEmployeeImp <- JQ_Imp$Ind_Pension_NAs
JQ_Imp$Ind_ContinuousEmployment_Imp <- JQ_Imp$Ind_ContinuousEmployment_NAs
JQ_Imp$Ind_CollectiveVoice_Imp <- JQ_Imp$Ind_CollectiveVoice_NAs
JQ_Imp$Ind_Flexibility_Imp <- JQ_Imp$Ind_Flexibility_NAs

#* Recode year:
JQ_Imp$year <- as.character(JQ_Imp$year)

#* Select the specific variables I want to merge in:
JQ_Imp <- JQ_Imp |> select(pidp, year, Ind_Pension_OtherWavesEmployeeImp, 
                           Ind_ContinuousEmployment_Imp, Ind_CollectiveVoice_Imp, 
                           Ind_Flexibility_Imp)

#* Merge together:
Dat_Merge <- right_join(JQ_Imp, Dat_Merge, by = c("pidp", "year"))

#* This successfully passes the data over:
xtabs(~Ind_ContinuousEmployment_Imp + year, Dat_Merge)
xtabs(~Ind_CollectiveVoice_Imp + year, Dat_Merge)
xtabs(~Ind_Flexibility_Imp + year, Dat_Merge)

#* Use case_whens to turn self-employed into 0. Note there is no need to do this for
#* flexibility, since :
Dat_Merge$Ind_ContinuousEmployment_Imp <- case_when(Dat_Merge$DV_SelfEmployed == 1 ~ 0,
                                                    TRUE ~ as.numeric(as.character(Dat_Merge$Ind_ContinuousEmployment_Imp)))
Dat_Merge$Ind_CollectiveVoice_Imp <- case_when(Dat_Merge$DV_SelfEmployed == 1 ~ 0,
                                                    TRUE ~ as.numeric(as.character(Dat_Merge$Ind_CollectiveVoice_Imp)))

#* Data shows merge has been successful:
xtabs(~Ind_ContinuousEmployment_Imp + year + DV_SelfEmployed, Dat_Merge)
xtabs(~Ind_CollectiveVoice_Imp + year + DV_SelfEmployed, Dat_Merge)

#* This shows process has worked:  
JQ <- filter(Dat_Merge, QoW_Index_Member == 1)
length(which(is.na(JQ$Ind_EarningsEquity_Imp)))
length(which(is.na(JQ$Ind_CompositeSecurity_Imp)))
length(which(is.na(JQ$Ind_Autonomy_Imp)))
length(which(is.na(JQ$Ind_ExcessiveHours_Imp)))
length(which(is.na(JQ$Ind_ManagerialDuties_Imp)))
length(which(is.na(JQ$DV_SelfEmployed)))
length(which(is.na(JQ$DV_Region)))
length(which(is.na(JQ$DV_Sex)))
length(which(is.na(JQ$CS_ParentalNSSEC)))
xtabs(~Ind_ContinuousEmployment_NAs + year, JQ)
xtabs(~Ind_CollectiveVoice_NAs + year, JQ)
xtabs(~Ind_Flexibility_NAs + year, JQ)

JQ <- filter(Dat, QoW_Index_Member == 1)
length(which(is.na(JQ$DV_SelfEmployed)))
length(which(is.na(JQ$DV_Region)))
length(which(is.na(JQ$DV_Sex)))
xtabs(~Ind_ContinuousEmployment_NAs + year, JQ)
xtabs(~Ind_CollectiveVoice_NAs + year, JQ)
xtabs(~Ind_Flexibility_NAs + year, JQ)

xtabs(~Ind_ContinuousEmployment_Imp + year, Dat_Merge)
xtabs(~ Ind_CollectiveVoice_Imp + year, Dat_Merge)
xtabs(~Ind_Flexibility_Imp + year, Dat_Merge)

#* ----------------------------------------------------------------
#* -------------- [c - Merge Self employed pension data
#* ----------------------------------------------------------------

#* Download data:
JQ_Imp <- readRDS('231015 - Imp_SelfEmployed Imputed data.RData')

#* Rename the specific variables I want transferring over:
JQ_Imp$Ind_Pension_SEmployedImp <- JQ_Imp$Ind_Pension_NAs

#* Recode year:
JQ_Imp$year <- as.character(JQ_Imp$year)

#* Select the specific variables I want to merge in:
JQ_Imp <- JQ_Imp |> select(pidp, year, Ind_Pension_SEmployedImp)

#* Merge together:
Dat_Merge <- right_join(JQ_Imp, Dat_Merge, by = c("pidp", "year"))

#* ----------------------------------------------------------------
#* -------------- [d - Merge Employee pension data
#* ----------------------------------------------------------------

#* Download data:
JQ_Imp <- readRDS('231015 - Imp_Employees_Pension Imputed data.RData')

#* Rename the specific variables I want transferring over:
JQ_Imp$Ind_Pension_EmployeeImp <- JQ_Imp$Ind_Pension_NAs

#* Recode year:
JQ_Imp$year <- as.character(JQ_Imp$year)

#* Select the specific variables I want to merge in:
JQ_Imp <- JQ_Imp |> select(pidp, year, Ind_Pension_EmployeeImp)

#* Merge together:
Dat_Merge <- right_join(JQ_Imp, Dat_Merge, by = c("pidp", "year"))

#* Combine employee and self-employed pension data. To avoid issues with NAs I use the Ind_Pension
#* indicator here. This also allows me to track the number of -1s within the cross-tabs, since the 
#* NAs won't appear in the cross-tabs:
Dat_Merge$Ind_Pension_Imp <- case_when(Dat_Merge$DV_SelfEmployed == 1 ~ as.numeric(as.character(Dat_Merge$Ind_Pension_SEmployedImp)),
                                       Dat_Merge$DV_SelfEmployed == 0 & Dat_Merge$year == "2020-21" & Dat_Merge$Ind_Pension != 2 ~ as.numeric(as.character(Dat_Merge$Ind_Pension_EmployeeImp)),
                                       Dat_Merge$DV_SelfEmployed == 0 & Dat_Merge$year != "2020-21" ~ as.numeric(as.character(Dat_Merge$Ind_Pension_OtherWavesEmployeeImp)),
                                       TRUE ~ as.numeric(as.character(Dat_Merge$Ind_Pension)))

#* Data shows process worked:                                                                                    
xtabs(~Ind_Pension_Imp + year + DV_SelfEmployed, Dat_Merge)
xtabs(~Ind_Pension_NAs + year + DV_SelfEmployed, Dat_Merge)
xtabs(~Ind_Pension_SEmployedImp + year, Dat_Merge)
xtabs(~Ind_Pension_EmployeeImp + year, Dat_Merge)

JQ <- filter(Dat_Merge, QoW_Index_Member == 1)
length(which(is.na(JQ$Ind_Pension_Imp)))
length(which(is.na(JQ$Ind_Pension_NAs)))

#* Save the above into Dat [25.11.23]:
# Dat$variables <- Dat_Merge

#* Then you just put your data back into the survey design object, and save it for future
#* use. Last used as of [18.10.23] to remove above variables in advance of re-incorporation, due
#* to duplicates:
Dat$variables <- Dat_Variables

#######################################################################################
############### 6 - Analyse differences in imputed vs. non-imputed data ###############
#######################################################################################

#* Difference between imputed and non-imputed data (Employees):
Tab1 <- prop.table(xtabs((~Ind_EarningsEquity_Imp + Ind_EarningsEquity_ImpFlag),Employees), margin=2) |> round(3) |> as_tibble()
Tab1$Indicator <- "Earnings Equity"
Tab1 <- Tab1 |> rename(Score = Ind_EarningsEquity_Imp,
                       ImpFlag = Ind_EarningsEquity_ImpFlag)

Tab2 <- prop.table(xtabs((~Ind_Pension_Imp + Ind_Pension_ImpFlag),Employees), margin=2) |> round(3) |> as_tibble()
Tab2$Indicator <- "Pension"
Tab2 <- Tab2 |> rename(Score = Ind_Pension_Imp,
                       ImpFlag = Ind_Pension_ImpFlag)

Tab3 <- prop.table(xtabs((~Ind_ContinuousEmployment_Imp + Ind_ContinuousEmployment_ImpFlag),Employees), margin=2) |> round(3) |> as_tibble()
Tab3$Indicator <- "Continuous Employment"
Tab3 <- Tab3 |> rename(Score = Ind_ContinuousEmployment_Imp,
                       ImpFlag = Ind_ContinuousEmployment_ImpFlag)

Tab4 <- prop.table(xtabs((~Ind_CompositeSecurity_Imp + Ind_CompositeSecurity_ImpFlag),Employees), margin=2) |> round(3) |> as_tibble()
Tab4$Indicator <- "Composite Security"
Tab4 <- Tab4 |> rename(Score = Ind_CompositeSecurity_Imp,
                       ImpFlag = Ind_CompositeSecurity_ImpFlag)

Tab5 <- prop.table(xtabs((~Ind_Autonomy_Imp + Ind_Autonomy_ImpFlag),Employees), margin=2) |> round(3) |> as_tibble()
Tab5$Indicator <- "Autonomy"
Tab5 <- Tab5 |> rename(Score = Ind_Autonomy_Imp,
                       ImpFlag = Ind_Autonomy_ImpFlag)

Tab6 <- prop.table(xtabs((~Ind_CollectiveVoice_Imp + Ind_CollectiveVoice_ImpFlag),Employees), margin=2) |> round(3) |> as_tibble()
Tab6$Indicator <- "Collective Voice"
Tab6 <- Tab6 |> rename(Score = Ind_CollectiveVoice_Imp,
                       ImpFlag = Ind_CollectiveVoice_ImpFlag)

Tab7 <- prop.table(xtabs((~Ind_Flexibility_Imp + Ind_Flexibility_ImpFlag),Employees), margin=2) |> round(3) |> as_tibble()
Tab7$Indicator <- "Flexibility"
Tab7 <- Tab7 |> rename(Score = Ind_Flexibility_Imp,
                       ImpFlag = Ind_Flexibility_ImpFlag)

Tab8 <- prop.table(xtabs((~Ind_ExcessiveHours_Imp + Ind_ExcessiveHours_ImpFlag),Employees), margin=2) |> round(3) |> as_tibble()
Tab8$Indicator <- "Excessive Hours"
Tab8 <- Tab8 |> rename(Score = Ind_ExcessiveHours_Imp,
                       ImpFlag = Ind_ExcessiveHours_ImpFlag)

Tab9 <- prop.table(xtabs((~Ind_ManagerialDuties_Imp + Ind_ManagerialDuties_ImpFlag),Employees), margin=2) |> round(3) |> as_tibble()
Tab9$Indicator <- "Managerial Duties"
Tab9 <- Tab9 |> rename(Score = Ind_ManagerialDuties_Imp,
                       ImpFlag = Ind_ManagerialDuties_ImpFlag)

Tab10 <- prop.table(xtabs((~Ind_ShortTermProspects_Imp + Ind_ShortTermProspects_ImpFlag),Employees), margin=2) |> round(3) |> as_tibble()
Tab10$Indicator <- "Short-term Prospects"
Tab10 <- Tab10 |> rename(Score = Ind_ShortTermProspects_Imp,
                       ImpFlag = Ind_ShortTermProspects_ImpFlag)

Tab <- bind_rows(Tab1, Tab2, Tab3, Tab4, Tab5, Tab6, Tab7, Tab8, Tab9, Tab10)

#* Difference between imputed and non-imputed data (Self Employed):
Tab1 <- prop.table(xtabs((~Ind_EarningsEquity_Imp + Ind_EarningsEquity_ImpFlag),SelfEmployed), margin=2) |> round(3) |> as_tibble()
Tab1$Indicator <- "Earnings Equity"
Tab1 <- Tab1 |> rename(Score = Ind_EarningsEquity_Imp,
                       ImpFlag = Ind_EarningsEquity_ImpFlag)

Tab2 <- prop.table(xtabs((~Ind_Pension_Imp + Ind_Pension_ImpFlag),SelfEmployed), margin=2) |> round(3) |> as_tibble()
Tab2$Indicator <- "Pension"
Tab2 <- Tab2 |> rename(Score = Ind_Pension_Imp,
                       ImpFlag = Ind_Pension_ImpFlag)

Tab3 <- prop.table(xtabs((~Ind_CompositeSecurity_Imp + Ind_CompositeSecurity_ImpFlag),SelfEmployed), margin=2) |> round(3) |> as_tibble()
Tab3$Indicator <- "Composite Security"
Tab3 <- Tab3 |> rename(Score = Ind_CompositeSecurity_Imp,
                       ImpFlag = Ind_CompositeSecurity_ImpFlag)

Tab4 <- prop.table(xtabs((~Ind_Autonomy_Imp + Ind_Autonomy_ImpFlag),SelfEmployed), margin=2) |> round(3) |> as_tibble()
Tab4$Indicator <- "Autonomy"
Tab4 <- Tab4 |> rename(Score = Ind_Autonomy_Imp,
                       ImpFlag = Ind_Autonomy_ImpFlag)

Tab5 <- prop.table(xtabs((~Ind_ExcessiveHours_Imp + Ind_ExcessiveHours_ImpFlag),SelfEmployed), margin=2) |> round(3) |> as_tibble()
Tab5$Indicator <- "Excessive Hours"
Tab5 <- Tab5 |> rename(Score = Ind_ExcessiveHours_Imp,
                       ImpFlag = Ind_ExcessiveHours_ImpFlag)

Tab6 <- prop.table(xtabs((~Ind_ManagerialDuties_Imp + Ind_ManagerialDuties_ImpFlag),SelfEmployed), margin=2) |> round(3) |> as_tibble()
Tab6$Indicator <- "Managerial Duties"
Tab6 <- Tab6 |> rename(Score = Ind_ManagerialDuties_Imp,
                       ImpFlag = Ind_ManagerialDuties_ImpFlag)

Tab7 <- prop.table(xtabs((~Ind_ShortTermProspects_Imp + Ind_ShortTermProspects_ImpFlag),SelfEmployed), margin=2) |> round(3) |> as_tibble()
Tab7$Indicator <- "Short-term Prospects"
Tab7 <- Tab7 |> rename(Score = Ind_ShortTermProspects_Imp,
                       ImpFlag = Ind_ShortTermProspects_ImpFlag)

Tab <- bind_rows(Tab1, Tab2, Tab3, Tab4, Tab5, Tab6, Tab7)

#* Trends over time, imputed and non-imputed data combined:
Tab1 <- prop.table(xtabs((~Ind_EarningsEquity_Imp + year),JQ), margin=2) |> round(3) |> as_tibble()
Tab1$Indicator <- "Earnings Equity"
Tab1 <- Tab1 |> rename(Score = Ind_EarningsEquity_Imp)

Tab2 <- prop.table(xtabs((~Ind_Pension_Imp + year),JQ), margin=2) |> round(3) |> as_tibble()
Tab2$Indicator <- "Pension"
Tab2 <- Tab2 |> rename(Score = Ind_Pension_Imp)

Tab3 <- prop.table(xtabs((~Ind_ContinuousEmployment_Imp + year),JQ), margin=2) |> round(3) |> as_tibble()
Tab3$Indicator <- "Continuous Employment"
Tab3 <- Tab3 |> rename(Score = Ind_ContinuousEmployment_Imp)

Tab4 <- prop.table(xtabs((~Ind_CompositeSecurity_Imp + year),JQ), margin=2) |> round(3) |> as_tibble()
Tab4$Indicator <- "Composite Security"
Tab4 <- Tab4 |> rename(Score = Ind_CompositeSecurity_Imp)

Tab5 <- prop.table(xtabs((~Ind_Autonomy_Imp + year),JQ), margin=2) |> round(3) |> as_tibble()
Tab5$Indicator <- "Autonomy"
Tab5 <- Tab5 |> rename(Score = Ind_Autonomy_Imp)

Tab6 <- prop.table(xtabs((~Ind_CollectiveVoice_Imp + year),JQ), margin=2) |> round(3) |> as_tibble()
Tab6$Indicator <- "Collective Voice"
Tab6 <- Tab6 |> rename(Score = Ind_CollectiveVoice_Imp)

Tab7 <- prop.table(xtabs((~Ind_Flexibility_Imp + year),JQ), margin=2) |> round(3) |> as_tibble()
Tab7$Indicator <- "Flexibility"
Tab7 <- Tab7 |> rename(Score = Ind_Flexibility_Imp)

Tab8 <- prop.table(xtabs((~Ind_ExcessiveHours_Imp + year),JQ), margin=2) |> round(3) |> as_tibble()
Tab8$Indicator <- "Excessive Hours"
Tab8 <- Tab8 |> rename(Score = Ind_ExcessiveHours_Imp)

Tab9 <- prop.table(xtabs((~Ind_ManagerialDuties_Imp + year),JQ), margin=2) |> round(3) |> as_tibble()
Tab9$Indicator <- "Managerial Duties"
Tab9 <- Tab9 |> rename(Score = Ind_ManagerialDuties_Imp)

Tab10 <- prop.table(xtabs((~Ind_ShortTermProspects_Imp + year),JQ), margin=2) |> round(3) |> as_tibble()
Tab10$Indicator <- "Short-term Prospects"
Tab10 <- Tab10 |> rename(Score = Ind_ShortTermProspects_Imp)

Tab <- bind_rows(Tab1, Tab2, Tab3, Tab4, Tab5, Tab6, Tab7, Tab8, Tab9, Tab10)

#* Trends over time, non-imputed data only:
Tab1 <- prop.table(xtabs((~Ind_EarningsEquity_NAs + year),JQ), margin=2) |> round(3) |> as_tibble()
Tab1$Indicator <- "Earnings Equity"
Tab1 <- Tab1 |> rename(Score = Ind_EarningsEquity_NAs)

Tab2 <- prop.table(xtabs((~Ind_Pension_NAs + year),JQ), margin=2) |> round(3) |> as_tibble()
Tab2$Indicator <- "Pension"
Tab2 <- Tab2 |> rename(Score = Ind_Pension_NAs)

Tab3 <- prop.table(xtabs((~Ind_ContinuousEmployment_NAs + year),JQ), margin=2) |> round(3) |> as_tibble()
Tab3$Indicator <- "Continuous Employment"
Tab3 <- Tab3 |> rename(Score = Ind_ContinuousEmployment_NAs)

Tab4 <- prop.table(xtabs((~Ind_CompositeSecurity_NAs + year),JQ), margin=2) |> round(3) |> as_tibble()
Tab4$Indicator <- "Composite Security"
Tab4 <- Tab4 |> rename(Score = Ind_CompositeSecurity_NAs)

Tab5 <- prop.table(xtabs((~Ind_Autonomy_NAs + year),JQ), margin=2) |> round(3) |> as_tibble()
Tab5$Indicator <- "Autonomy"
Tab5 <- Tab5 |> rename(Score = Ind_Autonomy_NAs)

Tab6 <- prop.table(xtabs((~Ind_CollectiveVoice_NAs + year),JQ), margin=2) |> round(3) |> as_tibble()
Tab6$Indicator <- "Collective Voice"
Tab6 <- Tab6 |> rename(Score = Ind_CollectiveVoice_NAs)

Tab7 <- prop.table(xtabs((~Ind_Flexibility_NAs + year),JQ), margin=2) |> round(3) |> as_tibble()
Tab7$Indicator <- "Flexibility"
Tab7 <- Tab7 |> rename(Score = Ind_Flexibility_NAs)

Tab8 <- prop.table(xtabs((~Ind_ExcessiveHours_NAs + year),JQ), margin=2) |> round(3) |> as_tibble()
Tab8$Indicator <- "Excessive Hours"
Tab8 <- Tab8 |> rename(Score = Ind_ExcessiveHours_NAs)

Tab9 <- prop.table(xtabs((~Ind_ManagerialDuties_NAs + year),JQ), margin=2) |> round(3) |> as_tibble()
Tab9$Indicator <- "Managerial Duties"
Tab9 <- Tab9 |> rename(Score = Ind_ManagerialDuties_NAs)

Tab10 <- prop.table(xtabs((~Ind_ShortTermProspects_NAs + year),JQ), margin=2) |> round(3) |> as_tibble()
Tab10$Indicator <- "Short-term Prospects"
Tab10 <- Tab10 |> rename(Score = Ind_ShortTermProspects_NAs)

Tab <- bind_rows(Tab1, Tab2, Tab3, Tab4, Tab5, Tab6, Tab7, Tab8, Tab9, Tab10)

#######################################################################################
################################## 7 - Save data ######################################
#######################################################################################

#* Saved the above data as of [25.11.23]:
# saveRDS(Dat, file = "0 - Dat.RData")
